(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    395879,      12301]
NotebookOptionsPosition[    393681,      12229]
NotebookOutlinePosition[    394128,      12247]
CellTagsIndexPosition[    394085,      12244]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Dynamics of the Bush-Mosteller learning algorithm in 2x2 games - Figure 13 \
(500)\
\>", "Title",
 CellChangeTimes->{3.393473139484375*^9}],

Cell["Luis R. Izquierdo and Segismundo S. Izquierdo", "Subtitle"],

Cell["\<\
This program was used to generate figure 13 in the chapter of the \
reinforcement learning book: Izquierdo,L.R. & Izquierdo,S.S.(2007). Dynamics \
of the Bush-Mosteller 
learning algorithm in 2x2 games.\
\>", "Subsubtitle",
 CellChangeTimes->{{3.39347312015625*^9, 3.393473124640625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Licence", "Section"]], "Section"],

Cell["\<\
Copyright (C) 2007 Luis R. Izquierdo & Segismundo S. Izquierdo

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version. 

This program is distributed in the hope that it will be useful, 
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details. 

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, \
USA.\
\>", "Subsubtitle"]
}, Closed]],

Cell[CellGroupData[{

Cell["Setting the Environment", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`MultipleListPlot`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell"}], "]"}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Parameters", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "Payoffs", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"T", "=", "4"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"R", "=", "3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"S", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Aspiration", " ", "Threshold"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"A", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Learning", " ", "rate"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"l", "=", 
     RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "Noise", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"noiseList", "=", 
     RowBox[{"{", 
      RowBox[{"0.01", ",", "0.001", ",", "0.0001", ",", "0"}], "}"}]}], ";"}],
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Simulation", " ", "parameters"}], "*)"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"SeedRandom", "[", "0", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nOfRuns", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nOfIterations", "=", "500"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"initialProb1", "=", "0.9"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"initialProb2", "=", "0.9"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Directory", " ", "where", " ", "the", " ", "figure", " ", "will", " ", 
     "be", " ", "saved"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SetDirectory", "[", "\"\<C:\\\\temp\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"File", " ", "extensions", " ", "required"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"extensions", "=", 
     RowBox[{"{", "\"\<.gif\>\"", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"figureResolution", " ", "=", " ", "600"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nOfPoints", "=", 
     RowBox[{"Min", "[", 
      RowBox[{"250", ",", "nOfIterations"}], "]"}]}], ";"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definition of functions and labels", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Labels", ".", " ", "This"}], " ", "is", " ", "done", " ", "for", 
    " ", "efficiency", " ", "and", " ", "code", " ", "readability"}], "*)"}], 
  "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Cooperate", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Defect", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"CC", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"CD", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DC", "=", "2"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DD", "=", "3"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Calculation", " ", "of", " ", "possible", " ", 
     RowBox[{"stimuli", ".", " ", "These"}], " ", "operations", " ", "are", 
     " ", "performed", " ", "only", " ", "once", " ", "for", " ", 
     "efficiency"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"divisor", "=", 
     RowBox[{"Max", "[", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"T", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"R", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"P", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"S", "-", "A"}], "]"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterCC", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"R", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterCD", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"S", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterDC", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"T", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterDD", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"P", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Stimulus", " ", "after", " ", "a", " ", "certain", " ", 
     RowBox[{"outcome", ".", " ", "This"}], " ", "function", " ", "returns", 
     " ", "the", " ", "stimulus", " ", "after", " ", "a", " ", "given", " ", 
     "outcome", " ", 
     RowBox[{"(", 
      RowBox[{"e", ".", "g", ".", " ", "CD"}], ")"}], " ", "for", " ", "the", 
     " ", "agent", " ", "who", " ", "has", " ", "selected", " ", "the", " ", 
     "action", " ", "indicated", " ", "by", " ", "the", " ", "first", " ", 
     "letter", " ", "of", " ", "the", " ", "outcome", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"e", ".", "g", ".", " ", "C"}], ")"}], "."}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"stimulusAfter", "[", "x_", "]"}], ":=", 
     RowBox[{"Switch", "[", 
      RowBox[{
      "x", ",", "\[IndentingNewLine]", "CC", ",", "stimulusAfterCC", ",", 
       "\[IndentingNewLine]", "CD", ",", "stimulusAfterCD", ",", 
       "\[IndentingNewLine]", "DC", ",", "stimulusAfterDC", ",", 
       "\[IndentingNewLine]", "DD", ",", "stimulusAfterDD"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Changes", " ", "in", " ", "the", " ", "probability", " ", "of", " ", 
      "cooperating", " ", "after", " ", "given", " ", 
      RowBox[{"outcomes", ".", " ", "The"}], " ", "first", " ", "argument", 
      " ", "is", " ", "the", " ", "outcome"}], ",", " ", 
     RowBox[{
     "and", " ", "the", " ", "second", " ", "argument", " ", "is", " ", "the",
       " ", "probability", " ", "to", " ", "be", " ", 
      RowBox[{"updated", ".", " ", "This"}], " ", "function", " ", "returns", 
      " ", "the", " ", "change", " ", "on", " ", "the", " ", "probability", 
      " ", "indicated", " ", "by", " ", "the", " ", "second", " ", "argument",
       " ", "after", " ", "the", " ", "outcome", " ", "indicated", " ", "in", 
      " ", "the", " ", "first", " ", "argument", " ", 
      RowBox[{"(", 
       RowBox[{"e", ".", "g", ".", " ", "CD"}], ")"}], " ", "for", " ", "the",
       " ", "agent", " ", "who", " ", "has", " ", "selected", " ", "the", " ",
       "action", " ", "indicated", " ", "by", " ", "the", " ", "first", " ", 
      "letter", " ", "of", " ", "the", " ", "outcome", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"e", ".", "g", ".", " ", "C"}], ")"}], "."}]}]}], "*)"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"changeAfterOn", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "\[Equal]", "CC"}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{"x", "\[Equal]", "CD"}], ")"}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Agent", " ", "has", " ", "cooperated"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"stimulusAfter", "[", "x", "]"}], "\[GreaterEqual]", "0"}], 
         ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}], ",", 
         RowBox[{"y", "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Agent", " ", "has", " ", "defected"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"stimulusAfter", "[", "x", "]"}], "\[GreaterEqual]", "0"}], 
         ",", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"y", "*", "l", "*", 
            RowBox[{"stimulusAfter", "[", "x", "]"}]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "-", "y"}], ")"}]}], "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulations - Initialisation", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Vector", " ", "with", " ", "the", " ", "decisions", " ", "made", " ", 
    "by", " ", "each", " ", "of", " ", "the", " ", "agents"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"decisions", "=", 
     RowBox[{"{", ",", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Output", " ", "variables"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"listOfAverages", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"listOfStdErrors", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"reportingFreq", "=", 
     RowBox[{"Floor", "[", 
      RowBox[{"nOfIterations", "/", "nOfPoints"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Auxiliary", " ", "arrays", " ", "to", " ", "calculate", " ", "the", " ", 
     "standard", " ", "error", " ", "dynamically"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Mbefore", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"nOfIterations", "+", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Mnow", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"nOfIterations", "+", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Snow", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"nOfIterations", "+", "1"}]}], "}"}]}], "]"}]}], 
    ";"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulations - Execution", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"k", "=", "1"}], ",", 
    RowBox[{"k", "\[LessEqual]", 
     RowBox[{"Length", "[", "noiseList", "]"}]}], ",", 
    RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"noise", "=", 
      RowBox[{"noiseList", "[", 
       RowBox[{"[", "k", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Time", " ", "series", " ", "for", " ", "player", " ", "1"}], 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"averages", "=", 
      RowBox[{"Table", " ", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"i", "-", "1"}], ")"}], "*", "reportingFreq", "*", 
         RowBox[{"(", 
          RowBox[{"2", "-", "j"}], ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"nOfPoints", "+", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"averages", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "2"}], "]"}], "]"}], "=", "initialProb1"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"stdErrors", "=", 
      RowBox[{"Table", " ", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"i", "-", "1"}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{"2", "-", "j"}], ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"nOfIterations", "+", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"j", "\[LessEqual]", "nOfRuns"}], ",", 
       RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Starting run \>\"", ",", " ", "j"}], "]"}], ";"}], 
        "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"prob1", "=", "initialProb1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"prob2", "=", "initialProb2"}], ";", "\[IndentingNewLine]", 
        RowBox[{"reportedPoints", "=", "1"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"i", "=", "1"}], ",", 
          RowBox[{"i", "\[LessEqual]", "nOfIterations"}], ",", 
          RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"\"\<Starting iteration \>\"", ",", " ", "i"}], "]"}], 
            ";"}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Random", "[", "]"}], "\[LessEqual]", "prob1"}], ",", 
             RowBox[{
              RowBox[{"decisions", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "=", "Cooperate"}], ",", 
             RowBox[{
              RowBox[{"decisions", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "=", "Defect"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"noise", "\[NotEqual]", "0"}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Random", "[", "]"}], "\[LessEqual]", "noise"}], ",", 
               
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"decisions", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "Cooperate"}], 
                 ",", 
                 RowBox[{
                  RowBox[{"decisions", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "=", "Defect"}], ",", 
                 RowBox[{
                  RowBox[{"decisions", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "=", "Cooperate"}]}], 
                "]"}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Random", "[", "]"}], "\[LessEqual]", "prob2"}], ",", 
             RowBox[{
              RowBox[{"decisions", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "=", "Cooperate"}], ",", 
             RowBox[{
              RowBox[{"decisions", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "=", "Defect"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"noise", "\[NotEqual]", "0"}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Random", "[", "]"}], "\[LessEqual]", "noise"}], ",", 
               
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"decisions", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "Cooperate"}], 
                 ",", 
                 RowBox[{
                  RowBox[{"decisions", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "=", "Defect"}], ",", 
                 RowBox[{
                  RowBox[{"decisions", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "=", "Cooperate"}]}], 
                "]"}]}], "]"}]}], "]"}], ";", " ", "\[IndentingNewLine]", 
           "\t", "\[IndentingNewLine]", 
           RowBox[{"(*", 
            RowBox[{"For", " ", "the", " ", "first", " ", "player"}], "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{"outcome", "=", 
            RowBox[{"Switch", "[", 
             RowBox[{"decisions", ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Cooperate", ",", "Cooperate"}], "}"}], ",", "CC", ",",
               "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Cooperate", ",", "Defect"}], "}"}], ",", "CD", ",", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Defect", ",", "Cooperate"}], "}"}], ",", "DC", ",", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Defect", ",", "Defect"}], "}"}], ",", "DD"}], "]"}]}],
            ";", "\[IndentingNewLine]", 
           RowBox[{"prob1", "=", 
            RowBox[{"prob1", "+", 
             RowBox[{"changeAfterOn", "[", 
              RowBox[{"outcome", ",", "prob1"}], "]"}]}]}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"(*", 
            RowBox[{"For", " ", "the", " ", "second", " ", "player"}], "*)"}],
            "\[IndentingNewLine]", 
           RowBox[{"outcome", "=", 
            RowBox[{"Switch", "[", 
             RowBox[{"decisions", ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Cooperate", ",", "Cooperate"}], "}"}], ",", "CC", ",",
               "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Cooperate", ",", "Defect"}], "}"}], ",", "DC", ",", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Defect", ",", "Cooperate"}], "}"}], ",", "CD", ",", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"Defect", ",", "Defect"}], "}"}], ",", "DD"}], "]"}]}],
            ";", "\[IndentingNewLine]", 
           RowBox[{"prob2", "=", 
            RowBox[{"prob2", "+", 
             RowBox[{"changeAfterOn", "[", 
              RowBox[{"outcome", ",", "prob2"}], "]"}]}]}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"(*", 
            RowBox[{"Report", " ", "if", " ", "you", " ", "have", " ", "to"}],
             "*)"}], "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Mod", "[", 
               RowBox[{"i", ",", " ", "reportingFreq"}], "]"}], "\[Equal]", 
              "0"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"averages", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"reportedPoints", "+", "1"}], ",", "2"}], "]"}], 
                "]"}], "=", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"j", "-", "1"}], ")"}], "*", 
                   RowBox[{"averages", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"reportedPoints", "+", "1"}], ",", "2"}], "]"}], 
                    "]"}]}], "+", "prob1"}], ")"}], "/", "j"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"reportedPoints", "++"}], ";"}]}], 
            "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", 
           RowBox[{"(*", 
            RowBox[{
            "Calculate", " ", "the", " ", "standard", " ", "error", " ", "of",
              " ", "the", " ", "average", " ", "dynamically"}], "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Mnow", "[", 
             RowBox[{"[", 
              RowBox[{"i", "+", "1"}], "]"}], "]"}], " ", "=", 
            RowBox[{
             RowBox[{"Mbefore", "[", 
              RowBox[{"[", 
               RowBox[{"i", "+", "1"}], "]"}], "]"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"prob1", "-", 
                RowBox[{"Mbefore", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ")"}], "/", 
              "j"}]}]}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Snow", "[", 
             RowBox[{"[", 
              RowBox[{"i", "+", "1"}], "]"}], "]"}], " ", "=", " ", 
            RowBox[{
             RowBox[{"Snow", "[", 
              RowBox[{"[", 
               RowBox[{"i", "+", "1"}], "]"}], "]"}], " ", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"prob1", "-", 
                RowBox[{"Mbefore", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ")"}], "*", 
              RowBox[{"(", 
               RowBox[{"prob1", "-", 
                RowBox[{"Mnow", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ")"}]}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Mbefore", "[", 
             RowBox[{"[", 
              RowBox[{"i", "+", "1"}], "]"}], "]"}], "=", 
            RowBox[{"Mnow", "[", 
             RowBox[{"[", 
              RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ";"}]}], 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"\"\<End of iteration \>\"", ",", "i"}], "]"}], ";"}], 
          "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], 
        ";"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Mod", "[", 
            RowBox[{"j", ",", "100"}], "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"\"\<End of run \>\"", ",", " ", "j"}], "]"}], ";", 
           RowBox[{"Print", "[", 
            RowBox[{"Date", "[", "]"}], "]"}], ";"}]}], "]"}], ";"}], "*)"}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"nOfRuns", ">", "1"}], ",", 
       RowBox[{
        RowBox[{"stdErrors", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}], "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"Snow", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"nOfRuns", "-", "1"}], ")"}], "*", "nOfRuns"}], ")"}]}], 
         "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     
     RowBox[{"oneSeriesFigure", "=", 
      RowBox[{"ListPlot", "[", 
       RowBox[{"averages", ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "nOfIterations"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1.01"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<Iteration\>\"", ",", "\"\<Prop C, Player 1\>\""}], 
          "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"\"\<fig13-500-n\>\"", ",", 
         RowBox[{"ToString", "[", "noise", "]"}], ",", "\"\<.gif\>\""}], 
        "]"}], ",", "oneSeriesFigure", ",", 
       RowBox[{"ImageResolution", "\[Rule]", " ", "figureResolution"}]}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{
      "\"\<The maximum standard error of this series is: \>\"", ",", " ", 
       RowBox[{"Max", "[", 
        RowBox[{"stdErrors", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"listOfAverages", ",", "averages"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"listOfStdErrors", ",", "stdErrors"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"\"\<Finished noise = \>\"", ",", " ", 
       RowBox[{"noiseList", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], "]"}], ";"}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-017 0.002 -1.49349e-017 0.611915 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 58 6.28125 ]
[-0.0125 .12238 -18 -4.5 ]
[-0.0125 .12238 0 4.5 ]
[-0.0125 .24477 -18 -4.5 ]
[-0.0125 .24477 0 4.5 ]
[-0.0125 .36715 -18 -4.5 ]
[-0.0125 .36715 0 4.5 ]
[-0.0125 .48953 -18 -4.5 ]
[-0.0125 .48953 0 4.5 ]
[-0.0125 .61191 -6 -4.5 ]
[-0.0125 .61191 0 4.5 ]
[0 .64303 -50 0 ]
[0 .64303 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(100)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(200)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(300)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(400)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(500)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Iteration) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12238 m
.00625 .12238 L
s
[(0.2)] -0.0125 .12238 1 0 Mshowa
0 .24477 m
.00625 .24477 L
s
[(0.4)] -0.0125 .24477 1 0 Mshowa
0 .36715 m
.00625 .36715 L
s
[(0.6)] -0.0125 .36715 1 0 Mshowa
0 .48953 m
.00625 .48953 L
s
[(0.8)] -0.0125 .48953 1 0 Mshowa
0 .61191 m
.00625 .61191 L
s
[(1)] -0.0125 .61191 1 0 Mshowa
.125 Mabswid
0 .0306 m
.00375 .0306 L
s
0 .06119 m
.00375 .06119 L
s
0 .09179 m
.00375 .09179 L
s
0 .15298 m
.00375 .15298 L
s
0 .18357 m
.00375 .18357 L
s
0 .21417 m
.00375 .21417 L
s
0 .27536 m
.00375 .27536 L
s
0 .30596 m
.00375 .30596 L
s
0 .33655 m
.00375 .33655 L
s
0 .39774 m
.00375 .39774 L
s
0 .42834 m
.00375 .42834 L
s
0 .45894 m
.00375 .45894 L
s
0 .52013 m
.00375 .52013 L
s
0 .55072 m
.00375 .55072 L
s
0 .58132 m
.00375 .58132 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prop) show
93.000 12.813 moveto
(C) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Player) show
153.000 12.813 moveto
(1) show
159.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
0 .55072 Mdot
.004 .52348 Mdot
.008 .49993 Mdot
.012 .47805 Mdot
.016 .45952 Mdot
.02 .44215 Mdot
.024 .42637 Mdot
.028 .41056 Mdot
.032 .39556 Mdot
.036 .38262 Mdot
.04 .36968 Mdot
.044 .3577 Mdot
.048 .34711 Mdot
.052 .33636 Mdot
.056 .3256 Mdot
.06 .3157 Mdot
.064 .306 Mdot
.068 .296 Mdot
.072 .28678 Mdot
.076 .27782 Mdot
.08 .26958 Mdot
.084 .26067 Mdot
.088 .25278 Mdot
.092 .24533 Mdot
.096 .238 Mdot
.1 .23141 Mdot
.104 .22426 Mdot
.108 .21751 Mdot
.112 .21069 Mdot
.116 .2041 Mdot
.12 .1981 Mdot
.124 .19226 Mdot
.128 .18719 Mdot
.132 .18186 Mdot
.136 .17649 Mdot
.14 .17145 Mdot
.144 .16666 Mdot
.148 .16258 Mdot
.152 .15821 Mdot
.156 .15339 Mdot
.16 .14912 Mdot
.164 .14547 Mdot
.168 .14143 Mdot
.172 .13807 Mdot
.176 .1342 Mdot
.18 .13084 Mdot
.184 .12732 Mdot
.188 .12395 Mdot
.192 .12038 Mdot
.196 .11681 Mdot
.2 .11358 Mdot
.204 .11055 Mdot
.208 .10771 Mdot
.212 .10477 Mdot
.216 .10219 Mdot
.22 .09894 Mdot
.224 .09593 Mdot
.228 .09321 Mdot
.232 .09061 Mdot
.236 .08839 Mdot
.24 .08598 Mdot
.244 .08364 Mdot
.248 .08137 Mdot
.252 .07888 Mdot
.256 .07682 Mdot
.26 .0747 Mdot
.264 .07261 Mdot
.268 .0711 Mdot
.272 .06879 Mdot
.276 .06701 Mdot
.28 .06512 Mdot
.284 .06304 Mdot
.288 .06096 Mdot
.292 .05936 Mdot
.296 .05782 Mdot
.3 .05646 Mdot
.304 .05476 Mdot
.308 .0534 Mdot
.312 .05194 Mdot
.316 .05043 Mdot
.32 .04934 Mdot
.324 .04803 Mdot
.328 .047 Mdot
.332 .04567 Mdot
.336 .04476 Mdot
.34 .04331 Mdot
.344 .04212 Mdot
.348 .04106 Mdot
.352 .04021 Mdot
.356 .03936 Mdot
.36 .03845 Mdot
.364 .03719 Mdot
.368 .03633 Mdot
.372 .0352 Mdot
.376 .03443 Mdot
.38 .03336 Mdot
.384 .03235 Mdot
.388 .03144 Mdot
.392 .03028 Mdot
.396 .02911 Mdot
.4 .02823 Mdot
.404 .02737 Mdot
.408 .02659 Mdot
.412 .02589 Mdot
.416 .02515 Mdot
.42 .02425 Mdot
.424 .02359 Mdot
.428 .02296 Mdot
.432 .02223 Mdot
.436 .02175 Mdot
.44 .0211 Mdot
.444 .02056 Mdot
.448 .01993 Mdot
.452 .01932 Mdot
.456 .01876 Mdot
.46 .018 Mdot
.464 .0174 Mdot
.468 .01696 Mdot
.472 .01666 Mdot
.476 .0163 Mdot
.48 .01586 Mdot
.484 .01553 Mdot
.488 .01493 Mdot
.492 .01447 Mdot
.496 .01434 Mdot
.5 .01408 Mdot
.504 .0137 Mdot
.508 .01333 Mdot
.512 .01305 Mdot
.516 .01276 Mdot
.52 .01244 Mdot
.524 .01221 Mdot
.528 .01185 Mdot
.532 .01139 Mdot
.536 .01101 Mdot
.54 .01053 Mdot
.544 .01011 Mdot
.548 .0098 Mdot
.552 .00952 Mdot
.556 .00919 Mdot
.56 .0089 Mdot
.564 .00848 Mdot
.568 .00806 Mdot
.572 .00782 Mdot
.576 .00759 Mdot
.58 .00749 Mdot
.584 .00725 Mdot
.588 .00701 Mdot
.592 .00678 Mdot
.596 .00665 Mdot
.6 .00656 Mdot
.604 .00633 Mdot
.608 .00618 Mdot
.612 .00597 Mdot
.616 .00583 Mdot
.62 .00578 Mdot
.624 .00571 Mdot
.628 .00555 Mdot
.632 .00543 Mdot
.636 .00538 Mdot
.64 .00521 Mdot
.644 .00519 Mdot
.648 .00506 Mdot
.652 .0049 Mdot
.656 .00487 Mdot
.66 .00475 Mdot
.664 .00458 Mdot
.668 .0045 Mdot
.672 .00436 Mdot
.676 .00418 Mdot
.68 .00405 Mdot
.684 .00386 Mdot
.688 .00371 Mdot
.692 .00377 Mdot
.696 .00369 Mdot
.7 .00361 Mdot
.704 .00352 Mdot
.708 .00352 Mdot
.712 .00339 Mdot
.716 .00327 Mdot
.72 .00316 Mdot
.724 .00304 Mdot
.728 .00296 Mdot
.732 .00283 Mdot
.736 .0028 Mdot
.74 .00272 Mdot
.744 .00263 Mdot
.748 .0025 Mdot
.752 .00244 Mdot
.756 .00238 Mdot
.76 .0023 Mdot
.764 .00226 Mdot
.768 .00222 Mdot
.772 .00223 Mdot
.776 .00225 Mdot
.78 .0021 Mdot
.784 .00203 Mdot
.788 .00203 Mdot
.792 .00201 Mdot
.796 .00205 Mdot
.8 .00202 Mdot
.804 .00197 Mdot
.808 .00187 Mdot
.812 .00173 Mdot
.816 .00169 Mdot
.82 .00164 Mdot
.824 .00161 Mdot
.828 .0016 Mdot
.832 .00154 Mdot
.836 .00153 Mdot
.84 .00152 Mdot
.844 .00148 Mdot
.848 .00157 Mdot
.852 .00154 Mdot
.856 .00149 Mdot
.86 .00143 Mdot
.864 .00136 Mdot
.868 .00137 Mdot
.872 .00133 Mdot
.876 .00129 Mdot
.88 .00119 Mdot
.884 .00122 Mdot
.888 .00121 Mdot
.892 .00132 Mdot
.896 .00132 Mdot
.9 .00135 Mdot
.904 .00131 Mdot
.908 .00125 Mdot
.912 .00128 Mdot
.916 .0013 Mdot
.92 .00121 Mdot
.924 .00114 Mdot
.928 .00107 Mdot
.932 .00105 Mdot
.936 .00101 Mdot
.94 .00102 Mdot
.944 .00093 Mdot
.948 .00092 Mdot
.952 .00088 Mdot
.956 .00082 Mdot
.96 .00083 Mdot
.964 .00077 Mdot
.968 .0008 Mdot
.972 .00084 Mdot
.976 .00072 Mdot
.98 .00063 Mdot
.984 .00056 Mdot
.988 .00049 Mdot
.992 .00052 Mdot
.996 .00047 Mdot
1 .00044 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-143.16, -0.296013, 2.86316, \
0.00935802}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The maximum standard error of this series is: \"\>", 
   "\[InvisibleSpace]", "0.004585944611768785`"}],
  SequenceForm[
  "The maximum standard error of this series is: ", 0.004585944611768785],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Finished noise = \"\>", "\[InvisibleSpace]", "0.01`"}],
  SequenceForm["Finished noise = ", 0.01],
  Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-017 0.002 -1.49349e-017 0.611915 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 58 6.28125 ]
[-0.0125 .12238 -18 -4.5 ]
[-0.0125 .12238 0 4.5 ]
[-0.0125 .24477 -18 -4.5 ]
[-0.0125 .24477 0 4.5 ]
[-0.0125 .36715 -18 -4.5 ]
[-0.0125 .36715 0 4.5 ]
[-0.0125 .48953 -18 -4.5 ]
[-0.0125 .48953 0 4.5 ]
[-0.0125 .61191 -6 -4.5 ]
[-0.0125 .61191 0 4.5 ]
[0 .64303 -50 0 ]
[0 .64303 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(100)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(200)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(300)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(400)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(500)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Iteration) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12238 m
.00625 .12238 L
s
[(0.2)] -0.0125 .12238 1 0 Mshowa
0 .24477 m
.00625 .24477 L
s
[(0.4)] -0.0125 .24477 1 0 Mshowa
0 .36715 m
.00625 .36715 L
s
[(0.6)] -0.0125 .36715 1 0 Mshowa
0 .48953 m
.00625 .48953 L
s
[(0.8)] -0.0125 .48953 1 0 Mshowa
0 .61191 m
.00625 .61191 L
s
[(1)] -0.0125 .61191 1 0 Mshowa
.125 Mabswid
0 .0306 m
.00375 .0306 L
s
0 .06119 m
.00375 .06119 L
s
0 .09179 m
.00375 .09179 L
s
0 .15298 m
.00375 .15298 L
s
0 .18357 m
.00375 .18357 L
s
0 .21417 m
.00375 .21417 L
s
0 .27536 m
.00375 .27536 L
s
0 .30596 m
.00375 .30596 L
s
0 .33655 m
.00375 .33655 L
s
0 .39774 m
.00375 .39774 L
s
0 .42834 m
.00375 .42834 L
s
0 .45894 m
.00375 .45894 L
s
0 .52013 m
.00375 .52013 L
s
0 .55072 m
.00375 .55072 L
s
0 .58132 m
.00375 .58132 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prop) show
93.000 12.813 moveto
(C) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Player) show
153.000 12.813 moveto
(1) show
159.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
0 .55072 Mdot
.004 .52736 Mdot
.008 .50793 Mdot
.012 .49186 Mdot
.016 .47832 Mdot
.02 .46543 Mdot
.024 .4547 Mdot
.028 .44568 Mdot
.032 .43746 Mdot
.036 .43032 Mdot
.04 .42412 Mdot
.044 .41926 Mdot
.048 .41444 Mdot
.052 .41019 Mdot
.056 .40646 Mdot
.06 .40322 Mdot
.064 .40036 Mdot
.068 .39763 Mdot
.072 .39523 Mdot
.076 .393 Mdot
.08 .391 Mdot
.084 .38899 Mdot
.088 .38685 Mdot
.092 .38528 Mdot
.096 .38368 Mdot
.1 .38176 Mdot
.104 .38016 Mdot
.108 .37863 Mdot
.112 .37714 Mdot
.116 .37557 Mdot
.12 .3742 Mdot
.124 .37302 Mdot
.128 .37146 Mdot
.132 .37011 Mdot
.136 .36874 Mdot
.14 .36757 Mdot
.144 .36598 Mdot
.148 .36495 Mdot
.152 .36388 Mdot
.156 .36265 Mdot
.16 .36115 Mdot
.164 .36009 Mdot
.168 .35888 Mdot
.172 .35791 Mdot
.176 .35656 Mdot
.18 .35542 Mdot
.184 .3541 Mdot
.188 .35281 Mdot
.192 .35184 Mdot
.196 .35072 Mdot
.2 .34966 Mdot
.204 .34856 Mdot
.208 .34722 Mdot
.212 .34624 Mdot
.216 .34529 Mdot
.22 .34423 Mdot
.224 .34304 Mdot
.228 .34193 Mdot
.232 .34103 Mdot
.236 .3402 Mdot
.24 .33919 Mdot
.244 .33808 Mdot
.248 .33725 Mdot
.252 .3363 Mdot
.256 .33517 Mdot
.26 .33422 Mdot
.264 .33329 Mdot
.268 .33208 Mdot
.272 .33136 Mdot
.276 .33053 Mdot
.28 .32973 Mdot
.284 .32871 Mdot
.288 .32763 Mdot
.292 .32657 Mdot
.296 .32583 Mdot
.3 .32488 Mdot
.304 .32393 Mdot
.308 .32313 Mdot
.312 .32201 Mdot
.316 .32082 Mdot
.32 .31987 Mdot
.324 .31894 Mdot
.328 .3181 Mdot
.332 .31687 Mdot
.336 .31575 Mdot
.34 .31463 Mdot
.344 .31381 Mdot
.348 .31271 Mdot
.352 .31173 Mdot
.356 .3107 Mdot
.36 .30981 Mdot
.364 .30887 Mdot
.368 .30806 Mdot
.372 .30705 Mdot
.376 .3063 Mdot
.38 .30537 Mdot
.384 .30445 Mdot
.388 .3036 Mdot
.392 .30245 Mdot
.396 .30153 Mdot
.4 .30053 Mdot
.404 .29957 Mdot
.408 .29866 Mdot
.412 .29789 Mdot
.416 .29688 Mdot
.42 .29614 Mdot
.424 .29527 Mdot
.428 .29439 Mdot
.432 .29369 Mdot
.436 .29284 Mdot
.44 .29204 Mdot
.444 .29139 Mdot
.448 .29075 Mdot
.452 .2902 Mdot
.456 .28945 Mdot
.46 .28859 Mdot
.464 .28755 Mdot
.468 .28643 Mdot
.472 .28585 Mdot
.476 .28495 Mdot
.48 .28414 Mdot
.484 .28344 Mdot
.488 .28267 Mdot
.492 .28199 Mdot
.496 .28118 Mdot
.5 .28037 Mdot
.504 .27963 Mdot
.508 .27868 Mdot
.512 .27781 Mdot
.516 .27694 Mdot
.52 .27609 Mdot
.524 .27518 Mdot
.528 .27436 Mdot
.532 .27358 Mdot
.536 .27282 Mdot
.54 .27215 Mdot
.544 .27124 Mdot
.548 .27035 Mdot
.552 .26961 Mdot
.556 .26873 Mdot
.56 .26806 Mdot
.564 .26756 Mdot
.568 .26676 Mdot
.572 .26616 Mdot
.576 .2654 Mdot
.58 .26478 Mdot
.584 .26415 Mdot
.588 .26332 Mdot
.592 .26241 Mdot
.596 .26169 Mdot
.6 .26088 Mdot
.604 .26002 Mdot
.608 .25928 Mdot
.612 .25864 Mdot
.616 .25758 Mdot
.62 .25681 Mdot
.624 .25584 Mdot
.628 .25495 Mdot
.632 .25417 Mdot
.636 .25331 Mdot
.64 .25276 Mdot
.644 .25204 Mdot
.648 .25143 Mdot
.652 .25069 Mdot
.656 .24993 Mdot
.66 .24936 Mdot
.664 .2486 Mdot
.668 .24802 Mdot
.672 .24718 Mdot
.676 .24636 Mdot
.68 .2455 Mdot
.684 .24462 Mdot
.688 .24397 Mdot
.692 .2432 Mdot
.696 .24245 Mdot
.7 .24154 Mdot
.704 .24051 Mdot
.708 .23981 Mdot
.712 .23913 Mdot
.716 .23845 Mdot
.72 .23776 Mdot
.724 .23693 Mdot
.728 .23603 Mdot
.732 .23533 Mdot
.736 .23482 Mdot
.74 .23427 Mdot
.744 .2332 Mdot
.748 .23238 Mdot
.752 .23178 Mdot
.756 .23097 Mdot
.76 .23012 Mdot
.764 .22924 Mdot
.768 .22875 Mdot
.772 .22789 Mdot
.776 .22716 Mdot
.78 .22663 Mdot
.784 .22608 Mdot
.788 .22546 Mdot
.792 .22477 Mdot
.796 .22426 Mdot
.8 .22368 Mdot
.804 .22276 Mdot
.808 .22196 Mdot
.812 .2213 Mdot
.816 .22054 Mdot
.82 .21967 Mdot
.824 .21894 Mdot
.828 .21803 Mdot
.832 .21724 Mdot
.836 .21662 Mdot
.84 .216 Mdot
.844 .21531 Mdot
.848 .21485 Mdot
.852 .21421 Mdot
.856 .2137 Mdot
.86 .21283 Mdot
.864 .21224 Mdot
.868 .21181 Mdot
.872 .21121 Mdot
.876 .21054 Mdot
.88 .2101 Mdot
.884 .20934 Mdot
.888 .20844 Mdot
.892 .20768 Mdot
.896 .20683 Mdot
.9 .20605 Mdot
.904 .20559 Mdot
.908 .20487 Mdot
.912 .20418 Mdot
.916 .2035 Mdot
.92 .20282 Mdot
.924 .20192 Mdot
.928 .2012 Mdot
.932 .2006 Mdot
.936 .19993 Mdot
.94 .19944 Mdot
.944 .19892 Mdot
.948 .1982 Mdot
.952 .19754 Mdot
.956 .19712 Mdot
.96 .1964 Mdot
.964 .19591 Mdot
.968 .19543 Mdot
.972 .19497 Mdot
.976 .19441 Mdot
.98 .19392 Mdot
.984 .19343 Mdot
.988 .19277 Mdot
.992 .19206 Mdot
.996 .1915 Mdot
1 .19089 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-143.16, -0.296013, 2.86316, \
0.00935802}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The maximum standard error of this series is: \"\>", 
   "\[InvisibleSpace]", "0.006565236400621133`"}],
  SequenceForm[
  "The maximum standard error of this series is: ", 0.006565236400621133],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Finished noise = \"\>", "\[InvisibleSpace]", "0.001`"}],
  SequenceForm["Finished noise = ", 0.001],
  Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-017 0.002 -1.49349e-017 0.611915 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 58 6.28125 ]
[-0.0125 .12238 -18 -4.5 ]
[-0.0125 .12238 0 4.5 ]
[-0.0125 .24477 -18 -4.5 ]
[-0.0125 .24477 0 4.5 ]
[-0.0125 .36715 -18 -4.5 ]
[-0.0125 .36715 0 4.5 ]
[-0.0125 .48953 -18 -4.5 ]
[-0.0125 .48953 0 4.5 ]
[-0.0125 .61191 -6 -4.5 ]
[-0.0125 .61191 0 4.5 ]
[0 .64303 -50 0 ]
[0 .64303 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(100)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(200)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(300)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(400)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(500)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Iteration) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12238 m
.00625 .12238 L
s
[(0.2)] -0.0125 .12238 1 0 Mshowa
0 .24477 m
.00625 .24477 L
s
[(0.4)] -0.0125 .24477 1 0 Mshowa
0 .36715 m
.00625 .36715 L
s
[(0.6)] -0.0125 .36715 1 0 Mshowa
0 .48953 m
.00625 .48953 L
s
[(0.8)] -0.0125 .48953 1 0 Mshowa
0 .61191 m
.00625 .61191 L
s
[(1)] -0.0125 .61191 1 0 Mshowa
.125 Mabswid
0 .0306 m
.00375 .0306 L
s
0 .06119 m
.00375 .06119 L
s
0 .09179 m
.00375 .09179 L
s
0 .15298 m
.00375 .15298 L
s
0 .18357 m
.00375 .18357 L
s
0 .21417 m
.00375 .21417 L
s
0 .27536 m
.00375 .27536 L
s
0 .30596 m
.00375 .30596 L
s
0 .33655 m
.00375 .33655 L
s
0 .39774 m
.00375 .39774 L
s
0 .42834 m
.00375 .42834 L
s
0 .45894 m
.00375 .45894 L
s
0 .52013 m
.00375 .52013 L
s
0 .55072 m
.00375 .55072 L
s
0 .58132 m
.00375 .58132 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prop) show
93.000 12.813 moveto
(C) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Player) show
153.000 12.813 moveto
(1) show
159.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
0 .55072 Mdot
.004 .52966 Mdot
.008 .51108 Mdot
.012 .49411 Mdot
.016 .48198 Mdot
.02 .47022 Mdot
.024 .46057 Mdot
.028 .45172 Mdot
.032 .44441 Mdot
.036 .43854 Mdot
.04 .43376 Mdot
.044 .42945 Mdot
.048 .4257 Mdot
.052 .42245 Mdot
.056 .41973 Mdot
.06 .41737 Mdot
.064 .41541 Mdot
.068 .41367 Mdot
.072 .41217 Mdot
.076 .41089 Mdot
.08 .40959 Mdot
.084 .40859 Mdot
.088 .40777 Mdot
.092 .40706 Mdot
.096 .40624 Mdot
.1 .40573 Mdot
.104 .40534 Mdot
.108 .40496 Mdot
.112 .40457 Mdot
.116 .4042 Mdot
.12 .40388 Mdot
.124 .4036 Mdot
.128 .40322 Mdot
.132 .40299 Mdot
.136 .40275 Mdot
.14 .40254 Mdot
.144 .40233 Mdot
.148 .40217 Mdot
.152 .40192 Mdot
.156 .40175 Mdot
.16 .4015 Mdot
.164 .40127 Mdot
.168 .40115 Mdot
.172 .40098 Mdot
.176 .40086 Mdot
.18 .40074 Mdot
.184 .40061 Mdot
.188 .40052 Mdot
.192 .40032 Mdot
.196 .40011 Mdot
.2 .39996 Mdot
.204 .39981 Mdot
.208 .3997 Mdot
.212 .39955 Mdot
.216 .39939 Mdot
.22 .39925 Mdot
.224 .39909 Mdot
.228 .39897 Mdot
.232 .39875 Mdot
.236 .39862 Mdot
.24 .39851 Mdot
.244 .39831 Mdot
.248 .39818 Mdot
.252 .3981 Mdot
.256 .39799 Mdot
.26 .39783 Mdot
.264 .39764 Mdot
.268 .39748 Mdot
.272 .39743 Mdot
.276 .39725 Mdot
.28 .39717 Mdot
.284 .39706 Mdot
.288 .39703 Mdot
.292 .39686 Mdot
.296 .39671 Mdot
.3 .39661 Mdot
.304 .39651 Mdot
.308 .39635 Mdot
.312 .39628 Mdot
.316 .39618 Mdot
.32 .39604 Mdot
.324 .39596 Mdot
.328 .39585 Mdot
.332 .39577 Mdot
.336 .39566 Mdot
.34 .39559 Mdot
.344 .39543 Mdot
.348 .39531 Mdot
.352 .39523 Mdot
.356 .39511 Mdot
.36 .39501 Mdot
.364 .39489 Mdot
.368 .39479 Mdot
.372 .39467 Mdot
.376 .39457 Mdot
.38 .39451 Mdot
.384 .3944 Mdot
.388 .39431 Mdot
.392 .39426 Mdot
.396 .39414 Mdot
.4 .39403 Mdot
.404 .39403 Mdot
.408 .39393 Mdot
.412 .39387 Mdot
.416 .39377 Mdot
.42 .39361 Mdot
.424 .39348 Mdot
.428 .39339 Mdot
.432 .39329 Mdot
.436 .3931 Mdot
.44 .39288 Mdot
.444 .39275 Mdot
.448 .39256 Mdot
.452 .39239 Mdot
.456 .39234 Mdot
.46 .39228 Mdot
.464 .39219 Mdot
.468 .39199 Mdot
.472 .39197 Mdot
.476 .39187 Mdot
.48 .39182 Mdot
.484 .39176 Mdot
.488 .39165 Mdot
.492 .39149 Mdot
.496 .39138 Mdot
.5 .39137 Mdot
.504 .39136 Mdot
.508 .39126 Mdot
.512 .39113 Mdot
.516 .39108 Mdot
.52 .39094 Mdot
.524 .39087 Mdot
.528 .39077 Mdot
.532 .39059 Mdot
.536 .39044 Mdot
.54 .39033 Mdot
.544 .39032 Mdot
.548 .39025 Mdot
.552 .39014 Mdot
.556 .38998 Mdot
.56 .38993 Mdot
.564 .38987 Mdot
.568 .38979 Mdot
.572 .38964 Mdot
.576 .38954 Mdot
.58 .38946 Mdot
.584 .38934 Mdot
.588 .3892 Mdot
.592 .38898 Mdot
.596 .38882 Mdot
.6 .38865 Mdot
.604 .3885 Mdot
.608 .38823 Mdot
.612 .38802 Mdot
.616 .38788 Mdot
.62 .38772 Mdot
.624 .3876 Mdot
.628 .38743 Mdot
.632 .3873 Mdot
.636 .38726 Mdot
.64 .3871 Mdot
.644 .38701 Mdot
.648 .38688 Mdot
.652 .38679 Mdot
.656 .38666 Mdot
.66 .38653 Mdot
.664 .38649 Mdot
.668 .38637 Mdot
.672 .38619 Mdot
.676 .3861 Mdot
.68 .38603 Mdot
.684 .38599 Mdot
.688 .38589 Mdot
.692 .38575 Mdot
.696 .38569 Mdot
.7 .3856 Mdot
.704 .3855 Mdot
.708 .38529 Mdot
.712 .38519 Mdot
.716 .38502 Mdot
.72 .38494 Mdot
.724 .38479 Mdot
.728 .38473 Mdot
.732 .38457 Mdot
.736 .38437 Mdot
.74 .38425 Mdot
.744 .38416 Mdot
.748 .38407 Mdot
.752 .38391 Mdot
.756 .3838 Mdot
.76 .38365 Mdot
.764 .38362 Mdot
.768 .38351 Mdot
.772 .38336 Mdot
.776 .38329 Mdot
.78 .38317 Mdot
.784 .38311 Mdot
.788 .38302 Mdot
.792 .38291 Mdot
.796 .38275 Mdot
.8 .3827 Mdot
.804 .38264 Mdot
.808 .38251 Mdot
.812 .38245 Mdot
.816 .38245 Mdot
.82 .3823 Mdot
.824 .38217 Mdot
.828 .38206 Mdot
.832 .38188 Mdot
.836 .38179 Mdot
.84 .38169 Mdot
.844 .38167 Mdot
.848 .38161 Mdot
.852 .38157 Mdot
.856 .38149 Mdot
.86 .38146 Mdot
.864 .38136 Mdot
.868 .38131 Mdot
.872 .38117 Mdot
.876 .38113 Mdot
.88 .38102 Mdot
.884 .38098 Mdot
.888 .38078 Mdot
.892 .38064 Mdot
.896 .38048 Mdot
.9 .38027 Mdot
.904 .38017 Mdot
.908 .38 Mdot
.912 .37995 Mdot
.916 .37984 Mdot
.92 .37974 Mdot
.924 .37974 Mdot
.928 .37976 Mdot
.932 .37971 Mdot
.936 .37961 Mdot
.94 .37944 Mdot
.944 .37933 Mdot
.948 .3792 Mdot
.952 .37903 Mdot
.956 .37899 Mdot
.96 .37882 Mdot
.964 .37879 Mdot
.968 .37866 Mdot
.972 .37863 Mdot
.976 .37854 Mdot
.98 .37849 Mdot
.984 .37842 Mdot
.988 .3783 Mdot
.992 .37821 Mdot
.996 .37816 Mdot
1 .37807 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztWs2OHEUMru2/mV12pd3NIoLEz+yNAKccIDcuCFqCPAKHVYSUHCJQ6DNv
wBv0nSMKypnJM3DJjZEQJApw4wGG+rFdrmpX/+1KBDKjqHficn1lu2yX2zW3
L5q7X96/aO7duVh9+uDi67v37nyz+uSrB5qU7ym1t1JKPVwp832rv8Jjq/9t
z83DUF6u75/ZP0v9XKtG8U+t2o3lVJu2ziypUHW7saSAnAfkY0Rch3hK46/j
qaMQT+yzMMMMbJ0JZD0tQT6z5IqR5yooiZNeN0G+5cx/2/7JrbFwDTdjodqm
pTXb2hvP0DOYx+knRPPGzmdi0SZuWlXXONe4iLeanovKRZAS4jX7LANNQwlG
wciCGaXmCvYB34mqI5/VuibAdYPrMHLOyFt1ypCcp14WCSNpPhKZLRnmUxHP
+lhHIVy54cnFNMs6NJWaCdNw358GcwKhZzbPblyg36XgWBKcCwfG/5wHBAjo
csYrLKSMz7A4Eugn6K+dfNE/L0EnuCDlzIY7BbsQXNv41DxN0VPBlnMM9mFo
f8wV3v6FsyVt9DaTydeAnDh2poGM406Qz1AXIBtd5okR+fg0EDhZxxQ/zwaz
og1brA18uG2NiFgbELem5USD7Se+UrPVZJdtMMagnS4IgwnfGMSxLomVjKT/
T5tft8571E3z5wc3w7tYXGKYeUgzePa7S1g2ATrf9mkww9TITI4y4JiEmaVy
vFsrg32gVNkJIPudqwYmQqBcoBU72v+aViUdOw+cMGN8+MGYDCoq5byvRHTj
5CzkAZOGp/iyr92GffkRBlm0gFk/x3zBooPSyEGcRmzKQaURSqPEbzUeuQqQ
fVbZ5KC1VH7wvMdK8mxIxeGte1WgvZaG/ZH8QsznKwHtOI32527o3x16C0Jf
LG1yv8tU+VappoN0PASLlOIb8gKm8TfqMg31Jnc/FghQK/KD2EUP5DUbjn+N
wthnuuMrzhjlhAq0wpXkkn0QtVN4LeXtklL3i+Vnu6GZUVd0WK2bzYw28m12
KPRADURKxYeDjOBlnBB4C1A1epvvce6+2EO06IV0EK0Tc2Qz9s61C7j/1tCE
gMvBp0Kndv51qTOuZPWqc1Vzulxd9PFKU68yN/qM0DXlmlby9O/NszSUj8bG
IRzJsKx0wH9rnjcM5eMR4RhuJaobQX5hnueGcj/tIbZL946hfJdmum6ebxvK
ozTToXkeGcrPaSYrvnm5UL+kmRa0d7+mmUpi+i3N5Iuf39NMku2ujj0TaE85
exkM2QH9eT4y3kfMLgIW/fljJPbV5JKw2SacQeYzIo1UtO16BfbSbHh7DqSx
cd+w+rRZT62aF+NU7dixr3CW7wemn+BS1azJHRVfkMNqN8SHbnC/U/wzVAi/
hxHJit0e50mycxeZiPkuDPG7n7/DIX4tAUMWYsIPDILbNO/hNpLex7GgnezG
nrjpwaUC5JVjoFHHWv/vDS4x8AEENrulVaxJqH+V6Kt12vPU+WepxmWF/U4H
gnf7Ed3F/DItEb8FWND7hsesowuWHNKHS1bYDAkloUsK6tWxFampKTvyT86S
OVsMa8WcnvE1wTLYDLCom+daDlLHr+T7CAIWfAnQe18QpUAl4s4s37WDQCKS
mvd6nZjS/ceBEGFrbpv98EcqfE9ZH9gpfthvn/D3KWa5StD5GKwmLZsJ0hao
R9TcNjz+tol8xVUncp980BhHgaTE1tOb9vdcCzAM1iu1DxS9F4sBS8RrSpbI
QEZuuOB+nizpa6ZQxmWcF2KdpKu3wEKytNeZH6vgNy7W8kcTFcW2N8/zj3lq
rLr3ec6DXhecq24a6ziH3JG6U73AzhTnwonyeN6J8jJ8V3v/AF8SRDs=\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-143.16, -0.296013, 2.86316, \
0.00935802}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The maximum standard error of this series is: \"\>", 
   "\[InvisibleSpace]", "0.008061545712269726`"}],
  SequenceForm[
  "The maximum standard error of this series is: ", 0.008061545712269726],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Finished noise = \"\>", "\[InvisibleSpace]", "0.0001`"}],
  SequenceForm["Finished noise = ", 0.0001],
  Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-017 0.002 -1.49349e-017 0.611915 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 58 6.28125 ]
[-0.0125 .12238 -18 -4.5 ]
[-0.0125 .12238 0 4.5 ]
[-0.0125 .24477 -18 -4.5 ]
[-0.0125 .24477 0 4.5 ]
[-0.0125 .36715 -18 -4.5 ]
[-0.0125 .36715 0 4.5 ]
[-0.0125 .48953 -18 -4.5 ]
[-0.0125 .48953 0 4.5 ]
[-0.0125 .61191 -6 -4.5 ]
[-0.0125 .61191 0 4.5 ]
[0 .64303 -50 0 ]
[0 .64303 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(100)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(200)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(300)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(400)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(500)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Iteration) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12238 m
.00625 .12238 L
s
[(0.2)] -0.0125 .12238 1 0 Mshowa
0 .24477 m
.00625 .24477 L
s
[(0.4)] -0.0125 .24477 1 0 Mshowa
0 .36715 m
.00625 .36715 L
s
[(0.6)] -0.0125 .36715 1 0 Mshowa
0 .48953 m
.00625 .48953 L
s
[(0.8)] -0.0125 .48953 1 0 Mshowa
0 .61191 m
.00625 .61191 L
s
[(1)] -0.0125 .61191 1 0 Mshowa
.125 Mabswid
0 .0306 m
.00375 .0306 L
s
0 .06119 m
.00375 .06119 L
s
0 .09179 m
.00375 .09179 L
s
0 .15298 m
.00375 .15298 L
s
0 .18357 m
.00375 .18357 L
s
0 .21417 m
.00375 .21417 L
s
0 .27536 m
.00375 .27536 L
s
0 .30596 m
.00375 .30596 L
s
0 .33655 m
.00375 .33655 L
s
0 .39774 m
.00375 .39774 L
s
0 .42834 m
.00375 .42834 L
s
0 .45894 m
.00375 .45894 L
s
0 .52013 m
.00375 .52013 L
s
0 .55072 m
.00375 .55072 L
s
0 .58132 m
.00375 .58132 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prop) show
93.000 12.813 moveto
(C) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Player) show
153.000 12.813 moveto
(1) show
159.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
0 .55072 Mdot
.004 .52937 Mdot
.008 .50961 Mdot
.012 .49428 Mdot
.016 .48106 Mdot
.02 .4698 Mdot
.024 .4606 Mdot
.028 .45287 Mdot
.032 .44558 Mdot
.036 .43934 Mdot
.04 .43448 Mdot
.044 .43005 Mdot
.048 .42658 Mdot
.052 .42336 Mdot
.056 .42075 Mdot
.06 .4186 Mdot
.064 .41653 Mdot
.068 .41496 Mdot
.072 .4134 Mdot
.076 .41205 Mdot
.08 .411 Mdot
.084 .41005 Mdot
.088 .4092 Mdot
.092 .40845 Mdot
.096 .40787 Mdot
.1 .40733 Mdot
.104 .40685 Mdot
.108 .40647 Mdot
.112 .40613 Mdot
.116 .40585 Mdot
.12 .40561 Mdot
.124 .4054 Mdot
.128 .40522 Mdot
.132 .40507 Mdot
.136 .40494 Mdot
.14 .40482 Mdot
.144 .40472 Mdot
.148 .40464 Mdot
.152 .40457 Mdot
.156 .4045 Mdot
.16 .40445 Mdot
.164 .4044 Mdot
.168 .40436 Mdot
.172 .40433 Mdot
.176 .4043 Mdot
.18 .40427 Mdot
.184 .40425 Mdot
.188 .40423 Mdot
.192 .40421 Mdot
.196 .4042 Mdot
.2 .40419 Mdot
.204 .40418 Mdot
.208 .40417 Mdot
.212 .40416 Mdot
.216 .40415 Mdot
.22 .40415 Mdot
.224 .40414 Mdot
.228 .40414 Mdot
.232 .40413 Mdot
.236 .40413 Mdot
.24 .40413 Mdot
.244 .40412 Mdot
.248 .40412 Mdot
.252 .40412 Mdot
.256 .40412 Mdot
.26 .40412 Mdot
.264 .40412 Mdot
.268 .40411 Mdot
.272 .40411 Mdot
.276 .40411 Mdot
.28 .40411 Mdot
.284 .40411 Mdot
.288 .40411 Mdot
.292 .40411 Mdot
.296 .40411 Mdot
.3 .40411 Mdot
.304 .40411 Mdot
.308 .40411 Mdot
.312 .40411 Mdot
.316 .40411 Mdot
.32 .40411 Mdot
.324 .40411 Mdot
.328 .40411 Mdot
.332 .40411 Mdot
.336 .40411 Mdot
.34 .40411 Mdot
.344 .40411 Mdot
.348 .40411 Mdot
.352 .40411 Mdot
.356 .40411 Mdot
.36 .40411 Mdot
.364 .40411 Mdot
.368 .40411 Mdot
.372 .40411 Mdot
.376 .40411 Mdot
.38 .40411 Mdot
.384 .40411 Mdot
.388 .40411 Mdot
.392 .40411 Mdot
.396 .40411 Mdot
.4 .40411 Mdot
.404 .40411 Mdot
.408 .40411 Mdot
.412 .40411 Mdot
.416 .40411 Mdot
.42 .40411 Mdot
.424 .40411 Mdot
.428 .40411 Mdot
.432 .40411 Mdot
.436 .40411 Mdot
.44 .40411 Mdot
.444 .40411 Mdot
.448 .40411 Mdot
.452 .40411 Mdot
.456 .40411 Mdot
.46 .40411 Mdot
.464 .40411 Mdot
.468 .40411 Mdot
.472 .40411 Mdot
.476 .40411 Mdot
.48 .40411 Mdot
.484 .40411 Mdot
.488 .40411 Mdot
.492 .40411 Mdot
.496 .40411 Mdot
.5 .40411 Mdot
.504 .40411 Mdot
.508 .40411 Mdot
.512 .40411 Mdot
.516 .40411 Mdot
.52 .40411 Mdot
.524 .40411 Mdot
.528 .40411 Mdot
.532 .40411 Mdot
.536 .40411 Mdot
.54 .40411 Mdot
.544 .40411 Mdot
.548 .40411 Mdot
.552 .40411 Mdot
.556 .40411 Mdot
.56 .40411 Mdot
.564 .40411 Mdot
.568 .40411 Mdot
.572 .40411 Mdot
.576 .40411 Mdot
.58 .40411 Mdot
.584 .40411 Mdot
.588 .40411 Mdot
.592 .40411 Mdot
.596 .40411 Mdot
.6 .40411 Mdot
.604 .40411 Mdot
.608 .40411 Mdot
.612 .40411 Mdot
.616 .40411 Mdot
.62 .40411 Mdot
.624 .40411 Mdot
.628 .40411 Mdot
.632 .40411 Mdot
.636 .40411 Mdot
.64 .40411 Mdot
.644 .40411 Mdot
.648 .40411 Mdot
.652 .40411 Mdot
.656 .40411 Mdot
.66 .40411 Mdot
.664 .40411 Mdot
.668 .40411 Mdot
.672 .40411 Mdot
.676 .40411 Mdot
.68 .40411 Mdot
.684 .40411 Mdot
.688 .40411 Mdot
.692 .40411 Mdot
.696 .40411 Mdot
.7 .40411 Mdot
.704 .40411 Mdot
.708 .40411 Mdot
.712 .40411 Mdot
.716 .40411 Mdot
.72 .40411 Mdot
.724 .40411 Mdot
.728 .40411 Mdot
.732 .40411 Mdot
.736 .40411 Mdot
.74 .40411 Mdot
.744 .40411 Mdot
.748 .40411 Mdot
.752 .40411 Mdot
.756 .40411 Mdot
.76 .40411 Mdot
.764 .40411 Mdot
.768 .40411 Mdot
.772 .40411 Mdot
.776 .40411 Mdot
.78 .40411 Mdot
.784 .40411 Mdot
.788 .40411 Mdot
.792 .40411 Mdot
.796 .40411 Mdot
.8 .40411 Mdot
.804 .40411 Mdot
.808 .40411 Mdot
.812 .40411 Mdot
.816 .40411 Mdot
.82 .40411 Mdot
.824 .40411 Mdot
.828 .40411 Mdot
.832 .40411 Mdot
.836 .40411 Mdot
.84 .40411 Mdot
.844 .40411 Mdot
.848 .40411 Mdot
.852 .40411 Mdot
.856 .40411 Mdot
.86 .40411 Mdot
.864 .40411 Mdot
.868 .40411 Mdot
.872 .40411 Mdot
.876 .40411 Mdot
.88 .40411 Mdot
.884 .40411 Mdot
.888 .40411 Mdot
.892 .40411 Mdot
.896 .40411 Mdot
.9 .40411 Mdot
.904 .40411 Mdot
.908 .40411 Mdot
.912 .40411 Mdot
.916 .40411 Mdot
.92 .40411 Mdot
.924 .40411 Mdot
.928 .40411 Mdot
.932 .40411 Mdot
.936 .40411 Mdot
.94 .40411 Mdot
.944 .40411 Mdot
.948 .40411 Mdot
.952 .40411 Mdot
.956 .40411 Mdot
.96 .40411 Mdot
.964 .40411 Mdot
.968 .40411 Mdot
.972 .40411 Mdot
.976 .40411 Mdot
.98 .40411 Mdot
.984 .40411 Mdot
.988 .40411 Mdot
.992 .40411 Mdot
.996 .40411 Mdot
1 .40411 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztWs2OHEUMru2/mV0StLtZBEiAJkd+TjkAt9ygJchDrCKk5IBAoR+nxSsg
EGcmb8EFaYREQEBueYBJ/dguu9vVf7sIQqa16pl1ub6yXbbL7Z57l82DL768
bB7ev9x8+ujy6wcP73+z+eSrR5aUHxlztDHGfL8x7vvefoXb3v7tb7ubo7xc
3z/zH2t735rG8Ks27c5zml1bZ55UmLrdeZIg54J8iohbiWcs/rY7dRLimb8X
bpiBbTOFbKclyBeeXDHyUgU1cdLrJsgfB/Pf8x+5NxauEWasTNu0tGZbR+M5
egbzOP2MaNHY+UIs2sRda+oa5zoXiVazc1G5DqSGeMvfS6GplGASjC6YU2qp
YB/ynah68nmtawLcNrgOI+eMvDfnDCl46lWRMJKWI5HZkmE+F/FiiHUSwrUb
nlzMsmylqcxCmIb7/jyYMwg9t3l+44R+V4JjSXApHBj/cx4QIGDIGa+wkHI+
w+JIoZ+hv/byxfC8BJ3gRMpZDHcOdiG4tompeZ6i54otlxjsI2l/zBXR/kWw
JW30PtPJt4CcOHbmgUzjTpAvUBcgO12WidHx8XkgcLJOKX7+GM2KPmyxNojh
tnciYm1A3JaWEw22n/hKy1aTXfZijEEHXRAGE74zSGBdEysZyf5Pm1+3wXvM
HffxXZgRXaxbYrh5SHN4/ntIWD4BBt+OaTDD1MhMjjLgmIaZpXJ8WCuDfaBU
2Qsg/52rBiZCoFyhFQfa/5pWJR07F06YMT68MCZFRWWC95WI7pychTxg0vAc
X46127gv/4hB1lnArZ9jvmDRQWnkpJtGfMpBpRHKonSfaiJyJZBjVtnloLVW
fvC8x0rybEzF8a17TaG9nob9gfxCzecbBe00jfb3YejfHXoHQl8tbfK4y1T5
Vqmmg3Y8iEVK9Ql5BdP4E3WZhnqbux8LBKgV+UEcogfymg/Hp5Mwjpnu+Igz
RTmlAq1wJb1kH0XtFV5rfbu01P3f8rPD0MKoK3qs3s0WRhv5NjsUBqBGIqXi
wyIjRBlnBN4KVO08zQ8491DsIVrngXQUrRdzZDP2zHUIuBdraEbA5eBT0qmD
f13pjCtZvRpc1Z0u1xd9vNK0qyyNPid0TbmmvVL0wUEMiw0c64OhJ7cNVfun
PedVd//WUe6mmU7cvXSUX9JM3hae9GuaqaTt+i3NFEuZJ2kmzTrXx54ptN85
eymG/IC9/py4BxNmF4LFXn/N3l93Lc0MsnU28XxSkkJF225XYI/AjncAcmoU
N6zabLZza+DVclWTZbDe7e9JNqPyteTDQfxiDb3L/c7wa6ysfR8jkpWuA7uf
ZOe+NhPzPRjib3KeySH+kgGGPMSMnwuId2PR130kfYBjojkcxn4O08UrAsgr
p0Cj/rP97y0uMfABBLautVW8SagbleiS9Zrt1MdnqSZkheNeP4H37hE9RP86
LRHv6a/o6SFi1p3XJTkkkpCssLUhJaFXDtR5YytSi1J35J+CJXO2GFZ+Od27
Tf+12AywaJgXGgha/67k+wgCFnwJ0PtYEaVAJbp9Vr5rJ0Iikpp3boOY2tuM
EyXCttw2x/InJ3xPWVc3KH5j2D7y1yZuuUrR+RSspi2bKdIWqEenVe144rsj
8pVQnehd71Fj3BSSEttApzm+tVqBYbBeqWOg2L1YjViiu6ZmiQxk5IYTb9vJ
krFmkjKuu3mhq5P2Ik1YSJf2DebHRvxixVv+5kxFsYnN8/xjnhqr/tu54EFv
Ks5VN413nBvckfpTo8DBFLeVE+XxshPlZfhujp4DPrU1Sg==\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-143.16, -0.296013, 2.86316, \
0.00935802}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The maximum standard error of this series is: \"\>", 
   "\[InvisibleSpace]", "0.009322152827686425`"}],
  SequenceForm[
  "The maximum standard error of this series is: ", 0.009322152827686425],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Finished noise = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["Finished noise = ", 0],
  Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure - Creation", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"finalFigure", "=", 
   RowBox[{"MultipleListPlot", "[", 
    RowBox[{"listOfAverages", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "45"}], ",", "nOfIterations"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.15"}], ",", "1.01"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "10"}], ",", 
        RowBox[{"-", "0.05"}]}], "}"}]}], ",", 
     RowBox[{"SymbolShape", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PlotSymbol", "[", 
         RowBox[{"Star", ",", "1"}], "]"}], ",", 
        RowBox[{"PlotSymbol", "[", 
         RowBox[{"Star", ",", "1"}], "]"}], ",", 
        RowBox[{"PlotSymbol", "[", 
         RowBox[{"Diamond", ",", "1"}], "]"}], ",", 
        RowBox[{"PlotSymbol", "[", 
         RowBox[{"Diamond", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"SymbolStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "0"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"TextStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "9"}]}], "}"}]}], ",", " ", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"StyleForm", "[", 
         RowBox[{"\"\<       Iteration\>\"", ",", 
          RowBox[{"FontSize", "\[Rule]", "10"}]}], "]"}], ",", 
        RowBox[{"StyleForm", "[", 
         RowBox[{"\"\<      Propensity to Cooperate\>\"", ",", 
          RowBox[{"FontSize", "\[Rule]", "10"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"RGBColor", "[", 
        RowBox[{"1", ",", "1", ",", "1"}], "]"}], "}"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", "None"}]}], "]"}]}], ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0825688 0.00183486 0.0799182 0.532788 [
[ 0 0 -0.125 0 ]
[.5 -0.0125 -27.5625 -12.125 ]
[.5 -0.0125 27.5625 0 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -12.125 -57.5313 ]
[-0.01875 .30902 0 57.5313 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.08257 .04078 -4.28125 -12.125 ]
[.08257 .04078 4.28125 0 ]
[.26606 .04078 -8.84375 -12.125 ]
[.26606 .04078 8.84375 0 ]
[.44954 .04078 -8.84375 -12.125 ]
[.44954 .04078 8.84375 0 ]
[.63303 .04078 -8.84375 -12.125 ]
[.63303 .04078 8.84375 0 ]
[.81651 .04078 -8.84375 -12.125 ]
[.81651 .04078 8.84375 0 ]
[1 .04078 -8.84375 -12.125 ]
[1 .04078 8.84375 0 ]
[.05172 .07992 -8.5625 -6.0625 ]
[.05172 .07992 0 6.0625 ]
[.05172 .18648 -15.375 -6.0625 ]
[.05172 .18648 0 6.0625 ]
[.05172 .29303 -15.375 -6.0625 ]
[.05172 .29303 0 6.0625 ]
[.05172 .39959 -15.375 -6.0625 ]
[.05172 .39959 0 6.0625 ]
[.05172 .50615 -15.375 -6.0625 ]
[.05172 .50615 0 6.0625 ]
[.05172 .61271 -8.5625 -6.0625 ]
[.05172 .61271 0 6.0625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 1 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 g
gsave
.5 -0.0125 -88.5625 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
80.500 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Iteration) show
114.125 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 1 1 r
0 0 m
0 .61803 L
s
0 g
gsave
-0.01875 .30902 -124.594 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
118.531 10.0625 translate
90 rotate
-118.531 -10.0625 translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
78.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Propensity) show
122.875 13.000 moveto
(to) show
133.125 13.000 moveto
(Cooperate) show
174.063 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 1 1 r
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 g
.08257 .05328 m
.08257 .05953 L
s
gsave
.08257 .04078 -65.2813 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.26606 .05328 m
.26606 .05953 L
s
gsave
.26606 .04078 -69.8438 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.44954 .05328 m
.44954 .05953 L
s
gsave
.44954 .04078 -69.8438 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.63303 .05328 m
.63303 .05953 L
s
gsave
.63303 .04078 -69.8438 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.81651 .05328 m
.81651 .05953 L
s
gsave
.81651 .04078 -69.8438 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
1 .05328 m
1 .05953 L
s
gsave
1 .04078 -69.8438 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.125 Mabswid
.11927 .05328 m
.11927 .05703 L
s
.15596 .05328 m
.15596 .05703 L
s
.19266 .05328 m
.19266 .05703 L
s
.22936 .05328 m
.22936 .05703 L
s
.30275 .05328 m
.30275 .05703 L
s
.33945 .05328 m
.33945 .05703 L
s
.37615 .05328 m
.37615 .05703 L
s
.41284 .05328 m
.41284 .05703 L
s
.48624 .05328 m
.48624 .05703 L
s
.52294 .05328 m
.52294 .05703 L
s
.55963 .05328 m
.55963 .05703 L
s
.59633 .05328 m
.59633 .05703 L
s
.66972 .05328 m
.66972 .05703 L
s
.70642 .05328 m
.70642 .05703 L
s
.74312 .05328 m
.74312 .05703 L
s
.77982 .05328 m
.77982 .05703 L
s
.85321 .05328 m
.85321 .05703 L
s
.88991 .05328 m
.88991 .05703 L
s
.92661 .05328 m
.92661 .05703 L
s
.9633 .05328 m
.9633 .05703 L
s
.04587 .05328 m
.04587 .05703 L
s
.00917 .05328 m
.00917 .05703 L
s
.25 Mabswid
0 .05328 m
1 .05328 L
s
.06422 .07992 m
.07047 .07992 L
s
gsave
.05172 .07992 -69.5625 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.06422 .18648 m
.07047 .18648 L
s
gsave
.05172 .18648 -76.375 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.06422 .29303 m
.07047 .29303 L
s
gsave
.05172 .29303 -76.375 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.06422 .39959 m
.07047 .39959 L
s
gsave
.05172 .39959 -76.375 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.06422 .50615 m
.07047 .50615 L
s
gsave
.05172 .50615 -76.375 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.06422 .61271 m
.07047 .61271 L
s
gsave
.05172 .61271 -69.5625 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.06422 .10656 m
.06797 .10656 L
s
.06422 .1332 m
.06797 .1332 L
s
.06422 .15984 m
.06797 .15984 L
s
.06422 .21312 m
.06797 .21312 L
s
.06422 .23975 m
.06797 .23975 L
s
.06422 .26639 m
.06797 .26639 L
s
.06422 .31967 m
.06797 .31967 L
s
.06422 .34631 m
.06797 .34631 L
s
.06422 .37295 m
.06797 .37295 L
s
.06422 .42623 m
.06797 .42623 L
s
.06422 .45287 m
.06797 .45287 L
s
.06422 .47951 m
.06797 .47951 L
s
.06422 .53279 m
.06797 .53279 L
s
.06422 .55943 m
.06797 .55943 L
s
.06422 .58607 m
.06797 .58607 L
s
.06422 .02664 m
.06797 .02664 L
s
.25 Mabswid
.06422 0 m
.06422 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.0001 w
.08257 .55943 0 1 Mabsadd m
.08257 .55943 -0.22607 .31116 Mabsadd L
.08257 .55943 -0.95106 .30902 Mabsadd L
.08257 .55943 -0.36579 -0.11885 Mabsadd L
.08257 .55943 -0.58778 -0.80902 Mabsadd L
.08257 .55943 0 -0.38461 Mabsadd L
.08257 .55943 .58779 -0.80902 Mabsadd L
.08257 .55943 .36579 -0.11885 Mabsadd L
.08257 .55943 .95106 .30902 Mabsadd L
.08257 .55943 .22607 .31116 Mabsadd L
.08257 .55943 0 1 Mabsadd L closepath F
.08624 .53571 0 1 Mabsadd m
.08624 .53571 -0.22607 .31116 Mabsadd L
.08624 .53571 -0.95106 .30902 Mabsadd L
.08624 .53571 -0.36579 -0.11885 Mabsadd L
.08624 .53571 -0.58778 -0.80902 Mabsadd L
.08624 .53571 0 -0.38461 Mabsadd L
.08624 .53571 .58779 -0.80902 Mabsadd L
.08624 .53571 .36579 -0.11885 Mabsadd L
.08624 .53571 .95106 .30902 Mabsadd L
.08624 .53571 .22607 .31116 Mabsadd L
.08624 .53571 0 1 Mabsadd L closepath F
.08991 .5152 0 1 Mabsadd m
.08991 .5152 -0.22607 .31116 Mabsadd L
.08991 .5152 -0.95106 .30902 Mabsadd L
.08991 .5152 -0.36579 -0.11885 Mabsadd L
.08991 .5152 -0.58778 -0.80902 Mabsadd L
.08991 .5152 0 -0.38461 Mabsadd L
.08991 .5152 .58779 -0.80902 Mabsadd L
.08991 .5152 .36579 -0.11885 Mabsadd L
.08991 .5152 .95106 .30902 Mabsadd L
.08991 .5152 .22607 .31116 Mabsadd L
.08991 .5152 0 1 Mabsadd L closepath F
.09358 .49615 0 1 Mabsadd m
.09358 .49615 -0.22607 .31116 Mabsadd L
.09358 .49615 -0.95106 .30902 Mabsadd L
.09358 .49615 -0.36579 -0.11885 Mabsadd L
.09358 .49615 -0.58778 -0.80902 Mabsadd L
.09358 .49615 0 -0.38461 Mabsadd L
.09358 .49615 .58779 -0.80902 Mabsadd L
.09358 .49615 .36579 -0.11885 Mabsadd L
.09358 .49615 .95106 .30902 Mabsadd L
.09358 .49615 .22607 .31116 Mabsadd L
.09358 .49615 0 1 Mabsadd L closepath F
.09725 .48002 0 1 Mabsadd m
.09725 .48002 -0.22607 .31116 Mabsadd L
.09725 .48002 -0.95106 .30902 Mabsadd L
.09725 .48002 -0.36579 -0.11885 Mabsadd L
.09725 .48002 -0.58778 -0.80902 Mabsadd L
.09725 .48002 0 -0.38461 Mabsadd L
.09725 .48002 .58779 -0.80902 Mabsadd L
.09725 .48002 .36579 -0.11885 Mabsadd L
.09725 .48002 .95106 .30902 Mabsadd L
.09725 .48002 .22607 .31116 Mabsadd L
.09725 .48002 0 1 Mabsadd L closepath F
.10092 .4649 0 1 Mabsadd m
.10092 .4649 -0.22607 .31116 Mabsadd L
.10092 .4649 -0.95106 .30902 Mabsadd L
.10092 .4649 -0.36579 -0.11885 Mabsadd L
.10092 .4649 -0.58778 -0.80902 Mabsadd L
.10092 .4649 0 -0.38461 Mabsadd L
.10092 .4649 .58779 -0.80902 Mabsadd L
.10092 .4649 .36579 -0.11885 Mabsadd L
.10092 .4649 .95106 .30902 Mabsadd L
.10092 .4649 .22607 .31116 Mabsadd L
.10092 .4649 0 1 Mabsadd L closepath F
.10459 .45116 0 1 Mabsadd m
.10459 .45116 -0.22607 .31116 Mabsadd L
.10459 .45116 -0.95106 .30902 Mabsadd L
.10459 .45116 -0.36579 -0.11885 Mabsadd L
.10459 .45116 -0.58778 -0.80902 Mabsadd L
.10459 .45116 0 -0.38461 Mabsadd L
.10459 .45116 .58779 -0.80902 Mabsadd L
.10459 .45116 .36579 -0.11885 Mabsadd L
.10459 .45116 .95106 .30902 Mabsadd L
.10459 .45116 .22607 .31116 Mabsadd L
.10459 .45116 0 1 Mabsadd L closepath F
.10826 .43739 0 1 Mabsadd m
.10826 .43739 -0.22607 .31116 Mabsadd L
.10826 .43739 -0.95106 .30902 Mabsadd L
.10826 .43739 -0.36579 -0.11885 Mabsadd L
.10826 .43739 -0.58778 -0.80902 Mabsadd L
.10826 .43739 0 -0.38461 Mabsadd L
.10826 .43739 .58779 -0.80902 Mabsadd L
.10826 .43739 .36579 -0.11885 Mabsadd L
.10826 .43739 .95106 .30902 Mabsadd L
.10826 .43739 .22607 .31116 Mabsadd L
.10826 .43739 0 1 Mabsadd L closepath F
.11193 .42433 0 1 Mabsadd m
.11193 .42433 -0.22607 .31116 Mabsadd L
.11193 .42433 -0.95106 .30902 Mabsadd L
.11193 .42433 -0.36579 -0.11885 Mabsadd L
.11193 .42433 -0.58778 -0.80902 Mabsadd L
.11193 .42433 0 -0.38461 Mabsadd L
.11193 .42433 .58779 -0.80902 Mabsadd L
.11193 .42433 .36579 -0.11885 Mabsadd L
.11193 .42433 .95106 .30902 Mabsadd L
.11193 .42433 .22607 .31116 Mabsadd L
.11193 .42433 0 1 Mabsadd L closepath F
.1156 .41306 0 1 Mabsadd m
.1156 .41306 -0.22607 .31116 Mabsadd L
.1156 .41306 -0.95106 .30902 Mabsadd L
.1156 .41306 -0.36579 -0.11885 Mabsadd L
.1156 .41306 -0.58778 -0.80902 Mabsadd L
.1156 .41306 0 -0.38461 Mabsadd L
.1156 .41306 .58779 -0.80902 Mabsadd L
.1156 .41306 .36579 -0.11885 Mabsadd L
.1156 .41306 .95106 .30902 Mabsadd L
.1156 .41306 .22607 .31116 Mabsadd L
.1156 .41306 0 1 Mabsadd L closepath F
.11927 .4018 0 1 Mabsadd m
.11927 .4018 -0.22607 .31116 Mabsadd L
.11927 .4018 -0.95106 .30902 Mabsadd L
.11927 .4018 -0.36579 -0.11885 Mabsadd L
.11927 .4018 -0.58778 -0.80902 Mabsadd L
.11927 .4018 0 -0.38461 Mabsadd L
.11927 .4018 .58779 -0.80902 Mabsadd L
.11927 .4018 .36579 -0.11885 Mabsadd L
.11927 .4018 .95106 .30902 Mabsadd L
.11927 .4018 .22607 .31116 Mabsadd L
.11927 .4018 0 1 Mabsadd L closepath F
.12294 .39137 0 1 Mabsadd m
.12294 .39137 -0.22607 .31116 Mabsadd L
.12294 .39137 -0.95106 .30902 Mabsadd L
.12294 .39137 -0.36579 -0.11885 Mabsadd L
.12294 .39137 -0.58778 -0.80902 Mabsadd L
.12294 .39137 0 -0.38461 Mabsadd L
.12294 .39137 .58779 -0.80902 Mabsadd L
.12294 .39137 .36579 -0.11885 Mabsadd L
.12294 .39137 .95106 .30902 Mabsadd L
.12294 .39137 .22607 .31116 Mabsadd L
.12294 .39137 0 1 Mabsadd L closepath F
.12661 .38214 0 1 Mabsadd m
.12661 .38214 -0.22607 .31116 Mabsadd L
.12661 .38214 -0.95106 .30902 Mabsadd L
.12661 .38214 -0.36579 -0.11885 Mabsadd L
.12661 .38214 -0.58778 -0.80902 Mabsadd L
.12661 .38214 0 -0.38461 Mabsadd L
.12661 .38214 .58779 -0.80902 Mabsadd L
.12661 .38214 .36579 -0.11885 Mabsadd L
.12661 .38214 .95106 .30902 Mabsadd L
.12661 .38214 .22607 .31116 Mabsadd L
.12661 .38214 0 1 Mabsadd L closepath F
.13028 .37279 0 1 Mabsadd m
.13028 .37279 -0.22607 .31116 Mabsadd L
.13028 .37279 -0.95106 .30902 Mabsadd L
.13028 .37279 -0.36579 -0.11885 Mabsadd L
.13028 .37279 -0.58778 -0.80902 Mabsadd L
.13028 .37279 0 -0.38461 Mabsadd L
.13028 .37279 .58779 -0.80902 Mabsadd L
.13028 .37279 .36579 -0.11885 Mabsadd L
.13028 .37279 .95106 .30902 Mabsadd L
.13028 .37279 .22607 .31116 Mabsadd L
.13028 .37279 0 1 Mabsadd L closepath F
.13394 .36342 0 1 Mabsadd m
.13394 .36342 -0.22607 .31116 Mabsadd L
.13394 .36342 -0.95106 .30902 Mabsadd L
.13394 .36342 -0.36579 -0.11885 Mabsadd L
.13394 .36342 -0.58778 -0.80902 Mabsadd L
.13394 .36342 0 -0.38461 Mabsadd L
.13394 .36342 .58779 -0.80902 Mabsadd L
.13394 .36342 .36579 -0.11885 Mabsadd L
.13394 .36342 .95106 .30902 Mabsadd L
.13394 .36342 .22607 .31116 Mabsadd L
.13394 .36342 0 1 Mabsadd L closepath F
.13761 .35479 0 1 Mabsadd m
.13761 .35479 -0.22607 .31116 Mabsadd L
.13761 .35479 -0.95106 .30902 Mabsadd L
.13761 .35479 -0.36579 -0.11885 Mabsadd L
.13761 .35479 -0.58778 -0.80902 Mabsadd L
.13761 .35479 0 -0.38461 Mabsadd L
.13761 .35479 .58779 -0.80902 Mabsadd L
.13761 .35479 .36579 -0.11885 Mabsadd L
.13761 .35479 .95106 .30902 Mabsadd L
.13761 .35479 .22607 .31116 Mabsadd L
.13761 .35479 0 1 Mabsadd L closepath F
.14128 .34635 0 1 Mabsadd m
.14128 .34635 -0.22607 .31116 Mabsadd L
.14128 .34635 -0.95106 .30902 Mabsadd L
.14128 .34635 -0.36579 -0.11885 Mabsadd L
.14128 .34635 -0.58778 -0.80902 Mabsadd L
.14128 .34635 0 -0.38461 Mabsadd L
.14128 .34635 .58779 -0.80902 Mabsadd L
.14128 .34635 .36579 -0.11885 Mabsadd L
.14128 .34635 .95106 .30902 Mabsadd L
.14128 .34635 .22607 .31116 Mabsadd L
.14128 .34635 0 1 Mabsadd L closepath F
.14495 .33764 0 1 Mabsadd m
.14495 .33764 -0.22607 .31116 Mabsadd L
.14495 .33764 -0.95106 .30902 Mabsadd L
.14495 .33764 -0.36579 -0.11885 Mabsadd L
.14495 .33764 -0.58778 -0.80902 Mabsadd L
.14495 .33764 0 -0.38461 Mabsadd L
.14495 .33764 .58779 -0.80902 Mabsadd L
.14495 .33764 .36579 -0.11885 Mabsadd L
.14495 .33764 .95106 .30902 Mabsadd L
.14495 .33764 .22607 .31116 Mabsadd L
.14495 .33764 0 1 Mabsadd L closepath F
.14862 .32961 0 1 Mabsadd m
.14862 .32961 -0.22607 .31116 Mabsadd L
.14862 .32961 -0.95106 .30902 Mabsadd L
.14862 .32961 -0.36579 -0.11885 Mabsadd L
.14862 .32961 -0.58778 -0.80902 Mabsadd L
.14862 .32961 0 -0.38461 Mabsadd L
.14862 .32961 .58779 -0.80902 Mabsadd L
.14862 .32961 .36579 -0.11885 Mabsadd L
.14862 .32961 .95106 .30902 Mabsadd L
.14862 .32961 .22607 .31116 Mabsadd L
.14862 .32961 0 1 Mabsadd L closepath F
.15229 .32181 0 1 Mabsadd m
.15229 .32181 -0.22607 .31116 Mabsadd L
.15229 .32181 -0.95106 .30902 Mabsadd L
.15229 .32181 -0.36579 -0.11885 Mabsadd L
.15229 .32181 -0.58778 -0.80902 Mabsadd L
.15229 .32181 0 -0.38461 Mabsadd L
.15229 .32181 .58779 -0.80902 Mabsadd L
.15229 .32181 .36579 -0.11885 Mabsadd L
.15229 .32181 .95106 .30902 Mabsadd L
.15229 .32181 .22607 .31116 Mabsadd L
.15229 .32181 0 1 Mabsadd L closepath F
.15596 .31464 0 1 Mabsadd m
.15596 .31464 -0.22607 .31116 Mabsadd L
.15596 .31464 -0.95106 .30902 Mabsadd L
.15596 .31464 -0.36579 -0.11885 Mabsadd L
.15596 .31464 -0.58778 -0.80902 Mabsadd L
.15596 .31464 0 -0.38461 Mabsadd L
.15596 .31464 .58779 -0.80902 Mabsadd L
.15596 .31464 .36579 -0.11885 Mabsadd L
.15596 .31464 .95106 .30902 Mabsadd L
.15596 .31464 .22607 .31116 Mabsadd L
.15596 .31464 0 1 Mabsadd L closepath F
.15963 .30688 0 1 Mabsadd m
.15963 .30688 -0.22607 .31116 Mabsadd L
.15963 .30688 -0.95106 .30902 Mabsadd L
.15963 .30688 -0.36579 -0.11885 Mabsadd L
.15963 .30688 -0.58778 -0.80902 Mabsadd L
.15963 .30688 0 -0.38461 Mabsadd L
.15963 .30688 .58779 -0.80902 Mabsadd L
.15963 .30688 .36579 -0.11885 Mabsadd L
.15963 .30688 .95106 .30902 Mabsadd L
.15963 .30688 .22607 .31116 Mabsadd L
.15963 .30688 0 1 Mabsadd L closepath F
.1633 .30001 0 1 Mabsadd m
.1633 .30001 -0.22607 .31116 Mabsadd L
.1633 .30001 -0.95106 .30902 Mabsadd L
.1633 .30001 -0.36579 -0.11885 Mabsadd L
.1633 .30001 -0.58778 -0.80902 Mabsadd L
.1633 .30001 0 -0.38461 Mabsadd L
.1633 .30001 .58779 -0.80902 Mabsadd L
.1633 .30001 .36579 -0.11885 Mabsadd L
.1633 .30001 .95106 .30902 Mabsadd L
.1633 .30001 .22607 .31116 Mabsadd L
.1633 .30001 0 1 Mabsadd L closepath F
.16697 .29352 0 1 Mabsadd m
.16697 .29352 -0.22607 .31116 Mabsadd L
.16697 .29352 -0.95106 .30902 Mabsadd L
.16697 .29352 -0.36579 -0.11885 Mabsadd L
.16697 .29352 -0.58778 -0.80902 Mabsadd L
.16697 .29352 0 -0.38461 Mabsadd L
.16697 .29352 .58779 -0.80902 Mabsadd L
.16697 .29352 .36579 -0.11885 Mabsadd L
.16697 .29352 .95106 .30902 Mabsadd L
.16697 .29352 .22607 .31116 Mabsadd L
.16697 .29352 0 1 Mabsadd L closepath F
.17064 .28714 0 1 Mabsadd m
.17064 .28714 -0.22607 .31116 Mabsadd L
.17064 .28714 -0.95106 .30902 Mabsadd L
.17064 .28714 -0.36579 -0.11885 Mabsadd L
.17064 .28714 -0.58778 -0.80902 Mabsadd L
.17064 .28714 0 -0.38461 Mabsadd L
.17064 .28714 .58779 -0.80902 Mabsadd L
.17064 .28714 .36579 -0.11885 Mabsadd L
.17064 .28714 .95106 .30902 Mabsadd L
.17064 .28714 .22607 .31116 Mabsadd L
.17064 .28714 0 1 Mabsadd L closepath F
.17431 .2814 0 1 Mabsadd m
.17431 .2814 -0.22607 .31116 Mabsadd L
.17431 .2814 -0.95106 .30902 Mabsadd L
.17431 .2814 -0.36579 -0.11885 Mabsadd L
.17431 .2814 -0.58778 -0.80902 Mabsadd L
.17431 .2814 0 -0.38461 Mabsadd L
.17431 .2814 .58779 -0.80902 Mabsadd L
.17431 .2814 .36579 -0.11885 Mabsadd L
.17431 .2814 .95106 .30902 Mabsadd L
.17431 .2814 .22607 .31116 Mabsadd L
.17431 .2814 0 1 Mabsadd L closepath F
.17798 .27518 0 1 Mabsadd m
.17798 .27518 -0.22607 .31116 Mabsadd L
.17798 .27518 -0.95106 .30902 Mabsadd L
.17798 .27518 -0.36579 -0.11885 Mabsadd L
.17798 .27518 -0.58778 -0.80902 Mabsadd L
.17798 .27518 0 -0.38461 Mabsadd L
.17798 .27518 .58779 -0.80902 Mabsadd L
.17798 .27518 .36579 -0.11885 Mabsadd L
.17798 .27518 .95106 .30902 Mabsadd L
.17798 .27518 .22607 .31116 Mabsadd L
.17798 .27518 0 1 Mabsadd L closepath F
.18165 .2693 0 1 Mabsadd m
.18165 .2693 -0.22607 .31116 Mabsadd L
.18165 .2693 -0.95106 .30902 Mabsadd L
.18165 .2693 -0.36579 -0.11885 Mabsadd L
.18165 .2693 -0.58778 -0.80902 Mabsadd L
.18165 .2693 0 -0.38461 Mabsadd L
.18165 .2693 .58779 -0.80902 Mabsadd L
.18165 .2693 .36579 -0.11885 Mabsadd L
.18165 .2693 .95106 .30902 Mabsadd L
.18165 .2693 .22607 .31116 Mabsadd L
.18165 .2693 0 1 Mabsadd L closepath F
.18532 .26336 0 1 Mabsadd m
.18532 .26336 -0.22607 .31116 Mabsadd L
.18532 .26336 -0.95106 .30902 Mabsadd L
.18532 .26336 -0.36579 -0.11885 Mabsadd L
.18532 .26336 -0.58778 -0.80902 Mabsadd L
.18532 .26336 0 -0.38461 Mabsadd L
.18532 .26336 .58779 -0.80902 Mabsadd L
.18532 .26336 .36579 -0.11885 Mabsadd L
.18532 .26336 .95106 .30902 Mabsadd L
.18532 .26336 .22607 .31116 Mabsadd L
.18532 .26336 0 1 Mabsadd L closepath F
.18899 .25762 0 1 Mabsadd m
.18899 .25762 -0.22607 .31116 Mabsadd L
.18899 .25762 -0.95106 .30902 Mabsadd L
.18899 .25762 -0.36579 -0.11885 Mabsadd L
.18899 .25762 -0.58778 -0.80902 Mabsadd L
.18899 .25762 0 -0.38461 Mabsadd L
.18899 .25762 .58779 -0.80902 Mabsadd L
.18899 .25762 .36579 -0.11885 Mabsadd L
.18899 .25762 .95106 .30902 Mabsadd L
.18899 .25762 .22607 .31116 Mabsadd L
.18899 .25762 0 1 Mabsadd L closepath F
.19266 .2524 0 1 Mabsadd m
.19266 .2524 -0.22607 .31116 Mabsadd L
.19266 .2524 -0.95106 .30902 Mabsadd L
.19266 .2524 -0.36579 -0.11885 Mabsadd L
.19266 .2524 -0.58778 -0.80902 Mabsadd L
.19266 .2524 0 -0.38461 Mabsadd L
.19266 .2524 .58779 -0.80902 Mabsadd L
.19266 .2524 .36579 -0.11885 Mabsadd L
.19266 .2524 .95106 .30902 Mabsadd L
.19266 .2524 .22607 .31116 Mabsadd L
.19266 .2524 0 1 Mabsadd L closepath F
.19633 .24731 0 1 Mabsadd m
.19633 .24731 -0.22607 .31116 Mabsadd L
.19633 .24731 -0.95106 .30902 Mabsadd L
.19633 .24731 -0.36579 -0.11885 Mabsadd L
.19633 .24731 -0.58778 -0.80902 Mabsadd L
.19633 .24731 0 -0.38461 Mabsadd L
.19633 .24731 .58779 -0.80902 Mabsadd L
.19633 .24731 .36579 -0.11885 Mabsadd L
.19633 .24731 .95106 .30902 Mabsadd L
.19633 .24731 .22607 .31116 Mabsadd L
.19633 .24731 0 1 Mabsadd L closepath F
.2 .2429 0 1 Mabsadd m
.2 .2429 -0.22607 .31116 Mabsadd L
.2 .2429 -0.95106 .30902 Mabsadd L
.2 .2429 -0.36579 -0.11885 Mabsadd L
.2 .2429 -0.58778 -0.80902 Mabsadd L
.2 .2429 0 -0.38461 Mabsadd L
.2 .2429 .58779 -0.80902 Mabsadd L
.2 .2429 .36579 -0.11885 Mabsadd L
.2 .2429 .95106 .30902 Mabsadd L
.2 .2429 .22607 .31116 Mabsadd L
.2 .2429 0 1 Mabsadd L closepath F
.20367 .23826 0 1 Mabsadd m
.20367 .23826 -0.22607 .31116 Mabsadd L
.20367 .23826 -0.95106 .30902 Mabsadd L
.20367 .23826 -0.36579 -0.11885 Mabsadd L
.20367 .23826 -0.58778 -0.80902 Mabsadd L
.20367 .23826 0 -0.38461 Mabsadd L
.20367 .23826 .58779 -0.80902 Mabsadd L
.20367 .23826 .36579 -0.11885 Mabsadd L
.20367 .23826 .95106 .30902 Mabsadd L
.20367 .23826 .22607 .31116 Mabsadd L
.20367 .23826 0 1 Mabsadd L closepath F
.20734 .23359 0 1 Mabsadd m
.20734 .23359 -0.22607 .31116 Mabsadd L
.20734 .23359 -0.95106 .30902 Mabsadd L
.20734 .23359 -0.36579 -0.11885 Mabsadd L
.20734 .23359 -0.58778 -0.80902 Mabsadd L
.20734 .23359 0 -0.38461 Mabsadd L
.20734 .23359 .58779 -0.80902 Mabsadd L
.20734 .23359 .36579 -0.11885 Mabsadd L
.20734 .23359 .95106 .30902 Mabsadd L
.20734 .23359 .22607 .31116 Mabsadd L
.20734 .23359 0 1 Mabsadd L closepath F
.21101 .2292 0 1 Mabsadd m
.21101 .2292 -0.22607 .31116 Mabsadd L
.21101 .2292 -0.95106 .30902 Mabsadd L
.21101 .2292 -0.36579 -0.11885 Mabsadd L
.21101 .2292 -0.58778 -0.80902 Mabsadd L
.21101 .2292 0 -0.38461 Mabsadd L
.21101 .2292 .58779 -0.80902 Mabsadd L
.21101 .2292 .36579 -0.11885 Mabsadd L
.21101 .2292 .95106 .30902 Mabsadd L
.21101 .2292 .22607 .31116 Mabsadd L
.21101 .2292 0 1 Mabsadd L closepath F
.21468 .22502 0 1 Mabsadd m
.21468 .22502 -0.22607 .31116 Mabsadd L
.21468 .22502 -0.95106 .30902 Mabsadd L
.21468 .22502 -0.36579 -0.11885 Mabsadd L
.21468 .22502 -0.58778 -0.80902 Mabsadd L
.21468 .22502 0 -0.38461 Mabsadd L
.21468 .22502 .58779 -0.80902 Mabsadd L
.21468 .22502 .36579 -0.11885 Mabsadd L
.21468 .22502 .95106 .30902 Mabsadd L
.21468 .22502 .22607 .31116 Mabsadd L
.21468 .22502 0 1 Mabsadd L closepath F
.21835 .22148 0 1 Mabsadd m
.21835 .22148 -0.22607 .31116 Mabsadd L
.21835 .22148 -0.95106 .30902 Mabsadd L
.21835 .22148 -0.36579 -0.11885 Mabsadd L
.21835 .22148 -0.58778 -0.80902 Mabsadd L
.21835 .22148 0 -0.38461 Mabsadd L
.21835 .22148 .58779 -0.80902 Mabsadd L
.21835 .22148 .36579 -0.11885 Mabsadd L
.21835 .22148 .95106 .30902 Mabsadd L
.21835 .22148 .22607 .31116 Mabsadd L
.21835 .22148 0 1 Mabsadd L closepath F
.22202 .21767 0 1 Mabsadd m
.22202 .21767 -0.22607 .31116 Mabsadd L
.22202 .21767 -0.95106 .30902 Mabsadd L
.22202 .21767 -0.36579 -0.11885 Mabsadd L
.22202 .21767 -0.58778 -0.80902 Mabsadd L
.22202 .21767 0 -0.38461 Mabsadd L
.22202 .21767 .58779 -0.80902 Mabsadd L
.22202 .21767 .36579 -0.11885 Mabsadd L
.22202 .21767 .95106 .30902 Mabsadd L
.22202 .21767 .22607 .31116 Mabsadd L
.22202 .21767 0 1 Mabsadd L closepath F
.22569 .21347 0 1 Mabsadd m
.22569 .21347 -0.22607 .31116 Mabsadd L
.22569 .21347 -0.95106 .30902 Mabsadd L
.22569 .21347 -0.36579 -0.11885 Mabsadd L
.22569 .21347 -0.58778 -0.80902 Mabsadd L
.22569 .21347 0 -0.38461 Mabsadd L
.22569 .21347 .58779 -0.80902 Mabsadd L
.22569 .21347 .36579 -0.11885 Mabsadd L
.22569 .21347 .95106 .30902 Mabsadd L
.22569 .21347 .22607 .31116 Mabsadd L
.22569 .21347 0 1 Mabsadd L closepath F
.22936 .20976 0 1 Mabsadd m
.22936 .20976 -0.22607 .31116 Mabsadd L
.22936 .20976 -0.95106 .30902 Mabsadd L
.22936 .20976 -0.36579 -0.11885 Mabsadd L
.22936 .20976 -0.58778 -0.80902 Mabsadd L
.22936 .20976 0 -0.38461 Mabsadd L
.22936 .20976 .58779 -0.80902 Mabsadd L
.22936 .20976 .36579 -0.11885 Mabsadd L
.22936 .20976 .95106 .30902 Mabsadd L
.22936 .20976 .22607 .31116 Mabsadd L
.22936 .20976 0 1 Mabsadd L closepath F
.23303 .20658 0 1 Mabsadd m
.23303 .20658 -0.22607 .31116 Mabsadd L
.23303 .20658 -0.95106 .30902 Mabsadd L
.23303 .20658 -0.36579 -0.11885 Mabsadd L
.23303 .20658 -0.58778 -0.80902 Mabsadd L
.23303 .20658 0 -0.38461 Mabsadd L
.23303 .20658 .58779 -0.80902 Mabsadd L
.23303 .20658 .36579 -0.11885 Mabsadd L
.23303 .20658 .95106 .30902 Mabsadd L
.23303 .20658 .22607 .31116 Mabsadd L
.23303 .20658 0 1 Mabsadd L closepath F
.2367 .20306 0 1 Mabsadd m
.2367 .20306 -0.22607 .31116 Mabsadd L
.2367 .20306 -0.95106 .30902 Mabsadd L
.2367 .20306 -0.36579 -0.11885 Mabsadd L
.2367 .20306 -0.58778 -0.80902 Mabsadd L
.2367 .20306 0 -0.38461 Mabsadd L
.2367 .20306 .58779 -0.80902 Mabsadd L
.2367 .20306 .36579 -0.11885 Mabsadd L
.2367 .20306 .95106 .30902 Mabsadd L
.2367 .20306 .22607 .31116 Mabsadd L
.2367 .20306 0 1 Mabsadd L closepath F
.24037 .20013 0 1 Mabsadd m
.24037 .20013 -0.22607 .31116 Mabsadd L
.24037 .20013 -0.95106 .30902 Mabsadd L
.24037 .20013 -0.36579 -0.11885 Mabsadd L
.24037 .20013 -0.58778 -0.80902 Mabsadd L
.24037 .20013 0 -0.38461 Mabsadd L
.24037 .20013 .58779 -0.80902 Mabsadd L
.24037 .20013 .36579 -0.11885 Mabsadd L
.24037 .20013 .95106 .30902 Mabsadd L
.24037 .20013 .22607 .31116 Mabsadd L
.24037 .20013 0 1 Mabsadd L closepath F
.24404 .19676 0 1 Mabsadd m
.24404 .19676 -0.22607 .31116 Mabsadd L
.24404 .19676 -0.95106 .30902 Mabsadd L
.24404 .19676 -0.36579 -0.11885 Mabsadd L
.24404 .19676 -0.58778 -0.80902 Mabsadd L
.24404 .19676 0 -0.38461 Mabsadd L
.24404 .19676 .58779 -0.80902 Mabsadd L
.24404 .19676 .36579 -0.11885 Mabsadd L
.24404 .19676 .95106 .30902 Mabsadd L
.24404 .19676 .22607 .31116 Mabsadd L
.24404 .19676 0 1 Mabsadd L closepath F
.24771 .19384 0 1 Mabsadd m
.24771 .19384 -0.22607 .31116 Mabsadd L
.24771 .19384 -0.95106 .30902 Mabsadd L
.24771 .19384 -0.36579 -0.11885 Mabsadd L
.24771 .19384 -0.58778 -0.80902 Mabsadd L
.24771 .19384 0 -0.38461 Mabsadd L
.24771 .19384 .58779 -0.80902 Mabsadd L
.24771 .19384 .36579 -0.11885 Mabsadd L
.24771 .19384 .95106 .30902 Mabsadd L
.24771 .19384 .22607 .31116 Mabsadd L
.24771 .19384 0 1 Mabsadd L closepath F
.25138 .19077 0 1 Mabsadd m
.25138 .19077 -0.22607 .31116 Mabsadd L
.25138 .19077 -0.95106 .30902 Mabsadd L
.25138 .19077 -0.36579 -0.11885 Mabsadd L
.25138 .19077 -0.58778 -0.80902 Mabsadd L
.25138 .19077 0 -0.38461 Mabsadd L
.25138 .19077 .58779 -0.80902 Mabsadd L
.25138 .19077 .36579 -0.11885 Mabsadd L
.25138 .19077 .95106 .30902 Mabsadd L
.25138 .19077 .22607 .31116 Mabsadd L
.25138 .19077 0 1 Mabsadd L closepath F
.25505 .18784 0 1 Mabsadd m
.25505 .18784 -0.22607 .31116 Mabsadd L
.25505 .18784 -0.95106 .30902 Mabsadd L
.25505 .18784 -0.36579 -0.11885 Mabsadd L
.25505 .18784 -0.58778 -0.80902 Mabsadd L
.25505 .18784 0 -0.38461 Mabsadd L
.25505 .18784 .58779 -0.80902 Mabsadd L
.25505 .18784 .36579 -0.11885 Mabsadd L
.25505 .18784 .95106 .30902 Mabsadd L
.25505 .18784 .22607 .31116 Mabsadd L
.25505 .18784 0 1 Mabsadd L closepath F
.25872 .18473 0 1 Mabsadd m
.25872 .18473 -0.22607 .31116 Mabsadd L
.25872 .18473 -0.95106 .30902 Mabsadd L
.25872 .18473 -0.36579 -0.11885 Mabsadd L
.25872 .18473 -0.58778 -0.80902 Mabsadd L
.25872 .18473 0 -0.38461 Mabsadd L
.25872 .18473 .58779 -0.80902 Mabsadd L
.25872 .18473 .36579 -0.11885 Mabsadd L
.25872 .18473 .95106 .30902 Mabsadd L
.25872 .18473 .22607 .31116 Mabsadd L
.25872 .18473 0 1 Mabsadd L closepath F
.26239 .18162 0 1 Mabsadd m
.26239 .18162 -0.22607 .31116 Mabsadd L
.26239 .18162 -0.95106 .30902 Mabsadd L
.26239 .18162 -0.36579 -0.11885 Mabsadd L
.26239 .18162 -0.58778 -0.80902 Mabsadd L
.26239 .18162 0 -0.38461 Mabsadd L
.26239 .18162 .58779 -0.80902 Mabsadd L
.26239 .18162 .36579 -0.11885 Mabsadd L
.26239 .18162 .95106 .30902 Mabsadd L
.26239 .18162 .22607 .31116 Mabsadd L
.26239 .18162 0 1 Mabsadd L closepath F
.26606 .17881 0 1 Mabsadd m
.26606 .17881 -0.22607 .31116 Mabsadd L
.26606 .17881 -0.95106 .30902 Mabsadd L
.26606 .17881 -0.36579 -0.11885 Mabsadd L
.26606 .17881 -0.58778 -0.80902 Mabsadd L
.26606 .17881 0 -0.38461 Mabsadd L
.26606 .17881 .58779 -0.80902 Mabsadd L
.26606 .17881 .36579 -0.11885 Mabsadd L
.26606 .17881 .95106 .30902 Mabsadd L
.26606 .17881 .22607 .31116 Mabsadd L
.26606 .17881 0 1 Mabsadd L closepath F
.26972 .17617 0 1 Mabsadd m
.26972 .17617 -0.22607 .31116 Mabsadd L
.26972 .17617 -0.95106 .30902 Mabsadd L
.26972 .17617 -0.36579 -0.11885 Mabsadd L
.26972 .17617 -0.58778 -0.80902 Mabsadd L
.26972 .17617 0 -0.38461 Mabsadd L
.26972 .17617 .58779 -0.80902 Mabsadd L
.26972 .17617 .36579 -0.11885 Mabsadd L
.26972 .17617 .95106 .30902 Mabsadd L
.26972 .17617 .22607 .31116 Mabsadd L
.26972 .17617 0 1 Mabsadd L closepath F
.27339 .1737 0 1 Mabsadd m
.27339 .1737 -0.22607 .31116 Mabsadd L
.27339 .1737 -0.95106 .30902 Mabsadd L
.27339 .1737 -0.36579 -0.11885 Mabsadd L
.27339 .1737 -0.58778 -0.80902 Mabsadd L
.27339 .1737 0 -0.38461 Mabsadd L
.27339 .1737 .58779 -0.80902 Mabsadd L
.27339 .1737 .36579 -0.11885 Mabsadd L
.27339 .1737 .95106 .30902 Mabsadd L
.27339 .1737 .22607 .31116 Mabsadd L
.27339 .1737 0 1 Mabsadd L closepath F
.27706 .17114 0 1 Mabsadd m
.27706 .17114 -0.22607 .31116 Mabsadd L
.27706 .17114 -0.95106 .30902 Mabsadd L
.27706 .17114 -0.36579 -0.11885 Mabsadd L
.27706 .17114 -0.58778 -0.80902 Mabsadd L
.27706 .17114 0 -0.38461 Mabsadd L
.27706 .17114 .58779 -0.80902 Mabsadd L
.27706 .17114 .36579 -0.11885 Mabsadd L
.27706 .17114 .95106 .30902 Mabsadd L
.27706 .17114 .22607 .31116 Mabsadd L
.27706 .17114 0 1 Mabsadd L closepath F
.28073 .16889 0 1 Mabsadd m
.28073 .16889 -0.22607 .31116 Mabsadd L
.28073 .16889 -0.95106 .30902 Mabsadd L
.28073 .16889 -0.36579 -0.11885 Mabsadd L
.28073 .16889 -0.58778 -0.80902 Mabsadd L
.28073 .16889 0 -0.38461 Mabsadd L
.28073 .16889 .58779 -0.80902 Mabsadd L
.28073 .16889 .36579 -0.11885 Mabsadd L
.28073 .16889 .95106 .30902 Mabsadd L
.28073 .16889 .22607 .31116 Mabsadd L
.28073 .16889 0 1 Mabsadd L closepath F
.2844 .16606 0 1 Mabsadd m
.2844 .16606 -0.22607 .31116 Mabsadd L
.2844 .16606 -0.95106 .30902 Mabsadd L
.2844 .16606 -0.36579 -0.11885 Mabsadd L
.2844 .16606 -0.58778 -0.80902 Mabsadd L
.2844 .16606 0 -0.38461 Mabsadd L
.2844 .16606 .58779 -0.80902 Mabsadd L
.2844 .16606 .36579 -0.11885 Mabsadd L
.2844 .16606 .95106 .30902 Mabsadd L
.2844 .16606 .22607 .31116 Mabsadd L
.2844 .16606 0 1 Mabsadd L closepath F
.28807 .16345 0 1 Mabsadd m
.28807 .16345 -0.22607 .31116 Mabsadd L
.28807 .16345 -0.95106 .30902 Mabsadd L
.28807 .16345 -0.36579 -0.11885 Mabsadd L
.28807 .16345 -0.58778 -0.80902 Mabsadd L
.28807 .16345 0 -0.38461 Mabsadd L
.28807 .16345 .58779 -0.80902 Mabsadd L
.28807 .16345 .36579 -0.11885 Mabsadd L
.28807 .16345 .95106 .30902 Mabsadd L
.28807 .16345 .22607 .31116 Mabsadd L
.28807 .16345 0 1 Mabsadd L closepath F
.29174 .16107 0 1 Mabsadd m
.29174 .16107 -0.22607 .31116 Mabsadd L
.29174 .16107 -0.95106 .30902 Mabsadd L
.29174 .16107 -0.36579 -0.11885 Mabsadd L
.29174 .16107 -0.58778 -0.80902 Mabsadd L
.29174 .16107 0 -0.38461 Mabsadd L
.29174 .16107 .58779 -0.80902 Mabsadd L
.29174 .16107 .36579 -0.11885 Mabsadd L
.29174 .16107 .95106 .30902 Mabsadd L
.29174 .16107 .22607 .31116 Mabsadd L
.29174 .16107 0 1 Mabsadd L closepath F
.29541 .15881 0 1 Mabsadd m
.29541 .15881 -0.22607 .31116 Mabsadd L
.29541 .15881 -0.95106 .30902 Mabsadd L
.29541 .15881 -0.36579 -0.11885 Mabsadd L
.29541 .15881 -0.58778 -0.80902 Mabsadd L
.29541 .15881 0 -0.38461 Mabsadd L
.29541 .15881 .58779 -0.80902 Mabsadd L
.29541 .15881 .36579 -0.11885 Mabsadd L
.29541 .15881 .95106 .30902 Mabsadd L
.29541 .15881 .22607 .31116 Mabsadd L
.29541 .15881 0 1 Mabsadd L closepath F
.29908 .15688 0 1 Mabsadd m
.29908 .15688 -0.22607 .31116 Mabsadd L
.29908 .15688 -0.95106 .30902 Mabsadd L
.29908 .15688 -0.36579 -0.11885 Mabsadd L
.29908 .15688 -0.58778 -0.80902 Mabsadd L
.29908 .15688 0 -0.38461 Mabsadd L
.29908 .15688 .58779 -0.80902 Mabsadd L
.29908 .15688 .36579 -0.11885 Mabsadd L
.29908 .15688 .95106 .30902 Mabsadd L
.29908 .15688 .22607 .31116 Mabsadd L
.29908 .15688 0 1 Mabsadd L closepath F
.30275 .15478 0 1 Mabsadd m
.30275 .15478 -0.22607 .31116 Mabsadd L
.30275 .15478 -0.95106 .30902 Mabsadd L
.30275 .15478 -0.36579 -0.11885 Mabsadd L
.30275 .15478 -0.58778 -0.80902 Mabsadd L
.30275 .15478 0 -0.38461 Mabsadd L
.30275 .15478 .58779 -0.80902 Mabsadd L
.30275 .15478 .36579 -0.11885 Mabsadd L
.30275 .15478 .95106 .30902 Mabsadd L
.30275 .15478 .22607 .31116 Mabsadd L
.30275 .15478 0 1 Mabsadd L closepath F
.30642 .15274 0 1 Mabsadd m
.30642 .15274 -0.22607 .31116 Mabsadd L
.30642 .15274 -0.95106 .30902 Mabsadd L
.30642 .15274 -0.36579 -0.11885 Mabsadd L
.30642 .15274 -0.58778 -0.80902 Mabsadd L
.30642 .15274 0 -0.38461 Mabsadd L
.30642 .15274 .58779 -0.80902 Mabsadd L
.30642 .15274 .36579 -0.11885 Mabsadd L
.30642 .15274 .95106 .30902 Mabsadd L
.30642 .15274 .22607 .31116 Mabsadd L
.30642 .15274 0 1 Mabsadd L closepath F
.31009 .15076 0 1 Mabsadd m
.31009 .15076 -0.22607 .31116 Mabsadd L
.31009 .15076 -0.95106 .30902 Mabsadd L
.31009 .15076 -0.36579 -0.11885 Mabsadd L
.31009 .15076 -0.58778 -0.80902 Mabsadd L
.31009 .15076 0 -0.38461 Mabsadd L
.31009 .15076 .58779 -0.80902 Mabsadd L
.31009 .15076 .36579 -0.11885 Mabsadd L
.31009 .15076 .95106 .30902 Mabsadd L
.31009 .15076 .22607 .31116 Mabsadd L
.31009 .15076 0 1 Mabsadd L closepath F
.31376 .1486 0 1 Mabsadd m
.31376 .1486 -0.22607 .31116 Mabsadd L
.31376 .1486 -0.95106 .30902 Mabsadd L
.31376 .1486 -0.36579 -0.11885 Mabsadd L
.31376 .1486 -0.58778 -0.80902 Mabsadd L
.31376 .1486 0 -0.38461 Mabsadd L
.31376 .1486 .58779 -0.80902 Mabsadd L
.31376 .1486 .36579 -0.11885 Mabsadd L
.31376 .1486 .95106 .30902 Mabsadd L
.31376 .1486 .22607 .31116 Mabsadd L
.31376 .1486 0 1 Mabsadd L closepath F
.31743 .14681 0 1 Mabsadd m
.31743 .14681 -0.22607 .31116 Mabsadd L
.31743 .14681 -0.95106 .30902 Mabsadd L
.31743 .14681 -0.36579 -0.11885 Mabsadd L
.31743 .14681 -0.58778 -0.80902 Mabsadd L
.31743 .14681 0 -0.38461 Mabsadd L
.31743 .14681 .58779 -0.80902 Mabsadd L
.31743 .14681 .36579 -0.11885 Mabsadd L
.31743 .14681 .95106 .30902 Mabsadd L
.31743 .14681 .22607 .31116 Mabsadd L
.31743 .14681 0 1 Mabsadd L closepath F
.3211 .14496 0 1 Mabsadd m
.3211 .14496 -0.22607 .31116 Mabsadd L
.3211 .14496 -0.95106 .30902 Mabsadd L
.3211 .14496 -0.36579 -0.11885 Mabsadd L
.3211 .14496 -0.58778 -0.80902 Mabsadd L
.3211 .14496 0 -0.38461 Mabsadd L
.3211 .14496 .58779 -0.80902 Mabsadd L
.3211 .14496 .36579 -0.11885 Mabsadd L
.3211 .14496 .95106 .30902 Mabsadd L
.3211 .14496 .22607 .31116 Mabsadd L
.3211 .14496 0 1 Mabsadd L closepath F
.32477 .14314 0 1 Mabsadd m
.32477 .14314 -0.22607 .31116 Mabsadd L
.32477 .14314 -0.95106 .30902 Mabsadd L
.32477 .14314 -0.36579 -0.11885 Mabsadd L
.32477 .14314 -0.58778 -0.80902 Mabsadd L
.32477 .14314 0 -0.38461 Mabsadd L
.32477 .14314 .58779 -0.80902 Mabsadd L
.32477 .14314 .36579 -0.11885 Mabsadd L
.32477 .14314 .95106 .30902 Mabsadd L
.32477 .14314 .22607 .31116 Mabsadd L
.32477 .14314 0 1 Mabsadd L closepath F
.32844 .14182 0 1 Mabsadd m
.32844 .14182 -0.22607 .31116 Mabsadd L
.32844 .14182 -0.95106 .30902 Mabsadd L
.32844 .14182 -0.36579 -0.11885 Mabsadd L
.32844 .14182 -0.58778 -0.80902 Mabsadd L
.32844 .14182 0 -0.38461 Mabsadd L
.32844 .14182 .58779 -0.80902 Mabsadd L
.32844 .14182 .36579 -0.11885 Mabsadd L
.32844 .14182 .95106 .30902 Mabsadd L
.32844 .14182 .22607 .31116 Mabsadd L
.32844 .14182 0 1 Mabsadd L closepath F
.33211 .13981 0 1 Mabsadd m
.33211 .13981 -0.22607 .31116 Mabsadd L
.33211 .13981 -0.95106 .30902 Mabsadd L
.33211 .13981 -0.36579 -0.11885 Mabsadd L
.33211 .13981 -0.58778 -0.80902 Mabsadd L
.33211 .13981 0 -0.38461 Mabsadd L
.33211 .13981 .58779 -0.80902 Mabsadd L
.33211 .13981 .36579 -0.11885 Mabsadd L
.33211 .13981 .95106 .30902 Mabsadd L
.33211 .13981 .22607 .31116 Mabsadd L
.33211 .13981 0 1 Mabsadd L closepath F
.33578 .13826 0 1 Mabsadd m
.33578 .13826 -0.22607 .31116 Mabsadd L
.33578 .13826 -0.95106 .30902 Mabsadd L
.33578 .13826 -0.36579 -0.11885 Mabsadd L
.33578 .13826 -0.58778 -0.80902 Mabsadd L
.33578 .13826 0 -0.38461 Mabsadd L
.33578 .13826 .58779 -0.80902 Mabsadd L
.33578 .13826 .36579 -0.11885 Mabsadd L
.33578 .13826 .95106 .30902 Mabsadd L
.33578 .13826 .22607 .31116 Mabsadd L
.33578 .13826 0 1 Mabsadd L closepath F
.33945 .13662 0 1 Mabsadd m
.33945 .13662 -0.22607 .31116 Mabsadd L
.33945 .13662 -0.95106 .30902 Mabsadd L
.33945 .13662 -0.36579 -0.11885 Mabsadd L
.33945 .13662 -0.58778 -0.80902 Mabsadd L
.33945 .13662 0 -0.38461 Mabsadd L
.33945 .13662 .58779 -0.80902 Mabsadd L
.33945 .13662 .36579 -0.11885 Mabsadd L
.33945 .13662 .95106 .30902 Mabsadd L
.33945 .13662 .22607 .31116 Mabsadd L
.33945 .13662 0 1 Mabsadd L closepath F
.34312 .1348 0 1 Mabsadd m
.34312 .1348 -0.22607 .31116 Mabsadd L
.34312 .1348 -0.95106 .30902 Mabsadd L
.34312 .1348 -0.36579 -0.11885 Mabsadd L
.34312 .1348 -0.58778 -0.80902 Mabsadd L
.34312 .1348 0 -0.38461 Mabsadd L
.34312 .1348 .58779 -0.80902 Mabsadd L
.34312 .1348 .36579 -0.11885 Mabsadd L
.34312 .1348 .95106 .30902 Mabsadd L
.34312 .1348 .22607 .31116 Mabsadd L
.34312 .1348 0 1 Mabsadd L closepath F
.34679 .133 0 1 Mabsadd m
.34679 .133 -0.22607 .31116 Mabsadd L
.34679 .133 -0.95106 .30902 Mabsadd L
.34679 .133 -0.36579 -0.11885 Mabsadd L
.34679 .133 -0.58778 -0.80902 Mabsadd L
.34679 .133 0 -0.38461 Mabsadd L
.34679 .133 .58779 -0.80902 Mabsadd L
.34679 .133 .36579 -0.11885 Mabsadd L
.34679 .133 .95106 .30902 Mabsadd L
.34679 .133 .22607 .31116 Mabsadd L
.34679 .133 0 1 Mabsadd L closepath F
.35046 .1316 0 1 Mabsadd m
.35046 .1316 -0.22607 .31116 Mabsadd L
.35046 .1316 -0.95106 .30902 Mabsadd L
.35046 .1316 -0.36579 -0.11885 Mabsadd L
.35046 .1316 -0.58778 -0.80902 Mabsadd L
.35046 .1316 0 -0.38461 Mabsadd L
.35046 .1316 .58779 -0.80902 Mabsadd L
.35046 .1316 .36579 -0.11885 Mabsadd L
.35046 .1316 .95106 .30902 Mabsadd L
.35046 .1316 .22607 .31116 Mabsadd L
.35046 .1316 0 1 Mabsadd L closepath F
.35413 .13026 0 1 Mabsadd m
.35413 .13026 -0.22607 .31116 Mabsadd L
.35413 .13026 -0.95106 .30902 Mabsadd L
.35413 .13026 -0.36579 -0.11885 Mabsadd L
.35413 .13026 -0.58778 -0.80902 Mabsadd L
.35413 .13026 0 -0.38461 Mabsadd L
.35413 .13026 .58779 -0.80902 Mabsadd L
.35413 .13026 .36579 -0.11885 Mabsadd L
.35413 .13026 .95106 .30902 Mabsadd L
.35413 .13026 .22607 .31116 Mabsadd L
.35413 .13026 0 1 Mabsadd L closepath F
.3578 .12907 0 1 Mabsadd m
.3578 .12907 -0.22607 .31116 Mabsadd L
.3578 .12907 -0.95106 .30902 Mabsadd L
.3578 .12907 -0.36579 -0.11885 Mabsadd L
.3578 .12907 -0.58778 -0.80902 Mabsadd L
.3578 .12907 0 -0.38461 Mabsadd L
.3578 .12907 .58779 -0.80902 Mabsadd L
.3578 .12907 .36579 -0.11885 Mabsadd L
.3578 .12907 .95106 .30902 Mabsadd L
.3578 .12907 .22607 .31116 Mabsadd L
.3578 .12907 0 1 Mabsadd L closepath F
.36147 .1276 0 1 Mabsadd m
.36147 .1276 -0.22607 .31116 Mabsadd L
.36147 .1276 -0.95106 .30902 Mabsadd L
.36147 .1276 -0.36579 -0.11885 Mabsadd L
.36147 .1276 -0.58778 -0.80902 Mabsadd L
.36147 .1276 0 -0.38461 Mabsadd L
.36147 .1276 .58779 -0.80902 Mabsadd L
.36147 .1276 .36579 -0.11885 Mabsadd L
.36147 .1276 .95106 .30902 Mabsadd L
.36147 .1276 .22607 .31116 Mabsadd L
.36147 .1276 0 1 Mabsadd L closepath F
.36514 .12641 0 1 Mabsadd m
.36514 .12641 -0.22607 .31116 Mabsadd L
.36514 .12641 -0.95106 .30902 Mabsadd L
.36514 .12641 -0.36579 -0.11885 Mabsadd L
.36514 .12641 -0.58778 -0.80902 Mabsadd L
.36514 .12641 0 -0.38461 Mabsadd L
.36514 .12641 .58779 -0.80902 Mabsadd L
.36514 .12641 .36579 -0.11885 Mabsadd L
.36514 .12641 .95106 .30902 Mabsadd L
.36514 .12641 .22607 .31116 Mabsadd L
.36514 .12641 0 1 Mabsadd L closepath F
.36881 .12514 0 1 Mabsadd m
.36881 .12514 -0.22607 .31116 Mabsadd L
.36881 .12514 -0.95106 .30902 Mabsadd L
.36881 .12514 -0.36579 -0.11885 Mabsadd L
.36881 .12514 -0.58778 -0.80902 Mabsadd L
.36881 .12514 0 -0.38461 Mabsadd L
.36881 .12514 .58779 -0.80902 Mabsadd L
.36881 .12514 .36579 -0.11885 Mabsadd L
.36881 .12514 .95106 .30902 Mabsadd L
.36881 .12514 .22607 .31116 Mabsadd L
.36881 .12514 0 1 Mabsadd L closepath F
.37248 .12383 0 1 Mabsadd m
.37248 .12383 -0.22607 .31116 Mabsadd L
.37248 .12383 -0.95106 .30902 Mabsadd L
.37248 .12383 -0.36579 -0.11885 Mabsadd L
.37248 .12383 -0.58778 -0.80902 Mabsadd L
.37248 .12383 0 -0.38461 Mabsadd L
.37248 .12383 .58779 -0.80902 Mabsadd L
.37248 .12383 .36579 -0.11885 Mabsadd L
.37248 .12383 .95106 .30902 Mabsadd L
.37248 .12383 .22607 .31116 Mabsadd L
.37248 .12383 0 1 Mabsadd L closepath F
.37615 .12288 0 1 Mabsadd m
.37615 .12288 -0.22607 .31116 Mabsadd L
.37615 .12288 -0.95106 .30902 Mabsadd L
.37615 .12288 -0.36579 -0.11885 Mabsadd L
.37615 .12288 -0.58778 -0.80902 Mabsadd L
.37615 .12288 0 -0.38461 Mabsadd L
.37615 .12288 .58779 -0.80902 Mabsadd L
.37615 .12288 .36579 -0.11885 Mabsadd L
.37615 .12288 .95106 .30902 Mabsadd L
.37615 .12288 .22607 .31116 Mabsadd L
.37615 .12288 0 1 Mabsadd L closepath F
.37982 .12174 0 1 Mabsadd m
.37982 .12174 -0.22607 .31116 Mabsadd L
.37982 .12174 -0.95106 .30902 Mabsadd L
.37982 .12174 -0.36579 -0.11885 Mabsadd L
.37982 .12174 -0.58778 -0.80902 Mabsadd L
.37982 .12174 0 -0.38461 Mabsadd L
.37982 .12174 .58779 -0.80902 Mabsadd L
.37982 .12174 .36579 -0.11885 Mabsadd L
.37982 .12174 .95106 .30902 Mabsadd L
.37982 .12174 .22607 .31116 Mabsadd L
.37982 .12174 0 1 Mabsadd L closepath F
.38349 .12084 0 1 Mabsadd m
.38349 .12084 -0.22607 .31116 Mabsadd L
.38349 .12084 -0.95106 .30902 Mabsadd L
.38349 .12084 -0.36579 -0.11885 Mabsadd L
.38349 .12084 -0.58778 -0.80902 Mabsadd L
.38349 .12084 0 -0.38461 Mabsadd L
.38349 .12084 .58779 -0.80902 Mabsadd L
.38349 .12084 .36579 -0.11885 Mabsadd L
.38349 .12084 .95106 .30902 Mabsadd L
.38349 .12084 .22607 .31116 Mabsadd L
.38349 .12084 0 1 Mabsadd L closepath F
.38716 .11968 0 1 Mabsadd m
.38716 .11968 -0.22607 .31116 Mabsadd L
.38716 .11968 -0.95106 .30902 Mabsadd L
.38716 .11968 -0.36579 -0.11885 Mabsadd L
.38716 .11968 -0.58778 -0.80902 Mabsadd L
.38716 .11968 0 -0.38461 Mabsadd L
.38716 .11968 .58779 -0.80902 Mabsadd L
.38716 .11968 .36579 -0.11885 Mabsadd L
.38716 .11968 .95106 .30902 Mabsadd L
.38716 .11968 .22607 .31116 Mabsadd L
.38716 .11968 0 1 Mabsadd L closepath F
.39083 .11889 0 1 Mabsadd m
.39083 .11889 -0.22607 .31116 Mabsadd L
.39083 .11889 -0.95106 .30902 Mabsadd L
.39083 .11889 -0.36579 -0.11885 Mabsadd L
.39083 .11889 -0.58778 -0.80902 Mabsadd L
.39083 .11889 0 -0.38461 Mabsadd L
.39083 .11889 .58779 -0.80902 Mabsadd L
.39083 .11889 .36579 -0.11885 Mabsadd L
.39083 .11889 .95106 .30902 Mabsadd L
.39083 .11889 .22607 .31116 Mabsadd L
.39083 .11889 0 1 Mabsadd L closepath F
.3945 .11763 0 1 Mabsadd m
.3945 .11763 -0.22607 .31116 Mabsadd L
.3945 .11763 -0.95106 .30902 Mabsadd L
.3945 .11763 -0.36579 -0.11885 Mabsadd L
.3945 .11763 -0.58778 -0.80902 Mabsadd L
.3945 .11763 0 -0.38461 Mabsadd L
.3945 .11763 .58779 -0.80902 Mabsadd L
.3945 .11763 .36579 -0.11885 Mabsadd L
.3945 .11763 .95106 .30902 Mabsadd L
.3945 .11763 .22607 .31116 Mabsadd L
.3945 .11763 0 1 Mabsadd L closepath F
.39817 .11659 0 1 Mabsadd m
.39817 .11659 -0.22607 .31116 Mabsadd L
.39817 .11659 -0.95106 .30902 Mabsadd L
.39817 .11659 -0.36579 -0.11885 Mabsadd L
.39817 .11659 -0.58778 -0.80902 Mabsadd L
.39817 .11659 0 -0.38461 Mabsadd L
.39817 .11659 .58779 -0.80902 Mabsadd L
.39817 .11659 .36579 -0.11885 Mabsadd L
.39817 .11659 .95106 .30902 Mabsadd L
.39817 .11659 .22607 .31116 Mabsadd L
.39817 .11659 0 1 Mabsadd L closepath F
.40183 .11567 0 1 Mabsadd m
.40183 .11567 -0.22607 .31116 Mabsadd L
.40183 .11567 -0.95106 .30902 Mabsadd L
.40183 .11567 -0.36579 -0.11885 Mabsadd L
.40183 .11567 -0.58778 -0.80902 Mabsadd L
.40183 .11567 0 -0.38461 Mabsadd L
.40183 .11567 .58779 -0.80902 Mabsadd L
.40183 .11567 .36579 -0.11885 Mabsadd L
.40183 .11567 .95106 .30902 Mabsadd L
.40183 .11567 .22607 .31116 Mabsadd L
.40183 .11567 0 1 Mabsadd L closepath F
.4055 .11493 0 1 Mabsadd m
.4055 .11493 -0.22607 .31116 Mabsadd L
.4055 .11493 -0.95106 .30902 Mabsadd L
.4055 .11493 -0.36579 -0.11885 Mabsadd L
.4055 .11493 -0.58778 -0.80902 Mabsadd L
.4055 .11493 0 -0.38461 Mabsadd L
.4055 .11493 .58779 -0.80902 Mabsadd L
.4055 .11493 .36579 -0.11885 Mabsadd L
.4055 .11493 .95106 .30902 Mabsadd L
.4055 .11493 .22607 .31116 Mabsadd L
.4055 .11493 0 1 Mabsadd L closepath F
.40917 .11419 0 1 Mabsadd m
.40917 .11419 -0.22607 .31116 Mabsadd L
.40917 .11419 -0.95106 .30902 Mabsadd L
.40917 .11419 -0.36579 -0.11885 Mabsadd L
.40917 .11419 -0.58778 -0.80902 Mabsadd L
.40917 .11419 0 -0.38461 Mabsadd L
.40917 .11419 .58779 -0.80902 Mabsadd L
.40917 .11419 .36579 -0.11885 Mabsadd L
.40917 .11419 .95106 .30902 Mabsadd L
.40917 .11419 .22607 .31116 Mabsadd L
.40917 .11419 0 1 Mabsadd L closepath F
.41284 .1134 0 1 Mabsadd m
.41284 .1134 -0.22607 .31116 Mabsadd L
.41284 .1134 -0.95106 .30902 Mabsadd L
.41284 .1134 -0.36579 -0.11885 Mabsadd L
.41284 .1134 -0.58778 -0.80902 Mabsadd L
.41284 .1134 0 -0.38461 Mabsadd L
.41284 .1134 .58779 -0.80902 Mabsadd L
.41284 .1134 .36579 -0.11885 Mabsadd L
.41284 .1134 .95106 .30902 Mabsadd L
.41284 .1134 .22607 .31116 Mabsadd L
.41284 .1134 0 1 Mabsadd L closepath F
.41651 .1123 0 1 Mabsadd m
.41651 .1123 -0.22607 .31116 Mabsadd L
.41651 .1123 -0.95106 .30902 Mabsadd L
.41651 .1123 -0.36579 -0.11885 Mabsadd L
.41651 .1123 -0.58778 -0.80902 Mabsadd L
.41651 .1123 0 -0.38461 Mabsadd L
.41651 .1123 .58779 -0.80902 Mabsadd L
.41651 .1123 .36579 -0.11885 Mabsadd L
.41651 .1123 .95106 .30902 Mabsadd L
.41651 .1123 .22607 .31116 Mabsadd L
.41651 .1123 0 1 Mabsadd L closepath F
.42018 .11155 0 1 Mabsadd m
.42018 .11155 -0.22607 .31116 Mabsadd L
.42018 .11155 -0.95106 .30902 Mabsadd L
.42018 .11155 -0.36579 -0.11885 Mabsadd L
.42018 .11155 -0.58778 -0.80902 Mabsadd L
.42018 .11155 0 -0.38461 Mabsadd L
.42018 .11155 .58779 -0.80902 Mabsadd L
.42018 .11155 .36579 -0.11885 Mabsadd L
.42018 .11155 .95106 .30902 Mabsadd L
.42018 .11155 .22607 .31116 Mabsadd L
.42018 .11155 0 1 Mabsadd L closepath F
.42385 .11057 0 1 Mabsadd m
.42385 .11057 -0.22607 .31116 Mabsadd L
.42385 .11057 -0.95106 .30902 Mabsadd L
.42385 .11057 -0.36579 -0.11885 Mabsadd L
.42385 .11057 -0.58778 -0.80902 Mabsadd L
.42385 .11057 0 -0.38461 Mabsadd L
.42385 .11057 .58779 -0.80902 Mabsadd L
.42385 .11057 .36579 -0.11885 Mabsadd L
.42385 .11057 .95106 .30902 Mabsadd L
.42385 .11057 .22607 .31116 Mabsadd L
.42385 .11057 0 1 Mabsadd L closepath F
.42752 .1099 0 1 Mabsadd m
.42752 .1099 -0.22607 .31116 Mabsadd L
.42752 .1099 -0.95106 .30902 Mabsadd L
.42752 .1099 -0.36579 -0.11885 Mabsadd L
.42752 .1099 -0.58778 -0.80902 Mabsadd L
.42752 .1099 0 -0.38461 Mabsadd L
.42752 .1099 .58779 -0.80902 Mabsadd L
.42752 .1099 .36579 -0.11885 Mabsadd L
.42752 .1099 .95106 .30902 Mabsadd L
.42752 .1099 .22607 .31116 Mabsadd L
.42752 .1099 0 1 Mabsadd L closepath F
.43119 .10896 0 1 Mabsadd m
.43119 .10896 -0.22607 .31116 Mabsadd L
.43119 .10896 -0.95106 .30902 Mabsadd L
.43119 .10896 -0.36579 -0.11885 Mabsadd L
.43119 .10896 -0.58778 -0.80902 Mabsadd L
.43119 .10896 0 -0.38461 Mabsadd L
.43119 .10896 .58779 -0.80902 Mabsadd L
.43119 .10896 .36579 -0.11885 Mabsadd L
.43119 .10896 .95106 .30902 Mabsadd L
.43119 .10896 .22607 .31116 Mabsadd L
.43119 .10896 0 1 Mabsadd L closepath F
.43486 .10809 0 1 Mabsadd m
.43486 .10809 -0.22607 .31116 Mabsadd L
.43486 .10809 -0.95106 .30902 Mabsadd L
.43486 .10809 -0.36579 -0.11885 Mabsadd L
.43486 .10809 -0.58778 -0.80902 Mabsadd L
.43486 .10809 0 -0.38461 Mabsadd L
.43486 .10809 .58779 -0.80902 Mabsadd L
.43486 .10809 .36579 -0.11885 Mabsadd L
.43486 .10809 .95106 .30902 Mabsadd L
.43486 .10809 .22607 .31116 Mabsadd L
.43486 .10809 0 1 Mabsadd L closepath F
.43853 .10729 0 1 Mabsadd m
.43853 .10729 -0.22607 .31116 Mabsadd L
.43853 .10729 -0.95106 .30902 Mabsadd L
.43853 .10729 -0.36579 -0.11885 Mabsadd L
.43853 .10729 -0.58778 -0.80902 Mabsadd L
.43853 .10729 0 -0.38461 Mabsadd L
.43853 .10729 .58779 -0.80902 Mabsadd L
.43853 .10729 .36579 -0.11885 Mabsadd L
.43853 .10729 .95106 .30902 Mabsadd L
.43853 .10729 .22607 .31116 Mabsadd L
.43853 .10729 0 1 Mabsadd L closepath F
.4422 .10629 0 1 Mabsadd m
.4422 .10629 -0.22607 .31116 Mabsadd L
.4422 .10629 -0.95106 .30902 Mabsadd L
.4422 .10629 -0.36579 -0.11885 Mabsadd L
.4422 .10629 -0.58778 -0.80902 Mabsadd L
.4422 .10629 0 -0.38461 Mabsadd L
.4422 .10629 .58779 -0.80902 Mabsadd L
.4422 .10629 .36579 -0.11885 Mabsadd L
.4422 .10629 .95106 .30902 Mabsadd L
.4422 .10629 .22607 .31116 Mabsadd L
.4422 .10629 0 1 Mabsadd L closepath F
.44587 .10527 0 1 Mabsadd m
.44587 .10527 -0.22607 .31116 Mabsadd L
.44587 .10527 -0.95106 .30902 Mabsadd L
.44587 .10527 -0.36579 -0.11885 Mabsadd L
.44587 .10527 -0.58778 -0.80902 Mabsadd L
.44587 .10527 0 -0.38461 Mabsadd L
.44587 .10527 .58779 -0.80902 Mabsadd L
.44587 .10527 .36579 -0.11885 Mabsadd L
.44587 .10527 .95106 .30902 Mabsadd L
.44587 .10527 .22607 .31116 Mabsadd L
.44587 .10527 0 1 Mabsadd L closepath F
.44954 .1045 0 1 Mabsadd m
.44954 .1045 -0.22607 .31116 Mabsadd L
.44954 .1045 -0.95106 .30902 Mabsadd L
.44954 .1045 -0.36579 -0.11885 Mabsadd L
.44954 .1045 -0.58778 -0.80902 Mabsadd L
.44954 .1045 0 -0.38461 Mabsadd L
.44954 .1045 .58779 -0.80902 Mabsadd L
.44954 .1045 .36579 -0.11885 Mabsadd L
.44954 .1045 .95106 .30902 Mabsadd L
.44954 .1045 .22607 .31116 Mabsadd L
.44954 .1045 0 1 Mabsadd L closepath F
.45321 .10375 0 1 Mabsadd m
.45321 .10375 -0.22607 .31116 Mabsadd L
.45321 .10375 -0.95106 .30902 Mabsadd L
.45321 .10375 -0.36579 -0.11885 Mabsadd L
.45321 .10375 -0.58778 -0.80902 Mabsadd L
.45321 .10375 0 -0.38461 Mabsadd L
.45321 .10375 .58779 -0.80902 Mabsadd L
.45321 .10375 .36579 -0.11885 Mabsadd L
.45321 .10375 .95106 .30902 Mabsadd L
.45321 .10375 .22607 .31116 Mabsadd L
.45321 .10375 0 1 Mabsadd L closepath F
.45688 .10307 0 1 Mabsadd m
.45688 .10307 -0.22607 .31116 Mabsadd L
.45688 .10307 -0.95106 .30902 Mabsadd L
.45688 .10307 -0.36579 -0.11885 Mabsadd L
.45688 .10307 -0.58778 -0.80902 Mabsadd L
.45688 .10307 0 -0.38461 Mabsadd L
.45688 .10307 .58779 -0.80902 Mabsadd L
.45688 .10307 .36579 -0.11885 Mabsadd L
.45688 .10307 .95106 .30902 Mabsadd L
.45688 .10307 .22607 .31116 Mabsadd L
.45688 .10307 0 1 Mabsadd L closepath F
.46055 .10246 0 1 Mabsadd m
.46055 .10246 -0.22607 .31116 Mabsadd L
.46055 .10246 -0.95106 .30902 Mabsadd L
.46055 .10246 -0.36579 -0.11885 Mabsadd L
.46055 .10246 -0.58778 -0.80902 Mabsadd L
.46055 .10246 0 -0.38461 Mabsadd L
.46055 .10246 .58779 -0.80902 Mabsadd L
.46055 .10246 .36579 -0.11885 Mabsadd L
.46055 .10246 .95106 .30902 Mabsadd L
.46055 .10246 .22607 .31116 Mabsadd L
.46055 .10246 0 1 Mabsadd L closepath F
.46422 .10182 0 1 Mabsadd m
.46422 .10182 -0.22607 .31116 Mabsadd L
.46422 .10182 -0.95106 .30902 Mabsadd L
.46422 .10182 -0.36579 -0.11885 Mabsadd L
.46422 .10182 -0.58778 -0.80902 Mabsadd L
.46422 .10182 0 -0.38461 Mabsadd L
.46422 .10182 .58779 -0.80902 Mabsadd L
.46422 .10182 .36579 -0.11885 Mabsadd L
.46422 .10182 .95106 .30902 Mabsadd L
.46422 .10182 .22607 .31116 Mabsadd L
.46422 .10182 0 1 Mabsadd L closepath F
.46789 .10104 0 1 Mabsadd m
.46789 .10104 -0.22607 .31116 Mabsadd L
.46789 .10104 -0.95106 .30902 Mabsadd L
.46789 .10104 -0.36579 -0.11885 Mabsadd L
.46789 .10104 -0.58778 -0.80902 Mabsadd L
.46789 .10104 0 -0.38461 Mabsadd L
.46789 .10104 .58779 -0.80902 Mabsadd L
.46789 .10104 .36579 -0.11885 Mabsadd L
.46789 .10104 .95106 .30902 Mabsadd L
.46789 .10104 .22607 .31116 Mabsadd L
.46789 .10104 0 1 Mabsadd L closepath F
.47156 .10046 0 1 Mabsadd m
.47156 .10046 -0.22607 .31116 Mabsadd L
.47156 .10046 -0.95106 .30902 Mabsadd L
.47156 .10046 -0.36579 -0.11885 Mabsadd L
.47156 .10046 -0.58778 -0.80902 Mabsadd L
.47156 .10046 0 -0.38461 Mabsadd L
.47156 .10046 .58779 -0.80902 Mabsadd L
.47156 .10046 .36579 -0.11885 Mabsadd L
.47156 .10046 .95106 .30902 Mabsadd L
.47156 .10046 .22607 .31116 Mabsadd L
.47156 .10046 0 1 Mabsadd L closepath F
.47523 .09991 0 1 Mabsadd m
.47523 .09991 -0.22607 .31116 Mabsadd L
.47523 .09991 -0.95106 .30902 Mabsadd L
.47523 .09991 -0.36579 -0.11885 Mabsadd L
.47523 .09991 -0.58778 -0.80902 Mabsadd L
.47523 .09991 0 -0.38461 Mabsadd L
.47523 .09991 .58779 -0.80902 Mabsadd L
.47523 .09991 .36579 -0.11885 Mabsadd L
.47523 .09991 .95106 .30902 Mabsadd L
.47523 .09991 .22607 .31116 Mabsadd L
.47523 .09991 0 1 Mabsadd L closepath F
.4789 .09927 0 1 Mabsadd m
.4789 .09927 -0.22607 .31116 Mabsadd L
.4789 .09927 -0.95106 .30902 Mabsadd L
.4789 .09927 -0.36579 -0.11885 Mabsadd L
.4789 .09927 -0.58778 -0.80902 Mabsadd L
.4789 .09927 0 -0.38461 Mabsadd L
.4789 .09927 .58779 -0.80902 Mabsadd L
.4789 .09927 .36579 -0.11885 Mabsadd L
.4789 .09927 .95106 .30902 Mabsadd L
.4789 .09927 .22607 .31116 Mabsadd L
.4789 .09927 0 1 Mabsadd L closepath F
.48257 .09885 0 1 Mabsadd m
.48257 .09885 -0.22607 .31116 Mabsadd L
.48257 .09885 -0.95106 .30902 Mabsadd L
.48257 .09885 -0.36579 -0.11885 Mabsadd L
.48257 .09885 -0.58778 -0.80902 Mabsadd L
.48257 .09885 0 -0.38461 Mabsadd L
.48257 .09885 .58779 -0.80902 Mabsadd L
.48257 .09885 .36579 -0.11885 Mabsadd L
.48257 .09885 .95106 .30902 Mabsadd L
.48257 .09885 .22607 .31116 Mabsadd L
.48257 .09885 0 1 Mabsadd L closepath F
.48624 .09829 0 1 Mabsadd m
.48624 .09829 -0.22607 .31116 Mabsadd L
.48624 .09829 -0.95106 .30902 Mabsadd L
.48624 .09829 -0.36579 -0.11885 Mabsadd L
.48624 .09829 -0.58778 -0.80902 Mabsadd L
.48624 .09829 0 -0.38461 Mabsadd L
.48624 .09829 .58779 -0.80902 Mabsadd L
.48624 .09829 .36579 -0.11885 Mabsadd L
.48624 .09829 .95106 .30902 Mabsadd L
.48624 .09829 .22607 .31116 Mabsadd L
.48624 .09829 0 1 Mabsadd L closepath F
.48991 .09782 0 1 Mabsadd m
.48991 .09782 -0.22607 .31116 Mabsadd L
.48991 .09782 -0.95106 .30902 Mabsadd L
.48991 .09782 -0.36579 -0.11885 Mabsadd L
.48991 .09782 -0.58778 -0.80902 Mabsadd L
.48991 .09782 0 -0.38461 Mabsadd L
.48991 .09782 .58779 -0.80902 Mabsadd L
.48991 .09782 .36579 -0.11885 Mabsadd L
.48991 .09782 .95106 .30902 Mabsadd L
.48991 .09782 .22607 .31116 Mabsadd L
.48991 .09782 0 1 Mabsadd L closepath F
.49358 .09727 0 1 Mabsadd m
.49358 .09727 -0.22607 .31116 Mabsadd L
.49358 .09727 -0.95106 .30902 Mabsadd L
.49358 .09727 -0.36579 -0.11885 Mabsadd L
.49358 .09727 -0.58778 -0.80902 Mabsadd L
.49358 .09727 0 -0.38461 Mabsadd L
.49358 .09727 .58779 -0.80902 Mabsadd L
.49358 .09727 .36579 -0.11885 Mabsadd L
.49358 .09727 .95106 .30902 Mabsadd L
.49358 .09727 .22607 .31116 Mabsadd L
.49358 .09727 0 1 Mabsadd L closepath F
.49725 .09674 0 1 Mabsadd m
.49725 .09674 -0.22607 .31116 Mabsadd L
.49725 .09674 -0.95106 .30902 Mabsadd L
.49725 .09674 -0.36579 -0.11885 Mabsadd L
.49725 .09674 -0.58778 -0.80902 Mabsadd L
.49725 .09674 0 -0.38461 Mabsadd L
.49725 .09674 .58779 -0.80902 Mabsadd L
.49725 .09674 .36579 -0.11885 Mabsadd L
.49725 .09674 .95106 .30902 Mabsadd L
.49725 .09674 .22607 .31116 Mabsadd L
.49725 .09674 0 1 Mabsadd L closepath F
.50092 .09625 0 1 Mabsadd m
.50092 .09625 -0.22607 .31116 Mabsadd L
.50092 .09625 -0.95106 .30902 Mabsadd L
.50092 .09625 -0.36579 -0.11885 Mabsadd L
.50092 .09625 -0.58778 -0.80902 Mabsadd L
.50092 .09625 0 -0.38461 Mabsadd L
.50092 .09625 .58779 -0.80902 Mabsadd L
.50092 .09625 .36579 -0.11885 Mabsadd L
.50092 .09625 .95106 .30902 Mabsadd L
.50092 .09625 .22607 .31116 Mabsadd L
.50092 .09625 0 1 Mabsadd L closepath F
.50459 .09559 0 1 Mabsadd m
.50459 .09559 -0.22607 .31116 Mabsadd L
.50459 .09559 -0.95106 .30902 Mabsadd L
.50459 .09559 -0.36579 -0.11885 Mabsadd L
.50459 .09559 -0.58778 -0.80902 Mabsadd L
.50459 .09559 0 -0.38461 Mabsadd L
.50459 .09559 .58779 -0.80902 Mabsadd L
.50459 .09559 .36579 -0.11885 Mabsadd L
.50459 .09559 .95106 .30902 Mabsadd L
.50459 .09559 .22607 .31116 Mabsadd L
.50459 .09559 0 1 Mabsadd L closepath F
.50826 .09507 0 1 Mabsadd m
.50826 .09507 -0.22607 .31116 Mabsadd L
.50826 .09507 -0.95106 .30902 Mabsadd L
.50826 .09507 -0.36579 -0.11885 Mabsadd L
.50826 .09507 -0.58778 -0.80902 Mabsadd L
.50826 .09507 0 -0.38461 Mabsadd L
.50826 .09507 .58779 -0.80902 Mabsadd L
.50826 .09507 .36579 -0.11885 Mabsadd L
.50826 .09507 .95106 .30902 Mabsadd L
.50826 .09507 .22607 .31116 Mabsadd L
.50826 .09507 0 1 Mabsadd L closepath F
.51193 .09468 0 1 Mabsadd m
.51193 .09468 -0.22607 .31116 Mabsadd L
.51193 .09468 -0.95106 .30902 Mabsadd L
.51193 .09468 -0.36579 -0.11885 Mabsadd L
.51193 .09468 -0.58778 -0.80902 Mabsadd L
.51193 .09468 0 -0.38461 Mabsadd L
.51193 .09468 .58779 -0.80902 Mabsadd L
.51193 .09468 .36579 -0.11885 Mabsadd L
.51193 .09468 .95106 .30902 Mabsadd L
.51193 .09468 .22607 .31116 Mabsadd L
.51193 .09468 0 1 Mabsadd L closepath F
.5156 .09442 0 1 Mabsadd m
.5156 .09442 -0.22607 .31116 Mabsadd L
.5156 .09442 -0.95106 .30902 Mabsadd L
.5156 .09442 -0.36579 -0.11885 Mabsadd L
.5156 .09442 -0.58778 -0.80902 Mabsadd L
.5156 .09442 0 -0.38461 Mabsadd L
.5156 .09442 .58779 -0.80902 Mabsadd L
.5156 .09442 .36579 -0.11885 Mabsadd L
.5156 .09442 .95106 .30902 Mabsadd L
.5156 .09442 .22607 .31116 Mabsadd L
.5156 .09442 0 1 Mabsadd L closepath F
.51927 .09411 0 1 Mabsadd m
.51927 .09411 -0.22607 .31116 Mabsadd L
.51927 .09411 -0.95106 .30902 Mabsadd L
.51927 .09411 -0.36579 -0.11885 Mabsadd L
.51927 .09411 -0.58778 -0.80902 Mabsadd L
.51927 .09411 0 -0.38461 Mabsadd L
.51927 .09411 .58779 -0.80902 Mabsadd L
.51927 .09411 .36579 -0.11885 Mabsadd L
.51927 .09411 .95106 .30902 Mabsadd L
.51927 .09411 .22607 .31116 Mabsadd L
.51927 .09411 0 1 Mabsadd L closepath F
.52294 .09373 0 1 Mabsadd m
.52294 .09373 -0.22607 .31116 Mabsadd L
.52294 .09373 -0.95106 .30902 Mabsadd L
.52294 .09373 -0.36579 -0.11885 Mabsadd L
.52294 .09373 -0.58778 -0.80902 Mabsadd L
.52294 .09373 0 -0.38461 Mabsadd L
.52294 .09373 .58779 -0.80902 Mabsadd L
.52294 .09373 .36579 -0.11885 Mabsadd L
.52294 .09373 .95106 .30902 Mabsadd L
.52294 .09373 .22607 .31116 Mabsadd L
.52294 .09373 0 1 Mabsadd L closepath F
.52661 .09344 0 1 Mabsadd m
.52661 .09344 -0.22607 .31116 Mabsadd L
.52661 .09344 -0.95106 .30902 Mabsadd L
.52661 .09344 -0.36579 -0.11885 Mabsadd L
.52661 .09344 -0.58778 -0.80902 Mabsadd L
.52661 .09344 0 -0.38461 Mabsadd L
.52661 .09344 .58779 -0.80902 Mabsadd L
.52661 .09344 .36579 -0.11885 Mabsadd L
.52661 .09344 .95106 .30902 Mabsadd L
.52661 .09344 .22607 .31116 Mabsadd L
.52661 .09344 0 1 Mabsadd L closepath F
.53028 .09292 0 1 Mabsadd m
.53028 .09292 -0.22607 .31116 Mabsadd L
.53028 .09292 -0.95106 .30902 Mabsadd L
.53028 .09292 -0.36579 -0.11885 Mabsadd L
.53028 .09292 -0.58778 -0.80902 Mabsadd L
.53028 .09292 0 -0.38461 Mabsadd L
.53028 .09292 .58779 -0.80902 Mabsadd L
.53028 .09292 .36579 -0.11885 Mabsadd L
.53028 .09292 .95106 .30902 Mabsadd L
.53028 .09292 .22607 .31116 Mabsadd L
.53028 .09292 0 1 Mabsadd L closepath F
.53394 .09252 0 1 Mabsadd m
.53394 .09252 -0.22607 .31116 Mabsadd L
.53394 .09252 -0.95106 .30902 Mabsadd L
.53394 .09252 -0.36579 -0.11885 Mabsadd L
.53394 .09252 -0.58778 -0.80902 Mabsadd L
.53394 .09252 0 -0.38461 Mabsadd L
.53394 .09252 .58779 -0.80902 Mabsadd L
.53394 .09252 .36579 -0.11885 Mabsadd L
.53394 .09252 .95106 .30902 Mabsadd L
.53394 .09252 .22607 .31116 Mabsadd L
.53394 .09252 0 1 Mabsadd L closepath F
.53761 .09241 0 1 Mabsadd m
.53761 .09241 -0.22607 .31116 Mabsadd L
.53761 .09241 -0.95106 .30902 Mabsadd L
.53761 .09241 -0.36579 -0.11885 Mabsadd L
.53761 .09241 -0.58778 -0.80902 Mabsadd L
.53761 .09241 0 -0.38461 Mabsadd L
.53761 .09241 .58779 -0.80902 Mabsadd L
.53761 .09241 .36579 -0.11885 Mabsadd L
.53761 .09241 .95106 .30902 Mabsadd L
.53761 .09241 .22607 .31116 Mabsadd L
.53761 .09241 0 1 Mabsadd L closepath F
.54128 .09218 0 1 Mabsadd m
.54128 .09218 -0.22607 .31116 Mabsadd L
.54128 .09218 -0.95106 .30902 Mabsadd L
.54128 .09218 -0.36579 -0.11885 Mabsadd L
.54128 .09218 -0.58778 -0.80902 Mabsadd L
.54128 .09218 0 -0.38461 Mabsadd L
.54128 .09218 .58779 -0.80902 Mabsadd L
.54128 .09218 .36579 -0.11885 Mabsadd L
.54128 .09218 .95106 .30902 Mabsadd L
.54128 .09218 .22607 .31116 Mabsadd L
.54128 .09218 0 1 Mabsadd L closepath F
.54495 .09184 0 1 Mabsadd m
.54495 .09184 -0.22607 .31116 Mabsadd L
.54495 .09184 -0.95106 .30902 Mabsadd L
.54495 .09184 -0.36579 -0.11885 Mabsadd L
.54495 .09184 -0.58778 -0.80902 Mabsadd L
.54495 .09184 0 -0.38461 Mabsadd L
.54495 .09184 .58779 -0.80902 Mabsadd L
.54495 .09184 .36579 -0.11885 Mabsadd L
.54495 .09184 .95106 .30902 Mabsadd L
.54495 .09184 .22607 .31116 Mabsadd L
.54495 .09184 0 1 Mabsadd L closepath F
.54862 .09153 0 1 Mabsadd m
.54862 .09153 -0.22607 .31116 Mabsadd L
.54862 .09153 -0.95106 .30902 Mabsadd L
.54862 .09153 -0.36579 -0.11885 Mabsadd L
.54862 .09153 -0.58778 -0.80902 Mabsadd L
.54862 .09153 0 -0.38461 Mabsadd L
.54862 .09153 .58779 -0.80902 Mabsadd L
.54862 .09153 .36579 -0.11885 Mabsadd L
.54862 .09153 .95106 .30902 Mabsadd L
.54862 .09153 .22607 .31116 Mabsadd L
.54862 .09153 0 1 Mabsadd L closepath F
.55229 .09128 0 1 Mabsadd m
.55229 .09128 -0.22607 .31116 Mabsadd L
.55229 .09128 -0.95106 .30902 Mabsadd L
.55229 .09128 -0.36579 -0.11885 Mabsadd L
.55229 .09128 -0.58778 -0.80902 Mabsadd L
.55229 .09128 0 -0.38461 Mabsadd L
.55229 .09128 .58779 -0.80902 Mabsadd L
.55229 .09128 .36579 -0.11885 Mabsadd L
.55229 .09128 .95106 .30902 Mabsadd L
.55229 .09128 .22607 .31116 Mabsadd L
.55229 .09128 0 1 Mabsadd L closepath F
.55596 .09102 0 1 Mabsadd m
.55596 .09102 -0.22607 .31116 Mabsadd L
.55596 .09102 -0.95106 .30902 Mabsadd L
.55596 .09102 -0.36579 -0.11885 Mabsadd L
.55596 .09102 -0.58778 -0.80902 Mabsadd L
.55596 .09102 0 -0.38461 Mabsadd L
.55596 .09102 .58779 -0.80902 Mabsadd L
.55596 .09102 .36579 -0.11885 Mabsadd L
.55596 .09102 .95106 .30902 Mabsadd L
.55596 .09102 .22607 .31116 Mabsadd L
.55596 .09102 0 1 Mabsadd L closepath F
.55963 .09075 0 1 Mabsadd m
.55963 .09075 -0.22607 .31116 Mabsadd L
.55963 .09075 -0.95106 .30902 Mabsadd L
.55963 .09075 -0.36579 -0.11885 Mabsadd L
.55963 .09075 -0.58778 -0.80902 Mabsadd L
.55963 .09075 0 -0.38461 Mabsadd L
.55963 .09075 .58779 -0.80902 Mabsadd L
.55963 .09075 .36579 -0.11885 Mabsadd L
.55963 .09075 .95106 .30902 Mabsadd L
.55963 .09075 .22607 .31116 Mabsadd L
.55963 .09075 0 1 Mabsadd L closepath F
.5633 .09055 0 1 Mabsadd m
.5633 .09055 -0.22607 .31116 Mabsadd L
.5633 .09055 -0.95106 .30902 Mabsadd L
.5633 .09055 -0.36579 -0.11885 Mabsadd L
.5633 .09055 -0.58778 -0.80902 Mabsadd L
.5633 .09055 0 -0.38461 Mabsadd L
.5633 .09055 .58779 -0.80902 Mabsadd L
.5633 .09055 .36579 -0.11885 Mabsadd L
.5633 .09055 .95106 .30902 Mabsadd L
.5633 .09055 .22607 .31116 Mabsadd L
.5633 .09055 0 1 Mabsadd L closepath F
.56697 .09024 0 1 Mabsadd m
.56697 .09024 -0.22607 .31116 Mabsadd L
.56697 .09024 -0.95106 .30902 Mabsadd L
.56697 .09024 -0.36579 -0.11885 Mabsadd L
.56697 .09024 -0.58778 -0.80902 Mabsadd L
.56697 .09024 0 -0.38461 Mabsadd L
.56697 .09024 .58779 -0.80902 Mabsadd L
.56697 .09024 .36579 -0.11885 Mabsadd L
.56697 .09024 .95106 .30902 Mabsadd L
.56697 .09024 .22607 .31116 Mabsadd L
.56697 .09024 0 1 Mabsadd L closepath F
.57064 .08983 0 1 Mabsadd m
.57064 .08983 -0.22607 .31116 Mabsadd L
.57064 .08983 -0.95106 .30902 Mabsadd L
.57064 .08983 -0.36579 -0.11885 Mabsadd L
.57064 .08983 -0.58778 -0.80902 Mabsadd L
.57064 .08983 0 -0.38461 Mabsadd L
.57064 .08983 .58779 -0.80902 Mabsadd L
.57064 .08983 .36579 -0.11885 Mabsadd L
.57064 .08983 .95106 .30902 Mabsadd L
.57064 .08983 .22607 .31116 Mabsadd L
.57064 .08983 0 1 Mabsadd L closepath F
.57431 .08951 0 1 Mabsadd m
.57431 .08951 -0.22607 .31116 Mabsadd L
.57431 .08951 -0.95106 .30902 Mabsadd L
.57431 .08951 -0.36579 -0.11885 Mabsadd L
.57431 .08951 -0.58778 -0.80902 Mabsadd L
.57431 .08951 0 -0.38461 Mabsadd L
.57431 .08951 .58779 -0.80902 Mabsadd L
.57431 .08951 .36579 -0.11885 Mabsadd L
.57431 .08951 .95106 .30902 Mabsadd L
.57431 .08951 .22607 .31116 Mabsadd L
.57431 .08951 0 1 Mabsadd L closepath F
.57798 .08909 0 1 Mabsadd m
.57798 .08909 -0.22607 .31116 Mabsadd L
.57798 .08909 -0.95106 .30902 Mabsadd L
.57798 .08909 -0.36579 -0.11885 Mabsadd L
.57798 .08909 -0.58778 -0.80902 Mabsadd L
.57798 .08909 0 -0.38461 Mabsadd L
.57798 .08909 .58779 -0.80902 Mabsadd L
.57798 .08909 .36579 -0.11885 Mabsadd L
.57798 .08909 .95106 .30902 Mabsadd L
.57798 .08909 .22607 .31116 Mabsadd L
.57798 .08909 0 1 Mabsadd L closepath F
.58165 .08872 0 1 Mabsadd m
.58165 .08872 -0.22607 .31116 Mabsadd L
.58165 .08872 -0.95106 .30902 Mabsadd L
.58165 .08872 -0.36579 -0.11885 Mabsadd L
.58165 .08872 -0.58778 -0.80902 Mabsadd L
.58165 .08872 0 -0.38461 Mabsadd L
.58165 .08872 .58779 -0.80902 Mabsadd L
.58165 .08872 .36579 -0.11885 Mabsadd L
.58165 .08872 .95106 .30902 Mabsadd L
.58165 .08872 .22607 .31116 Mabsadd L
.58165 .08872 0 1 Mabsadd L closepath F
.58532 .08845 0 1 Mabsadd m
.58532 .08845 -0.22607 .31116 Mabsadd L
.58532 .08845 -0.95106 .30902 Mabsadd L
.58532 .08845 -0.36579 -0.11885 Mabsadd L
.58532 .08845 -0.58778 -0.80902 Mabsadd L
.58532 .08845 0 -0.38461 Mabsadd L
.58532 .08845 .58779 -0.80902 Mabsadd L
.58532 .08845 .36579 -0.11885 Mabsadd L
.58532 .08845 .95106 .30902 Mabsadd L
.58532 .08845 .22607 .31116 Mabsadd L
.58532 .08845 0 1 Mabsadd L closepath F
.58899 .08821 0 1 Mabsadd m
.58899 .08821 -0.22607 .31116 Mabsadd L
.58899 .08821 -0.95106 .30902 Mabsadd L
.58899 .08821 -0.36579 -0.11885 Mabsadd L
.58899 .08821 -0.58778 -0.80902 Mabsadd L
.58899 .08821 0 -0.38461 Mabsadd L
.58899 .08821 .58779 -0.80902 Mabsadd L
.58899 .08821 .36579 -0.11885 Mabsadd L
.58899 .08821 .95106 .30902 Mabsadd L
.58899 .08821 .22607 .31116 Mabsadd L
.58899 .08821 0 1 Mabsadd L closepath F
.59266 .08792 0 1 Mabsadd m
.59266 .08792 -0.22607 .31116 Mabsadd L
.59266 .08792 -0.95106 .30902 Mabsadd L
.59266 .08792 -0.36579 -0.11885 Mabsadd L
.59266 .08792 -0.58778 -0.80902 Mabsadd L
.59266 .08792 0 -0.38461 Mabsadd L
.59266 .08792 .58779 -0.80902 Mabsadd L
.59266 .08792 .36579 -0.11885 Mabsadd L
.59266 .08792 .95106 .30902 Mabsadd L
.59266 .08792 .22607 .31116 Mabsadd L
.59266 .08792 0 1 Mabsadd L closepath F
.59633 .08767 0 1 Mabsadd m
.59633 .08767 -0.22607 .31116 Mabsadd L
.59633 .08767 -0.95106 .30902 Mabsadd L
.59633 .08767 -0.36579 -0.11885 Mabsadd L
.59633 .08767 -0.58778 -0.80902 Mabsadd L
.59633 .08767 0 -0.38461 Mabsadd L
.59633 .08767 .58779 -0.80902 Mabsadd L
.59633 .08767 .36579 -0.11885 Mabsadd L
.59633 .08767 .95106 .30902 Mabsadd L
.59633 .08767 .22607 .31116 Mabsadd L
.59633 .08767 0 1 Mabsadd L closepath F
.6 .0873 0 1 Mabsadd m
.6 .0873 -0.22607 .31116 Mabsadd L
.6 .0873 -0.95106 .30902 Mabsadd L
.6 .0873 -0.36579 -0.11885 Mabsadd L
.6 .0873 -0.58778 -0.80902 Mabsadd L
.6 .0873 0 -0.38461 Mabsadd L
.6 .0873 .58779 -0.80902 Mabsadd L
.6 .0873 .36579 -0.11885 Mabsadd L
.6 .0873 .95106 .30902 Mabsadd L
.6 .0873 .22607 .31116 Mabsadd L
.6 .0873 0 1 Mabsadd L closepath F
.60367 .08694 0 1 Mabsadd m
.60367 .08694 -0.22607 .31116 Mabsadd L
.60367 .08694 -0.95106 .30902 Mabsadd L
.60367 .08694 -0.36579 -0.11885 Mabsadd L
.60367 .08694 -0.58778 -0.80902 Mabsadd L
.60367 .08694 0 -0.38461 Mabsadd L
.60367 .08694 .58779 -0.80902 Mabsadd L
.60367 .08694 .36579 -0.11885 Mabsadd L
.60367 .08694 .95106 .30902 Mabsadd L
.60367 .08694 .22607 .31116 Mabsadd L
.60367 .08694 0 1 Mabsadd L closepath F
.60734 .08673 0 1 Mabsadd m
.60734 .08673 -0.22607 .31116 Mabsadd L
.60734 .08673 -0.95106 .30902 Mabsadd L
.60734 .08673 -0.36579 -0.11885 Mabsadd L
.60734 .08673 -0.58778 -0.80902 Mabsadd L
.60734 .08673 0 -0.38461 Mabsadd L
.60734 .08673 .58779 -0.80902 Mabsadd L
.60734 .08673 .36579 -0.11885 Mabsadd L
.60734 .08673 .95106 .30902 Mabsadd L
.60734 .08673 .22607 .31116 Mabsadd L
.60734 .08673 0 1 Mabsadd L closepath F
.61101 .08653 0 1 Mabsadd m
.61101 .08653 -0.22607 .31116 Mabsadd L
.61101 .08653 -0.95106 .30902 Mabsadd L
.61101 .08653 -0.36579 -0.11885 Mabsadd L
.61101 .08653 -0.58778 -0.80902 Mabsadd L
.61101 .08653 0 -0.38461 Mabsadd L
.61101 .08653 .58779 -0.80902 Mabsadd L
.61101 .08653 .36579 -0.11885 Mabsadd L
.61101 .08653 .95106 .30902 Mabsadd L
.61101 .08653 .22607 .31116 Mabsadd L
.61101 .08653 0 1 Mabsadd L closepath F
.61468 .08644 0 1 Mabsadd m
.61468 .08644 -0.22607 .31116 Mabsadd L
.61468 .08644 -0.95106 .30902 Mabsadd L
.61468 .08644 -0.36579 -0.11885 Mabsadd L
.61468 .08644 -0.58778 -0.80902 Mabsadd L
.61468 .08644 0 -0.38461 Mabsadd L
.61468 .08644 .58779 -0.80902 Mabsadd L
.61468 .08644 .36579 -0.11885 Mabsadd L
.61468 .08644 .95106 .30902 Mabsadd L
.61468 .08644 .22607 .31116 Mabsadd L
.61468 .08644 0 1 Mabsadd L closepath F
.61835 .08623 0 1 Mabsadd m
.61835 .08623 -0.22607 .31116 Mabsadd L
.61835 .08623 -0.95106 .30902 Mabsadd L
.61835 .08623 -0.36579 -0.11885 Mabsadd L
.61835 .08623 -0.58778 -0.80902 Mabsadd L
.61835 .08623 0 -0.38461 Mabsadd L
.61835 .08623 .58779 -0.80902 Mabsadd L
.61835 .08623 .36579 -0.11885 Mabsadd L
.61835 .08623 .95106 .30902 Mabsadd L
.61835 .08623 .22607 .31116 Mabsadd L
.61835 .08623 0 1 Mabsadd L closepath F
.62202 .08602 0 1 Mabsadd m
.62202 .08602 -0.22607 .31116 Mabsadd L
.62202 .08602 -0.95106 .30902 Mabsadd L
.62202 .08602 -0.36579 -0.11885 Mabsadd L
.62202 .08602 -0.58778 -0.80902 Mabsadd L
.62202 .08602 0 -0.38461 Mabsadd L
.62202 .08602 .58779 -0.80902 Mabsadd L
.62202 .08602 .36579 -0.11885 Mabsadd L
.62202 .08602 .95106 .30902 Mabsadd L
.62202 .08602 .22607 .31116 Mabsadd L
.62202 .08602 0 1 Mabsadd L closepath F
.62569 .08583 0 1 Mabsadd m
.62569 .08583 -0.22607 .31116 Mabsadd L
.62569 .08583 -0.95106 .30902 Mabsadd L
.62569 .08583 -0.36579 -0.11885 Mabsadd L
.62569 .08583 -0.58778 -0.80902 Mabsadd L
.62569 .08583 0 -0.38461 Mabsadd L
.62569 .08583 .58779 -0.80902 Mabsadd L
.62569 .08583 .36579 -0.11885 Mabsadd L
.62569 .08583 .95106 .30902 Mabsadd L
.62569 .08583 .22607 .31116 Mabsadd L
.62569 .08583 0 1 Mabsadd L closepath F
.62936 .0857 0 1 Mabsadd m
.62936 .0857 -0.22607 .31116 Mabsadd L
.62936 .0857 -0.95106 .30902 Mabsadd L
.62936 .0857 -0.36579 -0.11885 Mabsadd L
.62936 .0857 -0.58778 -0.80902 Mabsadd L
.62936 .0857 0 -0.38461 Mabsadd L
.62936 .0857 .58779 -0.80902 Mabsadd L
.62936 .0857 .36579 -0.11885 Mabsadd L
.62936 .0857 .95106 .30902 Mabsadd L
.62936 .0857 .22607 .31116 Mabsadd L
.62936 .0857 0 1 Mabsadd L closepath F
.63303 .08563 0 1 Mabsadd m
.63303 .08563 -0.22607 .31116 Mabsadd L
.63303 .08563 -0.95106 .30902 Mabsadd L
.63303 .08563 -0.36579 -0.11885 Mabsadd L
.63303 .08563 -0.58778 -0.80902 Mabsadd L
.63303 .08563 0 -0.38461 Mabsadd L
.63303 .08563 .58779 -0.80902 Mabsadd L
.63303 .08563 .36579 -0.11885 Mabsadd L
.63303 .08563 .95106 .30902 Mabsadd L
.63303 .08563 .22607 .31116 Mabsadd L
.63303 .08563 0 1 Mabsadd L closepath F
.6367 .08543 0 1 Mabsadd m
.6367 .08543 -0.22607 .31116 Mabsadd L
.6367 .08543 -0.95106 .30902 Mabsadd L
.6367 .08543 -0.36579 -0.11885 Mabsadd L
.6367 .08543 -0.58778 -0.80902 Mabsadd L
.6367 .08543 0 -0.38461 Mabsadd L
.6367 .08543 .58779 -0.80902 Mabsadd L
.6367 .08543 .36579 -0.11885 Mabsadd L
.6367 .08543 .95106 .30902 Mabsadd L
.6367 .08543 .22607 .31116 Mabsadd L
.6367 .08543 0 1 Mabsadd L closepath F
.64037 .0853 0 1 Mabsadd m
.64037 .0853 -0.22607 .31116 Mabsadd L
.64037 .0853 -0.95106 .30902 Mabsadd L
.64037 .0853 -0.36579 -0.11885 Mabsadd L
.64037 .0853 -0.58778 -0.80902 Mabsadd L
.64037 .0853 0 -0.38461 Mabsadd L
.64037 .0853 .58779 -0.80902 Mabsadd L
.64037 .0853 .36579 -0.11885 Mabsadd L
.64037 .0853 .95106 .30902 Mabsadd L
.64037 .0853 .22607 .31116 Mabsadd L
.64037 .0853 0 1 Mabsadd L closepath F
.64404 .08511 0 1 Mabsadd m
.64404 .08511 -0.22607 .31116 Mabsadd L
.64404 .08511 -0.95106 .30902 Mabsadd L
.64404 .08511 -0.36579 -0.11885 Mabsadd L
.64404 .08511 -0.58778 -0.80902 Mabsadd L
.64404 .08511 0 -0.38461 Mabsadd L
.64404 .08511 .58779 -0.80902 Mabsadd L
.64404 .08511 .36579 -0.11885 Mabsadd L
.64404 .08511 .95106 .30902 Mabsadd L
.64404 .08511 .22607 .31116 Mabsadd L
.64404 .08511 0 1 Mabsadd L closepath F
.64771 .085 0 1 Mabsadd m
.64771 .085 -0.22607 .31116 Mabsadd L
.64771 .085 -0.95106 .30902 Mabsadd L
.64771 .085 -0.36579 -0.11885 Mabsadd L
.64771 .085 -0.58778 -0.80902 Mabsadd L
.64771 .085 0 -0.38461 Mabsadd L
.64771 .085 .58779 -0.80902 Mabsadd L
.64771 .085 .36579 -0.11885 Mabsadd L
.64771 .085 .95106 .30902 Mabsadd L
.64771 .085 .22607 .31116 Mabsadd L
.64771 .085 0 1 Mabsadd L closepath F
.65138 .08495 0 1 Mabsadd m
.65138 .08495 -0.22607 .31116 Mabsadd L
.65138 .08495 -0.95106 .30902 Mabsadd L
.65138 .08495 -0.36579 -0.11885 Mabsadd L
.65138 .08495 -0.58778 -0.80902 Mabsadd L
.65138 .08495 0 -0.38461 Mabsadd L
.65138 .08495 .58779 -0.80902 Mabsadd L
.65138 .08495 .36579 -0.11885 Mabsadd L
.65138 .08495 .95106 .30902 Mabsadd L
.65138 .08495 .22607 .31116 Mabsadd L
.65138 .08495 0 1 Mabsadd L closepath F
.65505 .08489 0 1 Mabsadd m
.65505 .08489 -0.22607 .31116 Mabsadd L
.65505 .08489 -0.95106 .30902 Mabsadd L
.65505 .08489 -0.36579 -0.11885 Mabsadd L
.65505 .08489 -0.58778 -0.80902 Mabsadd L
.65505 .08489 0 -0.38461 Mabsadd L
.65505 .08489 .58779 -0.80902 Mabsadd L
.65505 .08489 .36579 -0.11885 Mabsadd L
.65505 .08489 .95106 .30902 Mabsadd L
.65505 .08489 .22607 .31116 Mabsadd L
.65505 .08489 0 1 Mabsadd L closepath F
.65872 .08475 0 1 Mabsadd m
.65872 .08475 -0.22607 .31116 Mabsadd L
.65872 .08475 -0.95106 .30902 Mabsadd L
.65872 .08475 -0.36579 -0.11885 Mabsadd L
.65872 .08475 -0.58778 -0.80902 Mabsadd L
.65872 .08475 0 -0.38461 Mabsadd L
.65872 .08475 .58779 -0.80902 Mabsadd L
.65872 .08475 .36579 -0.11885 Mabsadd L
.65872 .08475 .95106 .30902 Mabsadd L
.65872 .08475 .22607 .31116 Mabsadd L
.65872 .08475 0 1 Mabsadd L closepath F
.66239 .08465 0 1 Mabsadd m
.66239 .08465 -0.22607 .31116 Mabsadd L
.66239 .08465 -0.95106 .30902 Mabsadd L
.66239 .08465 -0.36579 -0.11885 Mabsadd L
.66239 .08465 -0.58778 -0.80902 Mabsadd L
.66239 .08465 0 -0.38461 Mabsadd L
.66239 .08465 .58779 -0.80902 Mabsadd L
.66239 .08465 .36579 -0.11885 Mabsadd L
.66239 .08465 .95106 .30902 Mabsadd L
.66239 .08465 .22607 .31116 Mabsadd L
.66239 .08465 0 1 Mabsadd L closepath F
.66606 .0846 0 1 Mabsadd m
.66606 .0846 -0.22607 .31116 Mabsadd L
.66606 .0846 -0.95106 .30902 Mabsadd L
.66606 .0846 -0.36579 -0.11885 Mabsadd L
.66606 .0846 -0.58778 -0.80902 Mabsadd L
.66606 .0846 0 -0.38461 Mabsadd L
.66606 .0846 .58779 -0.80902 Mabsadd L
.66606 .0846 .36579 -0.11885 Mabsadd L
.66606 .0846 .95106 .30902 Mabsadd L
.66606 .0846 .22607 .31116 Mabsadd L
.66606 .0846 0 1 Mabsadd L closepath F
.66972 .08446 0 1 Mabsadd m
.66972 .08446 -0.22607 .31116 Mabsadd L
.66972 .08446 -0.95106 .30902 Mabsadd L
.66972 .08446 -0.36579 -0.11885 Mabsadd L
.66972 .08446 -0.58778 -0.80902 Mabsadd L
.66972 .08446 0 -0.38461 Mabsadd L
.66972 .08446 .58779 -0.80902 Mabsadd L
.66972 .08446 .36579 -0.11885 Mabsadd L
.66972 .08446 .95106 .30902 Mabsadd L
.66972 .08446 .22607 .31116 Mabsadd L
.66972 .08446 0 1 Mabsadd L closepath F
.67339 .08444 0 1 Mabsadd m
.67339 .08444 -0.22607 .31116 Mabsadd L
.67339 .08444 -0.95106 .30902 Mabsadd L
.67339 .08444 -0.36579 -0.11885 Mabsadd L
.67339 .08444 -0.58778 -0.80902 Mabsadd L
.67339 .08444 0 -0.38461 Mabsadd L
.67339 .08444 .58779 -0.80902 Mabsadd L
.67339 .08444 .36579 -0.11885 Mabsadd L
.67339 .08444 .95106 .30902 Mabsadd L
.67339 .08444 .22607 .31116 Mabsadd L
.67339 .08444 0 1 Mabsadd L closepath F
.67706 .08432 0 1 Mabsadd m
.67706 .08432 -0.22607 .31116 Mabsadd L
.67706 .08432 -0.95106 .30902 Mabsadd L
.67706 .08432 -0.36579 -0.11885 Mabsadd L
.67706 .08432 -0.58778 -0.80902 Mabsadd L
.67706 .08432 0 -0.38461 Mabsadd L
.67706 .08432 .58779 -0.80902 Mabsadd L
.67706 .08432 .36579 -0.11885 Mabsadd L
.67706 .08432 .95106 .30902 Mabsadd L
.67706 .08432 .22607 .31116 Mabsadd L
.67706 .08432 0 1 Mabsadd L closepath F
.68073 .08418 0 1 Mabsadd m
.68073 .08418 -0.22607 .31116 Mabsadd L
.68073 .08418 -0.95106 .30902 Mabsadd L
.68073 .08418 -0.36579 -0.11885 Mabsadd L
.68073 .08418 -0.58778 -0.80902 Mabsadd L
.68073 .08418 0 -0.38461 Mabsadd L
.68073 .08418 .58779 -0.80902 Mabsadd L
.68073 .08418 .36579 -0.11885 Mabsadd L
.68073 .08418 .95106 .30902 Mabsadd L
.68073 .08418 .22607 .31116 Mabsadd L
.68073 .08418 0 1 Mabsadd L closepath F
.6844 .08416 0 1 Mabsadd m
.6844 .08416 -0.22607 .31116 Mabsadd L
.6844 .08416 -0.95106 .30902 Mabsadd L
.6844 .08416 -0.36579 -0.11885 Mabsadd L
.6844 .08416 -0.58778 -0.80902 Mabsadd L
.6844 .08416 0 -0.38461 Mabsadd L
.6844 .08416 .58779 -0.80902 Mabsadd L
.6844 .08416 .36579 -0.11885 Mabsadd L
.6844 .08416 .95106 .30902 Mabsadd L
.6844 .08416 .22607 .31116 Mabsadd L
.6844 .08416 0 1 Mabsadd L closepath F
.68807 .08406 0 1 Mabsadd m
.68807 .08406 -0.22607 .31116 Mabsadd L
.68807 .08406 -0.95106 .30902 Mabsadd L
.68807 .08406 -0.36579 -0.11885 Mabsadd L
.68807 .08406 -0.58778 -0.80902 Mabsadd L
.68807 .08406 0 -0.38461 Mabsadd L
.68807 .08406 .58779 -0.80902 Mabsadd L
.68807 .08406 .36579 -0.11885 Mabsadd L
.68807 .08406 .95106 .30902 Mabsadd L
.68807 .08406 .22607 .31116 Mabsadd L
.68807 .08406 0 1 Mabsadd L closepath F
.69174 .0839 0 1 Mabsadd m
.69174 .0839 -0.22607 .31116 Mabsadd L
.69174 .0839 -0.95106 .30902 Mabsadd L
.69174 .0839 -0.36579 -0.11885 Mabsadd L
.69174 .0839 -0.58778 -0.80902 Mabsadd L
.69174 .0839 0 -0.38461 Mabsadd L
.69174 .0839 .58779 -0.80902 Mabsadd L
.69174 .0839 .36579 -0.11885 Mabsadd L
.69174 .0839 .95106 .30902 Mabsadd L
.69174 .0839 .22607 .31116 Mabsadd L
.69174 .0839 0 1 Mabsadd L closepath F
.69541 .08384 0 1 Mabsadd m
.69541 .08384 -0.22607 .31116 Mabsadd L
.69541 .08384 -0.95106 .30902 Mabsadd L
.69541 .08384 -0.36579 -0.11885 Mabsadd L
.69541 .08384 -0.58778 -0.80902 Mabsadd L
.69541 .08384 0 -0.38461 Mabsadd L
.69541 .08384 .58779 -0.80902 Mabsadd L
.69541 .08384 .36579 -0.11885 Mabsadd L
.69541 .08384 .95106 .30902 Mabsadd L
.69541 .08384 .22607 .31116 Mabsadd L
.69541 .08384 0 1 Mabsadd L closepath F
.69908 .08372 0 1 Mabsadd m
.69908 .08372 -0.22607 .31116 Mabsadd L
.69908 .08372 -0.95106 .30902 Mabsadd L
.69908 .08372 -0.36579 -0.11885 Mabsadd L
.69908 .08372 -0.58778 -0.80902 Mabsadd L
.69908 .08372 0 -0.38461 Mabsadd L
.69908 .08372 .58779 -0.80902 Mabsadd L
.69908 .08372 .36579 -0.11885 Mabsadd L
.69908 .08372 .95106 .30902 Mabsadd L
.69908 .08372 .22607 .31116 Mabsadd L
.69908 .08372 0 1 Mabsadd L closepath F
.70275 .08356 0 1 Mabsadd m
.70275 .08356 -0.22607 .31116 Mabsadd L
.70275 .08356 -0.95106 .30902 Mabsadd L
.70275 .08356 -0.36579 -0.11885 Mabsadd L
.70275 .08356 -0.58778 -0.80902 Mabsadd L
.70275 .08356 0 -0.38461 Mabsadd L
.70275 .08356 .58779 -0.80902 Mabsadd L
.70275 .08356 .36579 -0.11885 Mabsadd L
.70275 .08356 .95106 .30902 Mabsadd L
.70275 .08356 .22607 .31116 Mabsadd L
.70275 .08356 0 1 Mabsadd L closepath F
.70642 .08344 0 1 Mabsadd m
.70642 .08344 -0.22607 .31116 Mabsadd L
.70642 .08344 -0.95106 .30902 Mabsadd L
.70642 .08344 -0.36579 -0.11885 Mabsadd L
.70642 .08344 -0.58778 -0.80902 Mabsadd L
.70642 .08344 0 -0.38461 Mabsadd L
.70642 .08344 .58779 -0.80902 Mabsadd L
.70642 .08344 .36579 -0.11885 Mabsadd L
.70642 .08344 .95106 .30902 Mabsadd L
.70642 .08344 .22607 .31116 Mabsadd L
.70642 .08344 0 1 Mabsadd L closepath F
.71009 .08328 0 1 Mabsadd m
.71009 .08328 -0.22607 .31116 Mabsadd L
.71009 .08328 -0.95106 .30902 Mabsadd L
.71009 .08328 -0.36579 -0.11885 Mabsadd L
.71009 .08328 -0.58778 -0.80902 Mabsadd L
.71009 .08328 0 -0.38461 Mabsadd L
.71009 .08328 .58779 -0.80902 Mabsadd L
.71009 .08328 .36579 -0.11885 Mabsadd L
.71009 .08328 .95106 .30902 Mabsadd L
.71009 .08328 .22607 .31116 Mabsadd L
.71009 .08328 0 1 Mabsadd L closepath F
.71376 .08315 0 1 Mabsadd m
.71376 .08315 -0.22607 .31116 Mabsadd L
.71376 .08315 -0.95106 .30902 Mabsadd L
.71376 .08315 -0.36579 -0.11885 Mabsadd L
.71376 .08315 -0.58778 -0.80902 Mabsadd L
.71376 .08315 0 -0.38461 Mabsadd L
.71376 .08315 .58779 -0.80902 Mabsadd L
.71376 .08315 .36579 -0.11885 Mabsadd L
.71376 .08315 .95106 .30902 Mabsadd L
.71376 .08315 .22607 .31116 Mabsadd L
.71376 .08315 0 1 Mabsadd L closepath F
.71743 .0832 0 1 Mabsadd m
.71743 .0832 -0.22607 .31116 Mabsadd L
.71743 .0832 -0.95106 .30902 Mabsadd L
.71743 .0832 -0.36579 -0.11885 Mabsadd L
.71743 .0832 -0.58778 -0.80902 Mabsadd L
.71743 .0832 0 -0.38461 Mabsadd L
.71743 .0832 .58779 -0.80902 Mabsadd L
.71743 .0832 .36579 -0.11885 Mabsadd L
.71743 .0832 .95106 .30902 Mabsadd L
.71743 .0832 .22607 .31116 Mabsadd L
.71743 .0832 0 1 Mabsadd L closepath F
.7211 .08313 0 1 Mabsadd m
.7211 .08313 -0.22607 .31116 Mabsadd L
.7211 .08313 -0.95106 .30902 Mabsadd L
.7211 .08313 -0.36579 -0.11885 Mabsadd L
.7211 .08313 -0.58778 -0.80902 Mabsadd L
.7211 .08313 0 -0.38461 Mabsadd L
.7211 .08313 .58779 -0.80902 Mabsadd L
.7211 .08313 .36579 -0.11885 Mabsadd L
.7211 .08313 .95106 .30902 Mabsadd L
.7211 .08313 .22607 .31116 Mabsadd L
.7211 .08313 0 1 Mabsadd L closepath F
.72477 .08306 0 1 Mabsadd m
.72477 .08306 -0.22607 .31116 Mabsadd L
.72477 .08306 -0.95106 .30902 Mabsadd L
.72477 .08306 -0.36579 -0.11885 Mabsadd L
.72477 .08306 -0.58778 -0.80902 Mabsadd L
.72477 .08306 0 -0.38461 Mabsadd L
.72477 .08306 .58779 -0.80902 Mabsadd L
.72477 .08306 .36579 -0.11885 Mabsadd L
.72477 .08306 .95106 .30902 Mabsadd L
.72477 .08306 .22607 .31116 Mabsadd L
.72477 .08306 0 1 Mabsadd L closepath F
.72844 .08298 0 1 Mabsadd m
.72844 .08298 -0.22607 .31116 Mabsadd L
.72844 .08298 -0.95106 .30902 Mabsadd L
.72844 .08298 -0.36579 -0.11885 Mabsadd L
.72844 .08298 -0.58778 -0.80902 Mabsadd L
.72844 .08298 0 -0.38461 Mabsadd L
.72844 .08298 .58779 -0.80902 Mabsadd L
.72844 .08298 .36579 -0.11885 Mabsadd L
.72844 .08298 .95106 .30902 Mabsadd L
.72844 .08298 .22607 .31116 Mabsadd L
.72844 .08298 0 1 Mabsadd L closepath F
.73211 .08298 0 1 Mabsadd m
.73211 .08298 -0.22607 .31116 Mabsadd L
.73211 .08298 -0.95106 .30902 Mabsadd L
.73211 .08298 -0.36579 -0.11885 Mabsadd L
.73211 .08298 -0.58778 -0.80902 Mabsadd L
.73211 .08298 0 -0.38461 Mabsadd L
.73211 .08298 .58779 -0.80902 Mabsadd L
.73211 .08298 .36579 -0.11885 Mabsadd L
.73211 .08298 .95106 .30902 Mabsadd L
.73211 .08298 .22607 .31116 Mabsadd L
.73211 .08298 0 1 Mabsadd L closepath F
.73578 .08287 0 1 Mabsadd m
.73578 .08287 -0.22607 .31116 Mabsadd L
.73578 .08287 -0.95106 .30902 Mabsadd L
.73578 .08287 -0.36579 -0.11885 Mabsadd L
.73578 .08287 -0.58778 -0.80902 Mabsadd L
.73578 .08287 0 -0.38461 Mabsadd L
.73578 .08287 .58779 -0.80902 Mabsadd L
.73578 .08287 .36579 -0.11885 Mabsadd L
.73578 .08287 .95106 .30902 Mabsadd L
.73578 .08287 .22607 .31116 Mabsadd L
.73578 .08287 0 1 Mabsadd L closepath F
.73945 .08277 0 1 Mabsadd m
.73945 .08277 -0.22607 .31116 Mabsadd L
.73945 .08277 -0.95106 .30902 Mabsadd L
.73945 .08277 -0.36579 -0.11885 Mabsadd L
.73945 .08277 -0.58778 -0.80902 Mabsadd L
.73945 .08277 0 -0.38461 Mabsadd L
.73945 .08277 .58779 -0.80902 Mabsadd L
.73945 .08277 .36579 -0.11885 Mabsadd L
.73945 .08277 .95106 .30902 Mabsadd L
.73945 .08277 .22607 .31116 Mabsadd L
.73945 .08277 0 1 Mabsadd L closepath F
.74312 .08267 0 1 Mabsadd m
.74312 .08267 -0.22607 .31116 Mabsadd L
.74312 .08267 -0.95106 .30902 Mabsadd L
.74312 .08267 -0.36579 -0.11885 Mabsadd L
.74312 .08267 -0.58778 -0.80902 Mabsadd L
.74312 .08267 0 -0.38461 Mabsadd L
.74312 .08267 .58779 -0.80902 Mabsadd L
.74312 .08267 .36579 -0.11885 Mabsadd L
.74312 .08267 .95106 .30902 Mabsadd L
.74312 .08267 .22607 .31116 Mabsadd L
.74312 .08267 0 1 Mabsadd L closepath F
.74679 .08256 0 1 Mabsadd m
.74679 .08256 -0.22607 .31116 Mabsadd L
.74679 .08256 -0.95106 .30902 Mabsadd L
.74679 .08256 -0.36579 -0.11885 Mabsadd L
.74679 .08256 -0.58778 -0.80902 Mabsadd L
.74679 .08256 0 -0.38461 Mabsadd L
.74679 .08256 .58779 -0.80902 Mabsadd L
.74679 .08256 .36579 -0.11885 Mabsadd L
.74679 .08256 .95106 .30902 Mabsadd L
.74679 .08256 .22607 .31116 Mabsadd L
.74679 .08256 0 1 Mabsadd L closepath F
.75046 .0825 0 1 Mabsadd m
.75046 .0825 -0.22607 .31116 Mabsadd L
.75046 .0825 -0.95106 .30902 Mabsadd L
.75046 .0825 -0.36579 -0.11885 Mabsadd L
.75046 .0825 -0.58778 -0.80902 Mabsadd L
.75046 .0825 0 -0.38461 Mabsadd L
.75046 .0825 .58779 -0.80902 Mabsadd L
.75046 .0825 .36579 -0.11885 Mabsadd L
.75046 .0825 .95106 .30902 Mabsadd L
.75046 .0825 .22607 .31116 Mabsadd L
.75046 .0825 0 1 Mabsadd L closepath F
.75413 .08238 0 1 Mabsadd m
.75413 .08238 -0.22607 .31116 Mabsadd L
.75413 .08238 -0.95106 .30902 Mabsadd L
.75413 .08238 -0.36579 -0.11885 Mabsadd L
.75413 .08238 -0.58778 -0.80902 Mabsadd L
.75413 .08238 0 -0.38461 Mabsadd L
.75413 .08238 .58779 -0.80902 Mabsadd L
.75413 .08238 .36579 -0.11885 Mabsadd L
.75413 .08238 .95106 .30902 Mabsadd L
.75413 .08238 .22607 .31116 Mabsadd L
.75413 .08238 0 1 Mabsadd L closepath F
.7578 .08236 0 1 Mabsadd m
.7578 .08236 -0.22607 .31116 Mabsadd L
.7578 .08236 -0.95106 .30902 Mabsadd L
.7578 .08236 -0.36579 -0.11885 Mabsadd L
.7578 .08236 -0.58778 -0.80902 Mabsadd L
.7578 .08236 0 -0.38461 Mabsadd L
.7578 .08236 .58779 -0.80902 Mabsadd L
.7578 .08236 .36579 -0.11885 Mabsadd L
.7578 .08236 .95106 .30902 Mabsadd L
.7578 .08236 .22607 .31116 Mabsadd L
.7578 .08236 0 1 Mabsadd L closepath F
.76147 .08229 0 1 Mabsadd m
.76147 .08229 -0.22607 .31116 Mabsadd L
.76147 .08229 -0.95106 .30902 Mabsadd L
.76147 .08229 -0.36579 -0.11885 Mabsadd L
.76147 .08229 -0.58778 -0.80902 Mabsadd L
.76147 .08229 0 -0.38461 Mabsadd L
.76147 .08229 .58779 -0.80902 Mabsadd L
.76147 .08229 .36579 -0.11885 Mabsadd L
.76147 .08229 .95106 .30902 Mabsadd L
.76147 .08229 .22607 .31116 Mabsadd L
.76147 .08229 0 1 Mabsadd L closepath F
.76514 .08221 0 1 Mabsadd m
.76514 .08221 -0.22607 .31116 Mabsadd L
.76514 .08221 -0.95106 .30902 Mabsadd L
.76514 .08221 -0.36579 -0.11885 Mabsadd L
.76514 .08221 -0.58778 -0.80902 Mabsadd L
.76514 .08221 0 -0.38461 Mabsadd L
.76514 .08221 .58779 -0.80902 Mabsadd L
.76514 .08221 .36579 -0.11885 Mabsadd L
.76514 .08221 .95106 .30902 Mabsadd L
.76514 .08221 .22607 .31116 Mabsadd L
.76514 .08221 0 1 Mabsadd L closepath F
.76881 .0821 0 1 Mabsadd m
.76881 .0821 -0.22607 .31116 Mabsadd L
.76881 .0821 -0.95106 .30902 Mabsadd L
.76881 .0821 -0.36579 -0.11885 Mabsadd L
.76881 .0821 -0.58778 -0.80902 Mabsadd L
.76881 .0821 0 -0.38461 Mabsadd L
.76881 .0821 .58779 -0.80902 Mabsadd L
.76881 .0821 .36579 -0.11885 Mabsadd L
.76881 .0821 .95106 .30902 Mabsadd L
.76881 .0821 .22607 .31116 Mabsadd L
.76881 .0821 0 1 Mabsadd L closepath F
.77248 .08204 0 1 Mabsadd m
.77248 .08204 -0.22607 .31116 Mabsadd L
.77248 .08204 -0.95106 .30902 Mabsadd L
.77248 .08204 -0.36579 -0.11885 Mabsadd L
.77248 .08204 -0.58778 -0.80902 Mabsadd L
.77248 .08204 0 -0.38461 Mabsadd L
.77248 .08204 .58779 -0.80902 Mabsadd L
.77248 .08204 .36579 -0.11885 Mabsadd L
.77248 .08204 .95106 .30902 Mabsadd L
.77248 .08204 .22607 .31116 Mabsadd L
.77248 .08204 0 1 Mabsadd L closepath F
.77615 .08199 0 1 Mabsadd m
.77615 .08199 -0.22607 .31116 Mabsadd L
.77615 .08199 -0.95106 .30902 Mabsadd L
.77615 .08199 -0.36579 -0.11885 Mabsadd L
.77615 .08199 -0.58778 -0.80902 Mabsadd L
.77615 .08199 0 -0.38461 Mabsadd L
.77615 .08199 .58779 -0.80902 Mabsadd L
.77615 .08199 .36579 -0.11885 Mabsadd L
.77615 .08199 .95106 .30902 Mabsadd L
.77615 .08199 .22607 .31116 Mabsadd L
.77615 .08199 0 1 Mabsadd L closepath F
.77982 .08192 0 1 Mabsadd m
.77982 .08192 -0.22607 .31116 Mabsadd L
.77982 .08192 -0.95106 .30902 Mabsadd L
.77982 .08192 -0.36579 -0.11885 Mabsadd L
.77982 .08192 -0.58778 -0.80902 Mabsadd L
.77982 .08192 0 -0.38461 Mabsadd L
.77982 .08192 .58779 -0.80902 Mabsadd L
.77982 .08192 .36579 -0.11885 Mabsadd L
.77982 .08192 .95106 .30902 Mabsadd L
.77982 .08192 .22607 .31116 Mabsadd L
.77982 .08192 0 1 Mabsadd L closepath F
.78349 .08188 0 1 Mabsadd m
.78349 .08188 -0.22607 .31116 Mabsadd L
.78349 .08188 -0.95106 .30902 Mabsadd L
.78349 .08188 -0.36579 -0.11885 Mabsadd L
.78349 .08188 -0.58778 -0.80902 Mabsadd L
.78349 .08188 0 -0.38461 Mabsadd L
.78349 .08188 .58779 -0.80902 Mabsadd L
.78349 .08188 .36579 -0.11885 Mabsadd L
.78349 .08188 .95106 .30902 Mabsadd L
.78349 .08188 .22607 .31116 Mabsadd L
.78349 .08188 0 1 Mabsadd L closepath F
.78716 .08185 0 1 Mabsadd m
.78716 .08185 -0.22607 .31116 Mabsadd L
.78716 .08185 -0.95106 .30902 Mabsadd L
.78716 .08185 -0.36579 -0.11885 Mabsadd L
.78716 .08185 -0.58778 -0.80902 Mabsadd L
.78716 .08185 0 -0.38461 Mabsadd L
.78716 .08185 .58779 -0.80902 Mabsadd L
.78716 .08185 .36579 -0.11885 Mabsadd L
.78716 .08185 .95106 .30902 Mabsadd L
.78716 .08185 .22607 .31116 Mabsadd L
.78716 .08185 0 1 Mabsadd L closepath F
.79083 .08186 0 1 Mabsadd m
.79083 .08186 -0.22607 .31116 Mabsadd L
.79083 .08186 -0.95106 .30902 Mabsadd L
.79083 .08186 -0.36579 -0.11885 Mabsadd L
.79083 .08186 -0.58778 -0.80902 Mabsadd L
.79083 .08186 0 -0.38461 Mabsadd L
.79083 .08186 .58779 -0.80902 Mabsadd L
.79083 .08186 .36579 -0.11885 Mabsadd L
.79083 .08186 .95106 .30902 Mabsadd L
.79083 .08186 .22607 .31116 Mabsadd L
.79083 .08186 0 1 Mabsadd L closepath F
.7945 .08188 0 1 Mabsadd m
.7945 .08188 -0.22607 .31116 Mabsadd L
.7945 .08188 -0.95106 .30902 Mabsadd L
.7945 .08188 -0.36579 -0.11885 Mabsadd L
.7945 .08188 -0.58778 -0.80902 Mabsadd L
.7945 .08188 0 -0.38461 Mabsadd L
.7945 .08188 .58779 -0.80902 Mabsadd L
.7945 .08188 .36579 -0.11885 Mabsadd L
.7945 .08188 .95106 .30902 Mabsadd L
.7945 .08188 .22607 .31116 Mabsadd L
.7945 .08188 0 1 Mabsadd L closepath F
.79817 .08175 0 1 Mabsadd m
.79817 .08175 -0.22607 .31116 Mabsadd L
.79817 .08175 -0.95106 .30902 Mabsadd L
.79817 .08175 -0.36579 -0.11885 Mabsadd L
.79817 .08175 -0.58778 -0.80902 Mabsadd L
.79817 .08175 0 -0.38461 Mabsadd L
.79817 .08175 .58779 -0.80902 Mabsadd L
.79817 .08175 .36579 -0.11885 Mabsadd L
.79817 .08175 .95106 .30902 Mabsadd L
.79817 .08175 .22607 .31116 Mabsadd L
.79817 .08175 0 1 Mabsadd L closepath F
.80183 .08168 0 1 Mabsadd m
.80183 .08168 -0.22607 .31116 Mabsadd L
.80183 .08168 -0.95106 .30902 Mabsadd L
.80183 .08168 -0.36579 -0.11885 Mabsadd L
.80183 .08168 -0.58778 -0.80902 Mabsadd L
.80183 .08168 0 -0.38461 Mabsadd L
.80183 .08168 .58779 -0.80902 Mabsadd L
.80183 .08168 .36579 -0.11885 Mabsadd L
.80183 .08168 .95106 .30902 Mabsadd L
.80183 .08168 .22607 .31116 Mabsadd L
.80183 .08168 0 1 Mabsadd L closepath F
.8055 .08168 0 1 Mabsadd m
.8055 .08168 -0.22607 .31116 Mabsadd L
.8055 .08168 -0.95106 .30902 Mabsadd L
.8055 .08168 -0.36579 -0.11885 Mabsadd L
.8055 .08168 -0.58778 -0.80902 Mabsadd L
.8055 .08168 0 -0.38461 Mabsadd L
.8055 .08168 .58779 -0.80902 Mabsadd L
.8055 .08168 .36579 -0.11885 Mabsadd L
.8055 .08168 .95106 .30902 Mabsadd L
.8055 .08168 .22607 .31116 Mabsadd L
.8055 .08168 0 1 Mabsadd L closepath F
.80917 .08167 0 1 Mabsadd m
.80917 .08167 -0.22607 .31116 Mabsadd L
.80917 .08167 -0.95106 .30902 Mabsadd L
.80917 .08167 -0.36579 -0.11885 Mabsadd L
.80917 .08167 -0.58778 -0.80902 Mabsadd L
.80917 .08167 0 -0.38461 Mabsadd L
.80917 .08167 .58779 -0.80902 Mabsadd L
.80917 .08167 .36579 -0.11885 Mabsadd L
.80917 .08167 .95106 .30902 Mabsadd L
.80917 .08167 .22607 .31116 Mabsadd L
.80917 .08167 0 1 Mabsadd L closepath F
.81284 .0817 0 1 Mabsadd m
.81284 .0817 -0.22607 .31116 Mabsadd L
.81284 .0817 -0.95106 .30902 Mabsadd L
.81284 .0817 -0.36579 -0.11885 Mabsadd L
.81284 .0817 -0.58778 -0.80902 Mabsadd L
.81284 .0817 0 -0.38461 Mabsadd L
.81284 .0817 .58779 -0.80902 Mabsadd L
.81284 .0817 .36579 -0.11885 Mabsadd L
.81284 .0817 .95106 .30902 Mabsadd L
.81284 .0817 .22607 .31116 Mabsadd L
.81284 .0817 0 1 Mabsadd L closepath F
.81651 .08168 0 1 Mabsadd m
.81651 .08168 -0.22607 .31116 Mabsadd L
.81651 .08168 -0.95106 .30902 Mabsadd L
.81651 .08168 -0.36579 -0.11885 Mabsadd L
.81651 .08168 -0.58778 -0.80902 Mabsadd L
.81651 .08168 0 -0.38461 Mabsadd L
.81651 .08168 .58779 -0.80902 Mabsadd L
.81651 .08168 .36579 -0.11885 Mabsadd L
.81651 .08168 .95106 .30902 Mabsadd L
.81651 .08168 .22607 .31116 Mabsadd L
.81651 .08168 0 1 Mabsadd L closepath F
.82018 .08164 0 1 Mabsadd m
.82018 .08164 -0.22607 .31116 Mabsadd L
.82018 .08164 -0.95106 .30902 Mabsadd L
.82018 .08164 -0.36579 -0.11885 Mabsadd L
.82018 .08164 -0.58778 -0.80902 Mabsadd L
.82018 .08164 0 -0.38461 Mabsadd L
.82018 .08164 .58779 -0.80902 Mabsadd L
.82018 .08164 .36579 -0.11885 Mabsadd L
.82018 .08164 .95106 .30902 Mabsadd L
.82018 .08164 .22607 .31116 Mabsadd L
.82018 .08164 0 1 Mabsadd L closepath F
.82385 .08154 0 1 Mabsadd m
.82385 .08154 -0.22607 .31116 Mabsadd L
.82385 .08154 -0.95106 .30902 Mabsadd L
.82385 .08154 -0.36579 -0.11885 Mabsadd L
.82385 .08154 -0.58778 -0.80902 Mabsadd L
.82385 .08154 0 -0.38461 Mabsadd L
.82385 .08154 .58779 -0.80902 Mabsadd L
.82385 .08154 .36579 -0.11885 Mabsadd L
.82385 .08154 .95106 .30902 Mabsadd L
.82385 .08154 .22607 .31116 Mabsadd L
.82385 .08154 0 1 Mabsadd L closepath F
.82752 .08143 0 1 Mabsadd m
.82752 .08143 -0.22607 .31116 Mabsadd L
.82752 .08143 -0.95106 .30902 Mabsadd L
.82752 .08143 -0.36579 -0.11885 Mabsadd L
.82752 .08143 -0.58778 -0.80902 Mabsadd L
.82752 .08143 0 -0.38461 Mabsadd L
.82752 .08143 .58779 -0.80902 Mabsadd L
.82752 .08143 .36579 -0.11885 Mabsadd L
.82752 .08143 .95106 .30902 Mabsadd L
.82752 .08143 .22607 .31116 Mabsadd L
.82752 .08143 0 1 Mabsadd L closepath F
.83119 .08139 0 1 Mabsadd m
.83119 .08139 -0.22607 .31116 Mabsadd L
.83119 .08139 -0.95106 .30902 Mabsadd L
.83119 .08139 -0.36579 -0.11885 Mabsadd L
.83119 .08139 -0.58778 -0.80902 Mabsadd L
.83119 .08139 0 -0.38461 Mabsadd L
.83119 .08139 .58779 -0.80902 Mabsadd L
.83119 .08139 .36579 -0.11885 Mabsadd L
.83119 .08139 .95106 .30902 Mabsadd L
.83119 .08139 .22607 .31116 Mabsadd L
.83119 .08139 0 1 Mabsadd L closepath F
.83486 .08135 0 1 Mabsadd m
.83486 .08135 -0.22607 .31116 Mabsadd L
.83486 .08135 -0.95106 .30902 Mabsadd L
.83486 .08135 -0.36579 -0.11885 Mabsadd L
.83486 .08135 -0.58778 -0.80902 Mabsadd L
.83486 .08135 0 -0.38461 Mabsadd L
.83486 .08135 .58779 -0.80902 Mabsadd L
.83486 .08135 .36579 -0.11885 Mabsadd L
.83486 .08135 .95106 .30902 Mabsadd L
.83486 .08135 .22607 .31116 Mabsadd L
.83486 .08135 0 1 Mabsadd L closepath F
.83853 .08132 0 1 Mabsadd m
.83853 .08132 -0.22607 .31116 Mabsadd L
.83853 .08132 -0.95106 .30902 Mabsadd L
.83853 .08132 -0.36579 -0.11885 Mabsadd L
.83853 .08132 -0.58778 -0.80902 Mabsadd L
.83853 .08132 0 -0.38461 Mabsadd L
.83853 .08132 .58779 -0.80902 Mabsadd L
.83853 .08132 .36579 -0.11885 Mabsadd L
.83853 .08132 .95106 .30902 Mabsadd L
.83853 .08132 .22607 .31116 Mabsadd L
.83853 .08132 0 1 Mabsadd L closepath F
.8422 .08132 0 1 Mabsadd m
.8422 .08132 -0.22607 .31116 Mabsadd L
.8422 .08132 -0.95106 .30902 Mabsadd L
.8422 .08132 -0.36579 -0.11885 Mabsadd L
.8422 .08132 -0.58778 -0.80902 Mabsadd L
.8422 .08132 0 -0.38461 Mabsadd L
.8422 .08132 .58779 -0.80902 Mabsadd L
.8422 .08132 .36579 -0.11885 Mabsadd L
.8422 .08132 .95106 .30902 Mabsadd L
.8422 .08132 .22607 .31116 Mabsadd L
.8422 .08132 0 1 Mabsadd L closepath F
.84587 .08126 0 1 Mabsadd m
.84587 .08126 -0.22607 .31116 Mabsadd L
.84587 .08126 -0.95106 .30902 Mabsadd L
.84587 .08126 -0.36579 -0.11885 Mabsadd L
.84587 .08126 -0.58778 -0.80902 Mabsadd L
.84587 .08126 0 -0.38461 Mabsadd L
.84587 .08126 .58779 -0.80902 Mabsadd L
.84587 .08126 .36579 -0.11885 Mabsadd L
.84587 .08126 .95106 .30902 Mabsadd L
.84587 .08126 .22607 .31116 Mabsadd L
.84587 .08126 0 1 Mabsadd L closepath F
.84954 .08125 0 1 Mabsadd m
.84954 .08125 -0.22607 .31116 Mabsadd L
.84954 .08125 -0.95106 .30902 Mabsadd L
.84954 .08125 -0.36579 -0.11885 Mabsadd L
.84954 .08125 -0.58778 -0.80902 Mabsadd L
.84954 .08125 0 -0.38461 Mabsadd L
.84954 .08125 .58779 -0.80902 Mabsadd L
.84954 .08125 .36579 -0.11885 Mabsadd L
.84954 .08125 .95106 .30902 Mabsadd L
.84954 .08125 .22607 .31116 Mabsadd L
.84954 .08125 0 1 Mabsadd L closepath F
.85321 .08124 0 1 Mabsadd m
.85321 .08124 -0.22607 .31116 Mabsadd L
.85321 .08124 -0.95106 .30902 Mabsadd L
.85321 .08124 -0.36579 -0.11885 Mabsadd L
.85321 .08124 -0.58778 -0.80902 Mabsadd L
.85321 .08124 0 -0.38461 Mabsadd L
.85321 .08124 .58779 -0.80902 Mabsadd L
.85321 .08124 .36579 -0.11885 Mabsadd L
.85321 .08124 .95106 .30902 Mabsadd L
.85321 .08124 .22607 .31116 Mabsadd L
.85321 .08124 0 1 Mabsadd L closepath F
.85688 .0812 0 1 Mabsadd m
.85688 .0812 -0.22607 .31116 Mabsadd L
.85688 .0812 -0.95106 .30902 Mabsadd L
.85688 .0812 -0.36579 -0.11885 Mabsadd L
.85688 .0812 -0.58778 -0.80902 Mabsadd L
.85688 .0812 0 -0.38461 Mabsadd L
.85688 .0812 .58779 -0.80902 Mabsadd L
.85688 .0812 .36579 -0.11885 Mabsadd L
.85688 .0812 .95106 .30902 Mabsadd L
.85688 .0812 .22607 .31116 Mabsadd L
.85688 .0812 0 1 Mabsadd L closepath F
.86055 .08129 0 1 Mabsadd m
.86055 .08129 -0.22607 .31116 Mabsadd L
.86055 .08129 -0.95106 .30902 Mabsadd L
.86055 .08129 -0.36579 -0.11885 Mabsadd L
.86055 .08129 -0.58778 -0.80902 Mabsadd L
.86055 .08129 0 -0.38461 Mabsadd L
.86055 .08129 .58779 -0.80902 Mabsadd L
.86055 .08129 .36579 -0.11885 Mabsadd L
.86055 .08129 .95106 .30902 Mabsadd L
.86055 .08129 .22607 .31116 Mabsadd L
.86055 .08129 0 1 Mabsadd L closepath F
.86422 .08126 0 1 Mabsadd m
.86422 .08126 -0.22607 .31116 Mabsadd L
.86422 .08126 -0.95106 .30902 Mabsadd L
.86422 .08126 -0.36579 -0.11885 Mabsadd L
.86422 .08126 -0.58778 -0.80902 Mabsadd L
.86422 .08126 0 -0.38461 Mabsadd L
.86422 .08126 .58779 -0.80902 Mabsadd L
.86422 .08126 .36579 -0.11885 Mabsadd L
.86422 .08126 .95106 .30902 Mabsadd L
.86422 .08126 .22607 .31116 Mabsadd L
.86422 .08126 0 1 Mabsadd L closepath F
.86789 .08122 0 1 Mabsadd m
.86789 .08122 -0.22607 .31116 Mabsadd L
.86789 .08122 -0.95106 .30902 Mabsadd L
.86789 .08122 -0.36579 -0.11885 Mabsadd L
.86789 .08122 -0.58778 -0.80902 Mabsadd L
.86789 .08122 0 -0.38461 Mabsadd L
.86789 .08122 .58779 -0.80902 Mabsadd L
.86789 .08122 .36579 -0.11885 Mabsadd L
.86789 .08122 .95106 .30902 Mabsadd L
.86789 .08122 .22607 .31116 Mabsadd L
.86789 .08122 0 1 Mabsadd L closepath F
.87156 .08116 0 1 Mabsadd m
.87156 .08116 -0.22607 .31116 Mabsadd L
.87156 .08116 -0.95106 .30902 Mabsadd L
.87156 .08116 -0.36579 -0.11885 Mabsadd L
.87156 .08116 -0.58778 -0.80902 Mabsadd L
.87156 .08116 0 -0.38461 Mabsadd L
.87156 .08116 .58779 -0.80902 Mabsadd L
.87156 .08116 .36579 -0.11885 Mabsadd L
.87156 .08116 .95106 .30902 Mabsadd L
.87156 .08116 .22607 .31116 Mabsadd L
.87156 .08116 0 1 Mabsadd L closepath F
.87523 .0811 0 1 Mabsadd m
.87523 .0811 -0.22607 .31116 Mabsadd L
.87523 .0811 -0.95106 .30902 Mabsadd L
.87523 .0811 -0.36579 -0.11885 Mabsadd L
.87523 .0811 -0.58778 -0.80902 Mabsadd L
.87523 .0811 0 -0.38461 Mabsadd L
.87523 .0811 .58779 -0.80902 Mabsadd L
.87523 .0811 .36579 -0.11885 Mabsadd L
.87523 .0811 .95106 .30902 Mabsadd L
.87523 .0811 .22607 .31116 Mabsadd L
.87523 .0811 0 1 Mabsadd L closepath F
.8789 .08111 0 1 Mabsadd m
.8789 .08111 -0.22607 .31116 Mabsadd L
.8789 .08111 -0.95106 .30902 Mabsadd L
.8789 .08111 -0.36579 -0.11885 Mabsadd L
.8789 .08111 -0.58778 -0.80902 Mabsadd L
.8789 .08111 0 -0.38461 Mabsadd L
.8789 .08111 .58779 -0.80902 Mabsadd L
.8789 .08111 .36579 -0.11885 Mabsadd L
.8789 .08111 .95106 .30902 Mabsadd L
.8789 .08111 .22607 .31116 Mabsadd L
.8789 .08111 0 1 Mabsadd L closepath F
.88257 .08108 0 1 Mabsadd m
.88257 .08108 -0.22607 .31116 Mabsadd L
.88257 .08108 -0.95106 .30902 Mabsadd L
.88257 .08108 -0.36579 -0.11885 Mabsadd L
.88257 .08108 -0.58778 -0.80902 Mabsadd L
.88257 .08108 0 -0.38461 Mabsadd L
.88257 .08108 .58779 -0.80902 Mabsadd L
.88257 .08108 .36579 -0.11885 Mabsadd L
.88257 .08108 .95106 .30902 Mabsadd L
.88257 .08108 .22607 .31116 Mabsadd L
.88257 .08108 0 1 Mabsadd L closepath F
.88624 .08104 0 1 Mabsadd m
.88624 .08104 -0.22607 .31116 Mabsadd L
.88624 .08104 -0.95106 .30902 Mabsadd L
.88624 .08104 -0.36579 -0.11885 Mabsadd L
.88624 .08104 -0.58778 -0.80902 Mabsadd L
.88624 .08104 0 -0.38461 Mabsadd L
.88624 .08104 .58779 -0.80902 Mabsadd L
.88624 .08104 .36579 -0.11885 Mabsadd L
.88624 .08104 .95106 .30902 Mabsadd L
.88624 .08104 .22607 .31116 Mabsadd L
.88624 .08104 0 1 Mabsadd L closepath F
.88991 .08095 0 1 Mabsadd m
.88991 .08095 -0.22607 .31116 Mabsadd L
.88991 .08095 -0.95106 .30902 Mabsadd L
.88991 .08095 -0.36579 -0.11885 Mabsadd L
.88991 .08095 -0.58778 -0.80902 Mabsadd L
.88991 .08095 0 -0.38461 Mabsadd L
.88991 .08095 .58779 -0.80902 Mabsadd L
.88991 .08095 .36579 -0.11885 Mabsadd L
.88991 .08095 .95106 .30902 Mabsadd L
.88991 .08095 .22607 .31116 Mabsadd L
.88991 .08095 0 1 Mabsadd L closepath F
.89358 .08098 0 1 Mabsadd m
.89358 .08098 -0.22607 .31116 Mabsadd L
.89358 .08098 -0.95106 .30902 Mabsadd L
.89358 .08098 -0.36579 -0.11885 Mabsadd L
.89358 .08098 -0.58778 -0.80902 Mabsadd L
.89358 .08098 0 -0.38461 Mabsadd L
.89358 .08098 .58779 -0.80902 Mabsadd L
.89358 .08098 .36579 -0.11885 Mabsadd L
.89358 .08098 .95106 .30902 Mabsadd L
.89358 .08098 .22607 .31116 Mabsadd L
.89358 .08098 0 1 Mabsadd L closepath F
.89725 .08097 0 1 Mabsadd m
.89725 .08097 -0.22607 .31116 Mabsadd L
.89725 .08097 -0.95106 .30902 Mabsadd L
.89725 .08097 -0.36579 -0.11885 Mabsadd L
.89725 .08097 -0.58778 -0.80902 Mabsadd L
.89725 .08097 0 -0.38461 Mabsadd L
.89725 .08097 .58779 -0.80902 Mabsadd L
.89725 .08097 .36579 -0.11885 Mabsadd L
.89725 .08097 .95106 .30902 Mabsadd L
.89725 .08097 .22607 .31116 Mabsadd L
.89725 .08097 0 1 Mabsadd L closepath F
.90092 .08107 0 1 Mabsadd m
.90092 .08107 -0.22607 .31116 Mabsadd L
.90092 .08107 -0.95106 .30902 Mabsadd L
.90092 .08107 -0.36579 -0.11885 Mabsadd L
.90092 .08107 -0.58778 -0.80902 Mabsadd L
.90092 .08107 0 -0.38461 Mabsadd L
.90092 .08107 .58779 -0.80902 Mabsadd L
.90092 .08107 .36579 -0.11885 Mabsadd L
.90092 .08107 .95106 .30902 Mabsadd L
.90092 .08107 .22607 .31116 Mabsadd L
.90092 .08107 0 1 Mabsadd L closepath F
.90459 .08106 0 1 Mabsadd m
.90459 .08106 -0.22607 .31116 Mabsadd L
.90459 .08106 -0.95106 .30902 Mabsadd L
.90459 .08106 -0.36579 -0.11885 Mabsadd L
.90459 .08106 -0.58778 -0.80902 Mabsadd L
.90459 .08106 0 -0.38461 Mabsadd L
.90459 .08106 .58779 -0.80902 Mabsadd L
.90459 .08106 .36579 -0.11885 Mabsadd L
.90459 .08106 .95106 .30902 Mabsadd L
.90459 .08106 .22607 .31116 Mabsadd L
.90459 .08106 0 1 Mabsadd L closepath F
.90826 .08109 0 1 Mabsadd m
.90826 .08109 -0.22607 .31116 Mabsadd L
.90826 .08109 -0.95106 .30902 Mabsadd L
.90826 .08109 -0.36579 -0.11885 Mabsadd L
.90826 .08109 -0.58778 -0.80902 Mabsadd L
.90826 .08109 0 -0.38461 Mabsadd L
.90826 .08109 .58779 -0.80902 Mabsadd L
.90826 .08109 .36579 -0.11885 Mabsadd L
.90826 .08109 .95106 .30902 Mabsadd L
.90826 .08109 .22607 .31116 Mabsadd L
.90826 .08109 0 1 Mabsadd L closepath F
.91193 .08106 0 1 Mabsadd m
.91193 .08106 -0.22607 .31116 Mabsadd L
.91193 .08106 -0.95106 .30902 Mabsadd L
.91193 .08106 -0.36579 -0.11885 Mabsadd L
.91193 .08106 -0.58778 -0.80902 Mabsadd L
.91193 .08106 0 -0.38461 Mabsadd L
.91193 .08106 .58779 -0.80902 Mabsadd L
.91193 .08106 .36579 -0.11885 Mabsadd L
.91193 .08106 .95106 .30902 Mabsadd L
.91193 .08106 .22607 .31116 Mabsadd L
.91193 .08106 0 1 Mabsadd L closepath F
.9156 .08101 0 1 Mabsadd m
.9156 .08101 -0.22607 .31116 Mabsadd L
.9156 .08101 -0.95106 .30902 Mabsadd L
.9156 .08101 -0.36579 -0.11885 Mabsadd L
.9156 .08101 -0.58778 -0.80902 Mabsadd L
.9156 .08101 0 -0.38461 Mabsadd L
.9156 .08101 .58779 -0.80902 Mabsadd L
.9156 .08101 .36579 -0.11885 Mabsadd L
.9156 .08101 .95106 .30902 Mabsadd L
.9156 .08101 .22607 .31116 Mabsadd L
.9156 .08101 0 1 Mabsadd L closepath F
.91927 .08103 0 1 Mabsadd m
.91927 .08103 -0.22607 .31116 Mabsadd L
.91927 .08103 -0.95106 .30902 Mabsadd L
.91927 .08103 -0.36579 -0.11885 Mabsadd L
.91927 .08103 -0.58778 -0.80902 Mabsadd L
.91927 .08103 0 -0.38461 Mabsadd L
.91927 .08103 .58779 -0.80902 Mabsadd L
.91927 .08103 .36579 -0.11885 Mabsadd L
.91927 .08103 .95106 .30902 Mabsadd L
.91927 .08103 .22607 .31116 Mabsadd L
.91927 .08103 0 1 Mabsadd L closepath F
.92294 .08105 0 1 Mabsadd m
.92294 .08105 -0.22607 .31116 Mabsadd L
.92294 .08105 -0.95106 .30902 Mabsadd L
.92294 .08105 -0.36579 -0.11885 Mabsadd L
.92294 .08105 -0.58778 -0.80902 Mabsadd L
.92294 .08105 0 -0.38461 Mabsadd L
.92294 .08105 .58779 -0.80902 Mabsadd L
.92294 .08105 .36579 -0.11885 Mabsadd L
.92294 .08105 .95106 .30902 Mabsadd L
.92294 .08105 .22607 .31116 Mabsadd L
.92294 .08105 0 1 Mabsadd L closepath F
.92661 .08098 0 1 Mabsadd m
.92661 .08098 -0.22607 .31116 Mabsadd L
.92661 .08098 -0.95106 .30902 Mabsadd L
.92661 .08098 -0.36579 -0.11885 Mabsadd L
.92661 .08098 -0.58778 -0.80902 Mabsadd L
.92661 .08098 0 -0.38461 Mabsadd L
.92661 .08098 .58779 -0.80902 Mabsadd L
.92661 .08098 .36579 -0.11885 Mabsadd L
.92661 .08098 .95106 .30902 Mabsadd L
.92661 .08098 .22607 .31116 Mabsadd L
.92661 .08098 0 1 Mabsadd L closepath F
.93028 .08091 0 1 Mabsadd m
.93028 .08091 -0.22607 .31116 Mabsadd L
.93028 .08091 -0.95106 .30902 Mabsadd L
.93028 .08091 -0.36579 -0.11885 Mabsadd L
.93028 .08091 -0.58778 -0.80902 Mabsadd L
.93028 .08091 0 -0.38461 Mabsadd L
.93028 .08091 .58779 -0.80902 Mabsadd L
.93028 .08091 .36579 -0.11885 Mabsadd L
.93028 .08091 .95106 .30902 Mabsadd L
.93028 .08091 .22607 .31116 Mabsadd L
.93028 .08091 0 1 Mabsadd L closepath F
.93394 .08085 0 1 Mabsadd m
.93394 .08085 -0.22607 .31116 Mabsadd L
.93394 .08085 -0.95106 .30902 Mabsadd L
.93394 .08085 -0.36579 -0.11885 Mabsadd L
.93394 .08085 -0.58778 -0.80902 Mabsadd L
.93394 .08085 0 -0.38461 Mabsadd L
.93394 .08085 .58779 -0.80902 Mabsadd L
.93394 .08085 .36579 -0.11885 Mabsadd L
.93394 .08085 .95106 .30902 Mabsadd L
.93394 .08085 .22607 .31116 Mabsadd L
.93394 .08085 0 1 Mabsadd L closepath F
.93761 .08083 0 1 Mabsadd m
.93761 .08083 -0.22607 .31116 Mabsadd L
.93761 .08083 -0.95106 .30902 Mabsadd L
.93761 .08083 -0.36579 -0.11885 Mabsadd L
.93761 .08083 -0.58778 -0.80902 Mabsadd L
.93761 .08083 0 -0.38461 Mabsadd L
.93761 .08083 .58779 -0.80902 Mabsadd L
.93761 .08083 .36579 -0.11885 Mabsadd L
.93761 .08083 .95106 .30902 Mabsadd L
.93761 .08083 .22607 .31116 Mabsadd L
.93761 .08083 0 1 Mabsadd L closepath F
.94128 .0808 0 1 Mabsadd m
.94128 .0808 -0.22607 .31116 Mabsadd L
.94128 .0808 -0.95106 .30902 Mabsadd L
.94128 .0808 -0.36579 -0.11885 Mabsadd L
.94128 .0808 -0.58778 -0.80902 Mabsadd L
.94128 .0808 0 -0.38461 Mabsadd L
.94128 .0808 .58779 -0.80902 Mabsadd L
.94128 .0808 .36579 -0.11885 Mabsadd L
.94128 .0808 .95106 .30902 Mabsadd L
.94128 .0808 .22607 .31116 Mabsadd L
.94128 .0808 0 1 Mabsadd L closepath F
.94495 .08081 0 1 Mabsadd m
.94495 .08081 -0.22607 .31116 Mabsadd L
.94495 .08081 -0.95106 .30902 Mabsadd L
.94495 .08081 -0.36579 -0.11885 Mabsadd L
.94495 .08081 -0.58778 -0.80902 Mabsadd L
.94495 .08081 0 -0.38461 Mabsadd L
.94495 .08081 .58779 -0.80902 Mabsadd L
.94495 .08081 .36579 -0.11885 Mabsadd L
.94495 .08081 .95106 .30902 Mabsadd L
.94495 .08081 .22607 .31116 Mabsadd L
.94495 .08081 0 1 Mabsadd L closepath F
.94862 .08073 0 1 Mabsadd m
.94862 .08073 -0.22607 .31116 Mabsadd L
.94862 .08073 -0.95106 .30902 Mabsadd L
.94862 .08073 -0.36579 -0.11885 Mabsadd L
.94862 .08073 -0.58778 -0.80902 Mabsadd L
.94862 .08073 0 -0.38461 Mabsadd L
.94862 .08073 .58779 -0.80902 Mabsadd L
.94862 .08073 .36579 -0.11885 Mabsadd L
.94862 .08073 .95106 .30902 Mabsadd L
.94862 .08073 .22607 .31116 Mabsadd L
.94862 .08073 0 1 Mabsadd L closepath F
.95229 .08072 0 1 Mabsadd m
.95229 .08072 -0.22607 .31116 Mabsadd L
.95229 .08072 -0.95106 .30902 Mabsadd L
.95229 .08072 -0.36579 -0.11885 Mabsadd L
.95229 .08072 -0.58778 -0.80902 Mabsadd L
.95229 .08072 0 -0.38461 Mabsadd L
.95229 .08072 .58779 -0.80902 Mabsadd L
.95229 .08072 .36579 -0.11885 Mabsadd L
.95229 .08072 .95106 .30902 Mabsadd L
.95229 .08072 .22607 .31116 Mabsadd L
.95229 .08072 0 1 Mabsadd L closepath F
.95596 .08068 0 1 Mabsadd m
.95596 .08068 -0.22607 .31116 Mabsadd L
.95596 .08068 -0.95106 .30902 Mabsadd L
.95596 .08068 -0.36579 -0.11885 Mabsadd L
.95596 .08068 -0.58778 -0.80902 Mabsadd L
.95596 .08068 0 -0.38461 Mabsadd L
.95596 .08068 .58779 -0.80902 Mabsadd L
.95596 .08068 .36579 -0.11885 Mabsadd L
.95596 .08068 .95106 .30902 Mabsadd L
.95596 .08068 .22607 .31116 Mabsadd L
.95596 .08068 0 1 Mabsadd L closepath F
.95963 .08063 0 1 Mabsadd m
.95963 .08063 -0.22607 .31116 Mabsadd L
.95963 .08063 -0.95106 .30902 Mabsadd L
.95963 .08063 -0.36579 -0.11885 Mabsadd L
.95963 .08063 -0.58778 -0.80902 Mabsadd L
.95963 .08063 0 -0.38461 Mabsadd L
.95963 .08063 .58779 -0.80902 Mabsadd L
.95963 .08063 .36579 -0.11885 Mabsadd L
.95963 .08063 .95106 .30902 Mabsadd L
.95963 .08063 .22607 .31116 Mabsadd L
.95963 .08063 0 1 Mabsadd L closepath F
.9633 .08064 0 1 Mabsadd m
.9633 .08064 -0.22607 .31116 Mabsadd L
.9633 .08064 -0.95106 .30902 Mabsadd L
.9633 .08064 -0.36579 -0.11885 Mabsadd L
.9633 .08064 -0.58778 -0.80902 Mabsadd L
.9633 .08064 0 -0.38461 Mabsadd L
.9633 .08064 .58779 -0.80902 Mabsadd L
.9633 .08064 .36579 -0.11885 Mabsadd L
.9633 .08064 .95106 .30902 Mabsadd L
.9633 .08064 .22607 .31116 Mabsadd L
.9633 .08064 0 1 Mabsadd L closepath F
.96697 .08059 0 1 Mabsadd m
.96697 .08059 -0.22607 .31116 Mabsadd L
.96697 .08059 -0.95106 .30902 Mabsadd L
.96697 .08059 -0.36579 -0.11885 Mabsadd L
.96697 .08059 -0.58778 -0.80902 Mabsadd L
.96697 .08059 0 -0.38461 Mabsadd L
.96697 .08059 .58779 -0.80902 Mabsadd L
.96697 .08059 .36579 -0.11885 Mabsadd L
.96697 .08059 .95106 .30902 Mabsadd L
.96697 .08059 .22607 .31116 Mabsadd L
.96697 .08059 0 1 Mabsadd L closepath F
.97064 .08062 0 1 Mabsadd m
.97064 .08062 -0.22607 .31116 Mabsadd L
.97064 .08062 -0.95106 .30902 Mabsadd L
.97064 .08062 -0.36579 -0.11885 Mabsadd L
.97064 .08062 -0.58778 -0.80902 Mabsadd L
.97064 .08062 0 -0.38461 Mabsadd L
.97064 .08062 .58779 -0.80902 Mabsadd L
.97064 .08062 .36579 -0.11885 Mabsadd L
.97064 .08062 .95106 .30902 Mabsadd L
.97064 .08062 .22607 .31116 Mabsadd L
.97064 .08062 0 1 Mabsadd L closepath F
.97431 .08065 0 1 Mabsadd m
.97431 .08065 -0.22607 .31116 Mabsadd L
.97431 .08065 -0.95106 .30902 Mabsadd L
.97431 .08065 -0.36579 -0.11885 Mabsadd L
.97431 .08065 -0.58778 -0.80902 Mabsadd L
.97431 .08065 0 -0.38461 Mabsadd L
.97431 .08065 .58779 -0.80902 Mabsadd L
.97431 .08065 .36579 -0.11885 Mabsadd L
.97431 .08065 .95106 .30902 Mabsadd L
.97431 .08065 .22607 .31116 Mabsadd L
.97431 .08065 0 1 Mabsadd L closepath F
.97798 .08054 0 1 Mabsadd m
.97798 .08054 -0.22607 .31116 Mabsadd L
.97798 .08054 -0.95106 .30902 Mabsadd L
.97798 .08054 -0.36579 -0.11885 Mabsadd L
.97798 .08054 -0.58778 -0.80902 Mabsadd L
.97798 .08054 0 -0.38461 Mabsadd L
.97798 .08054 .58779 -0.80902 Mabsadd L
.97798 .08054 .36579 -0.11885 Mabsadd L
.97798 .08054 .95106 .30902 Mabsadd L
.97798 .08054 .22607 .31116 Mabsadd L
.97798 .08054 0 1 Mabsadd L closepath F
.98165 .08047 0 1 Mabsadd m
.98165 .08047 -0.22607 .31116 Mabsadd L
.98165 .08047 -0.95106 .30902 Mabsadd L
.98165 .08047 -0.36579 -0.11885 Mabsadd L
.98165 .08047 -0.58778 -0.80902 Mabsadd L
.98165 .08047 0 -0.38461 Mabsadd L
.98165 .08047 .58779 -0.80902 Mabsadd L
.98165 .08047 .36579 -0.11885 Mabsadd L
.98165 .08047 .95106 .30902 Mabsadd L
.98165 .08047 .22607 .31116 Mabsadd L
.98165 .08047 0 1 Mabsadd L closepath F
.98532 .0804 0 1 Mabsadd m
.98532 .0804 -0.22607 .31116 Mabsadd L
.98532 .0804 -0.95106 .30902 Mabsadd L
.98532 .0804 -0.36579 -0.11885 Mabsadd L
.98532 .0804 -0.58778 -0.80902 Mabsadd L
.98532 .0804 0 -0.38461 Mabsadd L
.98532 .0804 .58779 -0.80902 Mabsadd L
.98532 .0804 .36579 -0.11885 Mabsadd L
.98532 .0804 .95106 .30902 Mabsadd L
.98532 .0804 .22607 .31116 Mabsadd L
.98532 .0804 0 1 Mabsadd L closepath F
.98899 .08035 0 1 Mabsadd m
.98899 .08035 -0.22607 .31116 Mabsadd L
.98899 .08035 -0.95106 .30902 Mabsadd L
.98899 .08035 -0.36579 -0.11885 Mabsadd L
.98899 .08035 -0.58778 -0.80902 Mabsadd L
.98899 .08035 0 -0.38461 Mabsadd L
.98899 .08035 .58779 -0.80902 Mabsadd L
.98899 .08035 .36579 -0.11885 Mabsadd L
.98899 .08035 .95106 .30902 Mabsadd L
.98899 .08035 .22607 .31116 Mabsadd L
.98899 .08035 0 1 Mabsadd L closepath F
.99266 .08037 0 1 Mabsadd m
.99266 .08037 -0.22607 .31116 Mabsadd L
.99266 .08037 -0.95106 .30902 Mabsadd L
.99266 .08037 -0.36579 -0.11885 Mabsadd L
.99266 .08037 -0.58778 -0.80902 Mabsadd L
.99266 .08037 0 -0.38461 Mabsadd L
.99266 .08037 .58779 -0.80902 Mabsadd L
.99266 .08037 .36579 -0.11885 Mabsadd L
.99266 .08037 .95106 .30902 Mabsadd L
.99266 .08037 .22607 .31116 Mabsadd L
.99266 .08037 0 1 Mabsadd L closepath F
.99633 .08033 0 1 Mabsadd m
.99633 .08033 -0.22607 .31116 Mabsadd L
.99633 .08033 -0.95106 .30902 Mabsadd L
.99633 .08033 -0.36579 -0.11885 Mabsadd L
.99633 .08033 -0.58778 -0.80902 Mabsadd L
.99633 .08033 0 -0.38461 Mabsadd L
.99633 .08033 .58779 -0.80902 Mabsadd L
.99633 .08033 .36579 -0.11885 Mabsadd L
.99633 .08033 .95106 .30902 Mabsadd L
.99633 .08033 .22607 .31116 Mabsadd L
.99633 .08033 0 1 Mabsadd L closepath F
1 .0803 0 1 Mabsadd m
1 .0803 -0.22607 .31116 Mabsadd L
1 .0803 -0.95106 .30902 Mabsadd L
1 .0803 -0.36579 -0.11885 Mabsadd L
1 .0803 -0.58778 -0.80902 Mabsadd L
1 .0803 0 -0.38461 Mabsadd L
1 .0803 .58779 -0.80902 Mabsadd L
1 .0803 .36579 -0.11885 Mabsadd L
1 .0803 .95106 .30902 Mabsadd L
1 .0803 .22607 .31116 Mabsadd L
1 .0803 0 1 Mabsadd L closepath F
0 1 0 r
.08257 .55943 0 1 Mabsadd m
.08257 .55943 -0.22607 .31116 Mabsadd L
.08257 .55943 -0.95106 .30902 Mabsadd L
.08257 .55943 -0.36579 -0.11885 Mabsadd L
.08257 .55943 -0.58778 -0.80902 Mabsadd L
.08257 .55943 0 -0.38461 Mabsadd L
.08257 .55943 .58779 -0.80902 Mabsadd L
.08257 .55943 .36579 -0.11885 Mabsadd L
.08257 .55943 .95106 .30902 Mabsadd L
.08257 .55943 .22607 .31116 Mabsadd L
.08257 .55943 0 1 Mabsadd L closepath F
.08624 .53908 0 1 Mabsadd m
.08624 .53908 -0.22607 .31116 Mabsadd L
.08624 .53908 -0.95106 .30902 Mabsadd L
.08624 .53908 -0.36579 -0.11885 Mabsadd L
.08624 .53908 -0.58778 -0.80902 Mabsadd L
.08624 .53908 0 -0.38461 Mabsadd L
.08624 .53908 .58779 -0.80902 Mabsadd L
.08624 .53908 .36579 -0.11885 Mabsadd L
.08624 .53908 .95106 .30902 Mabsadd L
.08624 .53908 .22607 .31116 Mabsadd L
.08624 .53908 0 1 Mabsadd L closepath F
.08991 .52217 0 1 Mabsadd m
.08991 .52217 -0.22607 .31116 Mabsadd L
.08991 .52217 -0.95106 .30902 Mabsadd L
.08991 .52217 -0.36579 -0.11885 Mabsadd L
.08991 .52217 -0.58778 -0.80902 Mabsadd L
.08991 .52217 0 -0.38461 Mabsadd L
.08991 .52217 .58779 -0.80902 Mabsadd L
.08991 .52217 .36579 -0.11885 Mabsadd L
.08991 .52217 .95106 .30902 Mabsadd L
.08991 .52217 .22607 .31116 Mabsadd L
.08991 .52217 0 1 Mabsadd L closepath F
.09358 .50818 0 1 Mabsadd m
.09358 .50818 -0.22607 .31116 Mabsadd L
.09358 .50818 -0.95106 .30902 Mabsadd L
.09358 .50818 -0.36579 -0.11885 Mabsadd L
.09358 .50818 -0.58778 -0.80902 Mabsadd L
.09358 .50818 0 -0.38461 Mabsadd L
.09358 .50818 .58779 -0.80902 Mabsadd L
.09358 .50818 .36579 -0.11885 Mabsadd L
.09358 .50818 .95106 .30902 Mabsadd L
.09358 .50818 .22607 .31116 Mabsadd L
.09358 .50818 0 1 Mabsadd L closepath F
.09725 .49638 0 1 Mabsadd m
.09725 .49638 -0.22607 .31116 Mabsadd L
.09725 .49638 -0.95106 .30902 Mabsadd L
.09725 .49638 -0.36579 -0.11885 Mabsadd L
.09725 .49638 -0.58778 -0.80902 Mabsadd L
.09725 .49638 0 -0.38461 Mabsadd L
.09725 .49638 .58779 -0.80902 Mabsadd L
.09725 .49638 .36579 -0.11885 Mabsadd L
.09725 .49638 .95106 .30902 Mabsadd L
.09725 .49638 .22607 .31116 Mabsadd L
.09725 .49638 0 1 Mabsadd L closepath F
.10092 .48517 0 1 Mabsadd m
.10092 .48517 -0.22607 .31116 Mabsadd L
.10092 .48517 -0.95106 .30902 Mabsadd L
.10092 .48517 -0.36579 -0.11885 Mabsadd L
.10092 .48517 -0.58778 -0.80902 Mabsadd L
.10092 .48517 0 -0.38461 Mabsadd L
.10092 .48517 .58779 -0.80902 Mabsadd L
.10092 .48517 .36579 -0.11885 Mabsadd L
.10092 .48517 .95106 .30902 Mabsadd L
.10092 .48517 .22607 .31116 Mabsadd L
.10092 .48517 0 1 Mabsadd L closepath F
.10459 .47582 0 1 Mabsadd m
.10459 .47582 -0.22607 .31116 Mabsadd L
.10459 .47582 -0.95106 .30902 Mabsadd L
.10459 .47582 -0.36579 -0.11885 Mabsadd L
.10459 .47582 -0.58778 -0.80902 Mabsadd L
.10459 .47582 0 -0.38461 Mabsadd L
.10459 .47582 .58779 -0.80902 Mabsadd L
.10459 .47582 .36579 -0.11885 Mabsadd L
.10459 .47582 .95106 .30902 Mabsadd L
.10459 .47582 .22607 .31116 Mabsadd L
.10459 .47582 0 1 Mabsadd L closepath F
.10826 .46797 0 1 Mabsadd m
.10826 .46797 -0.22607 .31116 Mabsadd L
.10826 .46797 -0.95106 .30902 Mabsadd L
.10826 .46797 -0.36579 -0.11885 Mabsadd L
.10826 .46797 -0.58778 -0.80902 Mabsadd L
.10826 .46797 0 -0.38461 Mabsadd L
.10826 .46797 .58779 -0.80902 Mabsadd L
.10826 .46797 .36579 -0.11885 Mabsadd L
.10826 .46797 .95106 .30902 Mabsadd L
.10826 .46797 .22607 .31116 Mabsadd L
.10826 .46797 0 1 Mabsadd L closepath F
.11193 .46081 0 1 Mabsadd m
.11193 .46081 -0.22607 .31116 Mabsadd L
.11193 .46081 -0.95106 .30902 Mabsadd L
.11193 .46081 -0.36579 -0.11885 Mabsadd L
.11193 .46081 -0.58778 -0.80902 Mabsadd L
.11193 .46081 0 -0.38461 Mabsadd L
.11193 .46081 .58779 -0.80902 Mabsadd L
.11193 .46081 .36579 -0.11885 Mabsadd L
.11193 .46081 .95106 .30902 Mabsadd L
.11193 .46081 .22607 .31116 Mabsadd L
.11193 .46081 0 1 Mabsadd L closepath F
.1156 .45459 0 1 Mabsadd m
.1156 .45459 -0.22607 .31116 Mabsadd L
.1156 .45459 -0.95106 .30902 Mabsadd L
.1156 .45459 -0.36579 -0.11885 Mabsadd L
.1156 .45459 -0.58778 -0.80902 Mabsadd L
.1156 .45459 0 -0.38461 Mabsadd L
.1156 .45459 .58779 -0.80902 Mabsadd L
.1156 .45459 .36579 -0.11885 Mabsadd L
.1156 .45459 .95106 .30902 Mabsadd L
.1156 .45459 .22607 .31116 Mabsadd L
.1156 .45459 0 1 Mabsadd L closepath F
.11927 .44919 0 1 Mabsadd m
.11927 .44919 -0.22607 .31116 Mabsadd L
.11927 .44919 -0.95106 .30902 Mabsadd L
.11927 .44919 -0.36579 -0.11885 Mabsadd L
.11927 .44919 -0.58778 -0.80902 Mabsadd L
.11927 .44919 0 -0.38461 Mabsadd L
.11927 .44919 .58779 -0.80902 Mabsadd L
.11927 .44919 .36579 -0.11885 Mabsadd L
.11927 .44919 .95106 .30902 Mabsadd L
.11927 .44919 .22607 .31116 Mabsadd L
.11927 .44919 0 1 Mabsadd L closepath F
.12294 .44496 0 1 Mabsadd m
.12294 .44496 -0.22607 .31116 Mabsadd L
.12294 .44496 -0.95106 .30902 Mabsadd L
.12294 .44496 -0.36579 -0.11885 Mabsadd L
.12294 .44496 -0.58778 -0.80902 Mabsadd L
.12294 .44496 0 -0.38461 Mabsadd L
.12294 .44496 .58779 -0.80902 Mabsadd L
.12294 .44496 .36579 -0.11885 Mabsadd L
.12294 .44496 .95106 .30902 Mabsadd L
.12294 .44496 .22607 .31116 Mabsadd L
.12294 .44496 0 1 Mabsadd L closepath F
.12661 .44077 0 1 Mabsadd m
.12661 .44077 -0.22607 .31116 Mabsadd L
.12661 .44077 -0.95106 .30902 Mabsadd L
.12661 .44077 -0.36579 -0.11885 Mabsadd L
.12661 .44077 -0.58778 -0.80902 Mabsadd L
.12661 .44077 0 -0.38461 Mabsadd L
.12661 .44077 .58779 -0.80902 Mabsadd L
.12661 .44077 .36579 -0.11885 Mabsadd L
.12661 .44077 .95106 .30902 Mabsadd L
.12661 .44077 .22607 .31116 Mabsadd L
.12661 .44077 0 1 Mabsadd L closepath F
.13028 .43707 0 1 Mabsadd m
.13028 .43707 -0.22607 .31116 Mabsadd L
.13028 .43707 -0.95106 .30902 Mabsadd L
.13028 .43707 -0.36579 -0.11885 Mabsadd L
.13028 .43707 -0.58778 -0.80902 Mabsadd L
.13028 .43707 0 -0.38461 Mabsadd L
.13028 .43707 .58779 -0.80902 Mabsadd L
.13028 .43707 .36579 -0.11885 Mabsadd L
.13028 .43707 .95106 .30902 Mabsadd L
.13028 .43707 .22607 .31116 Mabsadd L
.13028 .43707 0 1 Mabsadd L closepath F
.13394 .43382 0 1 Mabsadd m
.13394 .43382 -0.22607 .31116 Mabsadd L
.13394 .43382 -0.95106 .30902 Mabsadd L
.13394 .43382 -0.36579 -0.11885 Mabsadd L
.13394 .43382 -0.58778 -0.80902 Mabsadd L
.13394 .43382 0 -0.38461 Mabsadd L
.13394 .43382 .58779 -0.80902 Mabsadd L
.13394 .43382 .36579 -0.11885 Mabsadd L
.13394 .43382 .95106 .30902 Mabsadd L
.13394 .43382 .22607 .31116 Mabsadd L
.13394 .43382 0 1 Mabsadd L closepath F
.13761 .431 0 1 Mabsadd m
.13761 .431 -0.22607 .31116 Mabsadd L
.13761 .431 -0.95106 .30902 Mabsadd L
.13761 .431 -0.36579 -0.11885 Mabsadd L
.13761 .431 -0.58778 -0.80902 Mabsadd L
.13761 .431 0 -0.38461 Mabsadd L
.13761 .431 .58779 -0.80902 Mabsadd L
.13761 .431 .36579 -0.11885 Mabsadd L
.13761 .431 .95106 .30902 Mabsadd L
.13761 .431 .22607 .31116 Mabsadd L
.13761 .431 0 1 Mabsadd L closepath F
.14128 .42851 0 1 Mabsadd m
.14128 .42851 -0.22607 .31116 Mabsadd L
.14128 .42851 -0.95106 .30902 Mabsadd L
.14128 .42851 -0.36579 -0.11885 Mabsadd L
.14128 .42851 -0.58778 -0.80902 Mabsadd L
.14128 .42851 0 -0.38461 Mabsadd L
.14128 .42851 .58779 -0.80902 Mabsadd L
.14128 .42851 .36579 -0.11885 Mabsadd L
.14128 .42851 .95106 .30902 Mabsadd L
.14128 .42851 .22607 .31116 Mabsadd L
.14128 .42851 0 1 Mabsadd L closepath F
.14495 .42613 0 1 Mabsadd m
.14495 .42613 -0.22607 .31116 Mabsadd L
.14495 .42613 -0.95106 .30902 Mabsadd L
.14495 .42613 -0.36579 -0.11885 Mabsadd L
.14495 .42613 -0.58778 -0.80902 Mabsadd L
.14495 .42613 0 -0.38461 Mabsadd L
.14495 .42613 .58779 -0.80902 Mabsadd L
.14495 .42613 .36579 -0.11885 Mabsadd L
.14495 .42613 .95106 .30902 Mabsadd L
.14495 .42613 .22607 .31116 Mabsadd L
.14495 .42613 0 1 Mabsadd L closepath F
.14862 .42404 0 1 Mabsadd m
.14862 .42404 -0.22607 .31116 Mabsadd L
.14862 .42404 -0.95106 .30902 Mabsadd L
.14862 .42404 -0.36579 -0.11885 Mabsadd L
.14862 .42404 -0.58778 -0.80902 Mabsadd L
.14862 .42404 0 -0.38461 Mabsadd L
.14862 .42404 .58779 -0.80902 Mabsadd L
.14862 .42404 .36579 -0.11885 Mabsadd L
.14862 .42404 .95106 .30902 Mabsadd L
.14862 .42404 .22607 .31116 Mabsadd L
.14862 .42404 0 1 Mabsadd L closepath F
.15229 .4221 0 1 Mabsadd m
.15229 .4221 -0.22607 .31116 Mabsadd L
.15229 .4221 -0.95106 .30902 Mabsadd L
.15229 .4221 -0.36579 -0.11885 Mabsadd L
.15229 .4221 -0.58778 -0.80902 Mabsadd L
.15229 .4221 0 -0.38461 Mabsadd L
.15229 .4221 .58779 -0.80902 Mabsadd L
.15229 .4221 .36579 -0.11885 Mabsadd L
.15229 .4221 .95106 .30902 Mabsadd L
.15229 .4221 .22607 .31116 Mabsadd L
.15229 .4221 0 1 Mabsadd L closepath F
.15596 .42036 0 1 Mabsadd m
.15596 .42036 -0.22607 .31116 Mabsadd L
.15596 .42036 -0.95106 .30902 Mabsadd L
.15596 .42036 -0.36579 -0.11885 Mabsadd L
.15596 .42036 -0.58778 -0.80902 Mabsadd L
.15596 .42036 0 -0.38461 Mabsadd L
.15596 .42036 .58779 -0.80902 Mabsadd L
.15596 .42036 .36579 -0.11885 Mabsadd L
.15596 .42036 .95106 .30902 Mabsadd L
.15596 .42036 .22607 .31116 Mabsadd L
.15596 .42036 0 1 Mabsadd L closepath F
.15963 .41861 0 1 Mabsadd m
.15963 .41861 -0.22607 .31116 Mabsadd L
.15963 .41861 -0.95106 .30902 Mabsadd L
.15963 .41861 -0.36579 -0.11885 Mabsadd L
.15963 .41861 -0.58778 -0.80902 Mabsadd L
.15963 .41861 0 -0.38461 Mabsadd L
.15963 .41861 .58779 -0.80902 Mabsadd L
.15963 .41861 .36579 -0.11885 Mabsadd L
.15963 .41861 .95106 .30902 Mabsadd L
.15963 .41861 .22607 .31116 Mabsadd L
.15963 .41861 0 1 Mabsadd L closepath F
.1633 .41674 0 1 Mabsadd m
.1633 .41674 -0.22607 .31116 Mabsadd L
.1633 .41674 -0.95106 .30902 Mabsadd L
.1633 .41674 -0.36579 -0.11885 Mabsadd L
.1633 .41674 -0.58778 -0.80902 Mabsadd L
.1633 .41674 0 -0.38461 Mabsadd L
.1633 .41674 .58779 -0.80902 Mabsadd L
.1633 .41674 .36579 -0.11885 Mabsadd L
.1633 .41674 .95106 .30902 Mabsadd L
.1633 .41674 .22607 .31116 Mabsadd L
.1633 .41674 0 1 Mabsadd L closepath F
.16697 .41538 0 1 Mabsadd m
.16697 .41538 -0.22607 .31116 Mabsadd L
.16697 .41538 -0.95106 .30902 Mabsadd L
.16697 .41538 -0.36579 -0.11885 Mabsadd L
.16697 .41538 -0.58778 -0.80902 Mabsadd L
.16697 .41538 0 -0.38461 Mabsadd L
.16697 .41538 .58779 -0.80902 Mabsadd L
.16697 .41538 .36579 -0.11885 Mabsadd L
.16697 .41538 .95106 .30902 Mabsadd L
.16697 .41538 .22607 .31116 Mabsadd L
.16697 .41538 0 1 Mabsadd L closepath F
.17064 .41399 0 1 Mabsadd m
.17064 .41399 -0.22607 .31116 Mabsadd L
.17064 .41399 -0.95106 .30902 Mabsadd L
.17064 .41399 -0.36579 -0.11885 Mabsadd L
.17064 .41399 -0.58778 -0.80902 Mabsadd L
.17064 .41399 0 -0.38461 Mabsadd L
.17064 .41399 .58779 -0.80902 Mabsadd L
.17064 .41399 .36579 -0.11885 Mabsadd L
.17064 .41399 .95106 .30902 Mabsadd L
.17064 .41399 .22607 .31116 Mabsadd L
.17064 .41399 0 1 Mabsadd L closepath F
.17431 .41231 0 1 Mabsadd m
.17431 .41231 -0.22607 .31116 Mabsadd L
.17431 .41231 -0.95106 .30902 Mabsadd L
.17431 .41231 -0.36579 -0.11885 Mabsadd L
.17431 .41231 -0.58778 -0.80902 Mabsadd L
.17431 .41231 0 -0.38461 Mabsadd L
.17431 .41231 .58779 -0.80902 Mabsadd L
.17431 .41231 .36579 -0.11885 Mabsadd L
.17431 .41231 .95106 .30902 Mabsadd L
.17431 .41231 .22607 .31116 Mabsadd L
.17431 .41231 0 1 Mabsadd L closepath F
.17798 .41092 0 1 Mabsadd m
.17798 .41092 -0.22607 .31116 Mabsadd L
.17798 .41092 -0.95106 .30902 Mabsadd L
.17798 .41092 -0.36579 -0.11885 Mabsadd L
.17798 .41092 -0.58778 -0.80902 Mabsadd L
.17798 .41092 0 -0.38461 Mabsadd L
.17798 .41092 .58779 -0.80902 Mabsadd L
.17798 .41092 .36579 -0.11885 Mabsadd L
.17798 .41092 .95106 .30902 Mabsadd L
.17798 .41092 .22607 .31116 Mabsadd L
.17798 .41092 0 1 Mabsadd L closepath F
.18165 .40959 0 1 Mabsadd m
.18165 .40959 -0.22607 .31116 Mabsadd L
.18165 .40959 -0.95106 .30902 Mabsadd L
.18165 .40959 -0.36579 -0.11885 Mabsadd L
.18165 .40959 -0.58778 -0.80902 Mabsadd L
.18165 .40959 0 -0.38461 Mabsadd L
.18165 .40959 .58779 -0.80902 Mabsadd L
.18165 .40959 .36579 -0.11885 Mabsadd L
.18165 .40959 .95106 .30902 Mabsadd L
.18165 .40959 .22607 .31116 Mabsadd L
.18165 .40959 0 1 Mabsadd L closepath F
.18532 .40829 0 1 Mabsadd m
.18532 .40829 -0.22607 .31116 Mabsadd L
.18532 .40829 -0.95106 .30902 Mabsadd L
.18532 .40829 -0.36579 -0.11885 Mabsadd L
.18532 .40829 -0.58778 -0.80902 Mabsadd L
.18532 .40829 0 -0.38461 Mabsadd L
.18532 .40829 .58779 -0.80902 Mabsadd L
.18532 .40829 .36579 -0.11885 Mabsadd L
.18532 .40829 .95106 .30902 Mabsadd L
.18532 .40829 .22607 .31116 Mabsadd L
.18532 .40829 0 1 Mabsadd L closepath F
.18899 .40692 0 1 Mabsadd m
.18899 .40692 -0.22607 .31116 Mabsadd L
.18899 .40692 -0.95106 .30902 Mabsadd L
.18899 .40692 -0.36579 -0.11885 Mabsadd L
.18899 .40692 -0.58778 -0.80902 Mabsadd L
.18899 .40692 0 -0.38461 Mabsadd L
.18899 .40692 .58779 -0.80902 Mabsadd L
.18899 .40692 .36579 -0.11885 Mabsadd L
.18899 .40692 .95106 .30902 Mabsadd L
.18899 .40692 .22607 .31116 Mabsadd L
.18899 .40692 0 1 Mabsadd L closepath F
.19266 .40573 0 1 Mabsadd m
.19266 .40573 -0.22607 .31116 Mabsadd L
.19266 .40573 -0.95106 .30902 Mabsadd L
.19266 .40573 -0.36579 -0.11885 Mabsadd L
.19266 .40573 -0.58778 -0.80902 Mabsadd L
.19266 .40573 0 -0.38461 Mabsadd L
.19266 .40573 .58779 -0.80902 Mabsadd L
.19266 .40573 .36579 -0.11885 Mabsadd L
.19266 .40573 .95106 .30902 Mabsadd L
.19266 .40573 .22607 .31116 Mabsadd L
.19266 .40573 0 1 Mabsadd L closepath F
.19633 .4047 0 1 Mabsadd m
.19633 .4047 -0.22607 .31116 Mabsadd L
.19633 .4047 -0.95106 .30902 Mabsadd L
.19633 .4047 -0.36579 -0.11885 Mabsadd L
.19633 .4047 -0.58778 -0.80902 Mabsadd L
.19633 .4047 0 -0.38461 Mabsadd L
.19633 .4047 .58779 -0.80902 Mabsadd L
.19633 .4047 .36579 -0.11885 Mabsadd L
.19633 .4047 .95106 .30902 Mabsadd L
.19633 .4047 .22607 .31116 Mabsadd L
.19633 .4047 0 1 Mabsadd L closepath F
.2 .40335 0 1 Mabsadd m
.2 .40335 -0.22607 .31116 Mabsadd L
.2 .40335 -0.95106 .30902 Mabsadd L
.2 .40335 -0.36579 -0.11885 Mabsadd L
.2 .40335 -0.58778 -0.80902 Mabsadd L
.2 .40335 0 -0.38461 Mabsadd L
.2 .40335 .58779 -0.80902 Mabsadd L
.2 .40335 .36579 -0.11885 Mabsadd L
.2 .40335 .95106 .30902 Mabsadd L
.2 .40335 .22607 .31116 Mabsadd L
.2 .40335 0 1 Mabsadd L closepath F
.20367 .40217 0 1 Mabsadd m
.20367 .40217 -0.22607 .31116 Mabsadd L
.20367 .40217 -0.95106 .30902 Mabsadd L
.20367 .40217 -0.36579 -0.11885 Mabsadd L
.20367 .40217 -0.58778 -0.80902 Mabsadd L
.20367 .40217 0 -0.38461 Mabsadd L
.20367 .40217 .58779 -0.80902 Mabsadd L
.20367 .40217 .36579 -0.11885 Mabsadd L
.20367 .40217 .95106 .30902 Mabsadd L
.20367 .40217 .22607 .31116 Mabsadd L
.20367 .40217 0 1 Mabsadd L closepath F
.20734 .40098 0 1 Mabsadd m
.20734 .40098 -0.22607 .31116 Mabsadd L
.20734 .40098 -0.95106 .30902 Mabsadd L
.20734 .40098 -0.36579 -0.11885 Mabsadd L
.20734 .40098 -0.58778 -0.80902 Mabsadd L
.20734 .40098 0 -0.38461 Mabsadd L
.20734 .40098 .58779 -0.80902 Mabsadd L
.20734 .40098 .36579 -0.11885 Mabsadd L
.20734 .40098 .95106 .30902 Mabsadd L
.20734 .40098 .22607 .31116 Mabsadd L
.20734 .40098 0 1 Mabsadd L closepath F
.21101 .39996 0 1 Mabsadd m
.21101 .39996 -0.22607 .31116 Mabsadd L
.21101 .39996 -0.95106 .30902 Mabsadd L
.21101 .39996 -0.36579 -0.11885 Mabsadd L
.21101 .39996 -0.58778 -0.80902 Mabsadd L
.21101 .39996 0 -0.38461 Mabsadd L
.21101 .39996 .58779 -0.80902 Mabsadd L
.21101 .39996 .36579 -0.11885 Mabsadd L
.21101 .39996 .95106 .30902 Mabsadd L
.21101 .39996 .22607 .31116 Mabsadd L
.21101 .39996 0 1 Mabsadd L closepath F
.21468 .39858 0 1 Mabsadd m
.21468 .39858 -0.22607 .31116 Mabsadd L
.21468 .39858 -0.95106 .30902 Mabsadd L
.21468 .39858 -0.36579 -0.11885 Mabsadd L
.21468 .39858 -0.58778 -0.80902 Mabsadd L
.21468 .39858 0 -0.38461 Mabsadd L
.21468 .39858 .58779 -0.80902 Mabsadd L
.21468 .39858 .36579 -0.11885 Mabsadd L
.21468 .39858 .95106 .30902 Mabsadd L
.21468 .39858 .22607 .31116 Mabsadd L
.21468 .39858 0 1 Mabsadd L closepath F
.21835 .39768 0 1 Mabsadd m
.21835 .39768 -0.22607 .31116 Mabsadd L
.21835 .39768 -0.95106 .30902 Mabsadd L
.21835 .39768 -0.36579 -0.11885 Mabsadd L
.21835 .39768 -0.58778 -0.80902 Mabsadd L
.21835 .39768 0 -0.38461 Mabsadd L
.21835 .39768 .58779 -0.80902 Mabsadd L
.21835 .39768 .36579 -0.11885 Mabsadd L
.21835 .39768 .95106 .30902 Mabsadd L
.21835 .39768 .22607 .31116 Mabsadd L
.21835 .39768 0 1 Mabsadd L closepath F
.22202 .39674 0 1 Mabsadd m
.22202 .39674 -0.22607 .31116 Mabsadd L
.22202 .39674 -0.95106 .30902 Mabsadd L
.22202 .39674 -0.36579 -0.11885 Mabsadd L
.22202 .39674 -0.58778 -0.80902 Mabsadd L
.22202 .39674 0 -0.38461 Mabsadd L
.22202 .39674 .58779 -0.80902 Mabsadd L
.22202 .39674 .36579 -0.11885 Mabsadd L
.22202 .39674 .95106 .30902 Mabsadd L
.22202 .39674 .22607 .31116 Mabsadd L
.22202 .39674 0 1 Mabsadd L closepath F
.22569 .39567 0 1 Mabsadd m
.22569 .39567 -0.22607 .31116 Mabsadd L
.22569 .39567 -0.95106 .30902 Mabsadd L
.22569 .39567 -0.36579 -0.11885 Mabsadd L
.22569 .39567 -0.58778 -0.80902 Mabsadd L
.22569 .39567 0 -0.38461 Mabsadd L
.22569 .39567 .58779 -0.80902 Mabsadd L
.22569 .39567 .36579 -0.11885 Mabsadd L
.22569 .39567 .95106 .30902 Mabsadd L
.22569 .39567 .22607 .31116 Mabsadd L
.22569 .39567 0 1 Mabsadd L closepath F
.22936 .39437 0 1 Mabsadd m
.22936 .39437 -0.22607 .31116 Mabsadd L
.22936 .39437 -0.95106 .30902 Mabsadd L
.22936 .39437 -0.36579 -0.11885 Mabsadd L
.22936 .39437 -0.58778 -0.80902 Mabsadd L
.22936 .39437 0 -0.38461 Mabsadd L
.22936 .39437 .58779 -0.80902 Mabsadd L
.22936 .39437 .36579 -0.11885 Mabsadd L
.22936 .39437 .95106 .30902 Mabsadd L
.22936 .39437 .22607 .31116 Mabsadd L
.22936 .39437 0 1 Mabsadd L closepath F
.23303 .39345 0 1 Mabsadd m
.23303 .39345 -0.22607 .31116 Mabsadd L
.23303 .39345 -0.95106 .30902 Mabsadd L
.23303 .39345 -0.36579 -0.11885 Mabsadd L
.23303 .39345 -0.58778 -0.80902 Mabsadd L
.23303 .39345 0 -0.38461 Mabsadd L
.23303 .39345 .58779 -0.80902 Mabsadd L
.23303 .39345 .36579 -0.11885 Mabsadd L
.23303 .39345 .95106 .30902 Mabsadd L
.23303 .39345 .22607 .31116 Mabsadd L
.23303 .39345 0 1 Mabsadd L closepath F
.2367 .39239 0 1 Mabsadd m
.2367 .39239 -0.22607 .31116 Mabsadd L
.2367 .39239 -0.95106 .30902 Mabsadd L
.2367 .39239 -0.36579 -0.11885 Mabsadd L
.2367 .39239 -0.58778 -0.80902 Mabsadd L
.2367 .39239 0 -0.38461 Mabsadd L
.2367 .39239 .58779 -0.80902 Mabsadd L
.2367 .39239 .36579 -0.11885 Mabsadd L
.2367 .39239 .95106 .30902 Mabsadd L
.2367 .39239 .22607 .31116 Mabsadd L
.2367 .39239 0 1 Mabsadd L closepath F
.24037 .39154 0 1 Mabsadd m
.24037 .39154 -0.22607 .31116 Mabsadd L
.24037 .39154 -0.95106 .30902 Mabsadd L
.24037 .39154 -0.36579 -0.11885 Mabsadd L
.24037 .39154 -0.58778 -0.80902 Mabsadd L
.24037 .39154 0 -0.38461 Mabsadd L
.24037 .39154 .58779 -0.80902 Mabsadd L
.24037 .39154 .36579 -0.11885 Mabsadd L
.24037 .39154 .95106 .30902 Mabsadd L
.24037 .39154 .22607 .31116 Mabsadd L
.24037 .39154 0 1 Mabsadd L closepath F
.24404 .39037 0 1 Mabsadd m
.24404 .39037 -0.22607 .31116 Mabsadd L
.24404 .39037 -0.95106 .30902 Mabsadd L
.24404 .39037 -0.36579 -0.11885 Mabsadd L
.24404 .39037 -0.58778 -0.80902 Mabsadd L
.24404 .39037 0 -0.38461 Mabsadd L
.24404 .39037 .58779 -0.80902 Mabsadd L
.24404 .39037 .36579 -0.11885 Mabsadd L
.24404 .39037 .95106 .30902 Mabsadd L
.24404 .39037 .22607 .31116 Mabsadd L
.24404 .39037 0 1 Mabsadd L closepath F
.24771 .38938 0 1 Mabsadd m
.24771 .38938 -0.22607 .31116 Mabsadd L
.24771 .38938 -0.95106 .30902 Mabsadd L
.24771 .38938 -0.36579 -0.11885 Mabsadd L
.24771 .38938 -0.58778 -0.80902 Mabsadd L
.24771 .38938 0 -0.38461 Mabsadd L
.24771 .38938 .58779 -0.80902 Mabsadd L
.24771 .38938 .36579 -0.11885 Mabsadd L
.24771 .38938 .95106 .30902 Mabsadd L
.24771 .38938 .22607 .31116 Mabsadd L
.24771 .38938 0 1 Mabsadd L closepath F
.25138 .38823 0 1 Mabsadd m
.25138 .38823 -0.22607 .31116 Mabsadd L
.25138 .38823 -0.95106 .30902 Mabsadd L
.25138 .38823 -0.36579 -0.11885 Mabsadd L
.25138 .38823 -0.58778 -0.80902 Mabsadd L
.25138 .38823 0 -0.38461 Mabsadd L
.25138 .38823 .58779 -0.80902 Mabsadd L
.25138 .38823 .36579 -0.11885 Mabsadd L
.25138 .38823 .95106 .30902 Mabsadd L
.25138 .38823 .22607 .31116 Mabsadd L
.25138 .38823 0 1 Mabsadd L closepath F
.25505 .38711 0 1 Mabsadd m
.25505 .38711 -0.22607 .31116 Mabsadd L
.25505 .38711 -0.95106 .30902 Mabsadd L
.25505 .38711 -0.36579 -0.11885 Mabsadd L
.25505 .38711 -0.58778 -0.80902 Mabsadd L
.25505 .38711 0 -0.38461 Mabsadd L
.25505 .38711 .58779 -0.80902 Mabsadd L
.25505 .38711 .36579 -0.11885 Mabsadd L
.25505 .38711 .95106 .30902 Mabsadd L
.25505 .38711 .22607 .31116 Mabsadd L
.25505 .38711 0 1 Mabsadd L closepath F
.25872 .38626 0 1 Mabsadd m
.25872 .38626 -0.22607 .31116 Mabsadd L
.25872 .38626 -0.95106 .30902 Mabsadd L
.25872 .38626 -0.36579 -0.11885 Mabsadd L
.25872 .38626 -0.58778 -0.80902 Mabsadd L
.25872 .38626 0 -0.38461 Mabsadd L
.25872 .38626 .58779 -0.80902 Mabsadd L
.25872 .38626 .36579 -0.11885 Mabsadd L
.25872 .38626 .95106 .30902 Mabsadd L
.25872 .38626 .22607 .31116 Mabsadd L
.25872 .38626 0 1 Mabsadd L closepath F
.26239 .38528 0 1 Mabsadd m
.26239 .38528 -0.22607 .31116 Mabsadd L
.26239 .38528 -0.95106 .30902 Mabsadd L
.26239 .38528 -0.36579 -0.11885 Mabsadd L
.26239 .38528 -0.58778 -0.80902 Mabsadd L
.26239 .38528 0 -0.38461 Mabsadd L
.26239 .38528 .58779 -0.80902 Mabsadd L
.26239 .38528 .36579 -0.11885 Mabsadd L
.26239 .38528 .95106 .30902 Mabsadd L
.26239 .38528 .22607 .31116 Mabsadd L
.26239 .38528 0 1 Mabsadd L closepath F
.26606 .38436 0 1 Mabsadd m
.26606 .38436 -0.22607 .31116 Mabsadd L
.26606 .38436 -0.95106 .30902 Mabsadd L
.26606 .38436 -0.36579 -0.11885 Mabsadd L
.26606 .38436 -0.58778 -0.80902 Mabsadd L
.26606 .38436 0 -0.38461 Mabsadd L
.26606 .38436 .58779 -0.80902 Mabsadd L
.26606 .38436 .36579 -0.11885 Mabsadd L
.26606 .38436 .95106 .30902 Mabsadd L
.26606 .38436 .22607 .31116 Mabsadd L
.26606 .38436 0 1 Mabsadd L closepath F
.26972 .38341 0 1 Mabsadd m
.26972 .38341 -0.22607 .31116 Mabsadd L
.26972 .38341 -0.95106 .30902 Mabsadd L
.26972 .38341 -0.36579 -0.11885 Mabsadd L
.26972 .38341 -0.58778 -0.80902 Mabsadd L
.26972 .38341 0 -0.38461 Mabsadd L
.26972 .38341 .58779 -0.80902 Mabsadd L
.26972 .38341 .36579 -0.11885 Mabsadd L
.26972 .38341 .95106 .30902 Mabsadd L
.26972 .38341 .22607 .31116 Mabsadd L
.26972 .38341 0 1 Mabsadd L closepath F
.27339 .38224 0 1 Mabsadd m
.27339 .38224 -0.22607 .31116 Mabsadd L
.27339 .38224 -0.95106 .30902 Mabsadd L
.27339 .38224 -0.36579 -0.11885 Mabsadd L
.27339 .38224 -0.58778 -0.80902 Mabsadd L
.27339 .38224 0 -0.38461 Mabsadd L
.27339 .38224 .58779 -0.80902 Mabsadd L
.27339 .38224 .36579 -0.11885 Mabsadd L
.27339 .38224 .95106 .30902 Mabsadd L
.27339 .38224 .22607 .31116 Mabsadd L
.27339 .38224 0 1 Mabsadd L closepath F
.27706 .38138 0 1 Mabsadd m
.27706 .38138 -0.22607 .31116 Mabsadd L
.27706 .38138 -0.95106 .30902 Mabsadd L
.27706 .38138 -0.36579 -0.11885 Mabsadd L
.27706 .38138 -0.58778 -0.80902 Mabsadd L
.27706 .38138 0 -0.38461 Mabsadd L
.27706 .38138 .58779 -0.80902 Mabsadd L
.27706 .38138 .36579 -0.11885 Mabsadd L
.27706 .38138 .95106 .30902 Mabsadd L
.27706 .38138 .22607 .31116 Mabsadd L
.27706 .38138 0 1 Mabsadd L closepath F
.28073 .38056 0 1 Mabsadd m
.28073 .38056 -0.22607 .31116 Mabsadd L
.28073 .38056 -0.95106 .30902 Mabsadd L
.28073 .38056 -0.36579 -0.11885 Mabsadd L
.28073 .38056 -0.58778 -0.80902 Mabsadd L
.28073 .38056 0 -0.38461 Mabsadd L
.28073 .38056 .58779 -0.80902 Mabsadd L
.28073 .38056 .36579 -0.11885 Mabsadd L
.28073 .38056 .95106 .30902 Mabsadd L
.28073 .38056 .22607 .31116 Mabsadd L
.28073 .38056 0 1 Mabsadd L closepath F
.2844 .37964 0 1 Mabsadd m
.2844 .37964 -0.22607 .31116 Mabsadd L
.2844 .37964 -0.95106 .30902 Mabsadd L
.2844 .37964 -0.36579 -0.11885 Mabsadd L
.2844 .37964 -0.58778 -0.80902 Mabsadd L
.2844 .37964 0 -0.38461 Mabsadd L
.2844 .37964 .58779 -0.80902 Mabsadd L
.2844 .37964 .36579 -0.11885 Mabsadd L
.2844 .37964 .95106 .30902 Mabsadd L
.2844 .37964 .22607 .31116 Mabsadd L
.2844 .37964 0 1 Mabsadd L closepath F
.28807 .3786 0 1 Mabsadd m
.28807 .3786 -0.22607 .31116 Mabsadd L
.28807 .3786 -0.95106 .30902 Mabsadd L
.28807 .3786 -0.36579 -0.11885 Mabsadd L
.28807 .3786 -0.58778 -0.80902 Mabsadd L
.28807 .3786 0 -0.38461 Mabsadd L
.28807 .3786 .58779 -0.80902 Mabsadd L
.28807 .3786 .36579 -0.11885 Mabsadd L
.28807 .3786 .95106 .30902 Mabsadd L
.28807 .3786 .22607 .31116 Mabsadd L
.28807 .3786 0 1 Mabsadd L closepath F
.29174 .37764 0 1 Mabsadd m
.29174 .37764 -0.22607 .31116 Mabsadd L
.29174 .37764 -0.95106 .30902 Mabsadd L
.29174 .37764 -0.36579 -0.11885 Mabsadd L
.29174 .37764 -0.58778 -0.80902 Mabsadd L
.29174 .37764 0 -0.38461 Mabsadd L
.29174 .37764 .58779 -0.80902 Mabsadd L
.29174 .37764 .36579 -0.11885 Mabsadd L
.29174 .37764 .95106 .30902 Mabsadd L
.29174 .37764 .22607 .31116 Mabsadd L
.29174 .37764 0 1 Mabsadd L closepath F
.29541 .37685 0 1 Mabsadd m
.29541 .37685 -0.22607 .31116 Mabsadd L
.29541 .37685 -0.95106 .30902 Mabsadd L
.29541 .37685 -0.36579 -0.11885 Mabsadd L
.29541 .37685 -0.58778 -0.80902 Mabsadd L
.29541 .37685 0 -0.38461 Mabsadd L
.29541 .37685 .58779 -0.80902 Mabsadd L
.29541 .37685 .36579 -0.11885 Mabsadd L
.29541 .37685 .95106 .30902 Mabsadd L
.29541 .37685 .22607 .31116 Mabsadd L
.29541 .37685 0 1 Mabsadd L closepath F
.29908 .37613 0 1 Mabsadd m
.29908 .37613 -0.22607 .31116 Mabsadd L
.29908 .37613 -0.95106 .30902 Mabsadd L
.29908 .37613 -0.36579 -0.11885 Mabsadd L
.29908 .37613 -0.58778 -0.80902 Mabsadd L
.29908 .37613 0 -0.38461 Mabsadd L
.29908 .37613 .58779 -0.80902 Mabsadd L
.29908 .37613 .36579 -0.11885 Mabsadd L
.29908 .37613 .95106 .30902 Mabsadd L
.29908 .37613 .22607 .31116 Mabsadd L
.29908 .37613 0 1 Mabsadd L closepath F
.30275 .37525 0 1 Mabsadd m
.30275 .37525 -0.22607 .31116 Mabsadd L
.30275 .37525 -0.95106 .30902 Mabsadd L
.30275 .37525 -0.36579 -0.11885 Mabsadd L
.30275 .37525 -0.58778 -0.80902 Mabsadd L
.30275 .37525 0 -0.38461 Mabsadd L
.30275 .37525 .58779 -0.80902 Mabsadd L
.30275 .37525 .36579 -0.11885 Mabsadd L
.30275 .37525 .95106 .30902 Mabsadd L
.30275 .37525 .22607 .31116 Mabsadd L
.30275 .37525 0 1 Mabsadd L closepath F
.30642 .37428 0 1 Mabsadd m
.30642 .37428 -0.22607 .31116 Mabsadd L
.30642 .37428 -0.95106 .30902 Mabsadd L
.30642 .37428 -0.36579 -0.11885 Mabsadd L
.30642 .37428 -0.58778 -0.80902 Mabsadd L
.30642 .37428 0 -0.38461 Mabsadd L
.30642 .37428 .58779 -0.80902 Mabsadd L
.30642 .37428 .36579 -0.11885 Mabsadd L
.30642 .37428 .95106 .30902 Mabsadd L
.30642 .37428 .22607 .31116 Mabsadd L
.30642 .37428 0 1 Mabsadd L closepath F
.31009 .37356 0 1 Mabsadd m
.31009 .37356 -0.22607 .31116 Mabsadd L
.31009 .37356 -0.95106 .30902 Mabsadd L
.31009 .37356 -0.36579 -0.11885 Mabsadd L
.31009 .37356 -0.58778 -0.80902 Mabsadd L
.31009 .37356 0 -0.38461 Mabsadd L
.31009 .37356 .58779 -0.80902 Mabsadd L
.31009 .37356 .36579 -0.11885 Mabsadd L
.31009 .37356 .95106 .30902 Mabsadd L
.31009 .37356 .22607 .31116 Mabsadd L
.31009 .37356 0 1 Mabsadd L closepath F
.31376 .37273 0 1 Mabsadd m
.31376 .37273 -0.22607 .31116 Mabsadd L
.31376 .37273 -0.95106 .30902 Mabsadd L
.31376 .37273 -0.36579 -0.11885 Mabsadd L
.31376 .37273 -0.58778 -0.80902 Mabsadd L
.31376 .37273 0 -0.38461 Mabsadd L
.31376 .37273 .58779 -0.80902 Mabsadd L
.31376 .37273 .36579 -0.11885 Mabsadd L
.31376 .37273 .95106 .30902 Mabsadd L
.31376 .37273 .22607 .31116 Mabsadd L
.31376 .37273 0 1 Mabsadd L closepath F
.31743 .37174 0 1 Mabsadd m
.31743 .37174 -0.22607 .31116 Mabsadd L
.31743 .37174 -0.95106 .30902 Mabsadd L
.31743 .37174 -0.36579 -0.11885 Mabsadd L
.31743 .37174 -0.58778 -0.80902 Mabsadd L
.31743 .37174 0 -0.38461 Mabsadd L
.31743 .37174 .58779 -0.80902 Mabsadd L
.31743 .37174 .36579 -0.11885 Mabsadd L
.31743 .37174 .95106 .30902 Mabsadd L
.31743 .37174 .22607 .31116 Mabsadd L
.31743 .37174 0 1 Mabsadd L closepath F
.3211 .37092 0 1 Mabsadd m
.3211 .37092 -0.22607 .31116 Mabsadd L
.3211 .37092 -0.95106 .30902 Mabsadd L
.3211 .37092 -0.36579 -0.11885 Mabsadd L
.3211 .37092 -0.58778 -0.80902 Mabsadd L
.3211 .37092 0 -0.38461 Mabsadd L
.3211 .37092 .58779 -0.80902 Mabsadd L
.3211 .37092 .36579 -0.11885 Mabsadd L
.3211 .37092 .95106 .30902 Mabsadd L
.3211 .37092 .22607 .31116 Mabsadd L
.3211 .37092 0 1 Mabsadd L closepath F
.32477 .37011 0 1 Mabsadd m
.32477 .37011 -0.22607 .31116 Mabsadd L
.32477 .37011 -0.95106 .30902 Mabsadd L
.32477 .37011 -0.36579 -0.11885 Mabsadd L
.32477 .37011 -0.58778 -0.80902 Mabsadd L
.32477 .37011 0 -0.38461 Mabsadd L
.32477 .37011 .58779 -0.80902 Mabsadd L
.32477 .37011 .36579 -0.11885 Mabsadd L
.32477 .37011 .95106 .30902 Mabsadd L
.32477 .37011 .22607 .31116 Mabsadd L
.32477 .37011 0 1 Mabsadd L closepath F
.32844 .36906 0 1 Mabsadd m
.32844 .36906 -0.22607 .31116 Mabsadd L
.32844 .36906 -0.95106 .30902 Mabsadd L
.32844 .36906 -0.36579 -0.11885 Mabsadd L
.32844 .36906 -0.58778 -0.80902 Mabsadd L
.32844 .36906 0 -0.38461 Mabsadd L
.32844 .36906 .58779 -0.80902 Mabsadd L
.32844 .36906 .36579 -0.11885 Mabsadd L
.32844 .36906 .95106 .30902 Mabsadd L
.32844 .36906 .22607 .31116 Mabsadd L
.32844 .36906 0 1 Mabsadd L closepath F
.33211 .36843 0 1 Mabsadd m
.33211 .36843 -0.22607 .31116 Mabsadd L
.33211 .36843 -0.95106 .30902 Mabsadd L
.33211 .36843 -0.36579 -0.11885 Mabsadd L
.33211 .36843 -0.58778 -0.80902 Mabsadd L
.33211 .36843 0 -0.38461 Mabsadd L
.33211 .36843 .58779 -0.80902 Mabsadd L
.33211 .36843 .36579 -0.11885 Mabsadd L
.33211 .36843 .95106 .30902 Mabsadd L
.33211 .36843 .22607 .31116 Mabsadd L
.33211 .36843 0 1 Mabsadd L closepath F
.33578 .36771 0 1 Mabsadd m
.33578 .36771 -0.22607 .31116 Mabsadd L
.33578 .36771 -0.95106 .30902 Mabsadd L
.33578 .36771 -0.36579 -0.11885 Mabsadd L
.33578 .36771 -0.58778 -0.80902 Mabsadd L
.33578 .36771 0 -0.38461 Mabsadd L
.33578 .36771 .58779 -0.80902 Mabsadd L
.33578 .36771 .36579 -0.11885 Mabsadd L
.33578 .36771 .95106 .30902 Mabsadd L
.33578 .36771 .22607 .31116 Mabsadd L
.33578 .36771 0 1 Mabsadd L closepath F
.33945 .36701 0 1 Mabsadd m
.33945 .36701 -0.22607 .31116 Mabsadd L
.33945 .36701 -0.95106 .30902 Mabsadd L
.33945 .36701 -0.36579 -0.11885 Mabsadd L
.33945 .36701 -0.58778 -0.80902 Mabsadd L
.33945 .36701 0 -0.38461 Mabsadd L
.33945 .36701 .58779 -0.80902 Mabsadd L
.33945 .36701 .36579 -0.11885 Mabsadd L
.33945 .36701 .95106 .30902 Mabsadd L
.33945 .36701 .22607 .31116 Mabsadd L
.33945 .36701 0 1 Mabsadd L closepath F
.34312 .36612 0 1 Mabsadd m
.34312 .36612 -0.22607 .31116 Mabsadd L
.34312 .36612 -0.95106 .30902 Mabsadd L
.34312 .36612 -0.36579 -0.11885 Mabsadd L
.34312 .36612 -0.58778 -0.80902 Mabsadd L
.34312 .36612 0 -0.38461 Mabsadd L
.34312 .36612 .58779 -0.80902 Mabsadd L
.34312 .36612 .36579 -0.11885 Mabsadd L
.34312 .36612 .95106 .30902 Mabsadd L
.34312 .36612 .22607 .31116 Mabsadd L
.34312 .36612 0 1 Mabsadd L closepath F
.34679 .36518 0 1 Mabsadd m
.34679 .36518 -0.22607 .31116 Mabsadd L
.34679 .36518 -0.95106 .30902 Mabsadd L
.34679 .36518 -0.36579 -0.11885 Mabsadd L
.34679 .36518 -0.58778 -0.80902 Mabsadd L
.34679 .36518 0 -0.38461 Mabsadd L
.34679 .36518 .58779 -0.80902 Mabsadd L
.34679 .36518 .36579 -0.11885 Mabsadd L
.34679 .36518 .95106 .30902 Mabsadd L
.34679 .36518 .22607 .31116 Mabsadd L
.34679 .36518 0 1 Mabsadd L closepath F
.35046 .36426 0 1 Mabsadd m
.35046 .36426 -0.22607 .31116 Mabsadd L
.35046 .36426 -0.95106 .30902 Mabsadd L
.35046 .36426 -0.36579 -0.11885 Mabsadd L
.35046 .36426 -0.58778 -0.80902 Mabsadd L
.35046 .36426 0 -0.38461 Mabsadd L
.35046 .36426 .58779 -0.80902 Mabsadd L
.35046 .36426 .36579 -0.11885 Mabsadd L
.35046 .36426 .95106 .30902 Mabsadd L
.35046 .36426 .22607 .31116 Mabsadd L
.35046 .36426 0 1 Mabsadd L closepath F
.35413 .36362 0 1 Mabsadd m
.35413 .36362 -0.22607 .31116 Mabsadd L
.35413 .36362 -0.95106 .30902 Mabsadd L
.35413 .36362 -0.36579 -0.11885 Mabsadd L
.35413 .36362 -0.58778 -0.80902 Mabsadd L
.35413 .36362 0 -0.38461 Mabsadd L
.35413 .36362 .58779 -0.80902 Mabsadd L
.35413 .36362 .36579 -0.11885 Mabsadd L
.35413 .36362 .95106 .30902 Mabsadd L
.35413 .36362 .22607 .31116 Mabsadd L
.35413 .36362 0 1 Mabsadd L closepath F
.3578 .36279 0 1 Mabsadd m
.3578 .36279 -0.22607 .31116 Mabsadd L
.3578 .36279 -0.95106 .30902 Mabsadd L
.3578 .36279 -0.36579 -0.11885 Mabsadd L
.3578 .36279 -0.58778 -0.80902 Mabsadd L
.3578 .36279 0 -0.38461 Mabsadd L
.3578 .36279 .58779 -0.80902 Mabsadd L
.3578 .36279 .36579 -0.11885 Mabsadd L
.3578 .36279 .95106 .30902 Mabsadd L
.3578 .36279 .22607 .31116 Mabsadd L
.3578 .36279 0 1 Mabsadd L closepath F
.36147 .36196 0 1 Mabsadd m
.36147 .36196 -0.22607 .31116 Mabsadd L
.36147 .36196 -0.95106 .30902 Mabsadd L
.36147 .36196 -0.36579 -0.11885 Mabsadd L
.36147 .36196 -0.58778 -0.80902 Mabsadd L
.36147 .36196 0 -0.38461 Mabsadd L
.36147 .36196 .58779 -0.80902 Mabsadd L
.36147 .36196 .36579 -0.11885 Mabsadd L
.36147 .36196 .95106 .30902 Mabsadd L
.36147 .36196 .22607 .31116 Mabsadd L
.36147 .36196 0 1 Mabsadd L closepath F
.36514 .36126 0 1 Mabsadd m
.36514 .36126 -0.22607 .31116 Mabsadd L
.36514 .36126 -0.95106 .30902 Mabsadd L
.36514 .36126 -0.36579 -0.11885 Mabsadd L
.36514 .36126 -0.58778 -0.80902 Mabsadd L
.36514 .36126 0 -0.38461 Mabsadd L
.36514 .36126 .58779 -0.80902 Mabsadd L
.36514 .36126 .36579 -0.11885 Mabsadd L
.36514 .36126 .95106 .30902 Mabsadd L
.36514 .36126 .22607 .31116 Mabsadd L
.36514 .36126 0 1 Mabsadd L closepath F
.36881 .36029 0 1 Mabsadd m
.36881 .36029 -0.22607 .31116 Mabsadd L
.36881 .36029 -0.95106 .30902 Mabsadd L
.36881 .36029 -0.36579 -0.11885 Mabsadd L
.36881 .36029 -0.58778 -0.80902 Mabsadd L
.36881 .36029 0 -0.38461 Mabsadd L
.36881 .36029 .58779 -0.80902 Mabsadd L
.36881 .36029 .36579 -0.11885 Mabsadd L
.36881 .36029 .95106 .30902 Mabsadd L
.36881 .36029 .22607 .31116 Mabsadd L
.36881 .36029 0 1 Mabsadd L closepath F
.37248 .35926 0 1 Mabsadd m
.37248 .35926 -0.22607 .31116 Mabsadd L
.37248 .35926 -0.95106 .30902 Mabsadd L
.37248 .35926 -0.36579 -0.11885 Mabsadd L
.37248 .35926 -0.58778 -0.80902 Mabsadd L
.37248 .35926 0 -0.38461 Mabsadd L
.37248 .35926 .58779 -0.80902 Mabsadd L
.37248 .35926 .36579 -0.11885 Mabsadd L
.37248 .35926 .95106 .30902 Mabsadd L
.37248 .35926 .22607 .31116 Mabsadd L
.37248 .35926 0 1 Mabsadd L closepath F
.37615 .35843 0 1 Mabsadd m
.37615 .35843 -0.22607 .31116 Mabsadd L
.37615 .35843 -0.95106 .30902 Mabsadd L
.37615 .35843 -0.36579 -0.11885 Mabsadd L
.37615 .35843 -0.58778 -0.80902 Mabsadd L
.37615 .35843 0 -0.38461 Mabsadd L
.37615 .35843 .58779 -0.80902 Mabsadd L
.37615 .35843 .36579 -0.11885 Mabsadd L
.37615 .35843 .95106 .30902 Mabsadd L
.37615 .35843 .22607 .31116 Mabsadd L
.37615 .35843 0 1 Mabsadd L closepath F
.37982 .35761 0 1 Mabsadd m
.37982 .35761 -0.22607 .31116 Mabsadd L
.37982 .35761 -0.95106 .30902 Mabsadd L
.37982 .35761 -0.36579 -0.11885 Mabsadd L
.37982 .35761 -0.58778 -0.80902 Mabsadd L
.37982 .35761 0 -0.38461 Mabsadd L
.37982 .35761 .58779 -0.80902 Mabsadd L
.37982 .35761 .36579 -0.11885 Mabsadd L
.37982 .35761 .95106 .30902 Mabsadd L
.37982 .35761 .22607 .31116 Mabsadd L
.37982 .35761 0 1 Mabsadd L closepath F
.38349 .35688 0 1 Mabsadd m
.38349 .35688 -0.22607 .31116 Mabsadd L
.38349 .35688 -0.95106 .30902 Mabsadd L
.38349 .35688 -0.36579 -0.11885 Mabsadd L
.38349 .35688 -0.58778 -0.80902 Mabsadd L
.38349 .35688 0 -0.38461 Mabsadd L
.38349 .35688 .58779 -0.80902 Mabsadd L
.38349 .35688 .36579 -0.11885 Mabsadd L
.38349 .35688 .95106 .30902 Mabsadd L
.38349 .35688 .22607 .31116 Mabsadd L
.38349 .35688 0 1 Mabsadd L closepath F
.38716 .35581 0 1 Mabsadd m
.38716 .35581 -0.22607 .31116 Mabsadd L
.38716 .35581 -0.95106 .30902 Mabsadd L
.38716 .35581 -0.36579 -0.11885 Mabsadd L
.38716 .35581 -0.58778 -0.80902 Mabsadd L
.38716 .35581 0 -0.38461 Mabsadd L
.38716 .35581 .58779 -0.80902 Mabsadd L
.38716 .35581 .36579 -0.11885 Mabsadd L
.38716 .35581 .95106 .30902 Mabsadd L
.38716 .35581 .22607 .31116 Mabsadd L
.38716 .35581 0 1 Mabsadd L closepath F
.39083 .35484 0 1 Mabsadd m
.39083 .35484 -0.22607 .31116 Mabsadd L
.39083 .35484 -0.95106 .30902 Mabsadd L
.39083 .35484 -0.36579 -0.11885 Mabsadd L
.39083 .35484 -0.58778 -0.80902 Mabsadd L
.39083 .35484 0 -0.38461 Mabsadd L
.39083 .35484 .58779 -0.80902 Mabsadd L
.39083 .35484 .36579 -0.11885 Mabsadd L
.39083 .35484 .95106 .30902 Mabsadd L
.39083 .35484 .22607 .31116 Mabsadd L
.39083 .35484 0 1 Mabsadd L closepath F
.3945 .35386 0 1 Mabsadd m
.3945 .35386 -0.22607 .31116 Mabsadd L
.3945 .35386 -0.95106 .30902 Mabsadd L
.3945 .35386 -0.36579 -0.11885 Mabsadd L
.3945 .35386 -0.58778 -0.80902 Mabsadd L
.3945 .35386 0 -0.38461 Mabsadd L
.3945 .35386 .58779 -0.80902 Mabsadd L
.3945 .35386 .36579 -0.11885 Mabsadd L
.3945 .35386 .95106 .30902 Mabsadd L
.3945 .35386 .22607 .31116 Mabsadd L
.3945 .35386 0 1 Mabsadd L closepath F
.39817 .35315 0 1 Mabsadd m
.39817 .35315 -0.22607 .31116 Mabsadd L
.39817 .35315 -0.95106 .30902 Mabsadd L
.39817 .35315 -0.36579 -0.11885 Mabsadd L
.39817 .35315 -0.58778 -0.80902 Mabsadd L
.39817 .35315 0 -0.38461 Mabsadd L
.39817 .35315 .58779 -0.80902 Mabsadd L
.39817 .35315 .36579 -0.11885 Mabsadd L
.39817 .35315 .95106 .30902 Mabsadd L
.39817 .35315 .22607 .31116 Mabsadd L
.39817 .35315 0 1 Mabsadd L closepath F
.40183 .35219 0 1 Mabsadd m
.40183 .35219 -0.22607 .31116 Mabsadd L
.40183 .35219 -0.95106 .30902 Mabsadd L
.40183 .35219 -0.36579 -0.11885 Mabsadd L
.40183 .35219 -0.58778 -0.80902 Mabsadd L
.40183 .35219 0 -0.38461 Mabsadd L
.40183 .35219 .58779 -0.80902 Mabsadd L
.40183 .35219 .36579 -0.11885 Mabsadd L
.40183 .35219 .95106 .30902 Mabsadd L
.40183 .35219 .22607 .31116 Mabsadd L
.40183 .35219 0 1 Mabsadd L closepath F
.4055 .35134 0 1 Mabsadd m
.4055 .35134 -0.22607 .31116 Mabsadd L
.4055 .35134 -0.95106 .30902 Mabsadd L
.4055 .35134 -0.36579 -0.11885 Mabsadd L
.4055 .35134 -0.58778 -0.80902 Mabsadd L
.4055 .35134 0 -0.38461 Mabsadd L
.4055 .35134 .58779 -0.80902 Mabsadd L
.4055 .35134 .36579 -0.11885 Mabsadd L
.4055 .35134 .95106 .30902 Mabsadd L
.4055 .35134 .22607 .31116 Mabsadd L
.4055 .35134 0 1 Mabsadd L closepath F
.40917 .35044 0 1 Mabsadd m
.40917 .35044 -0.22607 .31116 Mabsadd L
.40917 .35044 -0.95106 .30902 Mabsadd L
.40917 .35044 -0.36579 -0.11885 Mabsadd L
.40917 .35044 -0.58778 -0.80902 Mabsadd L
.40917 .35044 0 -0.38461 Mabsadd L
.40917 .35044 .58779 -0.80902 Mabsadd L
.40917 .35044 .36579 -0.11885 Mabsadd L
.40917 .35044 .95106 .30902 Mabsadd L
.40917 .35044 .22607 .31116 Mabsadd L
.40917 .35044 0 1 Mabsadd L closepath F
.41284 .34966 0 1 Mabsadd m
.41284 .34966 -0.22607 .31116 Mabsadd L
.41284 .34966 -0.95106 .30902 Mabsadd L
.41284 .34966 -0.36579 -0.11885 Mabsadd L
.41284 .34966 -0.58778 -0.80902 Mabsadd L
.41284 .34966 0 -0.38461 Mabsadd L
.41284 .34966 .58779 -0.80902 Mabsadd L
.41284 .34966 .36579 -0.11885 Mabsadd L
.41284 .34966 .95106 .30902 Mabsadd L
.41284 .34966 .22607 .31116 Mabsadd L
.41284 .34966 0 1 Mabsadd L closepath F
.41651 .34884 0 1 Mabsadd m
.41651 .34884 -0.22607 .31116 Mabsadd L
.41651 .34884 -0.95106 .30902 Mabsadd L
.41651 .34884 -0.36579 -0.11885 Mabsadd L
.41651 .34884 -0.58778 -0.80902 Mabsadd L
.41651 .34884 0 -0.38461 Mabsadd L
.41651 .34884 .58779 -0.80902 Mabsadd L
.41651 .34884 .36579 -0.11885 Mabsadd L
.41651 .34884 .95106 .30902 Mabsadd L
.41651 .34884 .22607 .31116 Mabsadd L
.41651 .34884 0 1 Mabsadd L closepath F
.42018 .34814 0 1 Mabsadd m
.42018 .34814 -0.22607 .31116 Mabsadd L
.42018 .34814 -0.95106 .30902 Mabsadd L
.42018 .34814 -0.36579 -0.11885 Mabsadd L
.42018 .34814 -0.58778 -0.80902 Mabsadd L
.42018 .34814 0 -0.38461 Mabsadd L
.42018 .34814 .58779 -0.80902 Mabsadd L
.42018 .34814 .36579 -0.11885 Mabsadd L
.42018 .34814 .95106 .30902 Mabsadd L
.42018 .34814 .22607 .31116 Mabsadd L
.42018 .34814 0 1 Mabsadd L closepath F
.42385 .34726 0 1 Mabsadd m
.42385 .34726 -0.22607 .31116 Mabsadd L
.42385 .34726 -0.95106 .30902 Mabsadd L
.42385 .34726 -0.36579 -0.11885 Mabsadd L
.42385 .34726 -0.58778 -0.80902 Mabsadd L
.42385 .34726 0 -0.38461 Mabsadd L
.42385 .34726 .58779 -0.80902 Mabsadd L
.42385 .34726 .36579 -0.11885 Mabsadd L
.42385 .34726 .95106 .30902 Mabsadd L
.42385 .34726 .22607 .31116 Mabsadd L
.42385 .34726 0 1 Mabsadd L closepath F
.42752 .34661 0 1 Mabsadd m
.42752 .34661 -0.22607 .31116 Mabsadd L
.42752 .34661 -0.95106 .30902 Mabsadd L
.42752 .34661 -0.36579 -0.11885 Mabsadd L
.42752 .34661 -0.58778 -0.80902 Mabsadd L
.42752 .34661 0 -0.38461 Mabsadd L
.42752 .34661 .58779 -0.80902 Mabsadd L
.42752 .34661 .36579 -0.11885 Mabsadd L
.42752 .34661 .95106 .30902 Mabsadd L
.42752 .34661 .22607 .31116 Mabsadd L
.42752 .34661 0 1 Mabsadd L closepath F
.43119 .3458 0 1 Mabsadd m
.43119 .3458 -0.22607 .31116 Mabsadd L
.43119 .3458 -0.95106 .30902 Mabsadd L
.43119 .3458 -0.36579 -0.11885 Mabsadd L
.43119 .3458 -0.58778 -0.80902 Mabsadd L
.43119 .3458 0 -0.38461 Mabsadd L
.43119 .3458 .58779 -0.80902 Mabsadd L
.43119 .3458 .36579 -0.11885 Mabsadd L
.43119 .3458 .95106 .30902 Mabsadd L
.43119 .3458 .22607 .31116 Mabsadd L
.43119 .3458 0 1 Mabsadd L closepath F
.43486 .345 0 1 Mabsadd m
.43486 .345 -0.22607 .31116 Mabsadd L
.43486 .345 -0.95106 .30902 Mabsadd L
.43486 .345 -0.36579 -0.11885 Mabsadd L
.43486 .345 -0.58778 -0.80902 Mabsadd L
.43486 .345 0 -0.38461 Mabsadd L
.43486 .345 .58779 -0.80902 Mabsadd L
.43486 .345 .36579 -0.11885 Mabsadd L
.43486 .345 .95106 .30902 Mabsadd L
.43486 .345 .22607 .31116 Mabsadd L
.43486 .345 0 1 Mabsadd L closepath F
.43853 .34426 0 1 Mabsadd m
.43853 .34426 -0.22607 .31116 Mabsadd L
.43853 .34426 -0.95106 .30902 Mabsadd L
.43853 .34426 -0.36579 -0.11885 Mabsadd L
.43853 .34426 -0.58778 -0.80902 Mabsadd L
.43853 .34426 0 -0.38461 Mabsadd L
.43853 .34426 .58779 -0.80902 Mabsadd L
.43853 .34426 .36579 -0.11885 Mabsadd L
.43853 .34426 .95106 .30902 Mabsadd L
.43853 .34426 .22607 .31116 Mabsadd L
.43853 .34426 0 1 Mabsadd L closepath F
.4422 .34326 0 1 Mabsadd m
.4422 .34326 -0.22607 .31116 Mabsadd L
.4422 .34326 -0.95106 .30902 Mabsadd L
.4422 .34326 -0.36579 -0.11885 Mabsadd L
.4422 .34326 -0.58778 -0.80902 Mabsadd L
.4422 .34326 0 -0.38461 Mabsadd L
.4422 .34326 .58779 -0.80902 Mabsadd L
.4422 .34326 .36579 -0.11885 Mabsadd L
.4422 .34326 .95106 .30902 Mabsadd L
.4422 .34326 .22607 .31116 Mabsadd L
.4422 .34326 0 1 Mabsadd L closepath F
.44587 .34245 0 1 Mabsadd m
.44587 .34245 -0.22607 .31116 Mabsadd L
.44587 .34245 -0.95106 .30902 Mabsadd L
.44587 .34245 -0.36579 -0.11885 Mabsadd L
.44587 .34245 -0.58778 -0.80902 Mabsadd L
.44587 .34245 0 -0.38461 Mabsadd L
.44587 .34245 .58779 -0.80902 Mabsadd L
.44587 .34245 .36579 -0.11885 Mabsadd L
.44587 .34245 .95106 .30902 Mabsadd L
.44587 .34245 .22607 .31116 Mabsadd L
.44587 .34245 0 1 Mabsadd L closepath F
.44954 .34159 0 1 Mabsadd m
.44954 .34159 -0.22607 .31116 Mabsadd L
.44954 .34159 -0.95106 .30902 Mabsadd L
.44954 .34159 -0.36579 -0.11885 Mabsadd L
.44954 .34159 -0.58778 -0.80902 Mabsadd L
.44954 .34159 0 -0.38461 Mabsadd L
.44954 .34159 .58779 -0.80902 Mabsadd L
.44954 .34159 .36579 -0.11885 Mabsadd L
.44954 .34159 .95106 .30902 Mabsadd L
.44954 .34159 .22607 .31116 Mabsadd L
.44954 .34159 0 1 Mabsadd L closepath F
.45321 .34075 0 1 Mabsadd m
.45321 .34075 -0.22607 .31116 Mabsadd L
.45321 .34075 -0.95106 .30902 Mabsadd L
.45321 .34075 -0.36579 -0.11885 Mabsadd L
.45321 .34075 -0.58778 -0.80902 Mabsadd L
.45321 .34075 0 -0.38461 Mabsadd L
.45321 .34075 .58779 -0.80902 Mabsadd L
.45321 .34075 .36579 -0.11885 Mabsadd L
.45321 .34075 .95106 .30902 Mabsadd L
.45321 .34075 .22607 .31116 Mabsadd L
.45321 .34075 0 1 Mabsadd L closepath F
.45688 .33996 0 1 Mabsadd m
.45688 .33996 -0.22607 .31116 Mabsadd L
.45688 .33996 -0.95106 .30902 Mabsadd L
.45688 .33996 -0.36579 -0.11885 Mabsadd L
.45688 .33996 -0.58778 -0.80902 Mabsadd L
.45688 .33996 0 -0.38461 Mabsadd L
.45688 .33996 .58779 -0.80902 Mabsadd L
.45688 .33996 .36579 -0.11885 Mabsadd L
.45688 .33996 .95106 .30902 Mabsadd L
.45688 .33996 .22607 .31116 Mabsadd L
.45688 .33996 0 1 Mabsadd L closepath F
.46055 .33929 0 1 Mabsadd m
.46055 .33929 -0.22607 .31116 Mabsadd L
.46055 .33929 -0.95106 .30902 Mabsadd L
.46055 .33929 -0.36579 -0.11885 Mabsadd L
.46055 .33929 -0.58778 -0.80902 Mabsadd L
.46055 .33929 0 -0.38461 Mabsadd L
.46055 .33929 .58779 -0.80902 Mabsadd L
.46055 .33929 .36579 -0.11885 Mabsadd L
.46055 .33929 .95106 .30902 Mabsadd L
.46055 .33929 .22607 .31116 Mabsadd L
.46055 .33929 0 1 Mabsadd L closepath F
.46422 .33841 0 1 Mabsadd m
.46422 .33841 -0.22607 .31116 Mabsadd L
.46422 .33841 -0.95106 .30902 Mabsadd L
.46422 .33841 -0.36579 -0.11885 Mabsadd L
.46422 .33841 -0.58778 -0.80902 Mabsadd L
.46422 .33841 0 -0.38461 Mabsadd L
.46422 .33841 .58779 -0.80902 Mabsadd L
.46422 .33841 .36579 -0.11885 Mabsadd L
.46422 .33841 .95106 .30902 Mabsadd L
.46422 .33841 .22607 .31116 Mabsadd L
.46422 .33841 0 1 Mabsadd L closepath F
.46789 .33777 0 1 Mabsadd m
.46789 .33777 -0.22607 .31116 Mabsadd L
.46789 .33777 -0.95106 .30902 Mabsadd L
.46789 .33777 -0.36579 -0.11885 Mabsadd L
.46789 .33777 -0.58778 -0.80902 Mabsadd L
.46789 .33777 0 -0.38461 Mabsadd L
.46789 .33777 .58779 -0.80902 Mabsadd L
.46789 .33777 .36579 -0.11885 Mabsadd L
.46789 .33777 .95106 .30902 Mabsadd L
.46789 .33777 .22607 .31116 Mabsadd L
.46789 .33777 0 1 Mabsadd L closepath F
.47156 .337 0 1 Mabsadd m
.47156 .337 -0.22607 .31116 Mabsadd L
.47156 .337 -0.95106 .30902 Mabsadd L
.47156 .337 -0.36579 -0.11885 Mabsadd L
.47156 .337 -0.58778 -0.80902 Mabsadd L
.47156 .337 0 -0.38461 Mabsadd L
.47156 .337 .58779 -0.80902 Mabsadd L
.47156 .337 .36579 -0.11885 Mabsadd L
.47156 .337 .95106 .30902 Mabsadd L
.47156 .337 .22607 .31116 Mabsadd L
.47156 .337 0 1 Mabsadd L closepath F
.47523 .33624 0 1 Mabsadd m
.47523 .33624 -0.22607 .31116 Mabsadd L
.47523 .33624 -0.95106 .30902 Mabsadd L
.47523 .33624 -0.36579 -0.11885 Mabsadd L
.47523 .33624 -0.58778 -0.80902 Mabsadd L
.47523 .33624 0 -0.38461 Mabsadd L
.47523 .33624 .58779 -0.80902 Mabsadd L
.47523 .33624 .36579 -0.11885 Mabsadd L
.47523 .33624 .95106 .30902 Mabsadd L
.47523 .33624 .22607 .31116 Mabsadd L
.47523 .33624 0 1 Mabsadd L closepath F
.4789 .33563 0 1 Mabsadd m
.4789 .33563 -0.22607 .31116 Mabsadd L
.4789 .33563 -0.95106 .30902 Mabsadd L
.4789 .33563 -0.36579 -0.11885 Mabsadd L
.4789 .33563 -0.58778 -0.80902 Mabsadd L
.4789 .33563 0 -0.38461 Mabsadd L
.4789 .33563 .58779 -0.80902 Mabsadd L
.4789 .33563 .36579 -0.11885 Mabsadd L
.4789 .33563 .95106 .30902 Mabsadd L
.4789 .33563 .22607 .31116 Mabsadd L
.4789 .33563 0 1 Mabsadd L closepath F
.48257 .33489 0 1 Mabsadd m
.48257 .33489 -0.22607 .31116 Mabsadd L
.48257 .33489 -0.95106 .30902 Mabsadd L
.48257 .33489 -0.36579 -0.11885 Mabsadd L
.48257 .33489 -0.58778 -0.80902 Mabsadd L
.48257 .33489 0 -0.38461 Mabsadd L
.48257 .33489 .58779 -0.80902 Mabsadd L
.48257 .33489 .36579 -0.11885 Mabsadd L
.48257 .33489 .95106 .30902 Mabsadd L
.48257 .33489 .22607 .31116 Mabsadd L
.48257 .33489 0 1 Mabsadd L closepath F
.48624 .33419 0 1 Mabsadd m
.48624 .33419 -0.22607 .31116 Mabsadd L
.48624 .33419 -0.95106 .30902 Mabsadd L
.48624 .33419 -0.36579 -0.11885 Mabsadd L
.48624 .33419 -0.58778 -0.80902 Mabsadd L
.48624 .33419 0 -0.38461 Mabsadd L
.48624 .33419 .58779 -0.80902 Mabsadd L
.48624 .33419 .36579 -0.11885 Mabsadd L
.48624 .33419 .95106 .30902 Mabsadd L
.48624 .33419 .22607 .31116 Mabsadd L
.48624 .33419 0 1 Mabsadd L closepath F
.48991 .33363 0 1 Mabsadd m
.48991 .33363 -0.22607 .31116 Mabsadd L
.48991 .33363 -0.95106 .30902 Mabsadd L
.48991 .33363 -0.36579 -0.11885 Mabsadd L
.48991 .33363 -0.58778 -0.80902 Mabsadd L
.48991 .33363 0 -0.38461 Mabsadd L
.48991 .33363 .58779 -0.80902 Mabsadd L
.48991 .33363 .36579 -0.11885 Mabsadd L
.48991 .33363 .95106 .30902 Mabsadd L
.48991 .33363 .22607 .31116 Mabsadd L
.48991 .33363 0 1 Mabsadd L closepath F
.49358 .33307 0 1 Mabsadd m
.49358 .33307 -0.22607 .31116 Mabsadd L
.49358 .33307 -0.95106 .30902 Mabsadd L
.49358 .33307 -0.36579 -0.11885 Mabsadd L
.49358 .33307 -0.58778 -0.80902 Mabsadd L
.49358 .33307 0 -0.38461 Mabsadd L
.49358 .33307 .58779 -0.80902 Mabsadd L
.49358 .33307 .36579 -0.11885 Mabsadd L
.49358 .33307 .95106 .30902 Mabsadd L
.49358 .33307 .22607 .31116 Mabsadd L
.49358 .33307 0 1 Mabsadd L closepath F
.49725 .33259 0 1 Mabsadd m
.49725 .33259 -0.22607 .31116 Mabsadd L
.49725 .33259 -0.95106 .30902 Mabsadd L
.49725 .33259 -0.36579 -0.11885 Mabsadd L
.49725 .33259 -0.58778 -0.80902 Mabsadd L
.49725 .33259 0 -0.38461 Mabsadd L
.49725 .33259 .58779 -0.80902 Mabsadd L
.49725 .33259 .36579 -0.11885 Mabsadd L
.49725 .33259 .95106 .30902 Mabsadd L
.49725 .33259 .22607 .31116 Mabsadd L
.49725 .33259 0 1 Mabsadd L closepath F
.50092 .33194 0 1 Mabsadd m
.50092 .33194 -0.22607 .31116 Mabsadd L
.50092 .33194 -0.95106 .30902 Mabsadd L
.50092 .33194 -0.36579 -0.11885 Mabsadd L
.50092 .33194 -0.58778 -0.80902 Mabsadd L
.50092 .33194 0 -0.38461 Mabsadd L
.50092 .33194 .58779 -0.80902 Mabsadd L
.50092 .33194 .36579 -0.11885 Mabsadd L
.50092 .33194 .95106 .30902 Mabsadd L
.50092 .33194 .22607 .31116 Mabsadd L
.50092 .33194 0 1 Mabsadd L closepath F
.50459 .33119 0 1 Mabsadd m
.50459 .33119 -0.22607 .31116 Mabsadd L
.50459 .33119 -0.95106 .30902 Mabsadd L
.50459 .33119 -0.36579 -0.11885 Mabsadd L
.50459 .33119 -0.58778 -0.80902 Mabsadd L
.50459 .33119 0 -0.38461 Mabsadd L
.50459 .33119 .58779 -0.80902 Mabsadd L
.50459 .33119 .36579 -0.11885 Mabsadd L
.50459 .33119 .95106 .30902 Mabsadd L
.50459 .33119 .22607 .31116 Mabsadd L
.50459 .33119 0 1 Mabsadd L closepath F
.50826 .33028 0 1 Mabsadd m
.50826 .33028 -0.22607 .31116 Mabsadd L
.50826 .33028 -0.95106 .30902 Mabsadd L
.50826 .33028 -0.36579 -0.11885 Mabsadd L
.50826 .33028 -0.58778 -0.80902 Mabsadd L
.50826 .33028 0 -0.38461 Mabsadd L
.50826 .33028 .58779 -0.80902 Mabsadd L
.50826 .33028 .36579 -0.11885 Mabsadd L
.50826 .33028 .95106 .30902 Mabsadd L
.50826 .33028 .22607 .31116 Mabsadd L
.50826 .33028 0 1 Mabsadd L closepath F
.51193 .32931 0 1 Mabsadd m
.51193 .32931 -0.22607 .31116 Mabsadd L
.51193 .32931 -0.95106 .30902 Mabsadd L
.51193 .32931 -0.36579 -0.11885 Mabsadd L
.51193 .32931 -0.58778 -0.80902 Mabsadd L
.51193 .32931 0 -0.38461 Mabsadd L
.51193 .32931 .58779 -0.80902 Mabsadd L
.51193 .32931 .36579 -0.11885 Mabsadd L
.51193 .32931 .95106 .30902 Mabsadd L
.51193 .32931 .22607 .31116 Mabsadd L
.51193 .32931 0 1 Mabsadd L closepath F
.5156 .3288 0 1 Mabsadd m
.5156 .3288 -0.22607 .31116 Mabsadd L
.5156 .3288 -0.95106 .30902 Mabsadd L
.5156 .3288 -0.36579 -0.11885 Mabsadd L
.5156 .3288 -0.58778 -0.80902 Mabsadd L
.5156 .3288 0 -0.38461 Mabsadd L
.5156 .3288 .58779 -0.80902 Mabsadd L
.5156 .3288 .36579 -0.11885 Mabsadd L
.5156 .3288 .95106 .30902 Mabsadd L
.5156 .3288 .22607 .31116 Mabsadd L
.5156 .3288 0 1 Mabsadd L closepath F
.51927 .32802 0 1 Mabsadd m
.51927 .32802 -0.22607 .31116 Mabsadd L
.51927 .32802 -0.95106 .30902 Mabsadd L
.51927 .32802 -0.36579 -0.11885 Mabsadd L
.51927 .32802 -0.58778 -0.80902 Mabsadd L
.51927 .32802 0 -0.38461 Mabsadd L
.51927 .32802 .58779 -0.80902 Mabsadd L
.51927 .32802 .36579 -0.11885 Mabsadd L
.51927 .32802 .95106 .30902 Mabsadd L
.51927 .32802 .22607 .31116 Mabsadd L
.51927 .32802 0 1 Mabsadd L closepath F
.52294 .32732 0 1 Mabsadd m
.52294 .32732 -0.22607 .31116 Mabsadd L
.52294 .32732 -0.95106 .30902 Mabsadd L
.52294 .32732 -0.36579 -0.11885 Mabsadd L
.52294 .32732 -0.58778 -0.80902 Mabsadd L
.52294 .32732 0 -0.38461 Mabsadd L
.52294 .32732 .58779 -0.80902 Mabsadd L
.52294 .32732 .36579 -0.11885 Mabsadd L
.52294 .32732 .95106 .30902 Mabsadd L
.52294 .32732 .22607 .31116 Mabsadd L
.52294 .32732 0 1 Mabsadd L closepath F
.52661 .3267 0 1 Mabsadd m
.52661 .3267 -0.22607 .31116 Mabsadd L
.52661 .3267 -0.95106 .30902 Mabsadd L
.52661 .3267 -0.36579 -0.11885 Mabsadd L
.52661 .3267 -0.58778 -0.80902 Mabsadd L
.52661 .3267 0 -0.38461 Mabsadd L
.52661 .3267 .58779 -0.80902 Mabsadd L
.52661 .3267 .36579 -0.11885 Mabsadd L
.52661 .3267 .95106 .30902 Mabsadd L
.52661 .3267 .22607 .31116 Mabsadd L
.52661 .3267 0 1 Mabsadd L closepath F
.53028 .32604 0 1 Mabsadd m
.53028 .32604 -0.22607 .31116 Mabsadd L
.53028 .32604 -0.95106 .30902 Mabsadd L
.53028 .32604 -0.36579 -0.11885 Mabsadd L
.53028 .32604 -0.58778 -0.80902 Mabsadd L
.53028 .32604 0 -0.38461 Mabsadd L
.53028 .32604 .58779 -0.80902 Mabsadd L
.53028 .32604 .36579 -0.11885 Mabsadd L
.53028 .32604 .95106 .30902 Mabsadd L
.53028 .32604 .22607 .31116 Mabsadd L
.53028 .32604 0 1 Mabsadd L closepath F
.53394 .32544 0 1 Mabsadd m
.53394 .32544 -0.22607 .31116 Mabsadd L
.53394 .32544 -0.95106 .30902 Mabsadd L
.53394 .32544 -0.36579 -0.11885 Mabsadd L
.53394 .32544 -0.58778 -0.80902 Mabsadd L
.53394 .32544 0 -0.38461 Mabsadd L
.53394 .32544 .58779 -0.80902 Mabsadd L
.53394 .32544 .36579 -0.11885 Mabsadd L
.53394 .32544 .95106 .30902 Mabsadd L
.53394 .32544 .22607 .31116 Mabsadd L
.53394 .32544 0 1 Mabsadd L closepath F
.53761 .32473 0 1 Mabsadd m
.53761 .32473 -0.22607 .31116 Mabsadd L
.53761 .32473 -0.95106 .30902 Mabsadd L
.53761 .32473 -0.36579 -0.11885 Mabsadd L
.53761 .32473 -0.58778 -0.80902 Mabsadd L
.53761 .32473 0 -0.38461 Mabsadd L
.53761 .32473 .58779 -0.80902 Mabsadd L
.53761 .32473 .36579 -0.11885 Mabsadd L
.53761 .32473 .95106 .30902 Mabsadd L
.53761 .32473 .22607 .31116 Mabsadd L
.53761 .32473 0 1 Mabsadd L closepath F
.54128 .32403 0 1 Mabsadd m
.54128 .32403 -0.22607 .31116 Mabsadd L
.54128 .32403 -0.95106 .30902 Mabsadd L
.54128 .32403 -0.36579 -0.11885 Mabsadd L
.54128 .32403 -0.58778 -0.80902 Mabsadd L
.54128 .32403 0 -0.38461 Mabsadd L
.54128 .32403 .58779 -0.80902 Mabsadd L
.54128 .32403 .36579 -0.11885 Mabsadd L
.54128 .32403 .95106 .30902 Mabsadd L
.54128 .32403 .22607 .31116 Mabsadd L
.54128 .32403 0 1 Mabsadd L closepath F
.54495 .32339 0 1 Mabsadd m
.54495 .32339 -0.22607 .31116 Mabsadd L
.54495 .32339 -0.95106 .30902 Mabsadd L
.54495 .32339 -0.36579 -0.11885 Mabsadd L
.54495 .32339 -0.58778 -0.80902 Mabsadd L
.54495 .32339 0 -0.38461 Mabsadd L
.54495 .32339 .58779 -0.80902 Mabsadd L
.54495 .32339 .36579 -0.11885 Mabsadd L
.54495 .32339 .95106 .30902 Mabsadd L
.54495 .32339 .22607 .31116 Mabsadd L
.54495 .32339 0 1 Mabsadd L closepath F
.54862 .32256 0 1 Mabsadd m
.54862 .32256 -0.22607 .31116 Mabsadd L
.54862 .32256 -0.95106 .30902 Mabsadd L
.54862 .32256 -0.36579 -0.11885 Mabsadd L
.54862 .32256 -0.58778 -0.80902 Mabsadd L
.54862 .32256 0 -0.38461 Mabsadd L
.54862 .32256 .58779 -0.80902 Mabsadd L
.54862 .32256 .36579 -0.11885 Mabsadd L
.54862 .32256 .95106 .30902 Mabsadd L
.54862 .32256 .22607 .31116 Mabsadd L
.54862 .32256 0 1 Mabsadd L closepath F
.55229 .32181 0 1 Mabsadd m
.55229 .32181 -0.22607 .31116 Mabsadd L
.55229 .32181 -0.95106 .30902 Mabsadd L
.55229 .32181 -0.36579 -0.11885 Mabsadd L
.55229 .32181 -0.58778 -0.80902 Mabsadd L
.55229 .32181 0 -0.38461 Mabsadd L
.55229 .32181 .58779 -0.80902 Mabsadd L
.55229 .32181 .36579 -0.11885 Mabsadd L
.55229 .32181 .95106 .30902 Mabsadd L
.55229 .32181 .22607 .31116 Mabsadd L
.55229 .32181 0 1 Mabsadd L closepath F
.55596 .32104 0 1 Mabsadd m
.55596 .32104 -0.22607 .31116 Mabsadd L
.55596 .32104 -0.95106 .30902 Mabsadd L
.55596 .32104 -0.36579 -0.11885 Mabsadd L
.55596 .32104 -0.58778 -0.80902 Mabsadd L
.55596 .32104 0 -0.38461 Mabsadd L
.55596 .32104 .58779 -0.80902 Mabsadd L
.55596 .32104 .36579 -0.11885 Mabsadd L
.55596 .32104 .95106 .30902 Mabsadd L
.55596 .32104 .22607 .31116 Mabsadd L
.55596 .32104 0 1 Mabsadd L closepath F
.55963 .32031 0 1 Mabsadd m
.55963 .32031 -0.22607 .31116 Mabsadd L
.55963 .32031 -0.95106 .30902 Mabsadd L
.55963 .32031 -0.36579 -0.11885 Mabsadd L
.55963 .32031 -0.58778 -0.80902 Mabsadd L
.55963 .32031 0 -0.38461 Mabsadd L
.55963 .32031 .58779 -0.80902 Mabsadd L
.55963 .32031 .36579 -0.11885 Mabsadd L
.55963 .32031 .95106 .30902 Mabsadd L
.55963 .32031 .22607 .31116 Mabsadd L
.55963 .32031 0 1 Mabsadd L closepath F
.5633 .31951 0 1 Mabsadd m
.5633 .31951 -0.22607 .31116 Mabsadd L
.5633 .31951 -0.95106 .30902 Mabsadd L
.5633 .31951 -0.36579 -0.11885 Mabsadd L
.5633 .31951 -0.58778 -0.80902 Mabsadd L
.5633 .31951 0 -0.38461 Mabsadd L
.5633 .31951 .58779 -0.80902 Mabsadd L
.5633 .31951 .36579 -0.11885 Mabsadd L
.5633 .31951 .95106 .30902 Mabsadd L
.5633 .31951 .22607 .31116 Mabsadd L
.5633 .31951 0 1 Mabsadd L closepath F
.56697 .3188 0 1 Mabsadd m
.56697 .3188 -0.22607 .31116 Mabsadd L
.56697 .3188 -0.95106 .30902 Mabsadd L
.56697 .3188 -0.36579 -0.11885 Mabsadd L
.56697 .3188 -0.58778 -0.80902 Mabsadd L
.56697 .3188 0 -0.38461 Mabsadd L
.56697 .3188 .58779 -0.80902 Mabsadd L
.56697 .3188 .36579 -0.11885 Mabsadd L
.56697 .3188 .95106 .30902 Mabsadd L
.56697 .3188 .22607 .31116 Mabsadd L
.56697 .3188 0 1 Mabsadd L closepath F
.57064 .31812 0 1 Mabsadd m
.57064 .31812 -0.22607 .31116 Mabsadd L
.57064 .31812 -0.95106 .30902 Mabsadd L
.57064 .31812 -0.36579 -0.11885 Mabsadd L
.57064 .31812 -0.58778 -0.80902 Mabsadd L
.57064 .31812 0 -0.38461 Mabsadd L
.57064 .31812 .58779 -0.80902 Mabsadd L
.57064 .31812 .36579 -0.11885 Mabsadd L
.57064 .31812 .95106 .30902 Mabsadd L
.57064 .31812 .22607 .31116 Mabsadd L
.57064 .31812 0 1 Mabsadd L closepath F
.57431 .31746 0 1 Mabsadd m
.57431 .31746 -0.22607 .31116 Mabsadd L
.57431 .31746 -0.95106 .30902 Mabsadd L
.57431 .31746 -0.36579 -0.11885 Mabsadd L
.57431 .31746 -0.58778 -0.80902 Mabsadd L
.57431 .31746 0 -0.38461 Mabsadd L
.57431 .31746 .58779 -0.80902 Mabsadd L
.57431 .31746 .36579 -0.11885 Mabsadd L
.57431 .31746 .95106 .30902 Mabsadd L
.57431 .31746 .22607 .31116 Mabsadd L
.57431 .31746 0 1 Mabsadd L closepath F
.57798 .31688 0 1 Mabsadd m
.57798 .31688 -0.22607 .31116 Mabsadd L
.57798 .31688 -0.95106 .30902 Mabsadd L
.57798 .31688 -0.36579 -0.11885 Mabsadd L
.57798 .31688 -0.58778 -0.80902 Mabsadd L
.57798 .31688 0 -0.38461 Mabsadd L
.57798 .31688 .58779 -0.80902 Mabsadd L
.57798 .31688 .36579 -0.11885 Mabsadd L
.57798 .31688 .95106 .30902 Mabsadd L
.57798 .31688 .22607 .31116 Mabsadd L
.57798 .31688 0 1 Mabsadd L closepath F
.58165 .31608 0 1 Mabsadd m
.58165 .31608 -0.22607 .31116 Mabsadd L
.58165 .31608 -0.95106 .30902 Mabsadd L
.58165 .31608 -0.36579 -0.11885 Mabsadd L
.58165 .31608 -0.58778 -0.80902 Mabsadd L
.58165 .31608 0 -0.38461 Mabsadd L
.58165 .31608 .58779 -0.80902 Mabsadd L
.58165 .31608 .36579 -0.11885 Mabsadd L
.58165 .31608 .95106 .30902 Mabsadd L
.58165 .31608 .22607 .31116 Mabsadd L
.58165 .31608 0 1 Mabsadd L closepath F
.58532 .31531 0 1 Mabsadd m
.58532 .31531 -0.22607 .31116 Mabsadd L
.58532 .31531 -0.95106 .30902 Mabsadd L
.58532 .31531 -0.36579 -0.11885 Mabsadd L
.58532 .31531 -0.58778 -0.80902 Mabsadd L
.58532 .31531 0 -0.38461 Mabsadd L
.58532 .31531 .58779 -0.80902 Mabsadd L
.58532 .31531 .36579 -0.11885 Mabsadd L
.58532 .31531 .95106 .30902 Mabsadd L
.58532 .31531 .22607 .31116 Mabsadd L
.58532 .31531 0 1 Mabsadd L closepath F
.58899 .31467 0 1 Mabsadd m
.58899 .31467 -0.22607 .31116 Mabsadd L
.58899 .31467 -0.95106 .30902 Mabsadd L
.58899 .31467 -0.36579 -0.11885 Mabsadd L
.58899 .31467 -0.58778 -0.80902 Mabsadd L
.58899 .31467 0 -0.38461 Mabsadd L
.58899 .31467 .58779 -0.80902 Mabsadd L
.58899 .31467 .36579 -0.11885 Mabsadd L
.58899 .31467 .95106 .30902 Mabsadd L
.58899 .31467 .22607 .31116 Mabsadd L
.58899 .31467 0 1 Mabsadd L closepath F
.59266 .3139 0 1 Mabsadd m
.59266 .3139 -0.22607 .31116 Mabsadd L
.59266 .3139 -0.95106 .30902 Mabsadd L
.59266 .3139 -0.36579 -0.11885 Mabsadd L
.59266 .3139 -0.58778 -0.80902 Mabsadd L
.59266 .3139 0 -0.38461 Mabsadd L
.59266 .3139 .58779 -0.80902 Mabsadd L
.59266 .3139 .36579 -0.11885 Mabsadd L
.59266 .3139 .95106 .30902 Mabsadd L
.59266 .3139 .22607 .31116 Mabsadd L
.59266 .3139 0 1 Mabsadd L closepath F
.59633 .31331 0 1 Mabsadd m
.59633 .31331 -0.22607 .31116 Mabsadd L
.59633 .31331 -0.95106 .30902 Mabsadd L
.59633 .31331 -0.36579 -0.11885 Mabsadd L
.59633 .31331 -0.58778 -0.80902 Mabsadd L
.59633 .31331 0 -0.38461 Mabsadd L
.59633 .31331 .58779 -0.80902 Mabsadd L
.59633 .31331 .36579 -0.11885 Mabsadd L
.59633 .31331 .95106 .30902 Mabsadd L
.59633 .31331 .22607 .31116 Mabsadd L
.59633 .31331 0 1 Mabsadd L closepath F
.6 .31288 0 1 Mabsadd m
.6 .31288 -0.22607 .31116 Mabsadd L
.6 .31288 -0.95106 .30902 Mabsadd L
.6 .31288 -0.36579 -0.11885 Mabsadd L
.6 .31288 -0.58778 -0.80902 Mabsadd L
.6 .31288 0 -0.38461 Mabsadd L
.6 .31288 .58779 -0.80902 Mabsadd L
.6 .31288 .36579 -0.11885 Mabsadd L
.6 .31288 .95106 .30902 Mabsadd L
.6 .31288 .22607 .31116 Mabsadd L
.6 .31288 0 1 Mabsadd L closepath F
.60367 .31218 0 1 Mabsadd m
.60367 .31218 -0.22607 .31116 Mabsadd L
.60367 .31218 -0.95106 .30902 Mabsadd L
.60367 .31218 -0.36579 -0.11885 Mabsadd L
.60367 .31218 -0.58778 -0.80902 Mabsadd L
.60367 .31218 0 -0.38461 Mabsadd L
.60367 .31218 .58779 -0.80902 Mabsadd L
.60367 .31218 .36579 -0.11885 Mabsadd L
.60367 .31218 .95106 .30902 Mabsadd L
.60367 .31218 .22607 .31116 Mabsadd L
.60367 .31218 0 1 Mabsadd L closepath F
.60734 .31166 0 1 Mabsadd m
.60734 .31166 -0.22607 .31116 Mabsadd L
.60734 .31166 -0.95106 .30902 Mabsadd L
.60734 .31166 -0.36579 -0.11885 Mabsadd L
.60734 .31166 -0.58778 -0.80902 Mabsadd L
.60734 .31166 0 -0.38461 Mabsadd L
.60734 .31166 .58779 -0.80902 Mabsadd L
.60734 .31166 .36579 -0.11885 Mabsadd L
.60734 .31166 .95106 .30902 Mabsadd L
.60734 .31166 .22607 .31116 Mabsadd L
.60734 .31166 0 1 Mabsadd L closepath F
.61101 .311 0 1 Mabsadd m
.61101 .311 -0.22607 .31116 Mabsadd L
.61101 .311 -0.95106 .30902 Mabsadd L
.61101 .311 -0.36579 -0.11885 Mabsadd L
.61101 .311 -0.58778 -0.80902 Mabsadd L
.61101 .311 0 -0.38461 Mabsadd L
.61101 .311 .58779 -0.80902 Mabsadd L
.61101 .311 .36579 -0.11885 Mabsadd L
.61101 .311 .95106 .30902 Mabsadd L
.61101 .311 .22607 .31116 Mabsadd L
.61101 .311 0 1 Mabsadd L closepath F
.61468 .31046 0 1 Mabsadd m
.61468 .31046 -0.22607 .31116 Mabsadd L
.61468 .31046 -0.95106 .30902 Mabsadd L
.61468 .31046 -0.36579 -0.11885 Mabsadd L
.61468 .31046 -0.58778 -0.80902 Mabsadd L
.61468 .31046 0 -0.38461 Mabsadd L
.61468 .31046 .58779 -0.80902 Mabsadd L
.61468 .31046 .36579 -0.11885 Mabsadd L
.61468 .31046 .95106 .30902 Mabsadd L
.61468 .31046 .22607 .31116 Mabsadd L
.61468 .31046 0 1 Mabsadd L closepath F
.61835 .30991 0 1 Mabsadd m
.61835 .30991 -0.22607 .31116 Mabsadd L
.61835 .30991 -0.95106 .30902 Mabsadd L
.61835 .30991 -0.36579 -0.11885 Mabsadd L
.61835 .30991 -0.58778 -0.80902 Mabsadd L
.61835 .30991 0 -0.38461 Mabsadd L
.61835 .30991 .58779 -0.80902 Mabsadd L
.61835 .30991 .36579 -0.11885 Mabsadd L
.61835 .30991 .95106 .30902 Mabsadd L
.61835 .30991 .22607 .31116 Mabsadd L
.61835 .30991 0 1 Mabsadd L closepath F
.62202 .30919 0 1 Mabsadd m
.62202 .30919 -0.22607 .31116 Mabsadd L
.62202 .30919 -0.95106 .30902 Mabsadd L
.62202 .30919 -0.36579 -0.11885 Mabsadd L
.62202 .30919 -0.58778 -0.80902 Mabsadd L
.62202 .30919 0 -0.38461 Mabsadd L
.62202 .30919 .58779 -0.80902 Mabsadd L
.62202 .30919 .36579 -0.11885 Mabsadd L
.62202 .30919 .95106 .30902 Mabsadd L
.62202 .30919 .22607 .31116 Mabsadd L
.62202 .30919 0 1 Mabsadd L closepath F
.62569 .30839 0 1 Mabsadd m
.62569 .30839 -0.22607 .31116 Mabsadd L
.62569 .30839 -0.95106 .30902 Mabsadd L
.62569 .30839 -0.36579 -0.11885 Mabsadd L
.62569 .30839 -0.58778 -0.80902 Mabsadd L
.62569 .30839 0 -0.38461 Mabsadd L
.62569 .30839 .58779 -0.80902 Mabsadd L
.62569 .30839 .36579 -0.11885 Mabsadd L
.62569 .30839 .95106 .30902 Mabsadd L
.62569 .30839 .22607 .31116 Mabsadd L
.62569 .30839 0 1 Mabsadd L closepath F
.62936 .30777 0 1 Mabsadd m
.62936 .30777 -0.22607 .31116 Mabsadd L
.62936 .30777 -0.95106 .30902 Mabsadd L
.62936 .30777 -0.36579 -0.11885 Mabsadd L
.62936 .30777 -0.58778 -0.80902 Mabsadd L
.62936 .30777 0 -0.38461 Mabsadd L
.62936 .30777 .58779 -0.80902 Mabsadd L
.62936 .30777 .36579 -0.11885 Mabsadd L
.62936 .30777 .95106 .30902 Mabsadd L
.62936 .30777 .22607 .31116 Mabsadd L
.62936 .30777 0 1 Mabsadd L closepath F
.63303 .30707 0 1 Mabsadd m
.63303 .30707 -0.22607 .31116 Mabsadd L
.63303 .30707 -0.95106 .30902 Mabsadd L
.63303 .30707 -0.36579 -0.11885 Mabsadd L
.63303 .30707 -0.58778 -0.80902 Mabsadd L
.63303 .30707 0 -0.38461 Mabsadd L
.63303 .30707 .58779 -0.80902 Mabsadd L
.63303 .30707 .36579 -0.11885 Mabsadd L
.63303 .30707 .95106 .30902 Mabsadd L
.63303 .30707 .22607 .31116 Mabsadd L
.63303 .30707 0 1 Mabsadd L closepath F
.6367 .30631 0 1 Mabsadd m
.6367 .30631 -0.22607 .31116 Mabsadd L
.6367 .30631 -0.95106 .30902 Mabsadd L
.6367 .30631 -0.36579 -0.11885 Mabsadd L
.6367 .30631 -0.58778 -0.80902 Mabsadd L
.6367 .30631 0 -0.38461 Mabsadd L
.6367 .30631 .58779 -0.80902 Mabsadd L
.6367 .30631 .36579 -0.11885 Mabsadd L
.6367 .30631 .95106 .30902 Mabsadd L
.6367 .30631 .22607 .31116 Mabsadd L
.6367 .30631 0 1 Mabsadd L closepath F
.64037 .30567 0 1 Mabsadd m
.64037 .30567 -0.22607 .31116 Mabsadd L
.64037 .30567 -0.95106 .30902 Mabsadd L
.64037 .30567 -0.36579 -0.11885 Mabsadd L
.64037 .30567 -0.58778 -0.80902 Mabsadd L
.64037 .30567 0 -0.38461 Mabsadd L
.64037 .30567 .58779 -0.80902 Mabsadd L
.64037 .30567 .36579 -0.11885 Mabsadd L
.64037 .30567 .95106 .30902 Mabsadd L
.64037 .30567 .22607 .31116 Mabsadd L
.64037 .30567 0 1 Mabsadd L closepath F
.64404 .30511 0 1 Mabsadd m
.64404 .30511 -0.22607 .31116 Mabsadd L
.64404 .30511 -0.95106 .30902 Mabsadd L
.64404 .30511 -0.36579 -0.11885 Mabsadd L
.64404 .30511 -0.58778 -0.80902 Mabsadd L
.64404 .30511 0 -0.38461 Mabsadd L
.64404 .30511 .58779 -0.80902 Mabsadd L
.64404 .30511 .36579 -0.11885 Mabsadd L
.64404 .30511 .95106 .30902 Mabsadd L
.64404 .30511 .22607 .31116 Mabsadd L
.64404 .30511 0 1 Mabsadd L closepath F
.64771 .30419 0 1 Mabsadd m
.64771 .30419 -0.22607 .31116 Mabsadd L
.64771 .30419 -0.95106 .30902 Mabsadd L
.64771 .30419 -0.36579 -0.11885 Mabsadd L
.64771 .30419 -0.58778 -0.80902 Mabsadd L
.64771 .30419 0 -0.38461 Mabsadd L
.64771 .30419 .58779 -0.80902 Mabsadd L
.64771 .30419 .36579 -0.11885 Mabsadd L
.64771 .30419 .95106 .30902 Mabsadd L
.64771 .30419 .22607 .31116 Mabsadd L
.64771 .30419 0 1 Mabsadd L closepath F
.65138 .30352 0 1 Mabsadd m
.65138 .30352 -0.22607 .31116 Mabsadd L
.65138 .30352 -0.95106 .30902 Mabsadd L
.65138 .30352 -0.36579 -0.11885 Mabsadd L
.65138 .30352 -0.58778 -0.80902 Mabsadd L
.65138 .30352 0 -0.38461 Mabsadd L
.65138 .30352 .58779 -0.80902 Mabsadd L
.65138 .30352 .36579 -0.11885 Mabsadd L
.65138 .30352 .95106 .30902 Mabsadd L
.65138 .30352 .22607 .31116 Mabsadd L
.65138 .30352 0 1 Mabsadd L closepath F
.65505 .30267 0 1 Mabsadd m
.65505 .30267 -0.22607 .31116 Mabsadd L
.65505 .30267 -0.95106 .30902 Mabsadd L
.65505 .30267 -0.36579 -0.11885 Mabsadd L
.65505 .30267 -0.58778 -0.80902 Mabsadd L
.65505 .30267 0 -0.38461 Mabsadd L
.65505 .30267 .58779 -0.80902 Mabsadd L
.65505 .30267 .36579 -0.11885 Mabsadd L
.65505 .30267 .95106 .30902 Mabsadd L
.65505 .30267 .22607 .31116 Mabsadd L
.65505 .30267 0 1 Mabsadd L closepath F
.65872 .3019 0 1 Mabsadd m
.65872 .3019 -0.22607 .31116 Mabsadd L
.65872 .3019 -0.95106 .30902 Mabsadd L
.65872 .3019 -0.36579 -0.11885 Mabsadd L
.65872 .3019 -0.58778 -0.80902 Mabsadd L
.65872 .3019 0 -0.38461 Mabsadd L
.65872 .3019 .58779 -0.80902 Mabsadd L
.65872 .3019 .36579 -0.11885 Mabsadd L
.65872 .3019 .95106 .30902 Mabsadd L
.65872 .3019 .22607 .31116 Mabsadd L
.65872 .3019 0 1 Mabsadd L closepath F
.66239 .30122 0 1 Mabsadd m
.66239 .30122 -0.22607 .31116 Mabsadd L
.66239 .30122 -0.95106 .30902 Mabsadd L
.66239 .30122 -0.36579 -0.11885 Mabsadd L
.66239 .30122 -0.58778 -0.80902 Mabsadd L
.66239 .30122 0 -0.38461 Mabsadd L
.66239 .30122 .58779 -0.80902 Mabsadd L
.66239 .30122 .36579 -0.11885 Mabsadd L
.66239 .30122 .95106 .30902 Mabsadd L
.66239 .30122 .22607 .31116 Mabsadd L
.66239 .30122 0 1 Mabsadd L closepath F
.66606 .30048 0 1 Mabsadd m
.66606 .30048 -0.22607 .31116 Mabsadd L
.66606 .30048 -0.95106 .30902 Mabsadd L
.66606 .30048 -0.36579 -0.11885 Mabsadd L
.66606 .30048 -0.58778 -0.80902 Mabsadd L
.66606 .30048 0 -0.38461 Mabsadd L
.66606 .30048 .58779 -0.80902 Mabsadd L
.66606 .30048 .36579 -0.11885 Mabsadd L
.66606 .30048 .95106 .30902 Mabsadd L
.66606 .30048 .22607 .31116 Mabsadd L
.66606 .30048 0 1 Mabsadd L closepath F
.66972 .3 0 1 Mabsadd m
.66972 .3 -0.22607 .31116 Mabsadd L
.66972 .3 -0.95106 .30902 Mabsadd L
.66972 .3 -0.36579 -0.11885 Mabsadd L
.66972 .3 -0.58778 -0.80902 Mabsadd L
.66972 .3 0 -0.38461 Mabsadd L
.66972 .3 .58779 -0.80902 Mabsadd L
.66972 .3 .36579 -0.11885 Mabsadd L
.66972 .3 .95106 .30902 Mabsadd L
.66972 .3 .22607 .31116 Mabsadd L
.66972 .3 0 1 Mabsadd L closepath F
.67339 .29937 0 1 Mabsadd m
.67339 .29937 -0.22607 .31116 Mabsadd L
.67339 .29937 -0.95106 .30902 Mabsadd L
.67339 .29937 -0.36579 -0.11885 Mabsadd L
.67339 .29937 -0.58778 -0.80902 Mabsadd L
.67339 .29937 0 -0.38461 Mabsadd L
.67339 .29937 .58779 -0.80902 Mabsadd L
.67339 .29937 .36579 -0.11885 Mabsadd L
.67339 .29937 .95106 .30902 Mabsadd L
.67339 .29937 .22607 .31116 Mabsadd L
.67339 .29937 0 1 Mabsadd L closepath F
.67706 .29884 0 1 Mabsadd m
.67706 .29884 -0.22607 .31116 Mabsadd L
.67706 .29884 -0.95106 .30902 Mabsadd L
.67706 .29884 -0.36579 -0.11885 Mabsadd L
.67706 .29884 -0.58778 -0.80902 Mabsadd L
.67706 .29884 0 -0.38461 Mabsadd L
.67706 .29884 .58779 -0.80902 Mabsadd L
.67706 .29884 .36579 -0.11885 Mabsadd L
.67706 .29884 .95106 .30902 Mabsadd L
.67706 .29884 .22607 .31116 Mabsadd L
.67706 .29884 0 1 Mabsadd L closepath F
.68073 .29819 0 1 Mabsadd m
.68073 .29819 -0.22607 .31116 Mabsadd L
.68073 .29819 -0.95106 .30902 Mabsadd L
.68073 .29819 -0.36579 -0.11885 Mabsadd L
.68073 .29819 -0.58778 -0.80902 Mabsadd L
.68073 .29819 0 -0.38461 Mabsadd L
.68073 .29819 .58779 -0.80902 Mabsadd L
.68073 .29819 .36579 -0.11885 Mabsadd L
.68073 .29819 .95106 .30902 Mabsadd L
.68073 .29819 .22607 .31116 Mabsadd L
.68073 .29819 0 1 Mabsadd L closepath F
.6844 .29753 0 1 Mabsadd m
.6844 .29753 -0.22607 .31116 Mabsadd L
.6844 .29753 -0.95106 .30902 Mabsadd L
.6844 .29753 -0.36579 -0.11885 Mabsadd L
.6844 .29753 -0.58778 -0.80902 Mabsadd L
.6844 .29753 0 -0.38461 Mabsadd L
.6844 .29753 .58779 -0.80902 Mabsadd L
.6844 .29753 .36579 -0.11885 Mabsadd L
.6844 .29753 .95106 .30902 Mabsadd L
.6844 .29753 .22607 .31116 Mabsadd L
.6844 .29753 0 1 Mabsadd L closepath F
.68807 .29703 0 1 Mabsadd m
.68807 .29703 -0.22607 .31116 Mabsadd L
.68807 .29703 -0.95106 .30902 Mabsadd L
.68807 .29703 -0.36579 -0.11885 Mabsadd L
.68807 .29703 -0.58778 -0.80902 Mabsadd L
.68807 .29703 0 -0.38461 Mabsadd L
.68807 .29703 .58779 -0.80902 Mabsadd L
.68807 .29703 .36579 -0.11885 Mabsadd L
.68807 .29703 .95106 .30902 Mabsadd L
.68807 .29703 .22607 .31116 Mabsadd L
.68807 .29703 0 1 Mabsadd L closepath F
.69174 .29637 0 1 Mabsadd m
.69174 .29637 -0.22607 .31116 Mabsadd L
.69174 .29637 -0.95106 .30902 Mabsadd L
.69174 .29637 -0.36579 -0.11885 Mabsadd L
.69174 .29637 -0.58778 -0.80902 Mabsadd L
.69174 .29637 0 -0.38461 Mabsadd L
.69174 .29637 .58779 -0.80902 Mabsadd L
.69174 .29637 .36579 -0.11885 Mabsadd L
.69174 .29637 .95106 .30902 Mabsadd L
.69174 .29637 .22607 .31116 Mabsadd L
.69174 .29637 0 1 Mabsadd L closepath F
.69541 .29587 0 1 Mabsadd m
.69541 .29587 -0.22607 .31116 Mabsadd L
.69541 .29587 -0.95106 .30902 Mabsadd L
.69541 .29587 -0.36579 -0.11885 Mabsadd L
.69541 .29587 -0.58778 -0.80902 Mabsadd L
.69541 .29587 0 -0.38461 Mabsadd L
.69541 .29587 .58779 -0.80902 Mabsadd L
.69541 .29587 .36579 -0.11885 Mabsadd L
.69541 .29587 .95106 .30902 Mabsadd L
.69541 .29587 .22607 .31116 Mabsadd L
.69541 .29587 0 1 Mabsadd L closepath F
.69908 .29514 0 1 Mabsadd m
.69908 .29514 -0.22607 .31116 Mabsadd L
.69908 .29514 -0.95106 .30902 Mabsadd L
.69908 .29514 -0.36579 -0.11885 Mabsadd L
.69908 .29514 -0.58778 -0.80902 Mabsadd L
.69908 .29514 0 -0.38461 Mabsadd L
.69908 .29514 .58779 -0.80902 Mabsadd L
.69908 .29514 .36579 -0.11885 Mabsadd L
.69908 .29514 .95106 .30902 Mabsadd L
.69908 .29514 .22607 .31116 Mabsadd L
.69908 .29514 0 1 Mabsadd L closepath F
.70275 .29442 0 1 Mabsadd m
.70275 .29442 -0.22607 .31116 Mabsadd L
.70275 .29442 -0.95106 .30902 Mabsadd L
.70275 .29442 -0.36579 -0.11885 Mabsadd L
.70275 .29442 -0.58778 -0.80902 Mabsadd L
.70275 .29442 0 -0.38461 Mabsadd L
.70275 .29442 .58779 -0.80902 Mabsadd L
.70275 .29442 .36579 -0.11885 Mabsadd L
.70275 .29442 .95106 .30902 Mabsadd L
.70275 .29442 .22607 .31116 Mabsadd L
.70275 .29442 0 1 Mabsadd L closepath F
.70642 .29367 0 1 Mabsadd m
.70642 .29367 -0.22607 .31116 Mabsadd L
.70642 .29367 -0.95106 .30902 Mabsadd L
.70642 .29367 -0.36579 -0.11885 Mabsadd L
.70642 .29367 -0.58778 -0.80902 Mabsadd L
.70642 .29367 0 -0.38461 Mabsadd L
.70642 .29367 .58779 -0.80902 Mabsadd L
.70642 .29367 .36579 -0.11885 Mabsadd L
.70642 .29367 .95106 .30902 Mabsadd L
.70642 .29367 .22607 .31116 Mabsadd L
.70642 .29367 0 1 Mabsadd L closepath F
.71009 .29291 0 1 Mabsadd m
.71009 .29291 -0.22607 .31116 Mabsadd L
.71009 .29291 -0.95106 .30902 Mabsadd L
.71009 .29291 -0.36579 -0.11885 Mabsadd L
.71009 .29291 -0.58778 -0.80902 Mabsadd L
.71009 .29291 0 -0.38461 Mabsadd L
.71009 .29291 .58779 -0.80902 Mabsadd L
.71009 .29291 .36579 -0.11885 Mabsadd L
.71009 .29291 .95106 .30902 Mabsadd L
.71009 .29291 .22607 .31116 Mabsadd L
.71009 .29291 0 1 Mabsadd L closepath F
.71376 .29234 0 1 Mabsadd m
.71376 .29234 -0.22607 .31116 Mabsadd L
.71376 .29234 -0.95106 .30902 Mabsadd L
.71376 .29234 -0.36579 -0.11885 Mabsadd L
.71376 .29234 -0.58778 -0.80902 Mabsadd L
.71376 .29234 0 -0.38461 Mabsadd L
.71376 .29234 .58779 -0.80902 Mabsadd L
.71376 .29234 .36579 -0.11885 Mabsadd L
.71376 .29234 .95106 .30902 Mabsadd L
.71376 .29234 .22607 .31116 Mabsadd L
.71376 .29234 0 1 Mabsadd L closepath F
.71743 .29167 0 1 Mabsadd m
.71743 .29167 -0.22607 .31116 Mabsadd L
.71743 .29167 -0.95106 .30902 Mabsadd L
.71743 .29167 -0.36579 -0.11885 Mabsadd L
.71743 .29167 -0.58778 -0.80902 Mabsadd L
.71743 .29167 0 -0.38461 Mabsadd L
.71743 .29167 .58779 -0.80902 Mabsadd L
.71743 .29167 .36579 -0.11885 Mabsadd L
.71743 .29167 .95106 .30902 Mabsadd L
.71743 .29167 .22607 .31116 Mabsadd L
.71743 .29167 0 1 Mabsadd L closepath F
.7211 .29102 0 1 Mabsadd m
.7211 .29102 -0.22607 .31116 Mabsadd L
.7211 .29102 -0.95106 .30902 Mabsadd L
.7211 .29102 -0.36579 -0.11885 Mabsadd L
.7211 .29102 -0.58778 -0.80902 Mabsadd L
.7211 .29102 0 -0.38461 Mabsadd L
.7211 .29102 .58779 -0.80902 Mabsadd L
.7211 .29102 .36579 -0.11885 Mabsadd L
.7211 .29102 .95106 .30902 Mabsadd L
.7211 .29102 .22607 .31116 Mabsadd L
.7211 .29102 0 1 Mabsadd L closepath F
.72477 .29022 0 1 Mabsadd m
.72477 .29022 -0.22607 .31116 Mabsadd L
.72477 .29022 -0.95106 .30902 Mabsadd L
.72477 .29022 -0.36579 -0.11885 Mabsadd L
.72477 .29022 -0.58778 -0.80902 Mabsadd L
.72477 .29022 0 -0.38461 Mabsadd L
.72477 .29022 .58779 -0.80902 Mabsadd L
.72477 .29022 .36579 -0.11885 Mabsadd L
.72477 .29022 .95106 .30902 Mabsadd L
.72477 .29022 .22607 .31116 Mabsadd L
.72477 .29022 0 1 Mabsadd L closepath F
.72844 .28933 0 1 Mabsadd m
.72844 .28933 -0.22607 .31116 Mabsadd L
.72844 .28933 -0.95106 .30902 Mabsadd L
.72844 .28933 -0.36579 -0.11885 Mabsadd L
.72844 .28933 -0.58778 -0.80902 Mabsadd L
.72844 .28933 0 -0.38461 Mabsadd L
.72844 .28933 .58779 -0.80902 Mabsadd L
.72844 .28933 .36579 -0.11885 Mabsadd L
.72844 .28933 .95106 .30902 Mabsadd L
.72844 .28933 .22607 .31116 Mabsadd L
.72844 .28933 0 1 Mabsadd L closepath F
.73211 .28872 0 1 Mabsadd m
.73211 .28872 -0.22607 .31116 Mabsadd L
.73211 .28872 -0.95106 .30902 Mabsadd L
.73211 .28872 -0.36579 -0.11885 Mabsadd L
.73211 .28872 -0.58778 -0.80902 Mabsadd L
.73211 .28872 0 -0.38461 Mabsadd L
.73211 .28872 .58779 -0.80902 Mabsadd L
.73211 .28872 .36579 -0.11885 Mabsadd L
.73211 .28872 .95106 .30902 Mabsadd L
.73211 .28872 .22607 .31116 Mabsadd L
.73211 .28872 0 1 Mabsadd L closepath F
.73578 .28813 0 1 Mabsadd m
.73578 .28813 -0.22607 .31116 Mabsadd L
.73578 .28813 -0.95106 .30902 Mabsadd L
.73578 .28813 -0.36579 -0.11885 Mabsadd L
.73578 .28813 -0.58778 -0.80902 Mabsadd L
.73578 .28813 0 -0.38461 Mabsadd L
.73578 .28813 .58779 -0.80902 Mabsadd L
.73578 .28813 .36579 -0.11885 Mabsadd L
.73578 .28813 .95106 .30902 Mabsadd L
.73578 .28813 .22607 .31116 Mabsadd L
.73578 .28813 0 1 Mabsadd L closepath F
.73945 .28753 0 1 Mabsadd m
.73945 .28753 -0.22607 .31116 Mabsadd L
.73945 .28753 -0.95106 .30902 Mabsadd L
.73945 .28753 -0.36579 -0.11885 Mabsadd L
.73945 .28753 -0.58778 -0.80902 Mabsadd L
.73945 .28753 0 -0.38461 Mabsadd L
.73945 .28753 .58779 -0.80902 Mabsadd L
.73945 .28753 .36579 -0.11885 Mabsadd L
.73945 .28753 .95106 .30902 Mabsadd L
.73945 .28753 .22607 .31116 Mabsadd L
.73945 .28753 0 1 Mabsadd L closepath F
.74312 .28693 0 1 Mabsadd m
.74312 .28693 -0.22607 .31116 Mabsadd L
.74312 .28693 -0.95106 .30902 Mabsadd L
.74312 .28693 -0.36579 -0.11885 Mabsadd L
.74312 .28693 -0.58778 -0.80902 Mabsadd L
.74312 .28693 0 -0.38461 Mabsadd L
.74312 .28693 .58779 -0.80902 Mabsadd L
.74312 .28693 .36579 -0.11885 Mabsadd L
.74312 .28693 .95106 .30902 Mabsadd L
.74312 .28693 .22607 .31116 Mabsadd L
.74312 .28693 0 1 Mabsadd L closepath F
.74679 .28621 0 1 Mabsadd m
.74679 .28621 -0.22607 .31116 Mabsadd L
.74679 .28621 -0.95106 .30902 Mabsadd L
.74679 .28621 -0.36579 -0.11885 Mabsadd L
.74679 .28621 -0.58778 -0.80902 Mabsadd L
.74679 .28621 0 -0.38461 Mabsadd L
.74679 .28621 .58779 -0.80902 Mabsadd L
.74679 .28621 .36579 -0.11885 Mabsadd L
.74679 .28621 .95106 .30902 Mabsadd L
.74679 .28621 .22607 .31116 Mabsadd L
.74679 .28621 0 1 Mabsadd L closepath F
.75046 .28543 0 1 Mabsadd m
.75046 .28543 -0.22607 .31116 Mabsadd L
.75046 .28543 -0.95106 .30902 Mabsadd L
.75046 .28543 -0.36579 -0.11885 Mabsadd L
.75046 .28543 -0.58778 -0.80902 Mabsadd L
.75046 .28543 0 -0.38461 Mabsadd L
.75046 .28543 .58779 -0.80902 Mabsadd L
.75046 .28543 .36579 -0.11885 Mabsadd L
.75046 .28543 .95106 .30902 Mabsadd L
.75046 .28543 .22607 .31116 Mabsadd L
.75046 .28543 0 1 Mabsadd L closepath F
.75413 .28482 0 1 Mabsadd m
.75413 .28482 -0.22607 .31116 Mabsadd L
.75413 .28482 -0.95106 .30902 Mabsadd L
.75413 .28482 -0.36579 -0.11885 Mabsadd L
.75413 .28482 -0.58778 -0.80902 Mabsadd L
.75413 .28482 0 -0.38461 Mabsadd L
.75413 .28482 .58779 -0.80902 Mabsadd L
.75413 .28482 .36579 -0.11885 Mabsadd L
.75413 .28482 .95106 .30902 Mabsadd L
.75413 .28482 .22607 .31116 Mabsadd L
.75413 .28482 0 1 Mabsadd L closepath F
.7578 .28437 0 1 Mabsadd m
.7578 .28437 -0.22607 .31116 Mabsadd L
.7578 .28437 -0.95106 .30902 Mabsadd L
.7578 .28437 -0.36579 -0.11885 Mabsadd L
.7578 .28437 -0.58778 -0.80902 Mabsadd L
.7578 .28437 0 -0.38461 Mabsadd L
.7578 .28437 .58779 -0.80902 Mabsadd L
.7578 .28437 .36579 -0.11885 Mabsadd L
.7578 .28437 .95106 .30902 Mabsadd L
.7578 .28437 .22607 .31116 Mabsadd L
.7578 .28437 0 1 Mabsadd L closepath F
.76147 .2839 0 1 Mabsadd m
.76147 .2839 -0.22607 .31116 Mabsadd L
.76147 .2839 -0.95106 .30902 Mabsadd L
.76147 .2839 -0.36579 -0.11885 Mabsadd L
.76147 .2839 -0.58778 -0.80902 Mabsadd L
.76147 .2839 0 -0.38461 Mabsadd L
.76147 .2839 .58779 -0.80902 Mabsadd L
.76147 .2839 .36579 -0.11885 Mabsadd L
.76147 .2839 .95106 .30902 Mabsadd L
.76147 .2839 .22607 .31116 Mabsadd L
.76147 .2839 0 1 Mabsadd L closepath F
.76514 .28296 0 1 Mabsadd m
.76514 .28296 -0.22607 .31116 Mabsadd L
.76514 .28296 -0.95106 .30902 Mabsadd L
.76514 .28296 -0.36579 -0.11885 Mabsadd L
.76514 .28296 -0.58778 -0.80902 Mabsadd L
.76514 .28296 0 -0.38461 Mabsadd L
.76514 .28296 .58779 -0.80902 Mabsadd L
.76514 .28296 .36579 -0.11885 Mabsadd L
.76514 .28296 .95106 .30902 Mabsadd L
.76514 .28296 .22607 .31116 Mabsadd L
.76514 .28296 0 1 Mabsadd L closepath F
.76881 .28225 0 1 Mabsadd m
.76881 .28225 -0.22607 .31116 Mabsadd L
.76881 .28225 -0.95106 .30902 Mabsadd L
.76881 .28225 -0.36579 -0.11885 Mabsadd L
.76881 .28225 -0.58778 -0.80902 Mabsadd L
.76881 .28225 0 -0.38461 Mabsadd L
.76881 .28225 .58779 -0.80902 Mabsadd L
.76881 .28225 .36579 -0.11885 Mabsadd L
.76881 .28225 .95106 .30902 Mabsadd L
.76881 .28225 .22607 .31116 Mabsadd L
.76881 .28225 0 1 Mabsadd L closepath F
.77248 .28173 0 1 Mabsadd m
.77248 .28173 -0.22607 .31116 Mabsadd L
.77248 .28173 -0.95106 .30902 Mabsadd L
.77248 .28173 -0.36579 -0.11885 Mabsadd L
.77248 .28173 -0.58778 -0.80902 Mabsadd L
.77248 .28173 0 -0.38461 Mabsadd L
.77248 .28173 .58779 -0.80902 Mabsadd L
.77248 .28173 .36579 -0.11885 Mabsadd L
.77248 .28173 .95106 .30902 Mabsadd L
.77248 .28173 .22607 .31116 Mabsadd L
.77248 .28173 0 1 Mabsadd L closepath F
.77615 .28102 0 1 Mabsadd m
.77615 .28102 -0.22607 .31116 Mabsadd L
.77615 .28102 -0.95106 .30902 Mabsadd L
.77615 .28102 -0.36579 -0.11885 Mabsadd L
.77615 .28102 -0.58778 -0.80902 Mabsadd L
.77615 .28102 0 -0.38461 Mabsadd L
.77615 .28102 .58779 -0.80902 Mabsadd L
.77615 .28102 .36579 -0.11885 Mabsadd L
.77615 .28102 .95106 .30902 Mabsadd L
.77615 .28102 .22607 .31116 Mabsadd L
.77615 .28102 0 1 Mabsadd L closepath F
.77982 .28028 0 1 Mabsadd m
.77982 .28028 -0.22607 .31116 Mabsadd L
.77982 .28028 -0.95106 .30902 Mabsadd L
.77982 .28028 -0.36579 -0.11885 Mabsadd L
.77982 .28028 -0.58778 -0.80902 Mabsadd L
.77982 .28028 0 -0.38461 Mabsadd L
.77982 .28028 .58779 -0.80902 Mabsadd L
.77982 .28028 .36579 -0.11885 Mabsadd L
.77982 .28028 .95106 .30902 Mabsadd L
.77982 .28028 .22607 .31116 Mabsadd L
.77982 .28028 0 1 Mabsadd L closepath F
.78349 .27952 0 1 Mabsadd m
.78349 .27952 -0.22607 .31116 Mabsadd L
.78349 .27952 -0.95106 .30902 Mabsadd L
.78349 .27952 -0.36579 -0.11885 Mabsadd L
.78349 .27952 -0.58778 -0.80902 Mabsadd L
.78349 .27952 0 -0.38461 Mabsadd L
.78349 .27952 .58779 -0.80902 Mabsadd L
.78349 .27952 .36579 -0.11885 Mabsadd L
.78349 .27952 .95106 .30902 Mabsadd L
.78349 .27952 .22607 .31116 Mabsadd L
.78349 .27952 0 1 Mabsadd L closepath F
.78716 .27909 0 1 Mabsadd m
.78716 .27909 -0.22607 .31116 Mabsadd L
.78716 .27909 -0.95106 .30902 Mabsadd L
.78716 .27909 -0.36579 -0.11885 Mabsadd L
.78716 .27909 -0.58778 -0.80902 Mabsadd L
.78716 .27909 0 -0.38461 Mabsadd L
.78716 .27909 .58779 -0.80902 Mabsadd L
.78716 .27909 .36579 -0.11885 Mabsadd L
.78716 .27909 .95106 .30902 Mabsadd L
.78716 .27909 .22607 .31116 Mabsadd L
.78716 .27909 0 1 Mabsadd L closepath F
.79083 .27834 0 1 Mabsadd m
.79083 .27834 -0.22607 .31116 Mabsadd L
.79083 .27834 -0.95106 .30902 Mabsadd L
.79083 .27834 -0.36579 -0.11885 Mabsadd L
.79083 .27834 -0.58778 -0.80902 Mabsadd L
.79083 .27834 0 -0.38461 Mabsadd L
.79083 .27834 .58779 -0.80902 Mabsadd L
.79083 .27834 .36579 -0.11885 Mabsadd L
.79083 .27834 .95106 .30902 Mabsadd L
.79083 .27834 .22607 .31116 Mabsadd L
.79083 .27834 0 1 Mabsadd L closepath F
.7945 .27771 0 1 Mabsadd m
.7945 .27771 -0.22607 .31116 Mabsadd L
.7945 .27771 -0.95106 .30902 Mabsadd L
.7945 .27771 -0.36579 -0.11885 Mabsadd L
.7945 .27771 -0.58778 -0.80902 Mabsadd L
.7945 .27771 0 -0.38461 Mabsadd L
.7945 .27771 .58779 -0.80902 Mabsadd L
.7945 .27771 .36579 -0.11885 Mabsadd L
.7945 .27771 .95106 .30902 Mabsadd L
.7945 .27771 .22607 .31116 Mabsadd L
.7945 .27771 0 1 Mabsadd L closepath F
.79817 .27724 0 1 Mabsadd m
.79817 .27724 -0.22607 .31116 Mabsadd L
.79817 .27724 -0.95106 .30902 Mabsadd L
.79817 .27724 -0.36579 -0.11885 Mabsadd L
.79817 .27724 -0.58778 -0.80902 Mabsadd L
.79817 .27724 0 -0.38461 Mabsadd L
.79817 .27724 .58779 -0.80902 Mabsadd L
.79817 .27724 .36579 -0.11885 Mabsadd L
.79817 .27724 .95106 .30902 Mabsadd L
.79817 .27724 .22607 .31116 Mabsadd L
.79817 .27724 0 1 Mabsadd L closepath F
.80183 .27676 0 1 Mabsadd m
.80183 .27676 -0.22607 .31116 Mabsadd L
.80183 .27676 -0.95106 .30902 Mabsadd L
.80183 .27676 -0.36579 -0.11885 Mabsadd L
.80183 .27676 -0.58778 -0.80902 Mabsadd L
.80183 .27676 0 -0.38461 Mabsadd L
.80183 .27676 .58779 -0.80902 Mabsadd L
.80183 .27676 .36579 -0.11885 Mabsadd L
.80183 .27676 .95106 .30902 Mabsadd L
.80183 .27676 .22607 .31116 Mabsadd L
.80183 .27676 0 1 Mabsadd L closepath F
.8055 .27622 0 1 Mabsadd m
.8055 .27622 -0.22607 .31116 Mabsadd L
.8055 .27622 -0.95106 .30902 Mabsadd L
.8055 .27622 -0.36579 -0.11885 Mabsadd L
.8055 .27622 -0.58778 -0.80902 Mabsadd L
.8055 .27622 0 -0.38461 Mabsadd L
.8055 .27622 .58779 -0.80902 Mabsadd L
.8055 .27622 .36579 -0.11885 Mabsadd L
.8055 .27622 .95106 .30902 Mabsadd L
.8055 .27622 .22607 .31116 Mabsadd L
.8055 .27622 0 1 Mabsadd L closepath F
.80917 .27562 0 1 Mabsadd m
.80917 .27562 -0.22607 .31116 Mabsadd L
.80917 .27562 -0.95106 .30902 Mabsadd L
.80917 .27562 -0.36579 -0.11885 Mabsadd L
.80917 .27562 -0.58778 -0.80902 Mabsadd L
.80917 .27562 0 -0.38461 Mabsadd L
.80917 .27562 .58779 -0.80902 Mabsadd L
.80917 .27562 .36579 -0.11885 Mabsadd L
.80917 .27562 .95106 .30902 Mabsadd L
.80917 .27562 .22607 .31116 Mabsadd L
.80917 .27562 0 1 Mabsadd L closepath F
.81284 .27518 0 1 Mabsadd m
.81284 .27518 -0.22607 .31116 Mabsadd L
.81284 .27518 -0.95106 .30902 Mabsadd L
.81284 .27518 -0.36579 -0.11885 Mabsadd L
.81284 .27518 -0.58778 -0.80902 Mabsadd L
.81284 .27518 0 -0.38461 Mabsadd L
.81284 .27518 .58779 -0.80902 Mabsadd L
.81284 .27518 .36579 -0.11885 Mabsadd L
.81284 .27518 .95106 .30902 Mabsadd L
.81284 .27518 .22607 .31116 Mabsadd L
.81284 .27518 0 1 Mabsadd L closepath F
.81651 .27468 0 1 Mabsadd m
.81651 .27468 -0.22607 .31116 Mabsadd L
.81651 .27468 -0.95106 .30902 Mabsadd L
.81651 .27468 -0.36579 -0.11885 Mabsadd L
.81651 .27468 -0.58778 -0.80902 Mabsadd L
.81651 .27468 0 -0.38461 Mabsadd L
.81651 .27468 .58779 -0.80902 Mabsadd L
.81651 .27468 .36579 -0.11885 Mabsadd L
.81651 .27468 .95106 .30902 Mabsadd L
.81651 .27468 .22607 .31116 Mabsadd L
.81651 .27468 0 1 Mabsadd L closepath F
.82018 .27387 0 1 Mabsadd m
.82018 .27387 -0.22607 .31116 Mabsadd L
.82018 .27387 -0.95106 .30902 Mabsadd L
.82018 .27387 -0.36579 -0.11885 Mabsadd L
.82018 .27387 -0.58778 -0.80902 Mabsadd L
.82018 .27387 0 -0.38461 Mabsadd L
.82018 .27387 .58779 -0.80902 Mabsadd L
.82018 .27387 .36579 -0.11885 Mabsadd L
.82018 .27387 .95106 .30902 Mabsadd L
.82018 .27387 .22607 .31116 Mabsadd L
.82018 .27387 0 1 Mabsadd L closepath F
.82385 .27317 0 1 Mabsadd m
.82385 .27317 -0.22607 .31116 Mabsadd L
.82385 .27317 -0.95106 .30902 Mabsadd L
.82385 .27317 -0.36579 -0.11885 Mabsadd L
.82385 .27317 -0.58778 -0.80902 Mabsadd L
.82385 .27317 0 -0.38461 Mabsadd L
.82385 .27317 .58779 -0.80902 Mabsadd L
.82385 .27317 .36579 -0.11885 Mabsadd L
.82385 .27317 .95106 .30902 Mabsadd L
.82385 .27317 .22607 .31116 Mabsadd L
.82385 .27317 0 1 Mabsadd L closepath F
.82752 .2726 0 1 Mabsadd m
.82752 .2726 -0.22607 .31116 Mabsadd L
.82752 .2726 -0.95106 .30902 Mabsadd L
.82752 .2726 -0.36579 -0.11885 Mabsadd L
.82752 .2726 -0.58778 -0.80902 Mabsadd L
.82752 .2726 0 -0.38461 Mabsadd L
.82752 .2726 .58779 -0.80902 Mabsadd L
.82752 .2726 .36579 -0.11885 Mabsadd L
.82752 .2726 .95106 .30902 Mabsadd L
.82752 .2726 .22607 .31116 Mabsadd L
.82752 .2726 0 1 Mabsadd L closepath F
.83119 .27194 0 1 Mabsadd m
.83119 .27194 -0.22607 .31116 Mabsadd L
.83119 .27194 -0.95106 .30902 Mabsadd L
.83119 .27194 -0.36579 -0.11885 Mabsadd L
.83119 .27194 -0.58778 -0.80902 Mabsadd L
.83119 .27194 0 -0.38461 Mabsadd L
.83119 .27194 .58779 -0.80902 Mabsadd L
.83119 .27194 .36579 -0.11885 Mabsadd L
.83119 .27194 .95106 .30902 Mabsadd L
.83119 .27194 .22607 .31116 Mabsadd L
.83119 .27194 0 1 Mabsadd L closepath F
.83486 .27119 0 1 Mabsadd m
.83486 .27119 -0.22607 .31116 Mabsadd L
.83486 .27119 -0.95106 .30902 Mabsadd L
.83486 .27119 -0.36579 -0.11885 Mabsadd L
.83486 .27119 -0.58778 -0.80902 Mabsadd L
.83486 .27119 0 -0.38461 Mabsadd L
.83486 .27119 .58779 -0.80902 Mabsadd L
.83486 .27119 .36579 -0.11885 Mabsadd L
.83486 .27119 .95106 .30902 Mabsadd L
.83486 .27119 .22607 .31116 Mabsadd L
.83486 .27119 0 1 Mabsadd L closepath F
.83853 .27055 0 1 Mabsadd m
.83853 .27055 -0.22607 .31116 Mabsadd L
.83853 .27055 -0.95106 .30902 Mabsadd L
.83853 .27055 -0.36579 -0.11885 Mabsadd L
.83853 .27055 -0.58778 -0.80902 Mabsadd L
.83853 .27055 0 -0.38461 Mabsadd L
.83853 .27055 .58779 -0.80902 Mabsadd L
.83853 .27055 .36579 -0.11885 Mabsadd L
.83853 .27055 .95106 .30902 Mabsadd L
.83853 .27055 .22607 .31116 Mabsadd L
.83853 .27055 0 1 Mabsadd L closepath F
.8422 .26976 0 1 Mabsadd m
.8422 .26976 -0.22607 .31116 Mabsadd L
.8422 .26976 -0.95106 .30902 Mabsadd L
.8422 .26976 -0.36579 -0.11885 Mabsadd L
.8422 .26976 -0.58778 -0.80902 Mabsadd L
.8422 .26976 0 -0.38461 Mabsadd L
.8422 .26976 .58779 -0.80902 Mabsadd L
.8422 .26976 .36579 -0.11885 Mabsadd L
.8422 .26976 .95106 .30902 Mabsadd L
.8422 .26976 .22607 .31116 Mabsadd L
.8422 .26976 0 1 Mabsadd L closepath F
.84587 .26906 0 1 Mabsadd m
.84587 .26906 -0.22607 .31116 Mabsadd L
.84587 .26906 -0.95106 .30902 Mabsadd L
.84587 .26906 -0.36579 -0.11885 Mabsadd L
.84587 .26906 -0.58778 -0.80902 Mabsadd L
.84587 .26906 0 -0.38461 Mabsadd L
.84587 .26906 .58779 -0.80902 Mabsadd L
.84587 .26906 .36579 -0.11885 Mabsadd L
.84587 .26906 .95106 .30902 Mabsadd L
.84587 .26906 .22607 .31116 Mabsadd L
.84587 .26906 0 1 Mabsadd L closepath F
.84954 .26853 0 1 Mabsadd m
.84954 .26853 -0.22607 .31116 Mabsadd L
.84954 .26853 -0.95106 .30902 Mabsadd L
.84954 .26853 -0.36579 -0.11885 Mabsadd L
.84954 .26853 -0.58778 -0.80902 Mabsadd L
.84954 .26853 0 -0.38461 Mabsadd L
.84954 .26853 .58779 -0.80902 Mabsadd L
.84954 .26853 .36579 -0.11885 Mabsadd L
.84954 .26853 .95106 .30902 Mabsadd L
.84954 .26853 .22607 .31116 Mabsadd L
.84954 .26853 0 1 Mabsadd L closepath F
.85321 .26799 0 1 Mabsadd m
.85321 .26799 -0.22607 .31116 Mabsadd L
.85321 .26799 -0.95106 .30902 Mabsadd L
.85321 .26799 -0.36579 -0.11885 Mabsadd L
.85321 .26799 -0.58778 -0.80902 Mabsadd L
.85321 .26799 0 -0.38461 Mabsadd L
.85321 .26799 .58779 -0.80902 Mabsadd L
.85321 .26799 .36579 -0.11885 Mabsadd L
.85321 .26799 .95106 .30902 Mabsadd L
.85321 .26799 .22607 .31116 Mabsadd L
.85321 .26799 0 1 Mabsadd L closepath F
.85688 .26739 0 1 Mabsadd m
.85688 .26739 -0.22607 .31116 Mabsadd L
.85688 .26739 -0.95106 .30902 Mabsadd L
.85688 .26739 -0.36579 -0.11885 Mabsadd L
.85688 .26739 -0.58778 -0.80902 Mabsadd L
.85688 .26739 0 -0.38461 Mabsadd L
.85688 .26739 .58779 -0.80902 Mabsadd L
.85688 .26739 .36579 -0.11885 Mabsadd L
.85688 .26739 .95106 .30902 Mabsadd L
.85688 .26739 .22607 .31116 Mabsadd L
.85688 .26739 0 1 Mabsadd L closepath F
.86055 .26698 0 1 Mabsadd m
.86055 .26698 -0.22607 .31116 Mabsadd L
.86055 .26698 -0.95106 .30902 Mabsadd L
.86055 .26698 -0.36579 -0.11885 Mabsadd L
.86055 .26698 -0.58778 -0.80902 Mabsadd L
.86055 .26698 0 -0.38461 Mabsadd L
.86055 .26698 .58779 -0.80902 Mabsadd L
.86055 .26698 .36579 -0.11885 Mabsadd L
.86055 .26698 .95106 .30902 Mabsadd L
.86055 .26698 .22607 .31116 Mabsadd L
.86055 .26698 0 1 Mabsadd L closepath F
.86422 .26643 0 1 Mabsadd m
.86422 .26643 -0.22607 .31116 Mabsadd L
.86422 .26643 -0.95106 .30902 Mabsadd L
.86422 .26643 -0.36579 -0.11885 Mabsadd L
.86422 .26643 -0.58778 -0.80902 Mabsadd L
.86422 .26643 0 -0.38461 Mabsadd L
.86422 .26643 .58779 -0.80902 Mabsadd L
.86422 .26643 .36579 -0.11885 Mabsadd L
.86422 .26643 .95106 .30902 Mabsadd L
.86422 .26643 .22607 .31116 Mabsadd L
.86422 .26643 0 1 Mabsadd L closepath F
.86789 .26598 0 1 Mabsadd m
.86789 .26598 -0.22607 .31116 Mabsadd L
.86789 .26598 -0.95106 .30902 Mabsadd L
.86789 .26598 -0.36579 -0.11885 Mabsadd L
.86789 .26598 -0.58778 -0.80902 Mabsadd L
.86789 .26598 0 -0.38461 Mabsadd L
.86789 .26598 .58779 -0.80902 Mabsadd L
.86789 .26598 .36579 -0.11885 Mabsadd L
.86789 .26598 .95106 .30902 Mabsadd L
.86789 .26598 .22607 .31116 Mabsadd L
.86789 .26598 0 1 Mabsadd L closepath F
.87156 .26523 0 1 Mabsadd m
.87156 .26523 -0.22607 .31116 Mabsadd L
.87156 .26523 -0.95106 .30902 Mabsadd L
.87156 .26523 -0.36579 -0.11885 Mabsadd L
.87156 .26523 -0.58778 -0.80902 Mabsadd L
.87156 .26523 0 -0.38461 Mabsadd L
.87156 .26523 .58779 -0.80902 Mabsadd L
.87156 .26523 .36579 -0.11885 Mabsadd L
.87156 .26523 .95106 .30902 Mabsadd L
.87156 .26523 .22607 .31116 Mabsadd L
.87156 .26523 0 1 Mabsadd L closepath F
.87523 .26471 0 1 Mabsadd m
.87523 .26471 -0.22607 .31116 Mabsadd L
.87523 .26471 -0.95106 .30902 Mabsadd L
.87523 .26471 -0.36579 -0.11885 Mabsadd L
.87523 .26471 -0.58778 -0.80902 Mabsadd L
.87523 .26471 0 -0.38461 Mabsadd L
.87523 .26471 .58779 -0.80902 Mabsadd L
.87523 .26471 .36579 -0.11885 Mabsadd L
.87523 .26471 .95106 .30902 Mabsadd L
.87523 .26471 .22607 .31116 Mabsadd L
.87523 .26471 0 1 Mabsadd L closepath F
.8789 .26434 0 1 Mabsadd m
.8789 .26434 -0.22607 .31116 Mabsadd L
.8789 .26434 -0.95106 .30902 Mabsadd L
.8789 .26434 -0.36579 -0.11885 Mabsadd L
.8789 .26434 -0.58778 -0.80902 Mabsadd L
.8789 .26434 0 -0.38461 Mabsadd L
.8789 .26434 .58779 -0.80902 Mabsadd L
.8789 .26434 .36579 -0.11885 Mabsadd L
.8789 .26434 .95106 .30902 Mabsadd L
.8789 .26434 .22607 .31116 Mabsadd L
.8789 .26434 0 1 Mabsadd L closepath F
.88257 .26381 0 1 Mabsadd m
.88257 .26381 -0.22607 .31116 Mabsadd L
.88257 .26381 -0.95106 .30902 Mabsadd L
.88257 .26381 -0.36579 -0.11885 Mabsadd L
.88257 .26381 -0.58778 -0.80902 Mabsadd L
.88257 .26381 0 -0.38461 Mabsadd L
.88257 .26381 .58779 -0.80902 Mabsadd L
.88257 .26381 .36579 -0.11885 Mabsadd L
.88257 .26381 .95106 .30902 Mabsadd L
.88257 .26381 .22607 .31116 Mabsadd L
.88257 .26381 0 1 Mabsadd L closepath F
.88624 .26324 0 1 Mabsadd m
.88624 .26324 -0.22607 .31116 Mabsadd L
.88624 .26324 -0.95106 .30902 Mabsadd L
.88624 .26324 -0.36579 -0.11885 Mabsadd L
.88624 .26324 -0.58778 -0.80902 Mabsadd L
.88624 .26324 0 -0.38461 Mabsadd L
.88624 .26324 .58779 -0.80902 Mabsadd L
.88624 .26324 .36579 -0.11885 Mabsadd L
.88624 .26324 .95106 .30902 Mabsadd L
.88624 .26324 .22607 .31116 Mabsadd L
.88624 .26324 0 1 Mabsadd L closepath F
.88991 .26285 0 1 Mabsadd m
.88991 .26285 -0.22607 .31116 Mabsadd L
.88991 .26285 -0.95106 .30902 Mabsadd L
.88991 .26285 -0.36579 -0.11885 Mabsadd L
.88991 .26285 -0.58778 -0.80902 Mabsadd L
.88991 .26285 0 -0.38461 Mabsadd L
.88991 .26285 .58779 -0.80902 Mabsadd L
.88991 .26285 .36579 -0.11885 Mabsadd L
.88991 .26285 .95106 .30902 Mabsadd L
.88991 .26285 .22607 .31116 Mabsadd L
.88991 .26285 0 1 Mabsadd L closepath F
.89358 .26219 0 1 Mabsadd m
.89358 .26219 -0.22607 .31116 Mabsadd L
.89358 .26219 -0.95106 .30902 Mabsadd L
.89358 .26219 -0.36579 -0.11885 Mabsadd L
.89358 .26219 -0.58778 -0.80902 Mabsadd L
.89358 .26219 0 -0.38461 Mabsadd L
.89358 .26219 .58779 -0.80902 Mabsadd L
.89358 .26219 .36579 -0.11885 Mabsadd L
.89358 .26219 .95106 .30902 Mabsadd L
.89358 .26219 .22607 .31116 Mabsadd L
.89358 .26219 0 1 Mabsadd L closepath F
.89725 .2614 0 1 Mabsadd m
.89725 .2614 -0.22607 .31116 Mabsadd L
.89725 .2614 -0.95106 .30902 Mabsadd L
.89725 .2614 -0.36579 -0.11885 Mabsadd L
.89725 .2614 -0.58778 -0.80902 Mabsadd L
.89725 .2614 0 -0.38461 Mabsadd L
.89725 .2614 .58779 -0.80902 Mabsadd L
.89725 .2614 .36579 -0.11885 Mabsadd L
.89725 .2614 .95106 .30902 Mabsadd L
.89725 .2614 .22607 .31116 Mabsadd L
.89725 .2614 0 1 Mabsadd L closepath F
.90092 .26074 0 1 Mabsadd m
.90092 .26074 -0.22607 .31116 Mabsadd L
.90092 .26074 -0.95106 .30902 Mabsadd L
.90092 .26074 -0.36579 -0.11885 Mabsadd L
.90092 .26074 -0.58778 -0.80902 Mabsadd L
.90092 .26074 0 -0.38461 Mabsadd L
.90092 .26074 .58779 -0.80902 Mabsadd L
.90092 .26074 .36579 -0.11885 Mabsadd L
.90092 .26074 .95106 .30902 Mabsadd L
.90092 .26074 .22607 .31116 Mabsadd L
.90092 .26074 0 1 Mabsadd L closepath F
.90459 .26 0 1 Mabsadd m
.90459 .26 -0.22607 .31116 Mabsadd L
.90459 .26 -0.95106 .30902 Mabsadd L
.90459 .26 -0.36579 -0.11885 Mabsadd L
.90459 .26 -0.58778 -0.80902 Mabsadd L
.90459 .26 0 -0.38461 Mabsadd L
.90459 .26 .58779 -0.80902 Mabsadd L
.90459 .26 .36579 -0.11885 Mabsadd L
.90459 .26 .95106 .30902 Mabsadd L
.90459 .26 .22607 .31116 Mabsadd L
.90459 .26 0 1 Mabsadd L closepath F
.90826 .25932 0 1 Mabsadd m
.90826 .25932 -0.22607 .31116 Mabsadd L
.90826 .25932 -0.95106 .30902 Mabsadd L
.90826 .25932 -0.36579 -0.11885 Mabsadd L
.90826 .25932 -0.58778 -0.80902 Mabsadd L
.90826 .25932 0 -0.38461 Mabsadd L
.90826 .25932 .58779 -0.80902 Mabsadd L
.90826 .25932 .36579 -0.11885 Mabsadd L
.90826 .25932 .95106 .30902 Mabsadd L
.90826 .25932 .22607 .31116 Mabsadd L
.90826 .25932 0 1 Mabsadd L closepath F
.91193 .25892 0 1 Mabsadd m
.91193 .25892 -0.22607 .31116 Mabsadd L
.91193 .25892 -0.95106 .30902 Mabsadd L
.91193 .25892 -0.36579 -0.11885 Mabsadd L
.91193 .25892 -0.58778 -0.80902 Mabsadd L
.91193 .25892 0 -0.38461 Mabsadd L
.91193 .25892 .58779 -0.80902 Mabsadd L
.91193 .25892 .36579 -0.11885 Mabsadd L
.91193 .25892 .95106 .30902 Mabsadd L
.91193 .25892 .22607 .31116 Mabsadd L
.91193 .25892 0 1 Mabsadd L closepath F
.9156 .2583 0 1 Mabsadd m
.9156 .2583 -0.22607 .31116 Mabsadd L
.9156 .2583 -0.95106 .30902 Mabsadd L
.9156 .2583 -0.36579 -0.11885 Mabsadd L
.9156 .2583 -0.58778 -0.80902 Mabsadd L
.9156 .2583 0 -0.38461 Mabsadd L
.9156 .2583 .58779 -0.80902 Mabsadd L
.9156 .2583 .36579 -0.11885 Mabsadd L
.9156 .2583 .95106 .30902 Mabsadd L
.9156 .2583 .22607 .31116 Mabsadd L
.9156 .2583 0 1 Mabsadd L closepath F
.91927 .2577 0 1 Mabsadd m
.91927 .2577 -0.22607 .31116 Mabsadd L
.91927 .2577 -0.95106 .30902 Mabsadd L
.91927 .2577 -0.36579 -0.11885 Mabsadd L
.91927 .2577 -0.58778 -0.80902 Mabsadd L
.91927 .2577 0 -0.38461 Mabsadd L
.91927 .2577 .58779 -0.80902 Mabsadd L
.91927 .2577 .36579 -0.11885 Mabsadd L
.91927 .2577 .95106 .30902 Mabsadd L
.91927 .2577 .22607 .31116 Mabsadd L
.91927 .2577 0 1 Mabsadd L closepath F
.92294 .25711 0 1 Mabsadd m
.92294 .25711 -0.22607 .31116 Mabsadd L
.92294 .25711 -0.95106 .30902 Mabsadd L
.92294 .25711 -0.36579 -0.11885 Mabsadd L
.92294 .25711 -0.58778 -0.80902 Mabsadd L
.92294 .25711 0 -0.38461 Mabsadd L
.92294 .25711 .58779 -0.80902 Mabsadd L
.92294 .25711 .36579 -0.11885 Mabsadd L
.92294 .25711 .95106 .30902 Mabsadd L
.92294 .25711 .22607 .31116 Mabsadd L
.92294 .25711 0 1 Mabsadd L closepath F
.92661 .25651 0 1 Mabsadd m
.92661 .25651 -0.22607 .31116 Mabsadd L
.92661 .25651 -0.95106 .30902 Mabsadd L
.92661 .25651 -0.36579 -0.11885 Mabsadd L
.92661 .25651 -0.58778 -0.80902 Mabsadd L
.92661 .25651 0 -0.38461 Mabsadd L
.92661 .25651 .58779 -0.80902 Mabsadd L
.92661 .25651 .36579 -0.11885 Mabsadd L
.92661 .25651 .95106 .30902 Mabsadd L
.92661 .25651 .22607 .31116 Mabsadd L
.92661 .25651 0 1 Mabsadd L closepath F
.93028 .25573 0 1 Mabsadd m
.93028 .25573 -0.22607 .31116 Mabsadd L
.93028 .25573 -0.95106 .30902 Mabsadd L
.93028 .25573 -0.36579 -0.11885 Mabsadd L
.93028 .25573 -0.58778 -0.80902 Mabsadd L
.93028 .25573 0 -0.38461 Mabsadd L
.93028 .25573 .58779 -0.80902 Mabsadd L
.93028 .25573 .36579 -0.11885 Mabsadd L
.93028 .25573 .95106 .30902 Mabsadd L
.93028 .25573 .22607 .31116 Mabsadd L
.93028 .25573 0 1 Mabsadd L closepath F
.93394 .2551 0 1 Mabsadd m
.93394 .2551 -0.22607 .31116 Mabsadd L
.93394 .2551 -0.95106 .30902 Mabsadd L
.93394 .2551 -0.36579 -0.11885 Mabsadd L
.93394 .2551 -0.58778 -0.80902 Mabsadd L
.93394 .2551 0 -0.38461 Mabsadd L
.93394 .2551 .58779 -0.80902 Mabsadd L
.93394 .2551 .36579 -0.11885 Mabsadd L
.93394 .2551 .95106 .30902 Mabsadd L
.93394 .2551 .22607 .31116 Mabsadd L
.93394 .2551 0 1 Mabsadd L closepath F
.93761 .25457 0 1 Mabsadd m
.93761 .25457 -0.22607 .31116 Mabsadd L
.93761 .25457 -0.95106 .30902 Mabsadd L
.93761 .25457 -0.36579 -0.11885 Mabsadd L
.93761 .25457 -0.58778 -0.80902 Mabsadd L
.93761 .25457 0 -0.38461 Mabsadd L
.93761 .25457 .58779 -0.80902 Mabsadd L
.93761 .25457 .36579 -0.11885 Mabsadd L
.93761 .25457 .95106 .30902 Mabsadd L
.93761 .25457 .22607 .31116 Mabsadd L
.93761 .25457 0 1 Mabsadd L closepath F
.94128 .25399 0 1 Mabsadd m
.94128 .25399 -0.22607 .31116 Mabsadd L
.94128 .25399 -0.95106 .30902 Mabsadd L
.94128 .25399 -0.36579 -0.11885 Mabsadd L
.94128 .25399 -0.58778 -0.80902 Mabsadd L
.94128 .25399 0 -0.38461 Mabsadd L
.94128 .25399 .58779 -0.80902 Mabsadd L
.94128 .25399 .36579 -0.11885 Mabsadd L
.94128 .25399 .95106 .30902 Mabsadd L
.94128 .25399 .22607 .31116 Mabsadd L
.94128 .25399 0 1 Mabsadd L closepath F
.94495 .25357 0 1 Mabsadd m
.94495 .25357 -0.22607 .31116 Mabsadd L
.94495 .25357 -0.95106 .30902 Mabsadd L
.94495 .25357 -0.36579 -0.11885 Mabsadd L
.94495 .25357 -0.58778 -0.80902 Mabsadd L
.94495 .25357 0 -0.38461 Mabsadd L
.94495 .25357 .58779 -0.80902 Mabsadd L
.94495 .25357 .36579 -0.11885 Mabsadd L
.94495 .25357 .95106 .30902 Mabsadd L
.94495 .25357 .22607 .31116 Mabsadd L
.94495 .25357 0 1 Mabsadd L closepath F
.94862 .25312 0 1 Mabsadd m
.94862 .25312 -0.22607 .31116 Mabsadd L
.94862 .25312 -0.95106 .30902 Mabsadd L
.94862 .25312 -0.36579 -0.11885 Mabsadd L
.94862 .25312 -0.58778 -0.80902 Mabsadd L
.94862 .25312 0 -0.38461 Mabsadd L
.94862 .25312 .58779 -0.80902 Mabsadd L
.94862 .25312 .36579 -0.11885 Mabsadd L
.94862 .25312 .95106 .30902 Mabsadd L
.94862 .25312 .22607 .31116 Mabsadd L
.94862 .25312 0 1 Mabsadd L closepath F
.95229 .25249 0 1 Mabsadd m
.95229 .25249 -0.22607 .31116 Mabsadd L
.95229 .25249 -0.95106 .30902 Mabsadd L
.95229 .25249 -0.36579 -0.11885 Mabsadd L
.95229 .25249 -0.58778 -0.80902 Mabsadd L
.95229 .25249 0 -0.38461 Mabsadd L
.95229 .25249 .58779 -0.80902 Mabsadd L
.95229 .25249 .36579 -0.11885 Mabsadd L
.95229 .25249 .95106 .30902 Mabsadd L
.95229 .25249 .22607 .31116 Mabsadd L
.95229 .25249 0 1 Mabsadd L closepath F
.95596 .25192 0 1 Mabsadd m
.95596 .25192 -0.22607 .31116 Mabsadd L
.95596 .25192 -0.95106 .30902 Mabsadd L
.95596 .25192 -0.36579 -0.11885 Mabsadd L
.95596 .25192 -0.58778 -0.80902 Mabsadd L
.95596 .25192 0 -0.38461 Mabsadd L
.95596 .25192 .58779 -0.80902 Mabsadd L
.95596 .25192 .36579 -0.11885 Mabsadd L
.95596 .25192 .95106 .30902 Mabsadd L
.95596 .25192 .22607 .31116 Mabsadd L
.95596 .25192 0 1 Mabsadd L closepath F
.95963 .25155 0 1 Mabsadd m
.95963 .25155 -0.22607 .31116 Mabsadd L
.95963 .25155 -0.95106 .30902 Mabsadd L
.95963 .25155 -0.36579 -0.11885 Mabsadd L
.95963 .25155 -0.58778 -0.80902 Mabsadd L
.95963 .25155 0 -0.38461 Mabsadd L
.95963 .25155 .58779 -0.80902 Mabsadd L
.95963 .25155 .36579 -0.11885 Mabsadd L
.95963 .25155 .95106 .30902 Mabsadd L
.95963 .25155 .22607 .31116 Mabsadd L
.95963 .25155 0 1 Mabsadd L closepath F
.9633 .25093 0 1 Mabsadd m
.9633 .25093 -0.22607 .31116 Mabsadd L
.9633 .25093 -0.95106 .30902 Mabsadd L
.9633 .25093 -0.36579 -0.11885 Mabsadd L
.9633 .25093 -0.58778 -0.80902 Mabsadd L
.9633 .25093 0 -0.38461 Mabsadd L
.9633 .25093 .58779 -0.80902 Mabsadd L
.9633 .25093 .36579 -0.11885 Mabsadd L
.9633 .25093 .95106 .30902 Mabsadd L
.9633 .25093 .22607 .31116 Mabsadd L
.9633 .25093 0 1 Mabsadd L closepath F
.96697 .25049 0 1 Mabsadd m
.96697 .25049 -0.22607 .31116 Mabsadd L
.96697 .25049 -0.95106 .30902 Mabsadd L
.96697 .25049 -0.36579 -0.11885 Mabsadd L
.96697 .25049 -0.58778 -0.80902 Mabsadd L
.96697 .25049 0 -0.38461 Mabsadd L
.96697 .25049 .58779 -0.80902 Mabsadd L
.96697 .25049 .36579 -0.11885 Mabsadd L
.96697 .25049 .95106 .30902 Mabsadd L
.96697 .25049 .22607 .31116 Mabsadd L
.96697 .25049 0 1 Mabsadd L closepath F
.97064 .25007 0 1 Mabsadd m
.97064 .25007 -0.22607 .31116 Mabsadd L
.97064 .25007 -0.95106 .30902 Mabsadd L
.97064 .25007 -0.36579 -0.11885 Mabsadd L
.97064 .25007 -0.58778 -0.80902 Mabsadd L
.97064 .25007 0 -0.38461 Mabsadd L
.97064 .25007 .58779 -0.80902 Mabsadd L
.97064 .25007 .36579 -0.11885 Mabsadd L
.97064 .25007 .95106 .30902 Mabsadd L
.97064 .25007 .22607 .31116 Mabsadd L
.97064 .25007 0 1 Mabsadd L closepath F
.97431 .24968 0 1 Mabsadd m
.97431 .24968 -0.22607 .31116 Mabsadd L
.97431 .24968 -0.95106 .30902 Mabsadd L
.97431 .24968 -0.36579 -0.11885 Mabsadd L
.97431 .24968 -0.58778 -0.80902 Mabsadd L
.97431 .24968 0 -0.38461 Mabsadd L
.97431 .24968 .58779 -0.80902 Mabsadd L
.97431 .24968 .36579 -0.11885 Mabsadd L
.97431 .24968 .95106 .30902 Mabsadd L
.97431 .24968 .22607 .31116 Mabsadd L
.97431 .24968 0 1 Mabsadd L closepath F
.97798 .24919 0 1 Mabsadd m
.97798 .24919 -0.22607 .31116 Mabsadd L
.97798 .24919 -0.95106 .30902 Mabsadd L
.97798 .24919 -0.36579 -0.11885 Mabsadd L
.97798 .24919 -0.58778 -0.80902 Mabsadd L
.97798 .24919 0 -0.38461 Mabsadd L
.97798 .24919 .58779 -0.80902 Mabsadd L
.97798 .24919 .36579 -0.11885 Mabsadd L
.97798 .24919 .95106 .30902 Mabsadd L
.97798 .24919 .22607 .31116 Mabsadd L
.97798 .24919 0 1 Mabsadd L closepath F
.98165 .24876 0 1 Mabsadd m
.98165 .24876 -0.22607 .31116 Mabsadd L
.98165 .24876 -0.95106 .30902 Mabsadd L
.98165 .24876 -0.36579 -0.11885 Mabsadd L
.98165 .24876 -0.58778 -0.80902 Mabsadd L
.98165 .24876 0 -0.38461 Mabsadd L
.98165 .24876 .58779 -0.80902 Mabsadd L
.98165 .24876 .36579 -0.11885 Mabsadd L
.98165 .24876 .95106 .30902 Mabsadd L
.98165 .24876 .22607 .31116 Mabsadd L
.98165 .24876 0 1 Mabsadd L closepath F
.98532 .24833 0 1 Mabsadd m
.98532 .24833 -0.22607 .31116 Mabsadd L
.98532 .24833 -0.95106 .30902 Mabsadd L
.98532 .24833 -0.36579 -0.11885 Mabsadd L
.98532 .24833 -0.58778 -0.80902 Mabsadd L
.98532 .24833 0 -0.38461 Mabsadd L
.98532 .24833 .58779 -0.80902 Mabsadd L
.98532 .24833 .36579 -0.11885 Mabsadd L
.98532 .24833 .95106 .30902 Mabsadd L
.98532 .24833 .22607 .31116 Mabsadd L
.98532 .24833 0 1 Mabsadd L closepath F
.98899 .24776 0 1 Mabsadd m
.98899 .24776 -0.22607 .31116 Mabsadd L
.98899 .24776 -0.95106 .30902 Mabsadd L
.98899 .24776 -0.36579 -0.11885 Mabsadd L
.98899 .24776 -0.58778 -0.80902 Mabsadd L
.98899 .24776 0 -0.38461 Mabsadd L
.98899 .24776 .58779 -0.80902 Mabsadd L
.98899 .24776 .36579 -0.11885 Mabsadd L
.98899 .24776 .95106 .30902 Mabsadd L
.98899 .24776 .22607 .31116 Mabsadd L
.98899 .24776 0 1 Mabsadd L closepath F
.99266 .24714 0 1 Mabsadd m
.99266 .24714 -0.22607 .31116 Mabsadd L
.99266 .24714 -0.95106 .30902 Mabsadd L
.99266 .24714 -0.36579 -0.11885 Mabsadd L
.99266 .24714 -0.58778 -0.80902 Mabsadd L
.99266 .24714 0 -0.38461 Mabsadd L
.99266 .24714 .58779 -0.80902 Mabsadd L
.99266 .24714 .36579 -0.11885 Mabsadd L
.99266 .24714 .95106 .30902 Mabsadd L
.99266 .24714 .22607 .31116 Mabsadd L
.99266 .24714 0 1 Mabsadd L closepath F
.99633 .24665 0 1 Mabsadd m
.99633 .24665 -0.22607 .31116 Mabsadd L
.99633 .24665 -0.95106 .30902 Mabsadd L
.99633 .24665 -0.36579 -0.11885 Mabsadd L
.99633 .24665 -0.58778 -0.80902 Mabsadd L
.99633 .24665 0 -0.38461 Mabsadd L
.99633 .24665 .58779 -0.80902 Mabsadd L
.99633 .24665 .36579 -0.11885 Mabsadd L
.99633 .24665 .95106 .30902 Mabsadd L
.99633 .24665 .22607 .31116 Mabsadd L
.99633 .24665 0 1 Mabsadd L closepath F
1 .24613 0 1 Mabsadd m
1 .24613 -0.22607 .31116 Mabsadd L
1 .24613 -0.95106 .30902 Mabsadd L
1 .24613 -0.36579 -0.11885 Mabsadd L
1 .24613 -0.58778 -0.80902 Mabsadd L
1 .24613 0 -0.38461 Mabsadd L
1 .24613 .58779 -0.80902 Mabsadd L
1 .24613 .36579 -0.11885 Mabsadd L
1 .24613 .95106 .30902 Mabsadd L
1 .24613 .22607 .31116 Mabsadd L
1 .24613 0 1 Mabsadd L closepath F
1 0 0 r
.08257 .55943 -0.75 0 Mabsadd m
.08257 .55943 0 1 Mabsadd L
.08257 .55943 .75 0 Mabsadd L
.08257 .55943 0 -1 Mabsadd L
.08257 .55943 -0.75 0 Mabsadd L closepath F
.08624 .54109 -0.75 0 Mabsadd m
.08624 .54109 0 1 Mabsadd L
.08624 .54109 .75 0 Mabsadd L
.08624 .54109 0 -1 Mabsadd L
.08624 .54109 -0.75 0 Mabsadd L closepath F
.08991 .52491 -0.75 0 Mabsadd m
.08991 .52491 0 1 Mabsadd L
.08991 .52491 .75 0 Mabsadd L
.08991 .52491 0 -1 Mabsadd L
.08991 .52491 -0.75 0 Mabsadd L closepath F
.09358 .51014 -0.75 0 Mabsadd m
.09358 .51014 0 1 Mabsadd L
.09358 .51014 .75 0 Mabsadd L
.09358 .51014 0 -1 Mabsadd L
.09358 .51014 -0.75 0 Mabsadd L closepath F
.09725 .49957 -0.75 0 Mabsadd m
.09725 .49957 0 1 Mabsadd L
.09725 .49957 .75 0 Mabsadd L
.09725 .49957 0 -1 Mabsadd L
.09725 .49957 -0.75 0 Mabsadd L closepath F
.10092 .48934 -0.75 0 Mabsadd m
.10092 .48934 0 1 Mabsadd L
.10092 .48934 .75 0 Mabsadd L
.10092 .48934 0 -1 Mabsadd L
.10092 .48934 -0.75 0 Mabsadd L closepath F
.10459 .48093 -0.75 0 Mabsadd m
.10459 .48093 0 1 Mabsadd L
.10459 .48093 .75 0 Mabsadd L
.10459 .48093 0 -1 Mabsadd L
.10459 .48093 -0.75 0 Mabsadd L closepath F
.10826 .47322 -0.75 0 Mabsadd m
.10826 .47322 0 1 Mabsadd L
.10826 .47322 .75 0 Mabsadd L
.10826 .47322 0 -1 Mabsadd L
.10826 .47322 -0.75 0 Mabsadd L closepath F
.11193 .46686 -0.75 0 Mabsadd m
.11193 .46686 0 1 Mabsadd L
.11193 .46686 .75 0 Mabsadd L
.11193 .46686 0 -1 Mabsadd L
.11193 .46686 -0.75 0 Mabsadd L closepath F
.1156 .46175 -0.75 0 Mabsadd m
.1156 .46175 0 1 Mabsadd L
.1156 .46175 .75 0 Mabsadd L
.1156 .46175 0 -1 Mabsadd L
.1156 .46175 -0.75 0 Mabsadd L closepath F
.11927 .45759 -0.75 0 Mabsadd m
.11927 .45759 0 1 Mabsadd L
.11927 .45759 .75 0 Mabsadd L
.11927 .45759 0 -1 Mabsadd L
.11927 .45759 -0.75 0 Mabsadd L closepath F
.12294 .45384 -0.75 0 Mabsadd m
.12294 .45384 0 1 Mabsadd L
.12294 .45384 .75 0 Mabsadd L
.12294 .45384 0 -1 Mabsadd L
.12294 .45384 -0.75 0 Mabsadd L closepath F
.12661 .45057 -0.75 0 Mabsadd m
.12661 .45057 0 1 Mabsadd L
.12661 .45057 .75 0 Mabsadd L
.12661 .45057 0 -1 Mabsadd L
.12661 .45057 -0.75 0 Mabsadd L closepath F
.13028 .44774 -0.75 0 Mabsadd m
.13028 .44774 0 1 Mabsadd L
.13028 .44774 .75 0 Mabsadd L
.13028 .44774 0 -1 Mabsadd L
.13028 .44774 -0.75 0 Mabsadd L closepath F
.13394 .44537 -0.75 0 Mabsadd m
.13394 .44537 0 1 Mabsadd L
.13394 .44537 .75 0 Mabsadd L
.13394 .44537 0 -1 Mabsadd L
.13394 .44537 -0.75 0 Mabsadd L closepath F
.13761 .44332 -0.75 0 Mabsadd m
.13761 .44332 0 1 Mabsadd L
.13761 .44332 .75 0 Mabsadd L
.13761 .44332 0 -1 Mabsadd L
.13761 .44332 -0.75 0 Mabsadd L closepath F
.14128 .44162 -0.75 0 Mabsadd m
.14128 .44162 0 1 Mabsadd L
.14128 .44162 .75 0 Mabsadd L
.14128 .44162 0 -1 Mabsadd L
.14128 .44162 -0.75 0 Mabsadd L closepath F
.14495 .4401 -0.75 0 Mabsadd m
.14495 .4401 0 1 Mabsadd L
.14495 .4401 .75 0 Mabsadd L
.14495 .4401 0 -1 Mabsadd L
.14495 .4401 -0.75 0 Mabsadd L closepath F
.14862 .43879 -0.75 0 Mabsadd m
.14862 .43879 0 1 Mabsadd L
.14862 .43879 .75 0 Mabsadd L
.14862 .43879 0 -1 Mabsadd L
.14862 .43879 -0.75 0 Mabsadd L closepath F
.15229 .43768 -0.75 0 Mabsadd m
.15229 .43768 0 1 Mabsadd L
.15229 .43768 .75 0 Mabsadd L
.15229 .43768 0 -1 Mabsadd L
.15229 .43768 -0.75 0 Mabsadd L closepath F
.15596 .43655 -0.75 0 Mabsadd m
.15596 .43655 0 1 Mabsadd L
.15596 .43655 .75 0 Mabsadd L
.15596 .43655 0 -1 Mabsadd L
.15596 .43655 -0.75 0 Mabsadd L closepath F
.15963 .43567 -0.75 0 Mabsadd m
.15963 .43567 0 1 Mabsadd L
.15963 .43567 .75 0 Mabsadd L
.15963 .43567 0 -1 Mabsadd L
.15963 .43567 -0.75 0 Mabsadd L closepath F
.1633 .43496 -0.75 0 Mabsadd m
.1633 .43496 0 1 Mabsadd L
.1633 .43496 .75 0 Mabsadd L
.1633 .43496 0 -1 Mabsadd L
.1633 .43496 -0.75 0 Mabsadd L closepath F
.16697 .43434 -0.75 0 Mabsadd m
.16697 .43434 0 1 Mabsadd L
.16697 .43434 .75 0 Mabsadd L
.16697 .43434 0 -1 Mabsadd L
.16697 .43434 -0.75 0 Mabsadd L closepath F
.17064 .43363 -0.75 0 Mabsadd m
.17064 .43363 0 1 Mabsadd L
.17064 .43363 .75 0 Mabsadd L
.17064 .43363 0 -1 Mabsadd L
.17064 .43363 -0.75 0 Mabsadd L closepath F
.17431 .43318 -0.75 0 Mabsadd m
.17431 .43318 0 1 Mabsadd L
.17431 .43318 .75 0 Mabsadd L
.17431 .43318 0 -1 Mabsadd L
.17431 .43318 -0.75 0 Mabsadd L closepath F
.17798 .43284 -0.75 0 Mabsadd m
.17798 .43284 0 1 Mabsadd L
.17798 .43284 .75 0 Mabsadd L
.17798 .43284 0 -1 Mabsadd L
.17798 .43284 -0.75 0 Mabsadd L closepath F
.18165 .43252 -0.75 0 Mabsadd m
.18165 .43252 0 1 Mabsadd L
.18165 .43252 .75 0 Mabsadd L
.18165 .43252 0 -1 Mabsadd L
.18165 .43252 -0.75 0 Mabsadd L closepath F
.18532 .43217 -0.75 0 Mabsadd m
.18532 .43217 0 1 Mabsadd L
.18532 .43217 .75 0 Mabsadd L
.18532 .43217 0 -1 Mabsadd L
.18532 .43217 -0.75 0 Mabsadd L closepath F
.18899 .43185 -0.75 0 Mabsadd m
.18899 .43185 0 1 Mabsadd L
.18899 .43185 .75 0 Mabsadd L
.18899 .43185 0 -1 Mabsadd L
.18899 .43185 -0.75 0 Mabsadd L closepath F
.19266 .43157 -0.75 0 Mabsadd m
.19266 .43157 0 1 Mabsadd L
.19266 .43157 .75 0 Mabsadd L
.19266 .43157 0 -1 Mabsadd L
.19266 .43157 -0.75 0 Mabsadd L closepath F
.19633 .43133 -0.75 0 Mabsadd m
.19633 .43133 0 1 Mabsadd L
.19633 .43133 .75 0 Mabsadd L
.19633 .43133 0 -1 Mabsadd L
.19633 .43133 -0.75 0 Mabsadd L closepath F
.2 .431 -0.75 0 Mabsadd m
.2 .431 0 1 Mabsadd L
.2 .431 .75 0 Mabsadd L
.2 .431 0 -1 Mabsadd L
.2 .431 -0.75 0 Mabsadd L closepath F
.20367 .4308 -0.75 0 Mabsadd m
.20367 .4308 0 1 Mabsadd L
.20367 .4308 .75 0 Mabsadd L
.20367 .4308 0 -1 Mabsadd L
.20367 .4308 -0.75 0 Mabsadd L closepath F
.20734 .43059 -0.75 0 Mabsadd m
.20734 .43059 0 1 Mabsadd L
.20734 .43059 .75 0 Mabsadd L
.20734 .43059 0 -1 Mabsadd L
.20734 .43059 -0.75 0 Mabsadd L closepath F
.21101 .4304 -0.75 0 Mabsadd m
.21101 .4304 0 1 Mabsadd L
.21101 .4304 .75 0 Mabsadd L
.21101 .4304 0 -1 Mabsadd L
.21101 .4304 -0.75 0 Mabsadd L closepath F
.21468 .43022 -0.75 0 Mabsadd m
.21468 .43022 0 1 Mabsadd L
.21468 .43022 .75 0 Mabsadd L
.21468 .43022 0 -1 Mabsadd L
.21468 .43022 -0.75 0 Mabsadd L closepath F
.21835 .43008 -0.75 0 Mabsadd m
.21835 .43008 0 1 Mabsadd L
.21835 .43008 .75 0 Mabsadd L
.21835 .43008 0 -1 Mabsadd L
.21835 .43008 -0.75 0 Mabsadd L closepath F
.22202 .42987 -0.75 0 Mabsadd m
.22202 .42987 0 1 Mabsadd L
.22202 .42987 .75 0 Mabsadd L
.22202 .42987 0 -1 Mabsadd L
.22202 .42987 -0.75 0 Mabsadd L closepath F
.22569 .42971 -0.75 0 Mabsadd m
.22569 .42971 0 1 Mabsadd L
.22569 .42971 .75 0 Mabsadd L
.22569 .42971 0 -1 Mabsadd L
.22569 .42971 -0.75 0 Mabsadd L closepath F
.22936 .4295 -0.75 0 Mabsadd m
.22936 .4295 0 1 Mabsadd L
.22936 .4295 .75 0 Mabsadd L
.22936 .4295 0 -1 Mabsadd L
.22936 .4295 -0.75 0 Mabsadd L closepath F
.23303 .4293 -0.75 0 Mabsadd m
.23303 .4293 0 1 Mabsadd L
.23303 .4293 .75 0 Mabsadd L
.23303 .4293 0 -1 Mabsadd L
.23303 .4293 -0.75 0 Mabsadd L closepath F
.2367 .42919 -0.75 0 Mabsadd m
.2367 .42919 0 1 Mabsadd L
.2367 .42919 .75 0 Mabsadd L
.2367 .42919 0 -1 Mabsadd L
.2367 .42919 -0.75 0 Mabsadd L closepath F
.24037 .42904 -0.75 0 Mabsadd m
.24037 .42904 0 1 Mabsadd L
.24037 .42904 .75 0 Mabsadd L
.24037 .42904 0 -1 Mabsadd L
.24037 .42904 -0.75 0 Mabsadd L closepath F
.24404 .42894 -0.75 0 Mabsadd m
.24404 .42894 0 1 Mabsadd L
.24404 .42894 .75 0 Mabsadd L
.24404 .42894 0 -1 Mabsadd L
.24404 .42894 -0.75 0 Mabsadd L closepath F
.24771 .42884 -0.75 0 Mabsadd m
.24771 .42884 0 1 Mabsadd L
.24771 .42884 .75 0 Mabsadd L
.24771 .42884 0 -1 Mabsadd L
.24771 .42884 -0.75 0 Mabsadd L closepath F
.25138 .42872 -0.75 0 Mabsadd m
.25138 .42872 0 1 Mabsadd L
.25138 .42872 .75 0 Mabsadd L
.25138 .42872 0 -1 Mabsadd L
.25138 .42872 -0.75 0 Mabsadd L closepath F
.25505 .42864 -0.75 0 Mabsadd m
.25505 .42864 0 1 Mabsadd L
.25505 .42864 .75 0 Mabsadd L
.25505 .42864 0 -1 Mabsadd L
.25505 .42864 -0.75 0 Mabsadd L closepath F
.25872 .42847 -0.75 0 Mabsadd m
.25872 .42847 0 1 Mabsadd L
.25872 .42847 .75 0 Mabsadd L
.25872 .42847 0 -1 Mabsadd L
.25872 .42847 -0.75 0 Mabsadd L closepath F
.26239 .42829 -0.75 0 Mabsadd m
.26239 .42829 0 1 Mabsadd L
.26239 .42829 .75 0 Mabsadd L
.26239 .42829 0 -1 Mabsadd L
.26239 .42829 -0.75 0 Mabsadd L closepath F
.26606 .42816 -0.75 0 Mabsadd m
.26606 .42816 0 1 Mabsadd L
.26606 .42816 .75 0 Mabsadd L
.26606 .42816 0 -1 Mabsadd L
.26606 .42816 -0.75 0 Mabsadd L closepath F
.26972 .42803 -0.75 0 Mabsadd m
.26972 .42803 0 1 Mabsadd L
.26972 .42803 .75 0 Mabsadd L
.26972 .42803 0 -1 Mabsadd L
.26972 .42803 -0.75 0 Mabsadd L closepath F
.27339 .42793 -0.75 0 Mabsadd m
.27339 .42793 0 1 Mabsadd L
.27339 .42793 .75 0 Mabsadd L
.27339 .42793 0 -1 Mabsadd L
.27339 .42793 -0.75 0 Mabsadd L closepath F
.27706 .4278 -0.75 0 Mabsadd m
.27706 .4278 0 1 Mabsadd L
.27706 .4278 .75 0 Mabsadd L
.27706 .4278 0 -1 Mabsadd L
.27706 .4278 -0.75 0 Mabsadd L closepath F
.28073 .42767 -0.75 0 Mabsadd m
.28073 .42767 0 1 Mabsadd L
.28073 .42767 .75 0 Mabsadd L
.28073 .42767 0 -1 Mabsadd L
.28073 .42767 -0.75 0 Mabsadd L closepath F
.2844 .42754 -0.75 0 Mabsadd m
.2844 .42754 0 1 Mabsadd L
.2844 .42754 .75 0 Mabsadd L
.2844 .42754 0 -1 Mabsadd L
.2844 .42754 -0.75 0 Mabsadd L closepath F
.28807 .4274 -0.75 0 Mabsadd m
.28807 .4274 0 1 Mabsadd L
.28807 .4274 .75 0 Mabsadd L
.28807 .4274 0 -1 Mabsadd L
.28807 .4274 -0.75 0 Mabsadd L closepath F
.29174 .4273 -0.75 0 Mabsadd m
.29174 .4273 0 1 Mabsadd L
.29174 .4273 .75 0 Mabsadd L
.29174 .4273 0 -1 Mabsadd L
.29174 .4273 -0.75 0 Mabsadd L closepath F
.29541 .42711 -0.75 0 Mabsadd m
.29541 .42711 0 1 Mabsadd L
.29541 .42711 .75 0 Mabsadd L
.29541 .42711 0 -1 Mabsadd L
.29541 .42711 -0.75 0 Mabsadd L closepath F
.29908 .42699 -0.75 0 Mabsadd m
.29908 .42699 0 1 Mabsadd L
.29908 .42699 .75 0 Mabsadd L
.29908 .42699 0 -1 Mabsadd L
.29908 .42699 -0.75 0 Mabsadd L closepath F
.30275 .42689 -0.75 0 Mabsadd m
.30275 .42689 0 1 Mabsadd L
.30275 .42689 .75 0 Mabsadd L
.30275 .42689 0 -1 Mabsadd L
.30275 .42689 -0.75 0 Mabsadd L closepath F
.30642 .42672 -0.75 0 Mabsadd m
.30642 .42672 0 1 Mabsadd L
.30642 .42672 .75 0 Mabsadd L
.30642 .42672 0 -1 Mabsadd L
.30642 .42672 -0.75 0 Mabsadd L closepath F
.31009 .42661 -0.75 0 Mabsadd m
.31009 .42661 0 1 Mabsadd L
.31009 .42661 .75 0 Mabsadd L
.31009 .42661 0 -1 Mabsadd L
.31009 .42661 -0.75 0 Mabsadd L closepath F
.31376 .42654 -0.75 0 Mabsadd m
.31376 .42654 0 1 Mabsadd L
.31376 .42654 .75 0 Mabsadd L
.31376 .42654 0 -1 Mabsadd L
.31376 .42654 -0.75 0 Mabsadd L closepath F
.31743 .42644 -0.75 0 Mabsadd m
.31743 .42644 0 1 Mabsadd L
.31743 .42644 .75 0 Mabsadd L
.31743 .42644 0 -1 Mabsadd L
.31743 .42644 -0.75 0 Mabsadd L closepath F
.3211 .42631 -0.75 0 Mabsadd m
.3211 .42631 0 1 Mabsadd L
.3211 .42631 .75 0 Mabsadd L
.3211 .42631 0 -1 Mabsadd L
.3211 .42631 -0.75 0 Mabsadd L closepath F
.32477 .42614 -0.75 0 Mabsadd m
.32477 .42614 0 1 Mabsadd L
.32477 .42614 .75 0 Mabsadd L
.32477 .42614 0 -1 Mabsadd L
.32477 .42614 -0.75 0 Mabsadd L closepath F
.32844 .426 -0.75 0 Mabsadd m
.32844 .426 0 1 Mabsadd L
.32844 .426 .75 0 Mabsadd L
.32844 .426 0 -1 Mabsadd L
.32844 .426 -0.75 0 Mabsadd L closepath F
.33211 .42595 -0.75 0 Mabsadd m
.33211 .42595 0 1 Mabsadd L
.33211 .42595 .75 0 Mabsadd L
.33211 .42595 0 -1 Mabsadd L
.33211 .42595 -0.75 0 Mabsadd L closepath F
.33578 .4258 -0.75 0 Mabsadd m
.33578 .4258 0 1 Mabsadd L
.33578 .4258 .75 0 Mabsadd L
.33578 .4258 0 -1 Mabsadd L
.33578 .4258 -0.75 0 Mabsadd L closepath F
.33945 .42573 -0.75 0 Mabsadd m
.33945 .42573 0 1 Mabsadd L
.33945 .42573 .75 0 Mabsadd L
.33945 .42573 0 -1 Mabsadd L
.33945 .42573 -0.75 0 Mabsadd L closepath F
.34312 .42563 -0.75 0 Mabsadd m
.34312 .42563 0 1 Mabsadd L
.34312 .42563 .75 0 Mabsadd L
.34312 .42563 0 -1 Mabsadd L
.34312 .42563 -0.75 0 Mabsadd L closepath F
.34679 .42561 -0.75 0 Mabsadd m
.34679 .42561 0 1 Mabsadd L
.34679 .42561 .75 0 Mabsadd L
.34679 .42561 0 -1 Mabsadd L
.34679 .42561 -0.75 0 Mabsadd L closepath F
.35046 .42546 -0.75 0 Mabsadd m
.35046 .42546 0 1 Mabsadd L
.35046 .42546 .75 0 Mabsadd L
.35046 .42546 0 -1 Mabsadd L
.35046 .42546 -0.75 0 Mabsadd L closepath F
.35413 .42533 -0.75 0 Mabsadd m
.35413 .42533 0 1 Mabsadd L
.35413 .42533 .75 0 Mabsadd L
.35413 .42533 0 -1 Mabsadd L
.35413 .42533 -0.75 0 Mabsadd L closepath F
.3578 .42524 -0.75 0 Mabsadd m
.3578 .42524 0 1 Mabsadd L
.3578 .42524 .75 0 Mabsadd L
.3578 .42524 0 -1 Mabsadd L
.3578 .42524 -0.75 0 Mabsadd L closepath F
.36147 .42516 -0.75 0 Mabsadd m
.36147 .42516 0 1 Mabsadd L
.36147 .42516 .75 0 Mabsadd L
.36147 .42516 0 -1 Mabsadd L
.36147 .42516 -0.75 0 Mabsadd L closepath F
.36514 .42502 -0.75 0 Mabsadd m
.36514 .42502 0 1 Mabsadd L
.36514 .42502 .75 0 Mabsadd L
.36514 .42502 0 -1 Mabsadd L
.36514 .42502 -0.75 0 Mabsadd L closepath F
.36881 .42496 -0.75 0 Mabsadd m
.36881 .42496 0 1 Mabsadd L
.36881 .42496 .75 0 Mabsadd L
.36881 .42496 0 -1 Mabsadd L
.36881 .42496 -0.75 0 Mabsadd L closepath F
.37248 .42486 -0.75 0 Mabsadd m
.37248 .42486 0 1 Mabsadd L
.37248 .42486 .75 0 Mabsadd L
.37248 .42486 0 -1 Mabsadd L
.37248 .42486 -0.75 0 Mabsadd L closepath F
.37615 .42475 -0.75 0 Mabsadd m
.37615 .42475 0 1 Mabsadd L
.37615 .42475 .75 0 Mabsadd L
.37615 .42475 0 -1 Mabsadd L
.37615 .42475 -0.75 0 Mabsadd L closepath F
.37982 .42467 -0.75 0 Mabsadd m
.37982 .42467 0 1 Mabsadd L
.37982 .42467 .75 0 Mabsadd L
.37982 .42467 0 -1 Mabsadd L
.37982 .42467 -0.75 0 Mabsadd L closepath F
.38349 .42458 -0.75 0 Mabsadd m
.38349 .42458 0 1 Mabsadd L
.38349 .42458 .75 0 Mabsadd L
.38349 .42458 0 -1 Mabsadd L
.38349 .42458 -0.75 0 Mabsadd L closepath F
.38716 .42451 -0.75 0 Mabsadd m
.38716 .42451 0 1 Mabsadd L
.38716 .42451 .75 0 Mabsadd L
.38716 .42451 0 -1 Mabsadd L
.38716 .42451 -0.75 0 Mabsadd L closepath F
.39083 .42442 -0.75 0 Mabsadd m
.39083 .42442 0 1 Mabsadd L
.39083 .42442 .75 0 Mabsadd L
.39083 .42442 0 -1 Mabsadd L
.39083 .42442 -0.75 0 Mabsadd L closepath F
.3945 .42436 -0.75 0 Mabsadd m
.3945 .42436 0 1 Mabsadd L
.3945 .42436 .75 0 Mabsadd L
.3945 .42436 0 -1 Mabsadd L
.3945 .42436 -0.75 0 Mabsadd L closepath F
.39817 .42421 -0.75 0 Mabsadd m
.39817 .42421 0 1 Mabsadd L
.39817 .42421 .75 0 Mabsadd L
.39817 .42421 0 -1 Mabsadd L
.39817 .42421 -0.75 0 Mabsadd L closepath F
.40183 .42411 -0.75 0 Mabsadd m
.40183 .42411 0 1 Mabsadd L
.40183 .42411 .75 0 Mabsadd L
.40183 .42411 0 -1 Mabsadd L
.40183 .42411 -0.75 0 Mabsadd L closepath F
.4055 .42404 -0.75 0 Mabsadd m
.4055 .42404 0 1 Mabsadd L
.4055 .42404 .75 0 Mabsadd L
.4055 .42404 0 -1 Mabsadd L
.4055 .42404 -0.75 0 Mabsadd L closepath F
.40917 .42393 -0.75 0 Mabsadd m
.40917 .42393 0 1 Mabsadd L
.40917 .42393 .75 0 Mabsadd L
.40917 .42393 0 -1 Mabsadd L
.40917 .42393 -0.75 0 Mabsadd L closepath F
.41284 .42385 -0.75 0 Mabsadd m
.41284 .42385 0 1 Mabsadd L
.41284 .42385 .75 0 Mabsadd L
.41284 .42385 0 -1 Mabsadd L
.41284 .42385 -0.75 0 Mabsadd L closepath F
.41651 .42374 -0.75 0 Mabsadd m
.41651 .42374 0 1 Mabsadd L
.41651 .42374 .75 0 Mabsadd L
.41651 .42374 0 -1 Mabsadd L
.41651 .42374 -0.75 0 Mabsadd L closepath F
.42018 .42365 -0.75 0 Mabsadd m
.42018 .42365 0 1 Mabsadd L
.42018 .42365 .75 0 Mabsadd L
.42018 .42365 0 -1 Mabsadd L
.42018 .42365 -0.75 0 Mabsadd L closepath F
.42385 .42356 -0.75 0 Mabsadd m
.42385 .42356 0 1 Mabsadd L
.42385 .42356 .75 0 Mabsadd L
.42385 .42356 0 -1 Mabsadd L
.42385 .42356 -0.75 0 Mabsadd L closepath F
.42752 .42347 -0.75 0 Mabsadd m
.42752 .42347 0 1 Mabsadd L
.42752 .42347 .75 0 Mabsadd L
.42752 .42347 0 -1 Mabsadd L
.42752 .42347 -0.75 0 Mabsadd L closepath F
.43119 .42342 -0.75 0 Mabsadd m
.43119 .42342 0 1 Mabsadd L
.43119 .42342 .75 0 Mabsadd L
.43119 .42342 0 -1 Mabsadd L
.43119 .42342 -0.75 0 Mabsadd L closepath F
.43486 .42332 -0.75 0 Mabsadd m
.43486 .42332 0 1 Mabsadd L
.43486 .42332 .75 0 Mabsadd L
.43486 .42332 0 -1 Mabsadd L
.43486 .42332 -0.75 0 Mabsadd L closepath F
.43853 .42324 -0.75 0 Mabsadd m
.43853 .42324 0 1 Mabsadd L
.43853 .42324 .75 0 Mabsadd L
.43853 .42324 0 -1 Mabsadd L
.43853 .42324 -0.75 0 Mabsadd L closepath F
.4422 .42319 -0.75 0 Mabsadd m
.4422 .42319 0 1 Mabsadd L
.4422 .42319 .75 0 Mabsadd L
.4422 .42319 0 -1 Mabsadd L
.4422 .42319 -0.75 0 Mabsadd L closepath F
.44587 .42309 -0.75 0 Mabsadd m
.44587 .42309 0 1 Mabsadd L
.44587 .42309 .75 0 Mabsadd L
.44587 .42309 0 -1 Mabsadd L
.44587 .42309 -0.75 0 Mabsadd L closepath F
.44954 .423 -0.75 0 Mabsadd m
.44954 .423 0 1 Mabsadd L
.44954 .423 .75 0 Mabsadd L
.44954 .423 0 -1 Mabsadd L
.44954 .423 -0.75 0 Mabsadd L closepath F
.45321 .423 -0.75 0 Mabsadd m
.45321 .423 0 1 Mabsadd L
.45321 .423 .75 0 Mabsadd L
.45321 .423 0 -1 Mabsadd L
.45321 .423 -0.75 0 Mabsadd L closepath F
.45688 .42291 -0.75 0 Mabsadd m
.45688 .42291 0 1 Mabsadd L
.45688 .42291 .75 0 Mabsadd L
.45688 .42291 0 -1 Mabsadd L
.45688 .42291 -0.75 0 Mabsadd L closepath F
.46055 .42286 -0.75 0 Mabsadd m
.46055 .42286 0 1 Mabsadd L
.46055 .42286 .75 0 Mabsadd L
.46055 .42286 0 -1 Mabsadd L
.46055 .42286 -0.75 0 Mabsadd L closepath F
.46422 .42277 -0.75 0 Mabsadd m
.46422 .42277 0 1 Mabsadd L
.46422 .42277 .75 0 Mabsadd L
.46422 .42277 0 -1 Mabsadd L
.46422 .42277 -0.75 0 Mabsadd L closepath F
.46789 .42263 -0.75 0 Mabsadd m
.46789 .42263 0 1 Mabsadd L
.46789 .42263 .75 0 Mabsadd L
.46789 .42263 0 -1 Mabsadd L
.46789 .42263 -0.75 0 Mabsadd L closepath F
.47156 .42251 -0.75 0 Mabsadd m
.47156 .42251 0 1 Mabsadd L
.47156 .42251 .75 0 Mabsadd L
.47156 .42251 0 -1 Mabsadd L
.47156 .42251 -0.75 0 Mabsadd L closepath F
.47523 .42244 -0.75 0 Mabsadd m
.47523 .42244 0 1 Mabsadd L
.47523 .42244 .75 0 Mabsadd L
.47523 .42244 0 -1 Mabsadd L
.47523 .42244 -0.75 0 Mabsadd L closepath F
.4789 .42235 -0.75 0 Mabsadd m
.4789 .42235 0 1 Mabsadd L
.4789 .42235 .75 0 Mabsadd L
.4789 .42235 0 -1 Mabsadd L
.4789 .42235 -0.75 0 Mabsadd L closepath F
.48257 .42219 -0.75 0 Mabsadd m
.48257 .42219 0 1 Mabsadd L
.48257 .42219 .75 0 Mabsadd L
.48257 .42219 0 -1 Mabsadd L
.48257 .42219 -0.75 0 Mabsadd L closepath F
.48624 .42199 -0.75 0 Mabsadd m
.48624 .42199 0 1 Mabsadd L
.48624 .42199 .75 0 Mabsadd L
.48624 .42199 0 -1 Mabsadd L
.48624 .42199 -0.75 0 Mabsadd L closepath F
.48991 .42188 -0.75 0 Mabsadd m
.48991 .42188 0 1 Mabsadd L
.48991 .42188 .75 0 Mabsadd L
.48991 .42188 0 -1 Mabsadd L
.48991 .42188 -0.75 0 Mabsadd L closepath F
.49358 .42172 -0.75 0 Mabsadd m
.49358 .42172 0 1 Mabsadd L
.49358 .42172 .75 0 Mabsadd L
.49358 .42172 0 -1 Mabsadd L
.49358 .42172 -0.75 0 Mabsadd L closepath F
.49725 .42157 -0.75 0 Mabsadd m
.49725 .42157 0 1 Mabsadd L
.49725 .42157 .75 0 Mabsadd L
.49725 .42157 0 -1 Mabsadd L
.49725 .42157 -0.75 0 Mabsadd L closepath F
.50092 .42153 -0.75 0 Mabsadd m
.50092 .42153 0 1 Mabsadd L
.50092 .42153 .75 0 Mabsadd L
.50092 .42153 0 -1 Mabsadd L
.50092 .42153 -0.75 0 Mabsadd L closepath F
.50459 .42148 -0.75 0 Mabsadd m
.50459 .42148 0 1 Mabsadd L
.50459 .42148 .75 0 Mabsadd L
.50459 .42148 0 -1 Mabsadd L
.50459 .42148 -0.75 0 Mabsadd L closepath F
.50826 .42139 -0.75 0 Mabsadd m
.50826 .42139 0 1 Mabsadd L
.50826 .42139 .75 0 Mabsadd L
.50826 .42139 0 -1 Mabsadd L
.50826 .42139 -0.75 0 Mabsadd L closepath F
.51193 .42122 -0.75 0 Mabsadd m
.51193 .42122 0 1 Mabsadd L
.51193 .42122 .75 0 Mabsadd L
.51193 .42122 0 -1 Mabsadd L
.51193 .42122 -0.75 0 Mabsadd L closepath F
.5156 .4212 -0.75 0 Mabsadd m
.5156 .4212 0 1 Mabsadd L
.5156 .4212 .75 0 Mabsadd L
.5156 .4212 0 -1 Mabsadd L
.5156 .4212 -0.75 0 Mabsadd L closepath F
.51927 .42111 -0.75 0 Mabsadd m
.51927 .42111 0 1 Mabsadd L
.51927 .42111 .75 0 Mabsadd L
.51927 .42111 0 -1 Mabsadd L
.51927 .42111 -0.75 0 Mabsadd L closepath F
.52294 .42107 -0.75 0 Mabsadd m
.52294 .42107 0 1 Mabsadd L
.52294 .42107 .75 0 Mabsadd L
.52294 .42107 0 -1 Mabsadd L
.52294 .42107 -0.75 0 Mabsadd L closepath F
.52661 .42102 -0.75 0 Mabsadd m
.52661 .42102 0 1 Mabsadd L
.52661 .42102 .75 0 Mabsadd L
.52661 .42102 0 -1 Mabsadd L
.52661 .42102 -0.75 0 Mabsadd L closepath F
.53028 .42092 -0.75 0 Mabsadd m
.53028 .42092 0 1 Mabsadd L
.53028 .42092 .75 0 Mabsadd L
.53028 .42092 0 -1 Mabsadd L
.53028 .42092 -0.75 0 Mabsadd L closepath F
.53394 .42079 -0.75 0 Mabsadd m
.53394 .42079 0 1 Mabsadd L
.53394 .42079 .75 0 Mabsadd L
.53394 .42079 0 -1 Mabsadd L
.53394 .42079 -0.75 0 Mabsadd L closepath F
.53761 .42069 -0.75 0 Mabsadd m
.53761 .42069 0 1 Mabsadd L
.53761 .42069 .75 0 Mabsadd L
.53761 .42069 0 -1 Mabsadd L
.53761 .42069 -0.75 0 Mabsadd L closepath F
.54128 .42068 -0.75 0 Mabsadd m
.54128 .42068 0 1 Mabsadd L
.54128 .42068 .75 0 Mabsadd L
.54128 .42068 0 -1 Mabsadd L
.54128 .42068 -0.75 0 Mabsadd L closepath F
.54495 .42067 -0.75 0 Mabsadd m
.54495 .42067 0 1 Mabsadd L
.54495 .42067 .75 0 Mabsadd L
.54495 .42067 0 -1 Mabsadd L
.54495 .42067 -0.75 0 Mabsadd L closepath F
.54862 .42058 -0.75 0 Mabsadd m
.54862 .42058 0 1 Mabsadd L
.54862 .42058 .75 0 Mabsadd L
.54862 .42058 0 -1 Mabsadd L
.54862 .42058 -0.75 0 Mabsadd L closepath F
.55229 .42047 -0.75 0 Mabsadd m
.55229 .42047 0 1 Mabsadd L
.55229 .42047 .75 0 Mabsadd L
.55229 .42047 0 -1 Mabsadd L
.55229 .42047 -0.75 0 Mabsadd L closepath F
.55596 .42043 -0.75 0 Mabsadd m
.55596 .42043 0 1 Mabsadd L
.55596 .42043 .75 0 Mabsadd L
.55596 .42043 0 -1 Mabsadd L
.55596 .42043 -0.75 0 Mabsadd L closepath F
.55963 .4203 -0.75 0 Mabsadd m
.55963 .4203 0 1 Mabsadd L
.55963 .4203 .75 0 Mabsadd L
.55963 .4203 0 -1 Mabsadd L
.55963 .4203 -0.75 0 Mabsadd L closepath F
.5633 .42024 -0.75 0 Mabsadd m
.5633 .42024 0 1 Mabsadd L
.5633 .42024 .75 0 Mabsadd L
.5633 .42024 0 -1 Mabsadd L
.5633 .42024 -0.75 0 Mabsadd L closepath F
.56697 .42016 -0.75 0 Mabsadd m
.56697 .42016 0 1 Mabsadd L
.56697 .42016 .75 0 Mabsadd L
.56697 .42016 0 -1 Mabsadd L
.56697 .42016 -0.75 0 Mabsadd L closepath F
.57064 .42 -0.75 0 Mabsadd m
.57064 .42 0 1 Mabsadd L
.57064 .42 .75 0 Mabsadd L
.57064 .42 0 -1 Mabsadd L
.57064 .42 -0.75 0 Mabsadd L closepath F
.57431 .41987 -0.75 0 Mabsadd m
.57431 .41987 0 1 Mabsadd L
.57431 .41987 .75 0 Mabsadd L
.57431 .41987 0 -1 Mabsadd L
.57431 .41987 -0.75 0 Mabsadd L closepath F
.57798 .41978 -0.75 0 Mabsadd m
.57798 .41978 0 1 Mabsadd L
.57798 .41978 .75 0 Mabsadd L
.57798 .41978 0 -1 Mabsadd L
.57798 .41978 -0.75 0 Mabsadd L closepath F
.58165 .41976 -0.75 0 Mabsadd m
.58165 .41976 0 1 Mabsadd L
.58165 .41976 .75 0 Mabsadd L
.58165 .41976 0 -1 Mabsadd L
.58165 .41976 -0.75 0 Mabsadd L closepath F
.58532 .4197 -0.75 0 Mabsadd m
.58532 .4197 0 1 Mabsadd L
.58532 .4197 .75 0 Mabsadd L
.58532 .4197 0 -1 Mabsadd L
.58532 .4197 -0.75 0 Mabsadd L closepath F
.58899 .41961 -0.75 0 Mabsadd m
.58899 .41961 0 1 Mabsadd L
.58899 .41961 .75 0 Mabsadd L
.58899 .41961 0 -1 Mabsadd L
.58899 .41961 -0.75 0 Mabsadd L closepath F
.59266 .41947 -0.75 0 Mabsadd m
.59266 .41947 0 1 Mabsadd L
.59266 .41947 .75 0 Mabsadd L
.59266 .41947 0 -1 Mabsadd L
.59266 .41947 -0.75 0 Mabsadd L closepath F
.59633 .41942 -0.75 0 Mabsadd m
.59633 .41942 0 1 Mabsadd L
.59633 .41942 .75 0 Mabsadd L
.59633 .41942 0 -1 Mabsadd L
.59633 .41942 -0.75 0 Mabsadd L closepath F
.6 .41938 -0.75 0 Mabsadd m
.6 .41938 0 1 Mabsadd L
.6 .41938 .75 0 Mabsadd L
.6 .41938 0 -1 Mabsadd L
.6 .41938 -0.75 0 Mabsadd L closepath F
.60367 .4193 -0.75 0 Mabsadd m
.60367 .4193 0 1 Mabsadd L
.60367 .4193 .75 0 Mabsadd L
.60367 .4193 0 -1 Mabsadd L
.60367 .4193 -0.75 0 Mabsadd L closepath F
.60734 .41918 -0.75 0 Mabsadd m
.60734 .41918 0 1 Mabsadd L
.60734 .41918 .75 0 Mabsadd L
.60734 .41918 0 -1 Mabsadd L
.60734 .41918 -0.75 0 Mabsadd L closepath F
.61101 .41909 -0.75 0 Mabsadd m
.61101 .41909 0 1 Mabsadd L
.61101 .41909 .75 0 Mabsadd L
.61101 .41909 0 -1 Mabsadd L
.61101 .41909 -0.75 0 Mabsadd L closepath F
.61468 .41901 -0.75 0 Mabsadd m
.61468 .41901 0 1 Mabsadd L
.61468 .41901 .75 0 Mabsadd L
.61468 .41901 0 -1 Mabsadd L
.61468 .41901 -0.75 0 Mabsadd L closepath F
.61835 .41891 -0.75 0 Mabsadd m
.61835 .41891 0 1 Mabsadd L
.61835 .41891 .75 0 Mabsadd L
.61835 .41891 0 -1 Mabsadd L
.61835 .41891 -0.75 0 Mabsadd L closepath F
.62202 .41879 -0.75 0 Mabsadd m
.62202 .41879 0 1 Mabsadd L
.62202 .41879 .75 0 Mabsadd L
.62202 .41879 0 -1 Mabsadd L
.62202 .41879 -0.75 0 Mabsadd L closepath F
.62569 .4186 -0.75 0 Mabsadd m
.62569 .4186 0 1 Mabsadd L
.62569 .4186 .75 0 Mabsadd L
.62569 .4186 0 -1 Mabsadd L
.62569 .4186 -0.75 0 Mabsadd L closepath F
.62936 .41846 -0.75 0 Mabsadd m
.62936 .41846 0 1 Mabsadd L
.62936 .41846 .75 0 Mabsadd L
.62936 .41846 0 -1 Mabsadd L
.62936 .41846 -0.75 0 Mabsadd L closepath F
.63303 .41831 -0.75 0 Mabsadd m
.63303 .41831 0 1 Mabsadd L
.63303 .41831 .75 0 Mabsadd L
.63303 .41831 0 -1 Mabsadd L
.63303 .41831 -0.75 0 Mabsadd L closepath F
.6367 .41818 -0.75 0 Mabsadd m
.6367 .41818 0 1 Mabsadd L
.6367 .41818 .75 0 Mabsadd L
.6367 .41818 0 -1 Mabsadd L
.6367 .41818 -0.75 0 Mabsadd L closepath F
.64037 .41795 -0.75 0 Mabsadd m
.64037 .41795 0 1 Mabsadd L
.64037 .41795 .75 0 Mabsadd L
.64037 .41795 0 -1 Mabsadd L
.64037 .41795 -0.75 0 Mabsadd L closepath F
.64404 .41777 -0.75 0 Mabsadd m
.64404 .41777 0 1 Mabsadd L
.64404 .41777 .75 0 Mabsadd L
.64404 .41777 0 -1 Mabsadd L
.64404 .41777 -0.75 0 Mabsadd L closepath F
.64771 .41764 -0.75 0 Mabsadd m
.64771 .41764 0 1 Mabsadd L
.64771 .41764 .75 0 Mabsadd L
.64771 .41764 0 -1 Mabsadd L
.64771 .41764 -0.75 0 Mabsadd L closepath F
.65138 .41751 -0.75 0 Mabsadd m
.65138 .41751 0 1 Mabsadd L
.65138 .41751 .75 0 Mabsadd L
.65138 .41751 0 -1 Mabsadd L
.65138 .41751 -0.75 0 Mabsadd L closepath F
.65505 .4174 -0.75 0 Mabsadd m
.65505 .4174 0 1 Mabsadd L
.65505 .4174 .75 0 Mabsadd L
.65505 .4174 0 -1 Mabsadd L
.65505 .4174 -0.75 0 Mabsadd L closepath F
.65872 .41725 -0.75 0 Mabsadd m
.65872 .41725 0 1 Mabsadd L
.65872 .41725 .75 0 Mabsadd L
.65872 .41725 0 -1 Mabsadd L
.65872 .41725 -0.75 0 Mabsadd L closepath F
.66239 .41714 -0.75 0 Mabsadd m
.66239 .41714 0 1 Mabsadd L
.66239 .41714 .75 0 Mabsadd L
.66239 .41714 0 -1 Mabsadd L
.66239 .41714 -0.75 0 Mabsadd L closepath F
.66606 .4171 -0.75 0 Mabsadd m
.66606 .4171 0 1 Mabsadd L
.66606 .4171 .75 0 Mabsadd L
.66606 .4171 0 -1 Mabsadd L
.66606 .4171 -0.75 0 Mabsadd L closepath F
.66972 .41696 -0.75 0 Mabsadd m
.66972 .41696 0 1 Mabsadd L
.66972 .41696 .75 0 Mabsadd L
.66972 .41696 0 -1 Mabsadd L
.66972 .41696 -0.75 0 Mabsadd L closepath F
.67339 .41688 -0.75 0 Mabsadd m
.67339 .41688 0 1 Mabsadd L
.67339 .41688 .75 0 Mabsadd L
.67339 .41688 0 -1 Mabsadd L
.67339 .41688 -0.75 0 Mabsadd L closepath F
.67706 .41677 -0.75 0 Mabsadd m
.67706 .41677 0 1 Mabsadd L
.67706 .41677 .75 0 Mabsadd L
.67706 .41677 0 -1 Mabsadd L
.67706 .41677 -0.75 0 Mabsadd L closepath F
.68073 .41669 -0.75 0 Mabsadd m
.68073 .41669 0 1 Mabsadd L
.68073 .41669 .75 0 Mabsadd L
.68073 .41669 0 -1 Mabsadd L
.68073 .41669 -0.75 0 Mabsadd L closepath F
.6844 .41657 -0.75 0 Mabsadd m
.6844 .41657 0 1 Mabsadd L
.6844 .41657 .75 0 Mabsadd L
.6844 .41657 0 -1 Mabsadd L
.6844 .41657 -0.75 0 Mabsadd L closepath F
.68807 .41647 -0.75 0 Mabsadd m
.68807 .41647 0 1 Mabsadd L
.68807 .41647 .75 0 Mabsadd L
.68807 .41647 0 -1 Mabsadd L
.68807 .41647 -0.75 0 Mabsadd L closepath F
.69174 .41643 -0.75 0 Mabsadd m
.69174 .41643 0 1 Mabsadd L
.69174 .41643 .75 0 Mabsadd L
.69174 .41643 0 -1 Mabsadd L
.69174 .41643 -0.75 0 Mabsadd L closepath F
.69541 .41633 -0.75 0 Mabsadd m
.69541 .41633 0 1 Mabsadd L
.69541 .41633 .75 0 Mabsadd L
.69541 .41633 0 -1 Mabsadd L
.69541 .41633 -0.75 0 Mabsadd L closepath F
.69908 .41617 -0.75 0 Mabsadd m
.69908 .41617 0 1 Mabsadd L
.69908 .41617 .75 0 Mabsadd L
.69908 .41617 0 -1 Mabsadd L
.69908 .41617 -0.75 0 Mabsadd L closepath F
.70275 .41609 -0.75 0 Mabsadd m
.70275 .41609 0 1 Mabsadd L
.70275 .41609 .75 0 Mabsadd L
.70275 .41609 0 -1 Mabsadd L
.70275 .41609 -0.75 0 Mabsadd L closepath F
.70642 .41603 -0.75 0 Mabsadd m
.70642 .41603 0 1 Mabsadd L
.70642 .41603 .75 0 Mabsadd L
.70642 .41603 0 -1 Mabsadd L
.70642 .41603 -0.75 0 Mabsadd L closepath F
.71009 .41599 -0.75 0 Mabsadd m
.71009 .41599 0 1 Mabsadd L
.71009 .41599 .75 0 Mabsadd L
.71009 .41599 0 -1 Mabsadd L
.71009 .41599 -0.75 0 Mabsadd L closepath F
.71376 .41591 -0.75 0 Mabsadd m
.71376 .41591 0 1 Mabsadd L
.71376 .41591 .75 0 Mabsadd L
.71376 .41591 0 -1 Mabsadd L
.71376 .41591 -0.75 0 Mabsadd L closepath F
.71743 .41578 -0.75 0 Mabsadd m
.71743 .41578 0 1 Mabsadd L
.71743 .41578 .75 0 Mabsadd L
.71743 .41578 0 -1 Mabsadd L
.71743 .41578 -0.75 0 Mabsadd L closepath F
.7211 .41573 -0.75 0 Mabsadd m
.7211 .41573 0 1 Mabsadd L
.7211 .41573 .75 0 Mabsadd L
.7211 .41573 0 -1 Mabsadd L
.7211 .41573 -0.75 0 Mabsadd L closepath F
.72477 .41566 -0.75 0 Mabsadd m
.72477 .41566 0 1 Mabsadd L
.72477 .41566 .75 0 Mabsadd L
.72477 .41566 0 -1 Mabsadd L
.72477 .41566 -0.75 0 Mabsadd L closepath F
.72844 .41557 -0.75 0 Mabsadd m
.72844 .41557 0 1 Mabsadd L
.72844 .41557 .75 0 Mabsadd L
.72844 .41557 0 -1 Mabsadd L
.72844 .41557 -0.75 0 Mabsadd L closepath F
.73211 .41538 -0.75 0 Mabsadd m
.73211 .41538 0 1 Mabsadd L
.73211 .41538 .75 0 Mabsadd L
.73211 .41538 0 -1 Mabsadd L
.73211 .41538 -0.75 0 Mabsadd L closepath F
.73578 .4153 -0.75 0 Mabsadd m
.73578 .4153 0 1 Mabsadd L
.73578 .4153 .75 0 Mabsadd L
.73578 .4153 0 -1 Mabsadd L
.73578 .4153 -0.75 0 Mabsadd L closepath F
.73945 .41516 -0.75 0 Mabsadd m
.73945 .41516 0 1 Mabsadd L
.73945 .41516 .75 0 Mabsadd L
.73945 .41516 0 -1 Mabsadd L
.73945 .41516 -0.75 0 Mabsadd L closepath F
.74312 .41508 -0.75 0 Mabsadd m
.74312 .41508 0 1 Mabsadd L
.74312 .41508 .75 0 Mabsadd L
.74312 .41508 0 -1 Mabsadd L
.74312 .41508 -0.75 0 Mabsadd L closepath F
.74679 .41495 -0.75 0 Mabsadd m
.74679 .41495 0 1 Mabsadd L
.74679 .41495 .75 0 Mabsadd L
.74679 .41495 0 -1 Mabsadd L
.74679 .41495 -0.75 0 Mabsadd L closepath F
.75046 .4149 -0.75 0 Mabsadd m
.75046 .4149 0 1 Mabsadd L
.75046 .4149 .75 0 Mabsadd L
.75046 .4149 0 -1 Mabsadd L
.75046 .4149 -0.75 0 Mabsadd L closepath F
.75413 .41476 -0.75 0 Mabsadd m
.75413 .41476 0 1 Mabsadd L
.75413 .41476 .75 0 Mabsadd L
.75413 .41476 0 -1 Mabsadd L
.75413 .41476 -0.75 0 Mabsadd L closepath F
.7578 .41458 -0.75 0 Mabsadd m
.7578 .41458 0 1 Mabsadd L
.7578 .41458 .75 0 Mabsadd L
.7578 .41458 0 -1 Mabsadd L
.7578 .41458 -0.75 0 Mabsadd L closepath F
.76147 .41448 -0.75 0 Mabsadd m
.76147 .41448 0 1 Mabsadd L
.76147 .41448 .75 0 Mabsadd L
.76147 .41448 0 -1 Mabsadd L
.76147 .41448 -0.75 0 Mabsadd L closepath F
.76514 .4144 -0.75 0 Mabsadd m
.76514 .4144 0 1 Mabsadd L
.76514 .4144 .75 0 Mabsadd L
.76514 .4144 0 -1 Mabsadd L
.76514 .4144 -0.75 0 Mabsadd L closepath F
.76881 .41432 -0.75 0 Mabsadd m
.76881 .41432 0 1 Mabsadd L
.76881 .41432 .75 0 Mabsadd L
.76881 .41432 0 -1 Mabsadd L
.76881 .41432 -0.75 0 Mabsadd L closepath F
.77248 .41419 -0.75 0 Mabsadd m
.77248 .41419 0 1 Mabsadd L
.77248 .41419 .75 0 Mabsadd L
.77248 .41419 0 -1 Mabsadd L
.77248 .41419 -0.75 0 Mabsadd L closepath F
.77615 .41409 -0.75 0 Mabsadd m
.77615 .41409 0 1 Mabsadd L
.77615 .41409 .75 0 Mabsadd L
.77615 .41409 0 -1 Mabsadd L
.77615 .41409 -0.75 0 Mabsadd L closepath F
.77982 .41396 -0.75 0 Mabsadd m
.77982 .41396 0 1 Mabsadd L
.77982 .41396 .75 0 Mabsadd L
.77982 .41396 0 -1 Mabsadd L
.77982 .41396 -0.75 0 Mabsadd L closepath F
.78349 .41394 -0.75 0 Mabsadd m
.78349 .41394 0 1 Mabsadd L
.78349 .41394 .75 0 Mabsadd L
.78349 .41394 0 -1 Mabsadd L
.78349 .41394 -0.75 0 Mabsadd L closepath F
.78716 .41384 -0.75 0 Mabsadd m
.78716 .41384 0 1 Mabsadd L
.78716 .41384 .75 0 Mabsadd L
.78716 .41384 0 -1 Mabsadd L
.78716 .41384 -0.75 0 Mabsadd L closepath F
.79083 .41371 -0.75 0 Mabsadd m
.79083 .41371 0 1 Mabsadd L
.79083 .41371 .75 0 Mabsadd L
.79083 .41371 0 -1 Mabsadd L
.79083 .41371 -0.75 0 Mabsadd L closepath F
.7945 .41364 -0.75 0 Mabsadd m
.7945 .41364 0 1 Mabsadd L
.7945 .41364 .75 0 Mabsadd L
.7945 .41364 0 -1 Mabsadd L
.7945 .41364 -0.75 0 Mabsadd L closepath F
.79817 .41354 -0.75 0 Mabsadd m
.79817 .41354 0 1 Mabsadd L
.79817 .41354 .75 0 Mabsadd L
.79817 .41354 0 -1 Mabsadd L
.79817 .41354 -0.75 0 Mabsadd L closepath F
.80183 .41348 -0.75 0 Mabsadd m
.80183 .41348 0 1 Mabsadd L
.80183 .41348 .75 0 Mabsadd L
.80183 .41348 0 -1 Mabsadd L
.80183 .41348 -0.75 0 Mabsadd L closepath F
.8055 .41341 -0.75 0 Mabsadd m
.8055 .41341 0 1 Mabsadd L
.8055 .41341 .75 0 Mabsadd L
.8055 .41341 0 -1 Mabsadd L
.8055 .41341 -0.75 0 Mabsadd L closepath F
.80917 .41332 -0.75 0 Mabsadd m
.80917 .41332 0 1 Mabsadd L
.80917 .41332 .75 0 Mabsadd L
.80917 .41332 0 -1 Mabsadd L
.80917 .41332 -0.75 0 Mabsadd L closepath F
.81284 .41317 -0.75 0 Mabsadd m
.81284 .41317 0 1 Mabsadd L
.81284 .41317 .75 0 Mabsadd L
.81284 .41317 0 -1 Mabsadd L
.81284 .41317 -0.75 0 Mabsadd L closepath F
.81651 .41313 -0.75 0 Mabsadd m
.81651 .41313 0 1 Mabsadd L
.81651 .41313 .75 0 Mabsadd L
.81651 .41313 0 -1 Mabsadd L
.81651 .41313 -0.75 0 Mabsadd L closepath F
.82018 .41308 -0.75 0 Mabsadd m
.82018 .41308 0 1 Mabsadd L
.82018 .41308 .75 0 Mabsadd L
.82018 .41308 0 -1 Mabsadd L
.82018 .41308 -0.75 0 Mabsadd L closepath F
.82385 .41297 -0.75 0 Mabsadd m
.82385 .41297 0 1 Mabsadd L
.82385 .41297 .75 0 Mabsadd L
.82385 .41297 0 -1 Mabsadd L
.82385 .41297 -0.75 0 Mabsadd L closepath F
.82752 .41291 -0.75 0 Mabsadd m
.82752 .41291 0 1 Mabsadd L
.82752 .41291 .75 0 Mabsadd L
.82752 .41291 0 -1 Mabsadd L
.82752 .41291 -0.75 0 Mabsadd L closepath F
.83119 .41291 -0.75 0 Mabsadd m
.83119 .41291 0 1 Mabsadd L
.83119 .41291 .75 0 Mabsadd L
.83119 .41291 0 -1 Mabsadd L
.83119 .41291 -0.75 0 Mabsadd L closepath F
.83486 .41278 -0.75 0 Mabsadd m
.83486 .41278 0 1 Mabsadd L
.83486 .41278 .75 0 Mabsadd L
.83486 .41278 0 -1 Mabsadd L
.83486 .41278 -0.75 0 Mabsadd L closepath F
.83853 .41267 -0.75 0 Mabsadd m
.83853 .41267 0 1 Mabsadd L
.83853 .41267 .75 0 Mabsadd L
.83853 .41267 0 -1 Mabsadd L
.83853 .41267 -0.75 0 Mabsadd L closepath F
.8422 .41257 -0.75 0 Mabsadd m
.8422 .41257 0 1 Mabsadd L
.8422 .41257 .75 0 Mabsadd L
.8422 .41257 0 -1 Mabsadd L
.8422 .41257 -0.75 0 Mabsadd L closepath F
.84587 .41242 -0.75 0 Mabsadd m
.84587 .41242 0 1 Mabsadd L
.84587 .41242 .75 0 Mabsadd L
.84587 .41242 0 -1 Mabsadd L
.84587 .41242 -0.75 0 Mabsadd L closepath F
.84954 .41234 -0.75 0 Mabsadd m
.84954 .41234 0 1 Mabsadd L
.84954 .41234 .75 0 Mabsadd L
.84954 .41234 0 -1 Mabsadd L
.84954 .41234 -0.75 0 Mabsadd L closepath F
.85321 .41225 -0.75 0 Mabsadd m
.85321 .41225 0 1 Mabsadd L
.85321 .41225 .75 0 Mabsadd L
.85321 .41225 0 -1 Mabsadd L
.85321 .41225 -0.75 0 Mabsadd L closepath F
.85688 .41223 -0.75 0 Mabsadd m
.85688 .41223 0 1 Mabsadd L
.85688 .41223 .75 0 Mabsadd L
.85688 .41223 0 -1 Mabsadd L
.85688 .41223 -0.75 0 Mabsadd L closepath F
.86055 .41218 -0.75 0 Mabsadd m
.86055 .41218 0 1 Mabsadd L
.86055 .41218 .75 0 Mabsadd L
.86055 .41218 0 -1 Mabsadd L
.86055 .41218 -0.75 0 Mabsadd L closepath F
.86422 .41215 -0.75 0 Mabsadd m
.86422 .41215 0 1 Mabsadd L
.86422 .41215 .75 0 Mabsadd L
.86422 .41215 0 -1 Mabsadd L
.86422 .41215 -0.75 0 Mabsadd L closepath F
.86789 .41208 -0.75 0 Mabsadd m
.86789 .41208 0 1 Mabsadd L
.86789 .41208 .75 0 Mabsadd L
.86789 .41208 0 -1 Mabsadd L
.86789 .41208 -0.75 0 Mabsadd L closepath F
.87156 .41206 -0.75 0 Mabsadd m
.87156 .41206 0 1 Mabsadd L
.87156 .41206 .75 0 Mabsadd L
.87156 .41206 0 -1 Mabsadd L
.87156 .41206 -0.75 0 Mabsadd L closepath F
.87523 .41196 -0.75 0 Mabsadd m
.87523 .41196 0 1 Mabsadd L
.87523 .41196 .75 0 Mabsadd L
.87523 .41196 0 -1 Mabsadd L
.87523 .41196 -0.75 0 Mabsadd L closepath F
.8789 .41192 -0.75 0 Mabsadd m
.8789 .41192 0 1 Mabsadd L
.8789 .41192 .75 0 Mabsadd L
.8789 .41192 0 -1 Mabsadd L
.8789 .41192 -0.75 0 Mabsadd L closepath F
.88257 .4118 -0.75 0 Mabsadd m
.88257 .4118 0 1 Mabsadd L
.88257 .4118 .75 0 Mabsadd L
.88257 .4118 0 -1 Mabsadd L
.88257 .4118 -0.75 0 Mabsadd L closepath F
.88624 .41176 -0.75 0 Mabsadd m
.88624 .41176 0 1 Mabsadd L
.88624 .41176 .75 0 Mabsadd L
.88624 .41176 0 -1 Mabsadd L
.88624 .41176 -0.75 0 Mabsadd L closepath F
.88991 .41167 -0.75 0 Mabsadd m
.88991 .41167 0 1 Mabsadd L
.88991 .41167 .75 0 Mabsadd L
.88991 .41167 0 -1 Mabsadd L
.88991 .41167 -0.75 0 Mabsadd L closepath F
.89358 .41163 -0.75 0 Mabsadd m
.89358 .41163 0 1 Mabsadd L
.89358 .41163 .75 0 Mabsadd L
.89358 .41163 0 -1 Mabsadd L
.89358 .41163 -0.75 0 Mabsadd L closepath F
.89725 .41146 -0.75 0 Mabsadd m
.89725 .41146 0 1 Mabsadd L
.89725 .41146 .75 0 Mabsadd L
.89725 .41146 0 -1 Mabsadd L
.89725 .41146 -0.75 0 Mabsadd L closepath F
.90092 .41134 -0.75 0 Mabsadd m
.90092 .41134 0 1 Mabsadd L
.90092 .41134 .75 0 Mabsadd L
.90092 .41134 0 -1 Mabsadd L
.90092 .41134 -0.75 0 Mabsadd L closepath F
.90459 .4112 -0.75 0 Mabsadd m
.90459 .4112 0 1 Mabsadd L
.90459 .4112 .75 0 Mabsadd L
.90459 .4112 0 -1 Mabsadd L
.90459 .4112 -0.75 0 Mabsadd L closepath F
.90826 .41102 -0.75 0 Mabsadd m
.90826 .41102 0 1 Mabsadd L
.90826 .41102 .75 0 Mabsadd L
.90826 .41102 0 -1 Mabsadd L
.90826 .41102 -0.75 0 Mabsadd L closepath F
.91193 .41092 -0.75 0 Mabsadd m
.91193 .41092 0 1 Mabsadd L
.91193 .41092 .75 0 Mabsadd L
.91193 .41092 0 -1 Mabsadd L
.91193 .41092 -0.75 0 Mabsadd L closepath F
.9156 .41078 -0.75 0 Mabsadd m
.9156 .41078 0 1 Mabsadd L
.9156 .41078 .75 0 Mabsadd L
.9156 .41078 0 -1 Mabsadd L
.9156 .41078 -0.75 0 Mabsadd L closepath F
.91927 .41073 -0.75 0 Mabsadd m
.91927 .41073 0 1 Mabsadd L
.91927 .41073 .75 0 Mabsadd L
.91927 .41073 0 -1 Mabsadd L
.91927 .41073 -0.75 0 Mabsadd L closepath F
.92294 .41064 -0.75 0 Mabsadd m
.92294 .41064 0 1 Mabsadd L
.92294 .41064 .75 0 Mabsadd L
.92294 .41064 0 -1 Mabsadd L
.92294 .41064 -0.75 0 Mabsadd L closepath F
.92661 .41055 -0.75 0 Mabsadd m
.92661 .41055 0 1 Mabsadd L
.92661 .41055 .75 0 Mabsadd L
.92661 .41055 0 -1 Mabsadd L
.92661 .41055 -0.75 0 Mabsadd L closepath F
.93028 .41056 -0.75 0 Mabsadd m
.93028 .41056 0 1 Mabsadd L
.93028 .41056 .75 0 Mabsadd L
.93028 .41056 0 -1 Mabsadd L
.93028 .41056 -0.75 0 Mabsadd L closepath F
.93394 .41058 -0.75 0 Mabsadd m
.93394 .41058 0 1 Mabsadd L
.93394 .41058 .75 0 Mabsadd L
.93394 .41058 0 -1 Mabsadd L
.93394 .41058 -0.75 0 Mabsadd L closepath F
.93761 .41053 -0.75 0 Mabsadd m
.93761 .41053 0 1 Mabsadd L
.93761 .41053 .75 0 Mabsadd L
.93761 .41053 0 -1 Mabsadd L
.93761 .41053 -0.75 0 Mabsadd L closepath F
.94128 .41044 -0.75 0 Mabsadd m
.94128 .41044 0 1 Mabsadd L
.94128 .41044 .75 0 Mabsadd L
.94128 .41044 0 -1 Mabsadd L
.94128 .41044 -0.75 0 Mabsadd L closepath F
.94495 .41029 -0.75 0 Mabsadd m
.94495 .41029 0 1 Mabsadd L
.94495 .41029 .75 0 Mabsadd L
.94495 .41029 0 -1 Mabsadd L
.94495 .41029 -0.75 0 Mabsadd L closepath F
.94862 .4102 -0.75 0 Mabsadd m
.94862 .4102 0 1 Mabsadd L
.94862 .4102 .75 0 Mabsadd L
.94862 .4102 0 -1 Mabsadd L
.94862 .4102 -0.75 0 Mabsadd L closepath F
.95229 .41008 -0.75 0 Mabsadd m
.95229 .41008 0 1 Mabsadd L
.95229 .41008 .75 0 Mabsadd L
.95229 .41008 0 -1 Mabsadd L
.95229 .41008 -0.75 0 Mabsadd L closepath F
.95596 .40993 -0.75 0 Mabsadd m
.95596 .40993 0 1 Mabsadd L
.95596 .40993 .75 0 Mabsadd L
.95596 .40993 0 -1 Mabsadd L
.95596 .40993 -0.75 0 Mabsadd L closepath F
.95963 .4099 -0.75 0 Mabsadd m
.95963 .4099 0 1 Mabsadd L
.95963 .4099 .75 0 Mabsadd L
.95963 .4099 0 -1 Mabsadd L
.95963 .4099 -0.75 0 Mabsadd L closepath F
.9633 .40975 -0.75 0 Mabsadd m
.9633 .40975 0 1 Mabsadd L
.9633 .40975 .75 0 Mabsadd L
.9633 .40975 0 -1 Mabsadd L
.9633 .40975 -0.75 0 Mabsadd L closepath F
.96697 .40973 -0.75 0 Mabsadd m
.96697 .40973 0 1 Mabsadd L
.96697 .40973 .75 0 Mabsadd L
.96697 .40973 0 -1 Mabsadd L
.96697 .40973 -0.75 0 Mabsadd L closepath F
.97064 .40962 -0.75 0 Mabsadd m
.97064 .40962 0 1 Mabsadd L
.97064 .40962 .75 0 Mabsadd L
.97064 .40962 0 -1 Mabsadd L
.97064 .40962 -0.75 0 Mabsadd L closepath F
.97431 .40959 -0.75 0 Mabsadd m
.97431 .40959 0 1 Mabsadd L
.97431 .40959 .75 0 Mabsadd L
.97431 .40959 0 -1 Mabsadd L
.97431 .40959 -0.75 0 Mabsadd L closepath F
.97798 .40951 -0.75 0 Mabsadd m
.97798 .40951 0 1 Mabsadd L
.97798 .40951 .75 0 Mabsadd L
.97798 .40951 0 -1 Mabsadd L
.97798 .40951 -0.75 0 Mabsadd L closepath F
.98165 .40946 -0.75 0 Mabsadd m
.98165 .40946 0 1 Mabsadd L
.98165 .40946 .75 0 Mabsadd L
.98165 .40946 0 -1 Mabsadd L
.98165 .40946 -0.75 0 Mabsadd L closepath F
.98532 .4094 -0.75 0 Mabsadd m
.98532 .4094 0 1 Mabsadd L
.98532 .4094 .75 0 Mabsadd L
.98532 .4094 0 -1 Mabsadd L
.98532 .4094 -0.75 0 Mabsadd L closepath F
.98899 .4093 -0.75 0 Mabsadd m
.98899 .4093 0 1 Mabsadd L
.98899 .4093 .75 0 Mabsadd L
.98899 .4093 0 -1 Mabsadd L
.98899 .4093 -0.75 0 Mabsadd L closepath F
.99266 .40922 -0.75 0 Mabsadd m
.99266 .40922 0 1 Mabsadd L
.99266 .40922 .75 0 Mabsadd L
.99266 .40922 0 -1 Mabsadd L
.99266 .40922 -0.75 0 Mabsadd L closepath F
.99633 .40918 -0.75 0 Mabsadd m
.99633 .40918 0 1 Mabsadd L
.99633 .40918 .75 0 Mabsadd L
.99633 .40918 0 -1 Mabsadd L
.99633 .40918 -0.75 0 Mabsadd L closepath F
1 .4091 -0.75 0 Mabsadd m
1 .4091 0 1 Mabsadd L
1 .4091 .75 0 Mabsadd L
1 .4091 0 -1 Mabsadd L
1 .4091 -0.75 0 Mabsadd L closepath F
0 0 0 r
.08257 .55943 -0.75 0 Mabsadd m
.08257 .55943 0 1 Mabsadd L
.08257 .55943 .75 0 Mabsadd L
.08257 .55943 0 -1 Mabsadd L
.08257 .55943 -0.75 0 Mabsadd L closepath F
.08624 .54084 -0.75 0 Mabsadd m
.08624 .54084 0 1 Mabsadd L
.08624 .54084 .75 0 Mabsadd L
.08624 .54084 0 -1 Mabsadd L
.08624 .54084 -0.75 0 Mabsadd L closepath F
.08991 .52363 -0.75 0 Mabsadd m
.08991 .52363 0 1 Mabsadd L
.08991 .52363 .75 0 Mabsadd L
.08991 .52363 0 -1 Mabsadd L
.08991 .52363 -0.75 0 Mabsadd L closepath F
.09358 .51029 -0.75 0 Mabsadd m
.09358 .51029 0 1 Mabsadd L
.09358 .51029 .75 0 Mabsadd L
.09358 .51029 0 -1 Mabsadd L
.09358 .51029 -0.75 0 Mabsadd L closepath F
.09725 .49877 -0.75 0 Mabsadd m
.09725 .49877 0 1 Mabsadd L
.09725 .49877 .75 0 Mabsadd L
.09725 .49877 0 -1 Mabsadd L
.09725 .49877 -0.75 0 Mabsadd L closepath F
.10092 .48897 -0.75 0 Mabsadd m
.10092 .48897 0 1 Mabsadd L
.10092 .48897 .75 0 Mabsadd L
.10092 .48897 0 -1 Mabsadd L
.10092 .48897 -0.75 0 Mabsadd L closepath F
.10459 .48095 -0.75 0 Mabsadd m
.10459 .48095 0 1 Mabsadd L
.10459 .48095 .75 0 Mabsadd L
.10459 .48095 0 -1 Mabsadd L
.10459 .48095 -0.75 0 Mabsadd L closepath F
.10826 .47422 -0.75 0 Mabsadd m
.10826 .47422 0 1 Mabsadd L
.10826 .47422 .75 0 Mabsadd L
.10826 .47422 0 -1 Mabsadd L
.10826 .47422 -0.75 0 Mabsadd L closepath F
.11193 .46788 -0.75 0 Mabsadd m
.11193 .46788 0 1 Mabsadd L
.11193 .46788 .75 0 Mabsadd L
.11193 .46788 0 -1 Mabsadd L
.11193 .46788 -0.75 0 Mabsadd L closepath F
.1156 .46245 -0.75 0 Mabsadd m
.1156 .46245 0 1 Mabsadd L
.1156 .46245 .75 0 Mabsadd L
.1156 .46245 0 -1 Mabsadd L
.1156 .46245 -0.75 0 Mabsadd L closepath F
.11927 .45822 -0.75 0 Mabsadd m
.11927 .45822 0 1 Mabsadd L
.11927 .45822 .75 0 Mabsadd L
.11927 .45822 0 -1 Mabsadd L
.11927 .45822 -0.75 0 Mabsadd L closepath F
.12294 .45436 -0.75 0 Mabsadd m
.12294 .45436 0 1 Mabsadd L
.12294 .45436 .75 0 Mabsadd L
.12294 .45436 0 -1 Mabsadd L
.12294 .45436 -0.75 0 Mabsadd L closepath F
.12661 .45133 -0.75 0 Mabsadd m
.12661 .45133 0 1 Mabsadd L
.12661 .45133 .75 0 Mabsadd L
.12661 .45133 0 -1 Mabsadd L
.12661 .45133 -0.75 0 Mabsadd L closepath F
.13028 .44853 -0.75 0 Mabsadd m
.13028 .44853 0 1 Mabsadd L
.13028 .44853 .75 0 Mabsadd L
.13028 .44853 0 -1 Mabsadd L
.13028 .44853 -0.75 0 Mabsadd L closepath F
.13394 .44626 -0.75 0 Mabsadd m
.13394 .44626 0 1 Mabsadd L
.13394 .44626 .75 0 Mabsadd L
.13394 .44626 0 -1 Mabsadd L
.13394 .44626 -0.75 0 Mabsadd L closepath F
.13761 .44439 -0.75 0 Mabsadd m
.13761 .44439 0 1 Mabsadd L
.13761 .44439 .75 0 Mabsadd L
.13761 .44439 0 -1 Mabsadd L
.13761 .44439 -0.75 0 Mabsadd L closepath F
.14128 .44258 -0.75 0 Mabsadd m
.14128 .44258 0 1 Mabsadd L
.14128 .44258 .75 0 Mabsadd L
.14128 .44258 0 -1 Mabsadd L
.14128 .44258 -0.75 0 Mabsadd L closepath F
.14495 .44122 -0.75 0 Mabsadd m
.14495 .44122 0 1 Mabsadd L
.14495 .44122 .75 0 Mabsadd L
.14495 .44122 0 -1 Mabsadd L
.14495 .44122 -0.75 0 Mabsadd L closepath F
.14862 .43986 -0.75 0 Mabsadd m
.14862 .43986 0 1 Mabsadd L
.14862 .43986 .75 0 Mabsadd L
.14862 .43986 0 -1 Mabsadd L
.14862 .43986 -0.75 0 Mabsadd L closepath F
.15229 .43868 -0.75 0 Mabsadd m
.15229 .43868 0 1 Mabsadd L
.15229 .43868 .75 0 Mabsadd L
.15229 .43868 0 -1 Mabsadd L
.15229 .43868 -0.75 0 Mabsadd L closepath F
.15596 .43777 -0.75 0 Mabsadd m
.15596 .43777 0 1 Mabsadd L
.15596 .43777 .75 0 Mabsadd L
.15596 .43777 0 -1 Mabsadd L
.15596 .43777 -0.75 0 Mabsadd L closepath F
.15963 .43694 -0.75 0 Mabsadd m
.15963 .43694 0 1 Mabsadd L
.15963 .43694 .75 0 Mabsadd L
.15963 .43694 0 -1 Mabsadd L
.15963 .43694 -0.75 0 Mabsadd L closepath F
.1633 .4362 -0.75 0 Mabsadd m
.1633 .4362 0 1 Mabsadd L
.1633 .4362 .75 0 Mabsadd L
.1633 .4362 0 -1 Mabsadd L
.1633 .4362 -0.75 0 Mabsadd L closepath F
.16697 .43555 -0.75 0 Mabsadd m
.16697 .43555 0 1 Mabsadd L
.16697 .43555 .75 0 Mabsadd L
.16697 .43555 0 -1 Mabsadd L
.16697 .43555 -0.75 0 Mabsadd L closepath F
.17064 .43505 -0.75 0 Mabsadd m
.17064 .43505 0 1 Mabsadd L
.17064 .43505 .75 0 Mabsadd L
.17064 .43505 0 -1 Mabsadd L
.17064 .43505 -0.75 0 Mabsadd L closepath F
.17431 .43457 -0.75 0 Mabsadd m
.17431 .43457 0 1 Mabsadd L
.17431 .43457 .75 0 Mabsadd L
.17431 .43457 0 -1 Mabsadd L
.17431 .43457 -0.75 0 Mabsadd L closepath F
.17798 .43416 -0.75 0 Mabsadd m
.17798 .43416 0 1 Mabsadd L
.17798 .43416 .75 0 Mabsadd L
.17798 .43416 0 -1 Mabsadd L
.17798 .43416 -0.75 0 Mabsadd L closepath F
.18165 .43383 -0.75 0 Mabsadd m
.18165 .43383 0 1 Mabsadd L
.18165 .43383 .75 0 Mabsadd L
.18165 .43383 0 -1 Mabsadd L
.18165 .43383 -0.75 0 Mabsadd L closepath F
.18532 .43353 -0.75 0 Mabsadd m
.18532 .43353 0 1 Mabsadd L
.18532 .43353 .75 0 Mabsadd L
.18532 .43353 0 -1 Mabsadd L
.18532 .43353 -0.75 0 Mabsadd L closepath F
.18899 .43329 -0.75 0 Mabsadd m
.18899 .43329 0 1 Mabsadd L
.18899 .43329 .75 0 Mabsadd L
.18899 .43329 0 -1 Mabsadd L
.18899 .43329 -0.75 0 Mabsadd L closepath F
.19266 .43308 -0.75 0 Mabsadd m
.19266 .43308 0 1 Mabsadd L
.19266 .43308 .75 0 Mabsadd L
.19266 .43308 0 -1 Mabsadd L
.19266 .43308 -0.75 0 Mabsadd L closepath F
.19633 .4329 -0.75 0 Mabsadd m
.19633 .4329 0 1 Mabsadd L
.19633 .4329 .75 0 Mabsadd L
.19633 .4329 0 -1 Mabsadd L
.19633 .4329 -0.75 0 Mabsadd L closepath F
.2 .43274 -0.75 0 Mabsadd m
.2 .43274 0 1 Mabsadd L
.2 .43274 .75 0 Mabsadd L
.2 .43274 0 -1 Mabsadd L
.2 .43274 -0.75 0 Mabsadd L closepath F
.20367 .43261 -0.75 0 Mabsadd m
.20367 .43261 0 1 Mabsadd L
.20367 .43261 .75 0 Mabsadd L
.20367 .43261 0 -1 Mabsadd L
.20367 .43261 -0.75 0 Mabsadd L closepath F
.20734 .43249 -0.75 0 Mabsadd m
.20734 .43249 0 1 Mabsadd L
.20734 .43249 .75 0 Mabsadd L
.20734 .43249 0 -1 Mabsadd L
.20734 .43249 -0.75 0 Mabsadd L closepath F
.21101 .43239 -0.75 0 Mabsadd m
.21101 .43239 0 1 Mabsadd L
.21101 .43239 .75 0 Mabsadd L
.21101 .43239 0 -1 Mabsadd L
.21101 .43239 -0.75 0 Mabsadd L closepath F
.21468 .43231 -0.75 0 Mabsadd m
.21468 .43231 0 1 Mabsadd L
.21468 .43231 .75 0 Mabsadd L
.21468 .43231 0 -1 Mabsadd L
.21468 .43231 -0.75 0 Mabsadd L closepath F
.21835 .43223 -0.75 0 Mabsadd m
.21835 .43223 0 1 Mabsadd L
.21835 .43223 .75 0 Mabsadd L
.21835 .43223 0 -1 Mabsadd L
.21835 .43223 -0.75 0 Mabsadd L closepath F
.22202 .43217 -0.75 0 Mabsadd m
.22202 .43217 0 1 Mabsadd L
.22202 .43217 .75 0 Mabsadd L
.22202 .43217 0 -1 Mabsadd L
.22202 .43217 -0.75 0 Mabsadd L closepath F
.22569 .43211 -0.75 0 Mabsadd m
.22569 .43211 0 1 Mabsadd L
.22569 .43211 .75 0 Mabsadd L
.22569 .43211 0 -1 Mabsadd L
.22569 .43211 -0.75 0 Mabsadd L closepath F
.22936 .43207 -0.75 0 Mabsadd m
.22936 .43207 0 1 Mabsadd L
.22936 .43207 .75 0 Mabsadd L
.22936 .43207 0 -1 Mabsadd L
.22936 .43207 -0.75 0 Mabsadd L closepath F
.23303 .43203 -0.75 0 Mabsadd m
.23303 .43203 0 1 Mabsadd L
.23303 .43203 .75 0 Mabsadd L
.23303 .43203 0 -1 Mabsadd L
.23303 .43203 -0.75 0 Mabsadd L closepath F
.2367 .43199 -0.75 0 Mabsadd m
.2367 .43199 0 1 Mabsadd L
.2367 .43199 .75 0 Mabsadd L
.2367 .43199 0 -1 Mabsadd L
.2367 .43199 -0.75 0 Mabsadd L closepath F
.24037 .43196 -0.75 0 Mabsadd m
.24037 .43196 0 1 Mabsadd L
.24037 .43196 .75 0 Mabsadd L
.24037 .43196 0 -1 Mabsadd L
.24037 .43196 -0.75 0 Mabsadd L closepath F
.24404 .43193 -0.75 0 Mabsadd m
.24404 .43193 0 1 Mabsadd L
.24404 .43193 .75 0 Mabsadd L
.24404 .43193 0 -1 Mabsadd L
.24404 .43193 -0.75 0 Mabsadd L closepath F
.24771 .43191 -0.75 0 Mabsadd m
.24771 .43191 0 1 Mabsadd L
.24771 .43191 .75 0 Mabsadd L
.24771 .43191 0 -1 Mabsadd L
.24771 .43191 -0.75 0 Mabsadd L closepath F
.25138 .43189 -0.75 0 Mabsadd m
.25138 .43189 0 1 Mabsadd L
.25138 .43189 .75 0 Mabsadd L
.25138 .43189 0 -1 Mabsadd L
.25138 .43189 -0.75 0 Mabsadd L closepath F
.25505 .43188 -0.75 0 Mabsadd m
.25505 .43188 0 1 Mabsadd L
.25505 .43188 .75 0 Mabsadd L
.25505 .43188 0 -1 Mabsadd L
.25505 .43188 -0.75 0 Mabsadd L closepath F
.25872 .43186 -0.75 0 Mabsadd m
.25872 .43186 0 1 Mabsadd L
.25872 .43186 .75 0 Mabsadd L
.25872 .43186 0 -1 Mabsadd L
.25872 .43186 -0.75 0 Mabsadd L closepath F
.26239 .43185 -0.75 0 Mabsadd m
.26239 .43185 0 1 Mabsadd L
.26239 .43185 .75 0 Mabsadd L
.26239 .43185 0 -1 Mabsadd L
.26239 .43185 -0.75 0 Mabsadd L closepath F
.26606 .43184 -0.75 0 Mabsadd m
.26606 .43184 0 1 Mabsadd L
.26606 .43184 .75 0 Mabsadd L
.26606 .43184 0 -1 Mabsadd L
.26606 .43184 -0.75 0 Mabsadd L closepath F
.26972 .43183 -0.75 0 Mabsadd m
.26972 .43183 0 1 Mabsadd L
.26972 .43183 .75 0 Mabsadd L
.26972 .43183 0 -1 Mabsadd L
.26972 .43183 -0.75 0 Mabsadd L closepath F
.27339 .43182 -0.75 0 Mabsadd m
.27339 .43182 0 1 Mabsadd L
.27339 .43182 .75 0 Mabsadd L
.27339 .43182 0 -1 Mabsadd L
.27339 .43182 -0.75 0 Mabsadd L closepath F
.27706 .43181 -0.75 0 Mabsadd m
.27706 .43181 0 1 Mabsadd L
.27706 .43181 .75 0 Mabsadd L
.27706 .43181 0 -1 Mabsadd L
.27706 .43181 -0.75 0 Mabsadd L closepath F
.28073 .43181 -0.75 0 Mabsadd m
.28073 .43181 0 1 Mabsadd L
.28073 .43181 .75 0 Mabsadd L
.28073 .43181 0 -1 Mabsadd L
.28073 .43181 -0.75 0 Mabsadd L closepath F
.2844 .4318 -0.75 0 Mabsadd m
.2844 .4318 0 1 Mabsadd L
.2844 .4318 .75 0 Mabsadd L
.2844 .4318 0 -1 Mabsadd L
.2844 .4318 -0.75 0 Mabsadd L closepath F
.28807 .4318 -0.75 0 Mabsadd m
.28807 .4318 0 1 Mabsadd L
.28807 .4318 .75 0 Mabsadd L
.28807 .4318 0 -1 Mabsadd L
.28807 .4318 -0.75 0 Mabsadd L closepath F
.29174 .4318 -0.75 0 Mabsadd m
.29174 .4318 0 1 Mabsadd L
.29174 .4318 .75 0 Mabsadd L
.29174 .4318 0 -1 Mabsadd L
.29174 .4318 -0.75 0 Mabsadd L closepath F
.29541 .43179 -0.75 0 Mabsadd m
.29541 .43179 0 1 Mabsadd L
.29541 .43179 .75 0 Mabsadd L
.29541 .43179 0 -1 Mabsadd L
.29541 .43179 -0.75 0 Mabsadd L closepath F
.29908 .43179 -0.75 0 Mabsadd m
.29908 .43179 0 1 Mabsadd L
.29908 .43179 .75 0 Mabsadd L
.29908 .43179 0 -1 Mabsadd L
.29908 .43179 -0.75 0 Mabsadd L closepath F
.30275 .43179 -0.75 0 Mabsadd m
.30275 .43179 0 1 Mabsadd L
.30275 .43179 .75 0 Mabsadd L
.30275 .43179 0 -1 Mabsadd L
.30275 .43179 -0.75 0 Mabsadd L closepath F
.30642 .43178 -0.75 0 Mabsadd m
.30642 .43178 0 1 Mabsadd L
.30642 .43178 .75 0 Mabsadd L
.30642 .43178 0 -1 Mabsadd L
.30642 .43178 -0.75 0 Mabsadd L closepath F
.31009 .43178 -0.75 0 Mabsadd m
.31009 .43178 0 1 Mabsadd L
.31009 .43178 .75 0 Mabsadd L
.31009 .43178 0 -1 Mabsadd L
.31009 .43178 -0.75 0 Mabsadd L closepath F
.31376 .43178 -0.75 0 Mabsadd m
.31376 .43178 0 1 Mabsadd L
.31376 .43178 .75 0 Mabsadd L
.31376 .43178 0 -1 Mabsadd L
.31376 .43178 -0.75 0 Mabsadd L closepath F
.31743 .43178 -0.75 0 Mabsadd m
.31743 .43178 0 1 Mabsadd L
.31743 .43178 .75 0 Mabsadd L
.31743 .43178 0 -1 Mabsadd L
.31743 .43178 -0.75 0 Mabsadd L closepath F
.3211 .43178 -0.75 0 Mabsadd m
.3211 .43178 0 1 Mabsadd L
.3211 .43178 .75 0 Mabsadd L
.3211 .43178 0 -1 Mabsadd L
.3211 .43178 -0.75 0 Mabsadd L closepath F
.32477 .43178 -0.75 0 Mabsadd m
.32477 .43178 0 1 Mabsadd L
.32477 .43178 .75 0 Mabsadd L
.32477 .43178 0 -1 Mabsadd L
.32477 .43178 -0.75 0 Mabsadd L closepath F
.32844 .43178 -0.75 0 Mabsadd m
.32844 .43178 0 1 Mabsadd L
.32844 .43178 .75 0 Mabsadd L
.32844 .43178 0 -1 Mabsadd L
.32844 .43178 -0.75 0 Mabsadd L closepath F
.33211 .43178 -0.75 0 Mabsadd m
.33211 .43178 0 1 Mabsadd L
.33211 .43178 .75 0 Mabsadd L
.33211 .43178 0 -1 Mabsadd L
.33211 .43178 -0.75 0 Mabsadd L closepath F
.33578 .43178 -0.75 0 Mabsadd m
.33578 .43178 0 1 Mabsadd L
.33578 .43178 .75 0 Mabsadd L
.33578 .43178 0 -1 Mabsadd L
.33578 .43178 -0.75 0 Mabsadd L closepath F
.33945 .43177 -0.75 0 Mabsadd m
.33945 .43177 0 1 Mabsadd L
.33945 .43177 .75 0 Mabsadd L
.33945 .43177 0 -1 Mabsadd L
.33945 .43177 -0.75 0 Mabsadd L closepath F
.34312 .43177 -0.75 0 Mabsadd m
.34312 .43177 0 1 Mabsadd L
.34312 .43177 .75 0 Mabsadd L
.34312 .43177 0 -1 Mabsadd L
.34312 .43177 -0.75 0 Mabsadd L closepath F
.34679 .43177 -0.75 0 Mabsadd m
.34679 .43177 0 1 Mabsadd L
.34679 .43177 .75 0 Mabsadd L
.34679 .43177 0 -1 Mabsadd L
.34679 .43177 -0.75 0 Mabsadd L closepath F
.35046 .43177 -0.75 0 Mabsadd m
.35046 .43177 0 1 Mabsadd L
.35046 .43177 .75 0 Mabsadd L
.35046 .43177 0 -1 Mabsadd L
.35046 .43177 -0.75 0 Mabsadd L closepath F
.35413 .43177 -0.75 0 Mabsadd m
.35413 .43177 0 1 Mabsadd L
.35413 .43177 .75 0 Mabsadd L
.35413 .43177 0 -1 Mabsadd L
.35413 .43177 -0.75 0 Mabsadd L closepath F
.3578 .43177 -0.75 0 Mabsadd m
.3578 .43177 0 1 Mabsadd L
.3578 .43177 .75 0 Mabsadd L
.3578 .43177 0 -1 Mabsadd L
.3578 .43177 -0.75 0 Mabsadd L closepath F
.36147 .43177 -0.75 0 Mabsadd m
.36147 .43177 0 1 Mabsadd L
.36147 .43177 .75 0 Mabsadd L
.36147 .43177 0 -1 Mabsadd L
.36147 .43177 -0.75 0 Mabsadd L closepath F
.36514 .43177 -0.75 0 Mabsadd m
.36514 .43177 0 1 Mabsadd L
.36514 .43177 .75 0 Mabsadd L
.36514 .43177 0 -1 Mabsadd L
.36514 .43177 -0.75 0 Mabsadd L closepath F
.36881 .43177 -0.75 0 Mabsadd m
.36881 .43177 0 1 Mabsadd L
.36881 .43177 .75 0 Mabsadd L
.36881 .43177 0 -1 Mabsadd L
.36881 .43177 -0.75 0 Mabsadd L closepath F
.37248 .43177 -0.75 0 Mabsadd m
.37248 .43177 0 1 Mabsadd L
.37248 .43177 .75 0 Mabsadd L
.37248 .43177 0 -1 Mabsadd L
.37248 .43177 -0.75 0 Mabsadd L closepath F
.37615 .43177 -0.75 0 Mabsadd m
.37615 .43177 0 1 Mabsadd L
.37615 .43177 .75 0 Mabsadd L
.37615 .43177 0 -1 Mabsadd L
.37615 .43177 -0.75 0 Mabsadd L closepath F
.37982 .43177 -0.75 0 Mabsadd m
.37982 .43177 0 1 Mabsadd L
.37982 .43177 .75 0 Mabsadd L
.37982 .43177 0 -1 Mabsadd L
.37982 .43177 -0.75 0 Mabsadd L closepath F
.38349 .43177 -0.75 0 Mabsadd m
.38349 .43177 0 1 Mabsadd L
.38349 .43177 .75 0 Mabsadd L
.38349 .43177 0 -1 Mabsadd L
.38349 .43177 -0.75 0 Mabsadd L closepath F
.38716 .43177 -0.75 0 Mabsadd m
.38716 .43177 0 1 Mabsadd L
.38716 .43177 .75 0 Mabsadd L
.38716 .43177 0 -1 Mabsadd L
.38716 .43177 -0.75 0 Mabsadd L closepath F
.39083 .43177 -0.75 0 Mabsadd m
.39083 .43177 0 1 Mabsadd L
.39083 .43177 .75 0 Mabsadd L
.39083 .43177 0 -1 Mabsadd L
.39083 .43177 -0.75 0 Mabsadd L closepath F
.3945 .43177 -0.75 0 Mabsadd m
.3945 .43177 0 1 Mabsadd L
.3945 .43177 .75 0 Mabsadd L
.3945 .43177 0 -1 Mabsadd L
.3945 .43177 -0.75 0 Mabsadd L closepath F
.39817 .43177 -0.75 0 Mabsadd m
.39817 .43177 0 1 Mabsadd L
.39817 .43177 .75 0 Mabsadd L
.39817 .43177 0 -1 Mabsadd L
.39817 .43177 -0.75 0 Mabsadd L closepath F
.40183 .43177 -0.75 0 Mabsadd m
.40183 .43177 0 1 Mabsadd L
.40183 .43177 .75 0 Mabsadd L
.40183 .43177 0 -1 Mabsadd L
.40183 .43177 -0.75 0 Mabsadd L closepath F
.4055 .43177 -0.75 0 Mabsadd m
.4055 .43177 0 1 Mabsadd L
.4055 .43177 .75 0 Mabsadd L
.4055 .43177 0 -1 Mabsadd L
.4055 .43177 -0.75 0 Mabsadd L closepath F
.40917 .43177 -0.75 0 Mabsadd m
.40917 .43177 0 1 Mabsadd L
.40917 .43177 .75 0 Mabsadd L
.40917 .43177 0 -1 Mabsadd L
.40917 .43177 -0.75 0 Mabsadd L closepath F
.41284 .43177 -0.75 0 Mabsadd m
.41284 .43177 0 1 Mabsadd L
.41284 .43177 .75 0 Mabsadd L
.41284 .43177 0 -1 Mabsadd L
.41284 .43177 -0.75 0 Mabsadd L closepath F
.41651 .43177 -0.75 0 Mabsadd m
.41651 .43177 0 1 Mabsadd L
.41651 .43177 .75 0 Mabsadd L
.41651 .43177 0 -1 Mabsadd L
.41651 .43177 -0.75 0 Mabsadd L closepath F
.42018 .43177 -0.75 0 Mabsadd m
.42018 .43177 0 1 Mabsadd L
.42018 .43177 .75 0 Mabsadd L
.42018 .43177 0 -1 Mabsadd L
.42018 .43177 -0.75 0 Mabsadd L closepath F
.42385 .43177 -0.75 0 Mabsadd m
.42385 .43177 0 1 Mabsadd L
.42385 .43177 .75 0 Mabsadd L
.42385 .43177 0 -1 Mabsadd L
.42385 .43177 -0.75 0 Mabsadd L closepath F
.42752 .43177 -0.75 0 Mabsadd m
.42752 .43177 0 1 Mabsadd L
.42752 .43177 .75 0 Mabsadd L
.42752 .43177 0 -1 Mabsadd L
.42752 .43177 -0.75 0 Mabsadd L closepath F
.43119 .43177 -0.75 0 Mabsadd m
.43119 .43177 0 1 Mabsadd L
.43119 .43177 .75 0 Mabsadd L
.43119 .43177 0 -1 Mabsadd L
.43119 .43177 -0.75 0 Mabsadd L closepath F
.43486 .43177 -0.75 0 Mabsadd m
.43486 .43177 0 1 Mabsadd L
.43486 .43177 .75 0 Mabsadd L
.43486 .43177 0 -1 Mabsadd L
.43486 .43177 -0.75 0 Mabsadd L closepath F
.43853 .43177 -0.75 0 Mabsadd m
.43853 .43177 0 1 Mabsadd L
.43853 .43177 .75 0 Mabsadd L
.43853 .43177 0 -1 Mabsadd L
.43853 .43177 -0.75 0 Mabsadd L closepath F
.4422 .43177 -0.75 0 Mabsadd m
.4422 .43177 0 1 Mabsadd L
.4422 .43177 .75 0 Mabsadd L
.4422 .43177 0 -1 Mabsadd L
.4422 .43177 -0.75 0 Mabsadd L closepath F
.44587 .43177 -0.75 0 Mabsadd m
.44587 .43177 0 1 Mabsadd L
.44587 .43177 .75 0 Mabsadd L
.44587 .43177 0 -1 Mabsadd L
.44587 .43177 -0.75 0 Mabsadd L closepath F
.44954 .43177 -0.75 0 Mabsadd m
.44954 .43177 0 1 Mabsadd L
.44954 .43177 .75 0 Mabsadd L
.44954 .43177 0 -1 Mabsadd L
.44954 .43177 -0.75 0 Mabsadd L closepath F
.45321 .43177 -0.75 0 Mabsadd m
.45321 .43177 0 1 Mabsadd L
.45321 .43177 .75 0 Mabsadd L
.45321 .43177 0 -1 Mabsadd L
.45321 .43177 -0.75 0 Mabsadd L closepath F
.45688 .43177 -0.75 0 Mabsadd m
.45688 .43177 0 1 Mabsadd L
.45688 .43177 .75 0 Mabsadd L
.45688 .43177 0 -1 Mabsadd L
.45688 .43177 -0.75 0 Mabsadd L closepath F
.46055 .43177 -0.75 0 Mabsadd m
.46055 .43177 0 1 Mabsadd L
.46055 .43177 .75 0 Mabsadd L
.46055 .43177 0 -1 Mabsadd L
.46055 .43177 -0.75 0 Mabsadd L closepath F
.46422 .43177 -0.75 0 Mabsadd m
.46422 .43177 0 1 Mabsadd L
.46422 .43177 .75 0 Mabsadd L
.46422 .43177 0 -1 Mabsadd L
.46422 .43177 -0.75 0 Mabsadd L closepath F
.46789 .43177 -0.75 0 Mabsadd m
.46789 .43177 0 1 Mabsadd L
.46789 .43177 .75 0 Mabsadd L
.46789 .43177 0 -1 Mabsadd L
.46789 .43177 -0.75 0 Mabsadd L closepath F
.47156 .43177 -0.75 0 Mabsadd m
.47156 .43177 0 1 Mabsadd L
.47156 .43177 .75 0 Mabsadd L
.47156 .43177 0 -1 Mabsadd L
.47156 .43177 -0.75 0 Mabsadd L closepath F
.47523 .43177 -0.75 0 Mabsadd m
.47523 .43177 0 1 Mabsadd L
.47523 .43177 .75 0 Mabsadd L
.47523 .43177 0 -1 Mabsadd L
.47523 .43177 -0.75 0 Mabsadd L closepath F
.4789 .43177 -0.75 0 Mabsadd m
.4789 .43177 0 1 Mabsadd L
.4789 .43177 .75 0 Mabsadd L
.4789 .43177 0 -1 Mabsadd L
.4789 .43177 -0.75 0 Mabsadd L closepath F
.48257 .43177 -0.75 0 Mabsadd m
.48257 .43177 0 1 Mabsadd L
.48257 .43177 .75 0 Mabsadd L
.48257 .43177 0 -1 Mabsadd L
.48257 .43177 -0.75 0 Mabsadd L closepath F
.48624 .43177 -0.75 0 Mabsadd m
.48624 .43177 0 1 Mabsadd L
.48624 .43177 .75 0 Mabsadd L
.48624 .43177 0 -1 Mabsadd L
.48624 .43177 -0.75 0 Mabsadd L closepath F
.48991 .43177 -0.75 0 Mabsadd m
.48991 .43177 0 1 Mabsadd L
.48991 .43177 .75 0 Mabsadd L
.48991 .43177 0 -1 Mabsadd L
.48991 .43177 -0.75 0 Mabsadd L closepath F
.49358 .43177 -0.75 0 Mabsadd m
.49358 .43177 0 1 Mabsadd L
.49358 .43177 .75 0 Mabsadd L
.49358 .43177 0 -1 Mabsadd L
.49358 .43177 -0.75 0 Mabsadd L closepath F
.49725 .43177 -0.75 0 Mabsadd m
.49725 .43177 0 1 Mabsadd L
.49725 .43177 .75 0 Mabsadd L
.49725 .43177 0 -1 Mabsadd L
.49725 .43177 -0.75 0 Mabsadd L closepath F
.50092 .43177 -0.75 0 Mabsadd m
.50092 .43177 0 1 Mabsadd L
.50092 .43177 .75 0 Mabsadd L
.50092 .43177 0 -1 Mabsadd L
.50092 .43177 -0.75 0 Mabsadd L closepath F
.50459 .43177 -0.75 0 Mabsadd m
.50459 .43177 0 1 Mabsadd L
.50459 .43177 .75 0 Mabsadd L
.50459 .43177 0 -1 Mabsadd L
.50459 .43177 -0.75 0 Mabsadd L closepath F
.50826 .43177 -0.75 0 Mabsadd m
.50826 .43177 0 1 Mabsadd L
.50826 .43177 .75 0 Mabsadd L
.50826 .43177 0 -1 Mabsadd L
.50826 .43177 -0.75 0 Mabsadd L closepath F
.51193 .43177 -0.75 0 Mabsadd m
.51193 .43177 0 1 Mabsadd L
.51193 .43177 .75 0 Mabsadd L
.51193 .43177 0 -1 Mabsadd L
.51193 .43177 -0.75 0 Mabsadd L closepath F
.5156 .43177 -0.75 0 Mabsadd m
.5156 .43177 0 1 Mabsadd L
.5156 .43177 .75 0 Mabsadd L
.5156 .43177 0 -1 Mabsadd L
.5156 .43177 -0.75 0 Mabsadd L closepath F
.51927 .43177 -0.75 0 Mabsadd m
.51927 .43177 0 1 Mabsadd L
.51927 .43177 .75 0 Mabsadd L
.51927 .43177 0 -1 Mabsadd L
.51927 .43177 -0.75 0 Mabsadd L closepath F
.52294 .43177 -0.75 0 Mabsadd m
.52294 .43177 0 1 Mabsadd L
.52294 .43177 .75 0 Mabsadd L
.52294 .43177 0 -1 Mabsadd L
.52294 .43177 -0.75 0 Mabsadd L closepath F
.52661 .43177 -0.75 0 Mabsadd m
.52661 .43177 0 1 Mabsadd L
.52661 .43177 .75 0 Mabsadd L
.52661 .43177 0 -1 Mabsadd L
.52661 .43177 -0.75 0 Mabsadd L closepath F
.53028 .43177 -0.75 0 Mabsadd m
.53028 .43177 0 1 Mabsadd L
.53028 .43177 .75 0 Mabsadd L
.53028 .43177 0 -1 Mabsadd L
.53028 .43177 -0.75 0 Mabsadd L closepath F
.53394 .43177 -0.75 0 Mabsadd m
.53394 .43177 0 1 Mabsadd L
.53394 .43177 .75 0 Mabsadd L
.53394 .43177 0 -1 Mabsadd L
.53394 .43177 -0.75 0 Mabsadd L closepath F
.53761 .43177 -0.75 0 Mabsadd m
.53761 .43177 0 1 Mabsadd L
.53761 .43177 .75 0 Mabsadd L
.53761 .43177 0 -1 Mabsadd L
.53761 .43177 -0.75 0 Mabsadd L closepath F
.54128 .43177 -0.75 0 Mabsadd m
.54128 .43177 0 1 Mabsadd L
.54128 .43177 .75 0 Mabsadd L
.54128 .43177 0 -1 Mabsadd L
.54128 .43177 -0.75 0 Mabsadd L closepath F
.54495 .43177 -0.75 0 Mabsadd m
.54495 .43177 0 1 Mabsadd L
.54495 .43177 .75 0 Mabsadd L
.54495 .43177 0 -1 Mabsadd L
.54495 .43177 -0.75 0 Mabsadd L closepath F
.54862 .43177 -0.75 0 Mabsadd m
.54862 .43177 0 1 Mabsadd L
.54862 .43177 .75 0 Mabsadd L
.54862 .43177 0 -1 Mabsadd L
.54862 .43177 -0.75 0 Mabsadd L closepath F
.55229 .43177 -0.75 0 Mabsadd m
.55229 .43177 0 1 Mabsadd L
.55229 .43177 .75 0 Mabsadd L
.55229 .43177 0 -1 Mabsadd L
.55229 .43177 -0.75 0 Mabsadd L closepath F
.55596 .43177 -0.75 0 Mabsadd m
.55596 .43177 0 1 Mabsadd L
.55596 .43177 .75 0 Mabsadd L
.55596 .43177 0 -1 Mabsadd L
.55596 .43177 -0.75 0 Mabsadd L closepath F
.55963 .43177 -0.75 0 Mabsadd m
.55963 .43177 0 1 Mabsadd L
.55963 .43177 .75 0 Mabsadd L
.55963 .43177 0 -1 Mabsadd L
.55963 .43177 -0.75 0 Mabsadd L closepath F
.5633 .43177 -0.75 0 Mabsadd m
.5633 .43177 0 1 Mabsadd L
.5633 .43177 .75 0 Mabsadd L
.5633 .43177 0 -1 Mabsadd L
.5633 .43177 -0.75 0 Mabsadd L closepath F
.56697 .43177 -0.75 0 Mabsadd m
.56697 .43177 0 1 Mabsadd L
.56697 .43177 .75 0 Mabsadd L
.56697 .43177 0 -1 Mabsadd L
.56697 .43177 -0.75 0 Mabsadd L closepath F
.57064 .43177 -0.75 0 Mabsadd m
.57064 .43177 0 1 Mabsadd L
.57064 .43177 .75 0 Mabsadd L
.57064 .43177 0 -1 Mabsadd L
.57064 .43177 -0.75 0 Mabsadd L closepath F
.57431 .43177 -0.75 0 Mabsadd m
.57431 .43177 0 1 Mabsadd L
.57431 .43177 .75 0 Mabsadd L
.57431 .43177 0 -1 Mabsadd L
.57431 .43177 -0.75 0 Mabsadd L closepath F
.57798 .43177 -0.75 0 Mabsadd m
.57798 .43177 0 1 Mabsadd L
.57798 .43177 .75 0 Mabsadd L
.57798 .43177 0 -1 Mabsadd L
.57798 .43177 -0.75 0 Mabsadd L closepath F
.58165 .43177 -0.75 0 Mabsadd m
.58165 .43177 0 1 Mabsadd L
.58165 .43177 .75 0 Mabsadd L
.58165 .43177 0 -1 Mabsadd L
.58165 .43177 -0.75 0 Mabsadd L closepath F
.58532 .43177 -0.75 0 Mabsadd m
.58532 .43177 0 1 Mabsadd L
.58532 .43177 .75 0 Mabsadd L
.58532 .43177 0 -1 Mabsadd L
.58532 .43177 -0.75 0 Mabsadd L closepath F
.58899 .43177 -0.75 0 Mabsadd m
.58899 .43177 0 1 Mabsadd L
.58899 .43177 .75 0 Mabsadd L
.58899 .43177 0 -1 Mabsadd L
.58899 .43177 -0.75 0 Mabsadd L closepath F
.59266 .43177 -0.75 0 Mabsadd m
.59266 .43177 0 1 Mabsadd L
.59266 .43177 .75 0 Mabsadd L
.59266 .43177 0 -1 Mabsadd L
.59266 .43177 -0.75 0 Mabsadd L closepath F
.59633 .43177 -0.75 0 Mabsadd m
.59633 .43177 0 1 Mabsadd L
.59633 .43177 .75 0 Mabsadd L
.59633 .43177 0 -1 Mabsadd L
.59633 .43177 -0.75 0 Mabsadd L closepath F
.6 .43177 -0.75 0 Mabsadd m
.6 .43177 0 1 Mabsadd L
.6 .43177 .75 0 Mabsadd L
.6 .43177 0 -1 Mabsadd L
.6 .43177 -0.75 0 Mabsadd L closepath F
.60367 .43177 -0.75 0 Mabsadd m
.60367 .43177 0 1 Mabsadd L
.60367 .43177 .75 0 Mabsadd L
.60367 .43177 0 -1 Mabsadd L
.60367 .43177 -0.75 0 Mabsadd L closepath F
.60734 .43177 -0.75 0 Mabsadd m
.60734 .43177 0 1 Mabsadd L
.60734 .43177 .75 0 Mabsadd L
.60734 .43177 0 -1 Mabsadd L
.60734 .43177 -0.75 0 Mabsadd L closepath F
.61101 .43177 -0.75 0 Mabsadd m
.61101 .43177 0 1 Mabsadd L
.61101 .43177 .75 0 Mabsadd L
.61101 .43177 0 -1 Mabsadd L
.61101 .43177 -0.75 0 Mabsadd L closepath F
.61468 .43177 -0.75 0 Mabsadd m
.61468 .43177 0 1 Mabsadd L
.61468 .43177 .75 0 Mabsadd L
.61468 .43177 0 -1 Mabsadd L
.61468 .43177 -0.75 0 Mabsadd L closepath F
.61835 .43177 -0.75 0 Mabsadd m
.61835 .43177 0 1 Mabsadd L
.61835 .43177 .75 0 Mabsadd L
.61835 .43177 0 -1 Mabsadd L
.61835 .43177 -0.75 0 Mabsadd L closepath F
.62202 .43177 -0.75 0 Mabsadd m
.62202 .43177 0 1 Mabsadd L
.62202 .43177 .75 0 Mabsadd L
.62202 .43177 0 -1 Mabsadd L
.62202 .43177 -0.75 0 Mabsadd L closepath F
.62569 .43177 -0.75 0 Mabsadd m
.62569 .43177 0 1 Mabsadd L
.62569 .43177 .75 0 Mabsadd L
.62569 .43177 0 -1 Mabsadd L
.62569 .43177 -0.75 0 Mabsadd L closepath F
.62936 .43177 -0.75 0 Mabsadd m
.62936 .43177 0 1 Mabsadd L
.62936 .43177 .75 0 Mabsadd L
.62936 .43177 0 -1 Mabsadd L
.62936 .43177 -0.75 0 Mabsadd L closepath F
.63303 .43177 -0.75 0 Mabsadd m
.63303 .43177 0 1 Mabsadd L
.63303 .43177 .75 0 Mabsadd L
.63303 .43177 0 -1 Mabsadd L
.63303 .43177 -0.75 0 Mabsadd L closepath F
.6367 .43177 -0.75 0 Mabsadd m
.6367 .43177 0 1 Mabsadd L
.6367 .43177 .75 0 Mabsadd L
.6367 .43177 0 -1 Mabsadd L
.6367 .43177 -0.75 0 Mabsadd L closepath F
.64037 .43177 -0.75 0 Mabsadd m
.64037 .43177 0 1 Mabsadd L
.64037 .43177 .75 0 Mabsadd L
.64037 .43177 0 -1 Mabsadd L
.64037 .43177 -0.75 0 Mabsadd L closepath F
.64404 .43177 -0.75 0 Mabsadd m
.64404 .43177 0 1 Mabsadd L
.64404 .43177 .75 0 Mabsadd L
.64404 .43177 0 -1 Mabsadd L
.64404 .43177 -0.75 0 Mabsadd L closepath F
.64771 .43177 -0.75 0 Mabsadd m
.64771 .43177 0 1 Mabsadd L
.64771 .43177 .75 0 Mabsadd L
.64771 .43177 0 -1 Mabsadd L
.64771 .43177 -0.75 0 Mabsadd L closepath F
.65138 .43177 -0.75 0 Mabsadd m
.65138 .43177 0 1 Mabsadd L
.65138 .43177 .75 0 Mabsadd L
.65138 .43177 0 -1 Mabsadd L
.65138 .43177 -0.75 0 Mabsadd L closepath F
.65505 .43177 -0.75 0 Mabsadd m
.65505 .43177 0 1 Mabsadd L
.65505 .43177 .75 0 Mabsadd L
.65505 .43177 0 -1 Mabsadd L
.65505 .43177 -0.75 0 Mabsadd L closepath F
.65872 .43177 -0.75 0 Mabsadd m
.65872 .43177 0 1 Mabsadd L
.65872 .43177 .75 0 Mabsadd L
.65872 .43177 0 -1 Mabsadd L
.65872 .43177 -0.75 0 Mabsadd L closepath F
.66239 .43177 -0.75 0 Mabsadd m
.66239 .43177 0 1 Mabsadd L
.66239 .43177 .75 0 Mabsadd L
.66239 .43177 0 -1 Mabsadd L
.66239 .43177 -0.75 0 Mabsadd L closepath F
.66606 .43177 -0.75 0 Mabsadd m
.66606 .43177 0 1 Mabsadd L
.66606 .43177 .75 0 Mabsadd L
.66606 .43177 0 -1 Mabsadd L
.66606 .43177 -0.75 0 Mabsadd L closepath F
.66972 .43177 -0.75 0 Mabsadd m
.66972 .43177 0 1 Mabsadd L
.66972 .43177 .75 0 Mabsadd L
.66972 .43177 0 -1 Mabsadd L
.66972 .43177 -0.75 0 Mabsadd L closepath F
.67339 .43177 -0.75 0 Mabsadd m
.67339 .43177 0 1 Mabsadd L
.67339 .43177 .75 0 Mabsadd L
.67339 .43177 0 -1 Mabsadd L
.67339 .43177 -0.75 0 Mabsadd L closepath F
.67706 .43177 -0.75 0 Mabsadd m
.67706 .43177 0 1 Mabsadd L
.67706 .43177 .75 0 Mabsadd L
.67706 .43177 0 -1 Mabsadd L
.67706 .43177 -0.75 0 Mabsadd L closepath F
.68073 .43177 -0.75 0 Mabsadd m
.68073 .43177 0 1 Mabsadd L
.68073 .43177 .75 0 Mabsadd L
.68073 .43177 0 -1 Mabsadd L
.68073 .43177 -0.75 0 Mabsadd L closepath F
.6844 .43177 -0.75 0 Mabsadd m
.6844 .43177 0 1 Mabsadd L
.6844 .43177 .75 0 Mabsadd L
.6844 .43177 0 -1 Mabsadd L
.6844 .43177 -0.75 0 Mabsadd L closepath F
.68807 .43177 -0.75 0 Mabsadd m
.68807 .43177 0 1 Mabsadd L
.68807 .43177 .75 0 Mabsadd L
.68807 .43177 0 -1 Mabsadd L
.68807 .43177 -0.75 0 Mabsadd L closepath F
.69174 .43177 -0.75 0 Mabsadd m
.69174 .43177 0 1 Mabsadd L
.69174 .43177 .75 0 Mabsadd L
.69174 .43177 0 -1 Mabsadd L
.69174 .43177 -0.75 0 Mabsadd L closepath F
.69541 .43177 -0.75 0 Mabsadd m
.69541 .43177 0 1 Mabsadd L
.69541 .43177 .75 0 Mabsadd L
.69541 .43177 0 -1 Mabsadd L
.69541 .43177 -0.75 0 Mabsadd L closepath F
.69908 .43177 -0.75 0 Mabsadd m
.69908 .43177 0 1 Mabsadd L
.69908 .43177 .75 0 Mabsadd L
.69908 .43177 0 -1 Mabsadd L
.69908 .43177 -0.75 0 Mabsadd L closepath F
.70275 .43177 -0.75 0 Mabsadd m
.70275 .43177 0 1 Mabsadd L
.70275 .43177 .75 0 Mabsadd L
.70275 .43177 0 -1 Mabsadd L
.70275 .43177 -0.75 0 Mabsadd L closepath F
.70642 .43177 -0.75 0 Mabsadd m
.70642 .43177 0 1 Mabsadd L
.70642 .43177 .75 0 Mabsadd L
.70642 .43177 0 -1 Mabsadd L
.70642 .43177 -0.75 0 Mabsadd L closepath F
.71009 .43177 -0.75 0 Mabsadd m
.71009 .43177 0 1 Mabsadd L
.71009 .43177 .75 0 Mabsadd L
.71009 .43177 0 -1 Mabsadd L
.71009 .43177 -0.75 0 Mabsadd L closepath F
.71376 .43177 -0.75 0 Mabsadd m
.71376 .43177 0 1 Mabsadd L
.71376 .43177 .75 0 Mabsadd L
.71376 .43177 0 -1 Mabsadd L
.71376 .43177 -0.75 0 Mabsadd L closepath F
.71743 .43177 -0.75 0 Mabsadd m
.71743 .43177 0 1 Mabsadd L
.71743 .43177 .75 0 Mabsadd L
.71743 .43177 0 -1 Mabsadd L
.71743 .43177 -0.75 0 Mabsadd L closepath F
.7211 .43177 -0.75 0 Mabsadd m
.7211 .43177 0 1 Mabsadd L
.7211 .43177 .75 0 Mabsadd L
.7211 .43177 0 -1 Mabsadd L
.7211 .43177 -0.75 0 Mabsadd L closepath F
.72477 .43177 -0.75 0 Mabsadd m
.72477 .43177 0 1 Mabsadd L
.72477 .43177 .75 0 Mabsadd L
.72477 .43177 0 -1 Mabsadd L
.72477 .43177 -0.75 0 Mabsadd L closepath F
.72844 .43177 -0.75 0 Mabsadd m
.72844 .43177 0 1 Mabsadd L
.72844 .43177 .75 0 Mabsadd L
.72844 .43177 0 -1 Mabsadd L
.72844 .43177 -0.75 0 Mabsadd L closepath F
.73211 .43177 -0.75 0 Mabsadd m
.73211 .43177 0 1 Mabsadd L
.73211 .43177 .75 0 Mabsadd L
.73211 .43177 0 -1 Mabsadd L
.73211 .43177 -0.75 0 Mabsadd L closepath F
.73578 .43177 -0.75 0 Mabsadd m
.73578 .43177 0 1 Mabsadd L
.73578 .43177 .75 0 Mabsadd L
.73578 .43177 0 -1 Mabsadd L
.73578 .43177 -0.75 0 Mabsadd L closepath F
.73945 .43177 -0.75 0 Mabsadd m
.73945 .43177 0 1 Mabsadd L
.73945 .43177 .75 0 Mabsadd L
.73945 .43177 0 -1 Mabsadd L
.73945 .43177 -0.75 0 Mabsadd L closepath F
.74312 .43177 -0.75 0 Mabsadd m
.74312 .43177 0 1 Mabsadd L
.74312 .43177 .75 0 Mabsadd L
.74312 .43177 0 -1 Mabsadd L
.74312 .43177 -0.75 0 Mabsadd L closepath F
.74679 .43177 -0.75 0 Mabsadd m
.74679 .43177 0 1 Mabsadd L
.74679 .43177 .75 0 Mabsadd L
.74679 .43177 0 -1 Mabsadd L
.74679 .43177 -0.75 0 Mabsadd L closepath F
.75046 .43177 -0.75 0 Mabsadd m
.75046 .43177 0 1 Mabsadd L
.75046 .43177 .75 0 Mabsadd L
.75046 .43177 0 -1 Mabsadd L
.75046 .43177 -0.75 0 Mabsadd L closepath F
.75413 .43177 -0.75 0 Mabsadd m
.75413 .43177 0 1 Mabsadd L
.75413 .43177 .75 0 Mabsadd L
.75413 .43177 0 -1 Mabsadd L
.75413 .43177 -0.75 0 Mabsadd L closepath F
.7578 .43177 -0.75 0 Mabsadd m
.7578 .43177 0 1 Mabsadd L
.7578 .43177 .75 0 Mabsadd L
.7578 .43177 0 -1 Mabsadd L
.7578 .43177 -0.75 0 Mabsadd L closepath F
.76147 .43177 -0.75 0 Mabsadd m
.76147 .43177 0 1 Mabsadd L
.76147 .43177 .75 0 Mabsadd L
.76147 .43177 0 -1 Mabsadd L
.76147 .43177 -0.75 0 Mabsadd L closepath F
.76514 .43177 -0.75 0 Mabsadd m
.76514 .43177 0 1 Mabsadd L
.76514 .43177 .75 0 Mabsadd L
.76514 .43177 0 -1 Mabsadd L
.76514 .43177 -0.75 0 Mabsadd L closepath F
.76881 .43177 -0.75 0 Mabsadd m
.76881 .43177 0 1 Mabsadd L
.76881 .43177 .75 0 Mabsadd L
.76881 .43177 0 -1 Mabsadd L
.76881 .43177 -0.75 0 Mabsadd L closepath F
.77248 .43177 -0.75 0 Mabsadd m
.77248 .43177 0 1 Mabsadd L
.77248 .43177 .75 0 Mabsadd L
.77248 .43177 0 -1 Mabsadd L
.77248 .43177 -0.75 0 Mabsadd L closepath F
.77615 .43177 -0.75 0 Mabsadd m
.77615 .43177 0 1 Mabsadd L
.77615 .43177 .75 0 Mabsadd L
.77615 .43177 0 -1 Mabsadd L
.77615 .43177 -0.75 0 Mabsadd L closepath F
.77982 .43177 -0.75 0 Mabsadd m
.77982 .43177 0 1 Mabsadd L
.77982 .43177 .75 0 Mabsadd L
.77982 .43177 0 -1 Mabsadd L
.77982 .43177 -0.75 0 Mabsadd L closepath F
.78349 .43177 -0.75 0 Mabsadd m
.78349 .43177 0 1 Mabsadd L
.78349 .43177 .75 0 Mabsadd L
.78349 .43177 0 -1 Mabsadd L
.78349 .43177 -0.75 0 Mabsadd L closepath F
.78716 .43177 -0.75 0 Mabsadd m
.78716 .43177 0 1 Mabsadd L
.78716 .43177 .75 0 Mabsadd L
.78716 .43177 0 -1 Mabsadd L
.78716 .43177 -0.75 0 Mabsadd L closepath F
.79083 .43177 -0.75 0 Mabsadd m
.79083 .43177 0 1 Mabsadd L
.79083 .43177 .75 0 Mabsadd L
.79083 .43177 0 -1 Mabsadd L
.79083 .43177 -0.75 0 Mabsadd L closepath F
.7945 .43177 -0.75 0 Mabsadd m
.7945 .43177 0 1 Mabsadd L
.7945 .43177 .75 0 Mabsadd L
.7945 .43177 0 -1 Mabsadd L
.7945 .43177 -0.75 0 Mabsadd L closepath F
.79817 .43177 -0.75 0 Mabsadd m
.79817 .43177 0 1 Mabsadd L
.79817 .43177 .75 0 Mabsadd L
.79817 .43177 0 -1 Mabsadd L
.79817 .43177 -0.75 0 Mabsadd L closepath F
.80183 .43177 -0.75 0 Mabsadd m
.80183 .43177 0 1 Mabsadd L
.80183 .43177 .75 0 Mabsadd L
.80183 .43177 0 -1 Mabsadd L
.80183 .43177 -0.75 0 Mabsadd L closepath F
.8055 .43177 -0.75 0 Mabsadd m
.8055 .43177 0 1 Mabsadd L
.8055 .43177 .75 0 Mabsadd L
.8055 .43177 0 -1 Mabsadd L
.8055 .43177 -0.75 0 Mabsadd L closepath F
.80917 .43177 -0.75 0 Mabsadd m
.80917 .43177 0 1 Mabsadd L
.80917 .43177 .75 0 Mabsadd L
.80917 .43177 0 -1 Mabsadd L
.80917 .43177 -0.75 0 Mabsadd L closepath F
.81284 .43177 -0.75 0 Mabsadd m
.81284 .43177 0 1 Mabsadd L
.81284 .43177 .75 0 Mabsadd L
.81284 .43177 0 -1 Mabsadd L
.81284 .43177 -0.75 0 Mabsadd L closepath F
.81651 .43177 -0.75 0 Mabsadd m
.81651 .43177 0 1 Mabsadd L
.81651 .43177 .75 0 Mabsadd L
.81651 .43177 0 -1 Mabsadd L
.81651 .43177 -0.75 0 Mabsadd L closepath F
.82018 .43177 -0.75 0 Mabsadd m
.82018 .43177 0 1 Mabsadd L
.82018 .43177 .75 0 Mabsadd L
.82018 .43177 0 -1 Mabsadd L
.82018 .43177 -0.75 0 Mabsadd L closepath F
.82385 .43177 -0.75 0 Mabsadd m
.82385 .43177 0 1 Mabsadd L
.82385 .43177 .75 0 Mabsadd L
.82385 .43177 0 -1 Mabsadd L
.82385 .43177 -0.75 0 Mabsadd L closepath F
.82752 .43177 -0.75 0 Mabsadd m
.82752 .43177 0 1 Mabsadd L
.82752 .43177 .75 0 Mabsadd L
.82752 .43177 0 -1 Mabsadd L
.82752 .43177 -0.75 0 Mabsadd L closepath F
.83119 .43177 -0.75 0 Mabsadd m
.83119 .43177 0 1 Mabsadd L
.83119 .43177 .75 0 Mabsadd L
.83119 .43177 0 -1 Mabsadd L
.83119 .43177 -0.75 0 Mabsadd L closepath F
.83486 .43177 -0.75 0 Mabsadd m
.83486 .43177 0 1 Mabsadd L
.83486 .43177 .75 0 Mabsadd L
.83486 .43177 0 -1 Mabsadd L
.83486 .43177 -0.75 0 Mabsadd L closepath F
.83853 .43177 -0.75 0 Mabsadd m
.83853 .43177 0 1 Mabsadd L
.83853 .43177 .75 0 Mabsadd L
.83853 .43177 0 -1 Mabsadd L
.83853 .43177 -0.75 0 Mabsadd L closepath F
.8422 .43177 -0.75 0 Mabsadd m
.8422 .43177 0 1 Mabsadd L
.8422 .43177 .75 0 Mabsadd L
.8422 .43177 0 -1 Mabsadd L
.8422 .43177 -0.75 0 Mabsadd L closepath F
.84587 .43177 -0.75 0 Mabsadd m
.84587 .43177 0 1 Mabsadd L
.84587 .43177 .75 0 Mabsadd L
.84587 .43177 0 -1 Mabsadd L
.84587 .43177 -0.75 0 Mabsadd L closepath F
.84954 .43177 -0.75 0 Mabsadd m
.84954 .43177 0 1 Mabsadd L
.84954 .43177 .75 0 Mabsadd L
.84954 .43177 0 -1 Mabsadd L
.84954 .43177 -0.75 0 Mabsadd L closepath F
.85321 .43177 -0.75 0 Mabsadd m
.85321 .43177 0 1 Mabsadd L
.85321 .43177 .75 0 Mabsadd L
.85321 .43177 0 -1 Mabsadd L
.85321 .43177 -0.75 0 Mabsadd L closepath F
.85688 .43177 -0.75 0 Mabsadd m
.85688 .43177 0 1 Mabsadd L
.85688 .43177 .75 0 Mabsadd L
.85688 .43177 0 -1 Mabsadd L
.85688 .43177 -0.75 0 Mabsadd L closepath F
.86055 .43177 -0.75 0 Mabsadd m
.86055 .43177 0 1 Mabsadd L
.86055 .43177 .75 0 Mabsadd L
.86055 .43177 0 -1 Mabsadd L
.86055 .43177 -0.75 0 Mabsadd L closepath F
.86422 .43177 -0.75 0 Mabsadd m
.86422 .43177 0 1 Mabsadd L
.86422 .43177 .75 0 Mabsadd L
.86422 .43177 0 -1 Mabsadd L
.86422 .43177 -0.75 0 Mabsadd L closepath F
.86789 .43177 -0.75 0 Mabsadd m
.86789 .43177 0 1 Mabsadd L
.86789 .43177 .75 0 Mabsadd L
.86789 .43177 0 -1 Mabsadd L
.86789 .43177 -0.75 0 Mabsadd L closepath F
.87156 .43177 -0.75 0 Mabsadd m
.87156 .43177 0 1 Mabsadd L
.87156 .43177 .75 0 Mabsadd L
.87156 .43177 0 -1 Mabsadd L
.87156 .43177 -0.75 0 Mabsadd L closepath F
.87523 .43177 -0.75 0 Mabsadd m
.87523 .43177 0 1 Mabsadd L
.87523 .43177 .75 0 Mabsadd L
.87523 .43177 0 -1 Mabsadd L
.87523 .43177 -0.75 0 Mabsadd L closepath F
.8789 .43177 -0.75 0 Mabsadd m
.8789 .43177 0 1 Mabsadd L
.8789 .43177 .75 0 Mabsadd L
.8789 .43177 0 -1 Mabsadd L
.8789 .43177 -0.75 0 Mabsadd L closepath F
.88257 .43177 -0.75 0 Mabsadd m
.88257 .43177 0 1 Mabsadd L
.88257 .43177 .75 0 Mabsadd L
.88257 .43177 0 -1 Mabsadd L
.88257 .43177 -0.75 0 Mabsadd L closepath F
.88624 .43177 -0.75 0 Mabsadd m
.88624 .43177 0 1 Mabsadd L
.88624 .43177 .75 0 Mabsadd L
.88624 .43177 0 -1 Mabsadd L
.88624 .43177 -0.75 0 Mabsadd L closepath F
.88991 .43177 -0.75 0 Mabsadd m
.88991 .43177 0 1 Mabsadd L
.88991 .43177 .75 0 Mabsadd L
.88991 .43177 0 -1 Mabsadd L
.88991 .43177 -0.75 0 Mabsadd L closepath F
.89358 .43177 -0.75 0 Mabsadd m
.89358 .43177 0 1 Mabsadd L
.89358 .43177 .75 0 Mabsadd L
.89358 .43177 0 -1 Mabsadd L
.89358 .43177 -0.75 0 Mabsadd L closepath F
.89725 .43177 -0.75 0 Mabsadd m
.89725 .43177 0 1 Mabsadd L
.89725 .43177 .75 0 Mabsadd L
.89725 .43177 0 -1 Mabsadd L
.89725 .43177 -0.75 0 Mabsadd L closepath F
.90092 .43177 -0.75 0 Mabsadd m
.90092 .43177 0 1 Mabsadd L
.90092 .43177 .75 0 Mabsadd L
.90092 .43177 0 -1 Mabsadd L
.90092 .43177 -0.75 0 Mabsadd L closepath F
.90459 .43177 -0.75 0 Mabsadd m
.90459 .43177 0 1 Mabsadd L
.90459 .43177 .75 0 Mabsadd L
.90459 .43177 0 -1 Mabsadd L
.90459 .43177 -0.75 0 Mabsadd L closepath F
.90826 .43177 -0.75 0 Mabsadd m
.90826 .43177 0 1 Mabsadd L
.90826 .43177 .75 0 Mabsadd L
.90826 .43177 0 -1 Mabsadd L
.90826 .43177 -0.75 0 Mabsadd L closepath F
.91193 .43177 -0.75 0 Mabsadd m
.91193 .43177 0 1 Mabsadd L
.91193 .43177 .75 0 Mabsadd L
.91193 .43177 0 -1 Mabsadd L
.91193 .43177 -0.75 0 Mabsadd L closepath F
.9156 .43177 -0.75 0 Mabsadd m
.9156 .43177 0 1 Mabsadd L
.9156 .43177 .75 0 Mabsadd L
.9156 .43177 0 -1 Mabsadd L
.9156 .43177 -0.75 0 Mabsadd L closepath F
.91927 .43177 -0.75 0 Mabsadd m
.91927 .43177 0 1 Mabsadd L
.91927 .43177 .75 0 Mabsadd L
.91927 .43177 0 -1 Mabsadd L
.91927 .43177 -0.75 0 Mabsadd L closepath F
.92294 .43177 -0.75 0 Mabsadd m
.92294 .43177 0 1 Mabsadd L
.92294 .43177 .75 0 Mabsadd L
.92294 .43177 0 -1 Mabsadd L
.92294 .43177 -0.75 0 Mabsadd L closepath F
.92661 .43177 -0.75 0 Mabsadd m
.92661 .43177 0 1 Mabsadd L
.92661 .43177 .75 0 Mabsadd L
.92661 .43177 0 -1 Mabsadd L
.92661 .43177 -0.75 0 Mabsadd L closepath F
.93028 .43177 -0.75 0 Mabsadd m
.93028 .43177 0 1 Mabsadd L
.93028 .43177 .75 0 Mabsadd L
.93028 .43177 0 -1 Mabsadd L
.93028 .43177 -0.75 0 Mabsadd L closepath F
.93394 .43177 -0.75 0 Mabsadd m
.93394 .43177 0 1 Mabsadd L
.93394 .43177 .75 0 Mabsadd L
.93394 .43177 0 -1 Mabsadd L
.93394 .43177 -0.75 0 Mabsadd L closepath F
.93761 .43177 -0.75 0 Mabsadd m
.93761 .43177 0 1 Mabsadd L
.93761 .43177 .75 0 Mabsadd L
.93761 .43177 0 -1 Mabsadd L
.93761 .43177 -0.75 0 Mabsadd L closepath F
.94128 .43177 -0.75 0 Mabsadd m
.94128 .43177 0 1 Mabsadd L
.94128 .43177 .75 0 Mabsadd L
.94128 .43177 0 -1 Mabsadd L
.94128 .43177 -0.75 0 Mabsadd L closepath F
.94495 .43177 -0.75 0 Mabsadd m
.94495 .43177 0 1 Mabsadd L
.94495 .43177 .75 0 Mabsadd L
.94495 .43177 0 -1 Mabsadd L
.94495 .43177 -0.75 0 Mabsadd L closepath F
.94862 .43177 -0.75 0 Mabsadd m
.94862 .43177 0 1 Mabsadd L
.94862 .43177 .75 0 Mabsadd L
.94862 .43177 0 -1 Mabsadd L
.94862 .43177 -0.75 0 Mabsadd L closepath F
.95229 .43177 -0.75 0 Mabsadd m
.95229 .43177 0 1 Mabsadd L
.95229 .43177 .75 0 Mabsadd L
.95229 .43177 0 -1 Mabsadd L
.95229 .43177 -0.75 0 Mabsadd L closepath F
.95596 .43177 -0.75 0 Mabsadd m
.95596 .43177 0 1 Mabsadd L
.95596 .43177 .75 0 Mabsadd L
.95596 .43177 0 -1 Mabsadd L
.95596 .43177 -0.75 0 Mabsadd L closepath F
.95963 .43177 -0.75 0 Mabsadd m
.95963 .43177 0 1 Mabsadd L
.95963 .43177 .75 0 Mabsadd L
.95963 .43177 0 -1 Mabsadd L
.95963 .43177 -0.75 0 Mabsadd L closepath F
.9633 .43177 -0.75 0 Mabsadd m
.9633 .43177 0 1 Mabsadd L
.9633 .43177 .75 0 Mabsadd L
.9633 .43177 0 -1 Mabsadd L
.9633 .43177 -0.75 0 Mabsadd L closepath F
.96697 .43177 -0.75 0 Mabsadd m
.96697 .43177 0 1 Mabsadd L
.96697 .43177 .75 0 Mabsadd L
.96697 .43177 0 -1 Mabsadd L
.96697 .43177 -0.75 0 Mabsadd L closepath F
.97064 .43177 -0.75 0 Mabsadd m
.97064 .43177 0 1 Mabsadd L
.97064 .43177 .75 0 Mabsadd L
.97064 .43177 0 -1 Mabsadd L
.97064 .43177 -0.75 0 Mabsadd L closepath F
.97431 .43177 -0.75 0 Mabsadd m
.97431 .43177 0 1 Mabsadd L
.97431 .43177 .75 0 Mabsadd L
.97431 .43177 0 -1 Mabsadd L
.97431 .43177 -0.75 0 Mabsadd L closepath F
.97798 .43177 -0.75 0 Mabsadd m
.97798 .43177 0 1 Mabsadd L
.97798 .43177 .75 0 Mabsadd L
.97798 .43177 0 -1 Mabsadd L
.97798 .43177 -0.75 0 Mabsadd L closepath F
.98165 .43177 -0.75 0 Mabsadd m
.98165 .43177 0 1 Mabsadd L
.98165 .43177 .75 0 Mabsadd L
.98165 .43177 0 -1 Mabsadd L
.98165 .43177 -0.75 0 Mabsadd L closepath F
.98532 .43177 -0.75 0 Mabsadd m
.98532 .43177 0 1 Mabsadd L
.98532 .43177 .75 0 Mabsadd L
.98532 .43177 0 -1 Mabsadd L
.98532 .43177 -0.75 0 Mabsadd L closepath F
.98899 .43177 -0.75 0 Mabsadd m
.98899 .43177 0 1 Mabsadd L
.98899 .43177 .75 0 Mabsadd L
.98899 .43177 0 -1 Mabsadd L
.98899 .43177 -0.75 0 Mabsadd L closepath F
.99266 .43177 -0.75 0 Mabsadd m
.99266 .43177 0 1 Mabsadd L
.99266 .43177 .75 0 Mabsadd L
.99266 .43177 0 -1 Mabsadd L
.99266 .43177 -0.75 0 Mabsadd L closepath F
.99633 .43177 -0.75 0 Mabsadd m
.99633 .43177 0 1 Mabsadd L
.99633 .43177 .75 0 Mabsadd L
.99633 .43177 0 -1 Mabsadd L
.99633 .43177 -0.75 0 Mabsadd L closepath F
1 .43177 -0.75 0 Mabsadd m
1 .43177 0 1 Mabsadd L
1 .43177 .75 0 Mabsadd L
1 .43177 0 -1 Mabsadd L
1 .43177 -0.75 0 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-89.141, -0.263095, 2.14641, \
0.007392}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure - Saving to file", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"numberOfExtensions", "=", "  ", 
    RowBox[{"Length", "[", "extensions", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", " ", 
    RowBox[{"j", "\[LessEqual]", "numberOfExtensions"}], ",", 
    RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"\"\<fig13-500\>\"", ",", 
         RowBox[{"extensions", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", "finalFigure", ",", 
       RowBox[{"ImageResolution", "\[Rule]", " ", "figureResolution"}]}], 
      "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], "Input"]
}, Closed]]
},
CellGrouping->Manual,
WindowSize->{1432, 791},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"DemoText.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 149, 4, 56, "Title"],
Cell[720, 27, 65, 0, 37, "Subtitle"],
Cell[788, 29, 298, 6, 73, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1111, 39, 57, 0, 52, "Section"],
Cell[1171, 41, 779, 17, 310, "Subsubtitle"]
}, Closed]],
Cell[CellGroupData[{
Cell[1987, 63, 42, 0, 32, "Section"],
Cell[2032, 65, 224, 6, 60, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[2293, 76, 29, 0, 32, "Section"],
Cell[2325, 78, 2424, 64, 620, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[4786, 147, 53, 0, 32, "Section"],
Cell[4842, 149, 6046, 151, 680, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[10925, 305, 47, 0, 32, "Section"],
Cell[10975, 307, 1780, 53, 260, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[12792, 365, 42, 0, 32, "Section"],
Cell[CellGroupData[{
Cell[12859, 369, 14076, 342, 1580, "Input"],
Cell[26938, 713, 12362, 628, 194, 9912, 584, "GraphicsData", "PostScript", \
"Graphics"],
Cell[39303, 1343, 274, 6, 25, "Print"],
Cell[39580, 1351, 177, 4, 25, "Print"],
Cell[39760, 1357, 12306, 627, 194, 9917, 584, "GraphicsData", "PostScript", \
"Graphics"],
Cell[52069, 1986, 274, 6, 25, "Print"],
Cell[52346, 1994, 179, 4, 25, "Print"],
Cell[52528, 2000, 12055, 622, 194, 9923, 584, "GraphicsData", "PostScript", \
"Graphics"],
Cell[64586, 2624, 274, 6, 25, "Print"],
Cell[64863, 2632, 181, 4, 25, "Print"],
Cell[65047, 2638, 11998, 621, 194, 9935, 584, "GraphicsData", "PostScript", \
"Graphics"],
Cell[77048, 3261, 274, 6, 25, "Print"],
Cell[77325, 3269, 170, 4, 25, "Print"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[77544, 3279, 36, 0, 32, "Section"],
Cell[CellGroupData[{
Cell[77605, 3283, 2404, 61, 100, "Input"],
Cell[80012, 3346, 312774, 8852, 70, 309594, 8796, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[392835, 12204, 42, 0, 32, "Section"],
Cell[392880, 12206, 785, 20, 120, "Input"]
}, Closed]]
}
]
*)

(* End of internal cache information *)

